; ------------------------------------------------------------------------------------------------------------- ;
; Championship Lode Runner - IT.PRG
; ------------------------------------------------------------------------------------------------------------- ;
; Memory Map
; ------------------------------------------------------------------------------------------------------------- ;
; $0000 - $00ff:  Zero Page Values
; $0200 - $02ff:  <not used>
; $0300 - $03ff:  <not used>
; $0400 - $04f7:  Multi Color Screen
; $04f8 - $04ff:  Sprite Pointers
; $0800 - $09c3:  expanded level data row pointer
; $0a00 - $0bc3:  expanded level data row pointer - play level control
; $0c00 - $0cff:  Sprite Store 01
; $0d00 - $0dff:  Sprite Store 02
; $0e00 - $0ec7:  Tab Offsets HiRes Lo
; $0f00 - $0fc7:  Tab Offsets HiRes Hi
; $1000 - $10ff:  Level Data Save/Load
; $1100 - $11ff:  High Score Save/Load
; $1200 - $12ff:  Tables for Dynamic Value
; $1300 - $133b:  In Game Variables
; $1400 - $1fff:  Data Start Graphic
; $2000 - $3fff:  HighRes Display Screen
; $4000 - $5fff:  HighRes Prepare Screen
; $c000 - $c0ff:  Tunes Play Time
; $c100 - $c1ff:  Tunes Data Ptr Voice 2
; $c200 - $c2ff:  Tunes Data Ptr Voice 3
; $c300 - $c3ff:  Tunes Sustain/Release/Volume (not used)
; $c800 - $c8ff:  High Score Work Old
; $c900 - $c9ff:  High Score Work New
; ------------------------------------------------------------------------------------------------------------- ;
                  * equ $6000                     ; Start address
; ------------------------------------------------------------------------------------------------------------- ;
; compiler settings                                                                                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  incdir   ..\..\inc              ; C64 System Includes

C64CIA1           include  cia1.asm               ; Complex Interface Adapter (CIA) #1 Registers  $DC00-$DC0F
C64CIA2           include  cia2.asm               ; Complex Interface Adapter (CIA) #2 Registers  $DD00-$DD0F
C64SID            include  sid.asm                ; Sound Interface Device (SID) Registers        $D400-$D41C
C64VicII          include  vic.asm                ; Video Interface Chip (VIC-II) Registers       $D000-$D02E
C64Kernel         include  kernel.asm             ; Kernel Vectors
C64Colors         include  color.asm              ; Colour RAM Address / Colours
;
InGameVars        include  inc\LR_Vars.asm        ; Game Variables
InZeroPageVars    include  inc\LR_Zpg.asm         ; Zero Page Variables
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
Start             lda #$00                        ;
                  sta CR_Cheat                    ;
                  sta LR_Volume                   ; 
                  
                  lda #LR_Joystick                ;
                  sta LR_ControllerTyp            ; ca=joystick  cb=keyboard
                  
                  jsr GameInitOnce                ;
                  
                  lda #LR_DiskRead                ; 
                  jsr GetPutHiScores              ; ($1100-$11ff) ac: $01=load $02=store 81= 82=
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ColdStart         lda #LR_VolumeMax               ;
                  sta LR_Volume                   ; 
                  sta LR_FallsDown                ; $00=fall $20=no fall $ff=init
                  sta LR_DeathTune                ; 
                  sta LR_ShootMode                ; 
                  
                  lda #$00                        ;
                  sta CR_StatusColor              ; 
                  sta LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  sta LR_PtrTuneToPlay            ; 
                  sta LR_Shoots                   ; $00=no  $01=shoot right  $ff=shoot left
                  sta LR_DeathTune                ; 
                  sta LR_KeyNew                   ; 
                  sta LR_KeyOld                   ; 
                  sta LR_SprtPosCtrl              ;
                  
                  lda #>LR_LvlDataSavLod          ; $10 - Target: $1000-$10ff
                  sta Mod_GetDiskByte             ; set disk get to $1000 - DiskLevel
                  sta Mod_PutDiskByte             ; set disk put to $1000 - DiskLevel
                  
                  sta LR_Random                   ; last RND beam pos
                  
                  lda $c5                         ; C64: key value
                  sta LR_KeyOld                   ; 
                  lda #$40                        ; reset: $40=no key pressed
                  sta $c5                         ;
                  
                  lda #LR_SpeedNormal             ; wait 5 interupts before next move  (normal speed)
                  sta LR_GameSpeed                ; 
                  
                  lda #LR_GameStart               ;
                  sta LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  jmp StartGraficOut              ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
GameStart         lda #$00                        ; 
                  sta LR_ScoreLo                  ; scores
                  sta LR_ScoreMidLo               ; 
                  sta LR_ScoreMidHi               ; 
                  sta LR_ScoreHi                  ; 
                  sta LR_CntSpeedLaps             ; 
                  sta CR_NoFunction               ;
                  sta LR_EnmyBirthCol             ;
                  sta $58                         ; reset duration demo move for possible next demo rounds
                  
                  lda #<TabDemoLvlMoves           ; .hbu000.
                  sta $55                         ;
                  lda #>TabDemoLvlMoves           ;
                  sta $56                         ;
                  
                  sta LR_LvlReload                ; reload if <> LR_LevelNoDisk
                  
                  lda #LR_NumLivesInit            ;
                  sta LR_NumLives                 ; 
                  
                  lda #>LR_ScrnHiReDisp           ; $20
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  jsr MelodyInit                  ; init victory tune
                  jsr ClearHiresBoth              ; both gfx screens  +  status lines
                  jsr SetNewColors                ; SetNewColors (new colors any 10th level)

                  lda CR_LevelColor               ; lrNewLevelColor
                  jsr ColourLevel                 ; 
                  jsr SetUniquePlayId             ; SetUniquePlayId
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
LevelStart        lda #$00                        ; 
                  sta CR_StatusColor              ; lrNewStatusColor
                  
                  ldx #LR_LevelLoad               ; force new copy from disk
                  jsr InitLevel                   ; InitLevel
                  
                  sta LR_PtrTuneToPlay            ; lrScoreToPlay
                  sta LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  
                  ldy LR_EnmyNo                   ; 
                  lda TabEnmyEnab,y               ; 
                  sta SPENA                       ; VIC 2 - $D015 equ Sprite Enable
                  
                  lda #$00                        ;
                  sta LR_JoyUpDo                  ; 
                  sta LR_JoyLeRi                  ; 
                  
                  lda LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  lsr a                           ;
                  beq MainLoopInit                ; 
                  
.SetLrBlack       lda SPENA                       ; VIC 2 - $D015 equ Sprite Enable  (flicker sprite 0 meanwhile)
                  and #$fe                        ;    switch off lode runner sprite
                  sta SPENA                       ; VIC 2 - $D015 equ Sprite Enable
                  
                  ldy #$90                        ; init wait
                  ldx #$00                        ;
.WaitLrBlack      dex                             ; 
                  jsr ChkUserAction               ; check user input - carry_set=yes carry_clear=no
                  bcs .StartLr                    ; 
                  bne .WaitLrBlack                ; 
                  dey                             ;
                  bne .WaitLrBlack                ; 
                  
.SetLrWhite       lda SPENA                       ; VIC 2 - $D015 equ Sprite Enable
                  ora #$01                        ;   switch on lode runner sprite
                  sta SPENA                       ; VIC 2 - $D015 equ Sprite Enable
                  
                  ldy #$90                        ; init wait
                  ldx #$00                        ;
.WaitLrWhite      dex                             ; 
                  jsr ChkUserAction               ; check user input - carry_set=yes carry_clear=no
                  bcs .StartLr                    ; 
                  bne .WaitLrWhite                ; 
                  
                  dey                             ;
                  bne .WaitLrWhite                ; 
                  jmp .SetLrBlack                 ; 
                  
.StartLr          lda SPENA                       ; VIC 2 - $D015 equ Sprite Enable
                  ora #$01                        ;   switch on lode runner sprite
                  sta SPENA                       ; VIC 2 - $D015 equ Sprite Enable
                  lda LR_KeyNew                   ; 
.Chr_S            cmp #$8d                        ; ctrl+s
                  bne MainLoopInit                ; 
                  
.GoSaveGame       jsr SaveGame                    ; save a game only before player starts the level
                  
                  ldy LR_EnmyNo                   ; 
                  lda TabEnmyEnab,y               ; 
                  sta SPENA                       ; VIC 2 - $D015 equ Sprite Enable
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MainLoopInit      ldx #LR_ShootsNo                ; 
                  stx LR_Shoots                   ; $00=no  $01=shoot right  $ff=shoot left
                  
                  lda LR_CntSpeedLaps             ; 
                  clc                             ;
                  adc LR_EnmyNo                   ; 
                  tay                             ;
                  
                  ldx TabOffEnmyCycles,y          ; offsets enemy move cycles tab
                  lda TabEnmyCycles1,x            ; enemy move cycles tab
                  sta $32                         ;
                  lda TabEnmyCycles2,x            ; enemy move cycles tab + 1
                  sta $33                         ;
                  lda TabEnmyCycles3,x            ; enemy move cycles tab + 2
                  sta $34                         ;
                  
                  ldy LR_CntSpeedLaps             ; lrGameSpeed
                  lda TabEnmyHoleTime,y           ; time in hole tab
                  sta LR_EnmyHoleTime             ; enemy time in hole
; ------------------------------------------------------------------------------------------------------------- ;
; The Game Main Loop
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MainLoop          jsr MoveLodeRunner              ; 
                  lda LR_Alive                    ; 
.ChkLRAccident    beq .ChkLRTrapped               ; lr accident
                  
.ChkGold4Tune     lda LR_Gold2Get                 ; 
                  bne .ChkLrPos                   ; some gold left
                  
.Victory          jsr VictoryTuneCopy             ; prepare melody
                  jsr ShowExitLadders             ; display exit ladders
                  jsr VictoryMsg                  ; show level victory msg
                  
.ChkLrPos         lda $04                         ; actual row lode runner
                  bne .GoCloseHoles               ; lr not on top of the screen
                  
                  lda $06                         ; lr pos on image up/down
                  cmp #$02                        ; $02=center of screen image
                  bne .GoCloseHoles               ; lr not centerd
                  
.ChkGold4Finish   lda LR_Gold2Get                 ; lr fully on top of the screen and
                  beq LevelComplete               ; got all gold
                  cmp #$ff                        ;
                  beq LevelComplete               ; got all gold plus one
                  
.GoCloseHoles     jsr CloseHoles                  ; 

                  lda LR_Alive                    ; 
.ChkLRTrapped     beq LrDeath                     ; lr trapped

.GoMoveEnemies    jsr MoveEnemies                 ; 

                  lda LR_Alive                    ; 
.ChkLRCaught      beq LrDeath                     ; lr caught
                  
.DelayGame        lda LR_CountIRQs                ; wait counter - inc during each IRQ
                  cmp LR_GameSpeed                ; 
                  bcc .DelayGame                  ; lower
                  
.SetWait          lda #LR_IRQsDflt                ; reinit wait cycle time
                  sta LR_CountIRQs                ; wait counter - inc during each IRQ
                  
MainLoopX         jmp MainLoop                    ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
LevelComplete     inc LR_LevelNoGame              ; 001-050
                  inc LR_LevelNoDisk              ; 000-049

.FinishTunes      lda LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  cmp LR_PtrTuneToPlay            ; lrScoreToPlay
                  bne .FinishTunes                ; wait until all melodies have finished
                  
                  jsr SetNextMelody               ; 
                  
                  inc LR_NumLives                 ; get one extra chance for each completed level
                  bne .ScoreTuneI                 ; 
                  dec LR_NumLives                 ; max 255
                  
.ScoreTuneI       lda #CR_SoreValSub              ; 
                  sta $2f                         ;
                  
                  sei                             ; no interrupts
                  
.ScoreTuneNext    lda #LR_SoreValStart            ; 
                  sec                             ;
                  sbc $2f                         ;
                  sta FREHI1                      ; SID - $D401 equ Oscillator 1 Frequency Control (High Byte)
                  ldy #$2c                        ; 
.ScoreTuneSetX    ldx #$00                        ; 
.ScoreTuneWaitX   dex                             ; 
                  bne .ScoreTuneWaitX             ; 
                  
                  dey                             ;
                  bne .ScoreTuneSetX              ; 
                  
                  sty FREHI1                      ; SID - $D401 equ Oscillator 1 Frequency Control (High Byte)
                  tya                             ; 00
                  iny                             ; 01
                  jsr Score2BaseLine              ; AddDisplayScore (ac=1s yr=100s)
                  
                  dec $2f                         ;
                  bpl .ScoreTuneNext              ; 20 loops for 2000 points
                  
                  cli                             ; reallow interrupts
                  
                  lda CR_DiskStatus               ; 
.ChkDiskStatus    bmi GoLevelStart                ; bad
                  
                  lda LR_LevelNoGame              ; 001-050
                  cmp #CR_LevelNoMax              ; 051
.ChkMaxLevel      bcc GoLevelStart                ; start a new level

.GoGameOver       jmp GameOver                    ; finish after last level

GoLevelStart      jmp LevelStart                  ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
LrDeath           dec LR_NumLives                 ; 
                  
                  lda LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  lsr a                           ;
.ChkDemo          bne LrDeathTune                 ; was game
                  
LrDeathX          jmp SetVolume                   ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
LrDeathTune       lda #LR_DeathTuneVal            ; 
                  sta LR_DeathTune                ; 

.WaitGameTune     lda LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  cmp LR_PtrTuneToPlay            ; 
                  bne .WaitGameTune               ; wait for all in game tunes to be finished
                  
                  lda #LR_ShootsNo                ; 
                  sta LR_Shoots                   ; $00=no  $01=shoot right  $ff=shoot left
                  
                  lda #LR_FallsNo                 ;
                  sta LR_FallsDown                ; $00=fall $20=no fall $ff=init
                  jsr Lives2BaseLine              ; StatusOutLives
                  
.WaitDeathTune    lda LR_DeathTune                ; 
                  bne .WaitDeathTune              ; wait for death tune to be finished
                  
                  lda LR_NumLives                 ; 
.ChkGameOver      bne GoLevelStart                ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
GameOver          jsr ChkNewHighScore             ; 
                  jsr CheckNewChamp               ; 
                  bcs Wait4User                   ; new champ
                  
                  jsr FlipGmeOverSign             ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
Wait4User         ldx #$ff                        ; 
                  ldy #$ff                        ;
                  bcs .SetWaitLoops               ; user break during flip
                  
                  lda #$00                        ;
                  sta LR_KeyNew                   ; 
                  
.SetWaitLoops     lda #$03                        ; 
                  sta $50                         ; screen row ($00 - $0f)
                  
GetUserKey        lda CIAPRA                      ; CIA 1 - $DC00 equ Data Port A - cia#1 port a (joyport2):  bit4=fire  bit3=right  bit2=left  bit1=down  bit0=up
                  and #$10                        ; isolate fire button
                  beq GameRestart                 ; 
                  
.GetKey           lda LR_KeyNew                   ; lrNewKey
.Chk_L            cmp #$aa                        ; CTRL+l
                  bne .Chk_Enter                  ; 
                  
                  jsr LoadGame                    ; 
                  
.Chk_Enter        cmp #$01                        ; ENTER
                  beq GoScores                    ; 
                  
.Chk_C            cmp #$94                        ; CTRL+c
                  beq GoClrHighScores             ; 
                  
.Chk_Space        cmp #$3c                        ; SPACE
                  beq GameRestart                 ; 
                  
.Wait             dex                             ; wait x
                  bne GetUserKey                  ; 
                  dey                             ; wait y
                  bne GetUserKey                  ; 
                  dec $50                         ; wait a (screen row ($00 - $0f))
                  bne GetUserKey                  ; 
                  
                  lda LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  bne ChkDemo                     ; 
                  
                  ldx #LR_GameDemo                ;
                  stx LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  
                  stx LR_LevelNoGame              ; 001-050
                  stx $59                         ; save LR_LevelNoGame
                  stx LR_Cheated                  ;
                  
                  ldx LR_Volume                   ; lrVolume
                  stx Mod__Volume                 ;
                  
                  lda #$00                        ;
                  sta LR_Volume                   ; lrVolume
                  sta LR_LevelNoDisk              ; 000-049
                  
Wait4UserX        jmp GameStart                   ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
SetVolume         lda #$00                        ; 
Mod__Volume       equ *-1
                  sta LR_Volume                   ; lrVolume
                  jmp Wait4User                   ; WaitSomeTime
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ChkDemo           cmp #LR_GameDemo                ; 
                  bne ShowStartGfx                ; 
                  
GoScores          jsr ShowHighScores              ; 

                  lda #LR_GameGame                ;
                  sta LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  
                  clc                             ;
                  jmp Wait4User                   ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ShowStartGfx      lda #$00                        ; 
                  sta LR_LevelNoDisk              ; 000-049
                  sta LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  jmp StartGraficOut              ; StartGrafic
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
GoClrHighScores   jsr ClearHighScores             ; 
                  jmp GoScores                    ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
GameRestart       ldx #$00                        ; 
                  stx LR_LevelNoDisk              ; 000-049
                  
                  inx                             ;
                  stx LR_LevelNoGame              ; 001-050
                  stx LR_Cheated                  ; flag:
                  
                  lda #LR_GameGame                ;
                  sta LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  
.GetVolume        lda #LR_VolumeMax               ;
                  sta LR_Volume                   ; 
                  jmp GameStart                   ; 
; ------------------------------------------------------------------------------------------------------------- ;
TabOffEnmyCycles  dc.b $00
                  dc.b $03
                  dc.b $06
                  dc.b $09
                  dc.b $0c
                  dc.b $0f
                  dc.b $12
                  dc.b $15
                  dc.b $18
                  dc.b $1b
                  dc.b $1e
; ------------------------------------------------------------------------------------------------------------- ;
TabEnmyHoleTime   dc.b $26
                  dc.b $26
                  dc.b $2e
                  dc.b $44
                  dc.b $47
                  dc.b $49
                  dc.b $4a
                  dc.b $4b
                  dc.b $4c
                  dc.b $4d
                  dc.b $4e
                  dc.b $4f
                  dc.b $50
                  dc.b $51
                  dc.b $52
                  dc.b $53
                  dc.b $54
                  dc.b $55
                  dc.b $56
                  dc.b $57
                  dc.b $58
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
StartGraficOut    jsr ClearHiresDisp              ; ClearDisplay20

                  lda #HR_BlackBlack              ;
                  jsr ColourLevel                 ; 
                  
                  lda SCROLY                      ; VIC 2 - $D011 equ VIC Control Register 1
                  ora #$20                        ; set bitmap mode
                  sta SCROLY                      ; VIC 2 - $D011 equ VIC Control Register 1
                  
                  lda VMCSB                       ; VIC 2 - $D018 equ Chip Memory Control
                  and #$f0                        ; chr generator
                  ora #$08                        ;   to video base + 2000-3fff
                  sta VMCSB                       ; VIC 2 - $D018 equ Chip Memory Control
                  
                  lda #$00                        ;
                  sta LR_Counter                  ;
.GetNextGfxColor  ldx LR_Counter                  ; 
                  inc LR_Counter                  ;
                  lda TabColorOutLo,x             ; target lo
                  sta ..ModColorOutL              ; 
                  lda TabColorOutHi,x             ; target high
                  sta ..ModColorOutH              ; 
                  lda TabColorAmount,x            ; amount
                  tay                             ;
                  lda TabColorValue,x             ; color
                  beq StartGraphicPic             ; 
                  
.SetColor         sta LR_ScrnMultColor,y          ; color target
..ModColorOutH    equ *-1
..ModColorOutL    equ *-2
                  dey                             ;
                  cpy #$ff                        ;
                  bne .SetColor                   ; 
                  
                  jmp .GetNextGfxColor            ; 
; ------------------------------------------------------------------------------------------------------------- ;                  
TabColorOutLo     dc.b $05                        ; color target addresse low
                  dc.b $05
                  dc.b $21
                  dc.b $21
                  dc.b $ba
                  dc.b $27
                  dc.b $7c
TabColorOutHi     dc.b $04                        ; color target addresse high
                  dc.b $05
                  dc.b $05
                  dc.b $06
                  dc.b $06
                  dc.b $07
                  dc.b $07
TabColorAmount    dc.b $ff                        ; color amount
                  dc.b $09
                  dc.b $ff
                  dc.b $82
                  dc.b $68
                  dc.b $41
                  dc.b $37
TabColorValue     dc.b $30 ; Cyan                 ; color
                  dc.b $30 ; Cyan
                  dc.b $10 ; White
                  dc.b $10 ; White
                  dc.b $70 ; Yellow
                  dc.b $30 ; Cyan
                  dc.b $f0 ; Light Grey
                  
                  dc.b $00 ; EndOfTab
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
StartGraphicPic   lda SCROLX                      ; VIC 2 - $D016 equ Control Register 2 (and Horizontal Fine Scrolling)
                  and #$ef                        ; reset multi color mode
.MultiColorOff    sta SCROLX                      ; VIC 2 - $D016 equ Control Register 2 (and Horizontal Fine Scrolling)
                  
.CopyDataI        lda #<CR_StartGfx               ; from $13b0
                  sta $0f                         ;
                  lda #>CR_StartGfx               ;
                  sta $10                         ; ($0f/$10) -> graphic data start  address
                  
                  lda #<(LR_ScrnHiReDisp-1)       ; to   $2000
                  sta $0d                         ;
                  lda #>(LR_ScrnHiReDisp-1)       ; 
                  sta $0e                         ; ($0d/$0e) -> graphic data target address
                  
.GetData          ldy #$00                        ; 
                  lda ($0f),y                     ;
                  sta $1e                         ; first byte is counter
                  iny                             ;
                  lda ($0f),y                     ;
                  sta $1f                         ; second byte is data

.SetPtr           lda $0f                         ; 
                  clc                             ;
                  adc #$02                        ; set pointer to next pair of data
                  sta $0f                         ;
                  bcc .SetCounter                 ; 
                  inc $10                         ;
                  
.SetCounter       lda $1e                         ; first byte is counter
                  tay                             ;
                  lda $1f                         ; second byte is data
.CopyData         sta ($0d),y                     ; 
                  dey                             ;
                  bne .CopyData                   ; 
                  
.SetTarget        lda $0d                         ; set next target pos
                  clc                             ;
                  adc $1e                         ; first byte is counter
                  sta $0d                         ;
                  bcc .ChkEnd                     ; 
                  inc $0e                         ;
                  
.ChkEnd           lda $0e                         ; 
                  cmp #$3f                        ; max $3fff
                  bcc .GetData                    ; 
                  
                  lda #$0d                        ; 
                  jsr OutTheBest                  ; 
                  
StartGraficOutX   jmp Wait4User                   ; WaitSomeTime
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
IRQ_PlaySounds    ldx LR_PtrTuneToPlay
                  cpx LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  beq IRQ_SoundsReset             ; all tunes completed
                  
                  lda #$11                        ; triangle wave/start ADS
                  sta LR_WaveVoice2
                  sta LR_WaveVoice3
                  lda LR_TuneSuReVol,x            ; tune s/r/volume  (not used)
                  lda #$f0
                  and LR_Volume
                  sta SUREL2                      ; SID - $D40D equ Oscillator 2 Sustain/Release
                  sta SUREL3                      ; SID - $D414 equ Oscillator 3 Sustain/Release
                  lda LR_TuneDataPtrV2,x          ; tab tune data pointer voice 2
                  bne .Voice02
                  
                  sta LR_WaveVoice2
.Voice02          tay
                  lda TabVocsFreqDatLo,y
                  sta FRELO2                      ; SID - $D407 equ Oscillator 2 Frequency Control (Low Byte)
                  lda TabVocsFreqDatHi,y
                  sta FREHI2                      ; SID - $D408 equ Oscillator 2 Frequency Control (High Byte)
                  lda LR_TuneDataPtrV3,x          ; tab tune data pointer voice 3
                  bpl .ChkVoice03
                  
                  lda LR_TuneDataPtrV2,x          ; tab tune data pointer voice 2
                  tay
                  sec
                  lda TabVocsFreqDatLo,y
                  sbc #$80
                  sta FRELO3                      ; SID - $D40E equ Oscillator 3 Frequency Control (Low Byte)
                  lda TabVocsFreqDatHi,y
                  sbc #$00
                  sta FREHI3                      ; SID - $D40F equ Oscillator 3 Frequency Control (High Byte)
                  jmp .PlayTune
                  
.ChkVoice03       bne .Voice03
                  
                  sta LR_WaveVoice3
.Voice03          tay
                  lda TabVocsFreqDatLo,y
                  sta FRELO3                      ; SID - $D40E equ Oscillator 3 Frequency Control (Low Byte)
                  lda TabVocsFreqDatHi,y
                  sta FREHI3                      ; SID - $D40F equ Oscillator 3 Frequency Control (High Byte)
.PlayTune         lda LR_WaveVoice2
                  sta VCREG2                      ; SID - $D40B equ Oscillator 2 Control
                  lda LR_WaveVoice3
                  sta VCREG3                      ; SID - $D412 equ Oscillator 3 Control
.DecTime          dec LR_TunePlayTime,x           ; tab tune times
                  bne IRQ_PlaySoundsX             ; not completed yet
                  
                  inc LR_PtrTuneToPlay            ; next tune to play
                  
IRQ_PlaySoundsX   rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
IRQ_SoundsReset   lda #$00
                  sta VCREG2                      ; SID - $D40B equ Oscillator 2 Control
                  sta VCREG3                      ; SID - $D412 equ Oscillator 3 Control
                  
IRQ_SoundsResetX  rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
SetTune           pla                             ; played during IRQ
                  sta $7d
                  pla
                  sta $7e                         ; ($7d/$7e) ptr melody data
                  bne .SetNext
                  
.CpyTune          sei
                  
                  ldy #$00
                  lda ($7d),y
                  beq .PrepareXit
                  
                  ldx LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  sta LR_TunePlayTime,x           ; tab tune times
                  iny
                  lda ($7d),y
                  sta LR_TuneDataPtrV2,x          ; tab tune data pointer voice 2
                  iny
                  lda ($7d),y
                  sta LR_TuneDataPtrV3,x          ; tab tune data pointer voice 3
                  iny
                  lda ($7d),y
                  sta LR_TuneSuReVol,x            ; tune s/r/volume  (not used)
                  inc LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  lda $7d
                  clc
                  adc #$04                        ; tune entry length $04
                  sta $7d
                  lda $7e
                  adc #$00
                  sta $7e
                  bne .CpyTune
                  
.SetNext          inc $7d
                  bne .CpyTune
                  inc $7e
                  bne .CpyTune
                  
.PrepareXit       lda $7e                         ; point behind melody data
                  pha
                  lda $7d
                  pha
                  
                  cli
                  
SetTuneX          rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
Randomizer        sta LR_RandomAc                 ; save accumulator
.GetBeam          lda RASTER                      ; VIC 2 - $D012 equ Read: Raster Scan Line/ Write: Line for Raster IRQ
                  sta LR_RasterBeamPos
                  cpx LR_RasterBeamPos
                  bcc .ChkBeam
                  beq .ChkBeam
                  jmp .GetBeam
                  
.ChkBeam          cpy LR_RasterBeamPos
                  bcc .GetBeam
                  
                  sec
                  sbc LR_Random
                  bcs .ChkAc
                  
                  eor #$ff
                  adc #$01
.ChkAc            cmp LR_RandomAc
                  bcc .GetBeam
                  
                  lda LR_RasterBeamPos
                  sta LR_Random
                  
RandomizerX       rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MelodyInit        lda MelodyMaxNo
                  sta LR_MelodyNo
                  lda MelodyMinHight
                  sta LR_MelodyHeight
                  
MelodyInitX       rts
; ------------------------------------------------------------------------------------------------------------- ;
; SetNextMelody   Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
SetNextMelody     dec LR_MelodyNo                 ; $00-$09
                  bpl SetNextMelodyX              ; 
                  
                  inc LR_MelodyHeight             ; $02-$0b
                  lda LR_MelodyHeight             ; 
                  cmp MelodyMaxHight              ; 
                  bcc .GetMax                     ;
                  
                  lda MelodyMinHight              ; 
                  sta LR_MelodyHeight             ; 

.GetMax           lda MelodyMaxNo                 ; 
                  sta LR_MelodyNo                 ; $00-$09

SetNextMelodyX    rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
VictoryTuneCopy   lda LR_MelodyNo                 ; $00-$09
                  asl a                           ; *2
                  tax                             ;
                  lda TabMelodyPtr,x              ;
                  sta $7d                         ; lrzLoSoundFrom
                  lda TabMelodyPtr+1,x            ;
                  sta $7e                         ; ($7d/$7e) -> melody data
                  
.CpyTune          sei                             ; 

                  ldy #$00                        ;
                  lda ($7d),y                     ; lrzVecSoundFrom
                  beq .PrepXit                    ; 
                  
                  ldx LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  sta LR_TunePlayTime,x           ; SoundStack0 - score duration
                  iny                             ;
                  lda ($7d),y                     ; lrzVecSoundFrom
                  beq .Voice01                    ; 
                  
                  clc                             ;
                  adc LR_MelodyHeight             ; 
.Voice01          sta LR_TuneDataPtrV2,x          ; 
                  iny                             ;
                  lda ($7d),y                     ; lrzVecSoundFrom
                  beq .Voice02                    ;
                  bmi .Voice02                    ; 
                  
                  clc                             ;
                  adc LR_MelodyHeight             ; lrMelodyAdd (02-0b)
.Voice02          sta LR_TuneDataPtrV3,x          ;
                  iny                             ;
                  lda ($7d),y                     ; lrzVecSoundFrom
                  sta LR_TuneSuReVol,x            ; 
                  inc LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  
.SetPointer       lda $7d                         ; get next 4 bytes
                  clc                             ;
                  adc #$04                        ;
                  sta $7d                         ; 
                  lda $7e                         ; 
                  adc #$00                        ;
                  sta $7e                         ; 
                  bne .CpyTune                    ; always
                  
.PrepXit          cli                             ; 

VictoryTuneCopyX  rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
IRQ               inc LR_CountIRQs                ; 

                  lda #$00                        ;
                  sta $7c                         ; tune value voice 1
                  lda LR_Volume                   ; 
                  and #$0f                        ;
                  sta SIGVOL                      ; SID - $D418 equ Volume and Filter Select
                  lda LR_FallsDown                ; $00=fall $20=no fall $ff=init
                  bne .BeepInit                   ;
                  
                  ldx LR_FallBeep                 ; 
                  stx $7c                         ; tune value voice 1
                  jmp .ChkShoot                   ;
                  
.BeepInit         lda #LR_FallBeepIni             ; 
                  sta LR_FallBeep                 ; 
                  
.ChkShoot         lda LR_Shoots                   ; $00=no  $01=shoot right  $ff=shoot left
                  beq .ShootInit                  ;
                  
                  lda LR_ShootSound               ;
                  sec                             ;
                  sbc #LR_ShootSoundSub           ;
                  sta LR_ShootSound               ;
                  sta $7c                         ; tune value voice 1
                  beq .ShootInit                  ;
                  
                  jmp .ChkDeath                   ;
                  
.ShootInit        lda #LR_ShootSoundIni           ; 
                  sta LR_ShootSound               ;

.ChkDeath         lda LR_DeathTune                ; 
                  beq .SetTune                    ;
                  
                  sec                             ;
                  sbc #$04                        ;
                  sta $7c                         ; tune value voice 1
                  sta LR_DeathTune                ; 
                  
.SetTune          lda $7c                         ; tune value voice 1
                  sta FREHI1                      ; SID - $D401 equ Oscillator 1 Frequency Control (High Byte)
                  jsr IRQ_PlaySounds              ; 
                  
                  lda $c5                         ; key value
                  bne .ChkKey                     ;
                  
                  lda #$07                        ;
.ChkKey           cmp #$40                        ; no key pressed
                  bne .ChkKeyFlag                 ;
                  
                  lda #$00                        ; 
                  sta LR_KeyOld                   ; set no key
                  jmp C64_IRQ                     ; continue sytem IRQ
                  
.ChkKeyFlag       ldx C64_KeyFlag                 ; $01=shift $02=commodore $04=ctrl
                  beq .ChkKeyOld                  ;
                  
                  ora #$80                        ;
                  
.ChkKeyOld        cmp LR_KeyOld                   ; 
                  beq IRQ_X                       ;
                  
                  sta LR_KeyOld                   ; 
                  sta LR_KeyNew                   ; 
                  
IRQ_X             jmp C64_IRQ                     ; continue sytem IRQ
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
GameInitOnce      lda $01                         ; 
                  and #$fe                        ; basic off
                  sta $01                         ;
                  
                  lda #$00                        ;
                  sta $1e                         ;
                  sta $1f                         ;
                  
                  ldy #$00                        ;
                  lda #$19                        ; 25
                  sta CR_Work                     ;
.GetAmount        ldx #$08                        ;
.GetValue         lda $1f                         ;
                  sta LR_TabOffHiresHi,y          ; offset grafic output high
                  lda $1e                         ;
                  sta LR_TabOffHiresLo,y          ; offset grafic output low
                  inc $1e                         ;
                  iny                             ;
                  dex                             ;
                  bne .GetValue                   ;
                  
                  clc                             ;
                  adc #$39                        ;
                  sta $1e                         ;
                  lda $1f                         ;
                  adc #$01                        ;
                  sta $1f                         ;
                  
                  dec CR_Work                     ;
                  bne .GetAmount                  ;
                  
                  lda #<NMI                       ;
                  sta C64_PtrNMI                  ;
                  lda #>NMI                       ;
                  sta C64_PtrNMI+1                ; point NMI vector to rti
                  
                  lda #BLACK                      ; 
                  sta BGCOL0                      ; VIC 2 - $D021 equ BackGround Color 0
                  sta EXTCOL                      ; VIC 2 - $D020 equ Border Color

                  sei                             ;

                  lda #<IRQ                       ;
                  sta C64_PtrIRQ                  ;
                  lda #>IRQ                       ;
                  sta C64_PtrIRQ+1                ; irq vector

                  cli                             ;

                  lda #$b0                        ;
                  sta SUREL1                      ; SID - $D406 equ Oscillator 1 Sustain/Release
                  lda #$11                        ;
                  sta VCREG1                      ; SID - $D404 equ Oscillator 1 Control

                  ldx #$30                        ; $30*$40=$0c00
                  stx LR_SpritePtr00              ; sprite 0 data at $0c00
                  inx                             ;
                  stx LR_SpritePtr02              ; sprite 2 data at $0c40
                  inx                             ;
                  stx LR_SpritePtr03              ; sprite 3 data at $0c80
                  inx                             ;
                  stx LR_SpritePtr04              ; sprite 4 data at $0cc0
                  inx                             ;
                  stx LR_SpritePtr06              ; sprite 6 data at $0d00
                  inx                             ;
                  stx LR_SpritePtr07              ; sprite 7 data at $0d40
                  
                  lda #$00                        ;
                  sta SPBGPR                      ; VIC 2 - $D01B equ Sprite to Foreground Priority
                  tay                             ;
.ClearZP          sta $02,y                       ; .hbu000.
                  sta LR_SpriteStore01,y          ;
                  sta LR_SpriteStore02,y          ;
                  iny                             ;
                  bne .ClearZP                    ;
                  
                  lda #$ff                        ;
                  sta SPENA                       ; VIC 2 - $D015 equ Sprite Enable
                  
GameInitOnceX     lda #CYAN                       ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ColorSprites      ldy #$07                        ; 
.SetSpriteColor   sta SP0COL,y                    ; VIC 2 - $D027 - Color Sprite 0
                  dey                             ;
                  bne .SetSpriteColor             ; 
                  
                  iny                             ; always a white lode runner
                  sty SP0COL                      ; VIC 2 - $D027 - Color Sprite 0
                  
ColorSpritesX     rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ColourLevel       sta ..ModColor                  ; ac contains colours ac=color1 and color 2

                  lda SCROLX                      ; VIC 2 - $D016 equ Control Register 2 (and Horizontal Fine Scrolling)
                  ora #$10                        ; set multicolour bitmapping mode
                  sta SCROLX                      ; VIC 2 - $D016 equ Control Register 2 (and Horizontal Fine Scrolling)
                  
                  ldy #$00                        ;
.GetColor         lda #HR_OrangeBlue              ; modified by ac value
..ModColor        equ *-1
                  sta LR_ScrnMultColor,y          ; screen - colours 1 & 2
                  sta LR_ScrnMultColor+$0100,y    ;
                  sta LR_ScrnMultColor+$0200,y    ;
                  sta LR_ScrnMultColor+$02f8,y    ;
                  lda #WHITE                      ; 
                  sta COLORAM,y                   ; colour ram - colour 3
                  sta COLORAM+$0100,y             ;
                  sta COLORAM+$0200,y             ;
                  sta COLORAM+$0300,y             ;
                  dey                             ;
                  bne .GetColor                   ;
                  
ColourLevelX      rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
NMI               rti                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TabEnmyEnab       dc.b $01 ; .......#
                  dc.b $05 ; .....#.#
                  dc.b $0d ; ....##.#
                  dc.b $1d ; ...###.#
                  dc.b $5d ; .#.###.#
                  dc.b $dd ; ##.###.#
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ShowSaveList      lda #>LR_ScrnHiReDisp           ; 
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  
                  lda #CR_LevelDiskSave           ; 155 - (t=$0c s=$0b) containes the saved game entry list
                  sta LR_LevelNoDisk              ; 000-049
                  
                  lda #CR_SavListIdLen            ;
                  sta CR_InputBufMax              ;
                  
                  lda #$02                        ;
                  sta LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  
                  lda #LR_DiskRead                ;
                  jsr ControlDiskOper             ; ac: $01=load $02=store
                  jsr CheckSaveList               ; check "BJB" id - clear data otherwise
                  jsr ClearHiresDisp              ; 
                  
                  lda #HR_YellowCyan              ;
                  jsr ColourLevel                 ; 
                  
                  lda #$00                        ;
                  sta $4f                         ; screen col ($00 - $1b)
                  lda #$04                        ;
                  sta $50                         ; screen row ($00 - $0f)
                  jsr TextOut                     ; TextOut
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $ce ; N
                  dc.b $c1 ; A
                  dc.b $cd ; M
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $cc ; L
                  dc.b $c5 ; E
                  dc.b $d6 ; V
                  dc.b $c5 ; E
                  dc.b $cc ; L
                  dc.b $a0 ; <blank>
                  dc.b $cd ; M
                  dc.b $c5 ; E
                  dc.b $ce ; N
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $d3 ; S
                  dc.b $c3 ; C
                  dc.b $cf ; O
                  dc.b $d2 ; R
                  dc.b $c5 ; E
                  dc.b $8d ; <newline>
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $a0 ; <blank>
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $a0 ; <blank>
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $a0 ; <blank>
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $8d ; <newline>
                  dc.b $00 ; EndOfText
                  
                  ldy #$00                        ;
                  sty $1c                         ; ptr save game data

.SaveNameOutI     lda #CR_SavListIdLen            ;
                  sta $1d                         ; name length
                  
.SaveNameOut      ldy $1c                         ; ptr save game data
                  lda CR_SavList,y                ;
                  jsr PrepareChrOut               ;
                  
                  inc $1c                         ; ptr save game data
                  dec $1d                         ; name length
                  bne .SaveNameOut                ;
                  
.PosLevel         inc $4f                         ; screen col ($00 - $1b)
                  inc $4f                         ; screen col ($00 - $1b)
                  ldy $1c                         ; get ptr save game data
                  inc $1c                         ; set ptr save game data
                  inc $1c                         ; 
                  
.GetLevel         lda CR_SavList,y                ;
                  cmp #$a0                        ; <blank>
                  bne .OutLevel                   ;
                  
                  jmp .SetNextEntry               ;
                  
.OutLevel         jsr ConvertHex2Dec              ; Hex2Dec  (1307=100 1308=10 1309=1)

                  lda LR_Digit100                 ; lrDec100
                  jsr PrepareDigitOut             ; Digits2Screen
                  lda LR_Digit10                  ; lrDec10
                  jsr PrepareDigitOut             ; Digits2Screen
                  lda LR_Digit1                   ; lrDec1
                  jsr PrepareDigitOut             ; Digits2Screen
                  
.PosMen           inc $4f                         ; screen col ($00 - $1b)
                  inc $4f                         ; screen col ($00 - $1b)
                  ldy $1c                         ; get ptr save game data
                  inc $1c                         ; set ptr save game data
                  
.GetMen           lda CR_SavList,y                ;
                  jsr ConvertHex2Dec              ; Hex2Dec  (1307=100 1308=10 1309=1)
                  
.OutMen           lda LR_Digit100                 ; lrDec100
                  jsr PrepareDigitOut             ; Digits2Screen
                  lda LR_Digit10                  ; lrDec10
                  jsr PrepareDigitOut             ; Digits2Screen
                  lda LR_Digit1                   ; lrDec1
                  jsr PrepareDigitOut             ; Digits2Screen
 
.PosScore         inc $4f                         ; screen col ($00 - $1b)
                  ldy $1c                         ; get ptr save game data
                  inc $1c                         ; set ptr save game data
 
.GetScore         lda CR_SavList,y                ;
                  jsr SplitScoreOut               ;
                  
                  ldy $1c                         ; get ptr save game data
                  inc $1c                         ; set ptr save game data
                  lda CR_SavList,y                ;
                  jsr SplitScoreOut               ;
                  
                  ldy $1c                         ; get ptr save game data
                  inc $1c                         ; set ptr save game data
                  lda CR_SavList,y                ;
                  jsr SplitScoreOut               ;
                  
                  ldy $1c                         ; get ptr save game data
                  lda CR_SavList,y                ;
                  jsr SplitScoreOut               ;
                  
.SetNewRow        lda #$8d                        ; <newline>
                  jsr PrepareChrOut               ;
                  
.SetNextEntry     lda $1c                         ; get ptr save game data
                  and #$f0                        ;
                  clc                             ;
                  adc #$10                        ;
                  sta $1c                         ; set ptr save game data to next entry

.ChkMax           cmp #$a0                        ; maxiumum reached - $09*10
                  beq ShowSaveListX               ;
                  
.GoNextRow        jmp .SaveNameOutI               ;
                  
ShowSaveListX     rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
SaveGame          jsr LoadScoreBlock              ; 
                  bcs ShowSaveListX               ; bad
                  
                  jsr ChkUniquePlayId             ; 
                  
                  lda LR_LevelNoDisk              ; 000-049
                  sta CR_SaveNoDisk               ;
                  
.GoShowSaveList   jsr ShowSaveList                ; 

                  lda #>LR_ScrnHiReDisp           ;
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  jsr BaseLines                   ; 
                  
.TitleLine        lda #$00                        ;
                  sta $50                         ; screen row ($00 - $0f)
                  sta $4f                         ; screen col ($00 - $1b)
                  jsr TextOut                     ; TextOut
                  dc.b $a0 ; <blank>
                  dc.b $d3 ; S
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $d4 ; T
                  dc.b $cf ; O
                  dc.b $a0 ; <blank>
                  dc.b $d3 ; S
                  dc.b $c1 ; A
                  dc.b $d6 ; V
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $c7 ; G
                  dc.b $c1 ; A
                  dc.b $cd ; M
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $c9 ; I
                  dc.b $ce ; N
                  dc.b $a0 ; <blank>
                  dc.b $d0 ; P
                  dc.b $d2 ; R
                  dc.b $cf ; O
                  dc.b $c7 ; G
                  dc.b $d2 ; R
                  dc.b $c5 ; E
                  dc.b $d3 ; S
                  dc.b $d3 ; S
                  dc.b $8d ; <newline>
                  dc.b $a0 ; <blank>
                  dc.b $c4 ; D
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $d4 ; T
                  dc.b $cf ; O
                  dc.b $a0 ; <blank>
                  dc.b $c4 ; D
                  dc.b $c5 ; E
                  dc.b $cc ; L
                  dc.b $c5 ; E
                  dc.b $d4 ; T
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $c1 ; A
                  dc.b $ce ; N
                  dc.b $a0 ; <blank>
                  dc.b $c5 ; E
                  dc.b $ce ; N
                  dc.b $d4 ; T
                  dc.b $d2 ; R
                  dc.b $d9 ; Y
                  dc.b $a0 ; <blank>
                  dc.b $c2 ; B
                  dc.b $c5 ; E
                  dc.b $cc ; L
                  dc.b $cf ; O
                  dc.b $d7 ; W
                  dc.b $8d ; <newline>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $bc ; <
                  dc.b $d2 ; R
                  dc.b $af ; /
                  dc.b $d3 ; S
                  dc.b $be ; >
                  dc.b $a0 ; <blank>
                  dc.b $d4 ; T
                  dc.b $cf ; O
                  dc.b $a0 ; <blank>
                  dc.b $c3 ; C
                  dc.b $cf ; O
                  dc.b $ce ; N
                  dc.b $d4 ; T
                  dc.b $c9 ; I
                  dc.b $ce ; N
                  dc.b $d5 ; U
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $c7 ; G
                  dc.b $c1 ; A
                  dc.b $cd ; M
                  dc.b $c5 ; E
                  dc.b $00 ; EndOfText
                  
                  lda #$00                        ;
                  sta LR_KeyNew                   ; 
                  jsr WaitKeyBlink                ;
                  
                  ldx #$00                        ;
                  stx LR_KeyNew                   ; discard key pressed
                  
.Chk_s            cmp #$0d                        ; "s"
                  bne .Chk_d                      ;
                  
                  jmp .SaveNew                    ;
                  
.Chk_d            cmp #$12                        ; "d"
                  beq .DeleteOld                  ;
                  
                  cmp #$3f                        ; RUN/STOP
                  bne .BadKey                     ;
                  
.Abort            jmp .RestartLevelOne            ; 
                  
.BadKey           jsr Beep                        ; 
                  jmp .TitleLine                  ; start over
                  
.DeleteOld        lda #$00                        ; 
                  sta $50                         ; screen row ($00 - $0f)
                  sta $4f                         ; screen col ($00 - $1b)
                  jsr TextOut                     ; TextOut
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $c4 ; D
                  dc.b $c5 ; E
                  dc.b $cc ; L
                  dc.b $c5 ; E
                  dc.b $d4 ; T
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $c1 ; A
                  dc.b $ce ; N
                  dc.b $a0 ; <blank>
                  dc.b $c5 ; E
                  dc.b $ce ; N
                  dc.b $d4 ; T
                  dc.b $d2 ; R
                  dc.b $d9 ; Y
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $8d ; <newline>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $ce ; N
                  dc.b $c1 ; A
                  dc.b $cd ; M
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $be ; >
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $bc ; <
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $8d ; <newline>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $bc ; <
                  dc.b $d2 ; R
                  dc.b $af ; /
                  dc.b $d3 ; S
                  dc.b $be ; >
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $d4 ; T
                  dc.b $cf ; O
                  dc.b $a0 ; <blank>
                  dc.b $c1 ; A
                  dc.b $c2 ; B
                  dc.b $cf ; O
                  dc.b $d2 ; R
                  dc.b $d4 ; T
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $00 ; EndOfText
                  
.SetNameSpace     dec $50                         ; screen row ($00 - $0f)
                  lda #CR_DelSavColName           ;
                  sta $4f                         ; screen col ($00 - $1b)
                  
                  jsr InputControl                ; get a name
                  jsr DelSaveListLine             ; 
                  cpx #$00                        ; 
                  beq .RestartList                ;
                  
.ShowList         jmp .GoShowSaveList             ;
                  
.RestartList      jmp .TitleLine                  ; 

.SaveNew          lda #$00                        ; 
                  sta $50                         ; screen row ($00 - $0f)
                  sta $4f                         ; screen col ($00 - $1b)
                  jsr TextOut                     ; TextOut
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $d3 ; S
                  dc.b $c1 ; A
                  dc.b $d6 ; V
                  dc.b $c5 ; E
                  dc.b $a0 ; <newline>
                  dc.b $c7 ; G
                  dc.b $c1 ; A
                  dc.b $cd ; M
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $c9 ; I
                  dc.b $ce ; N
                  dc.b $a0 ; <blank>
                  dc.b $d0 ; P
                  dc.b $d2 ; R
                  dc.b $cf ; O
                  dc.b $c7 ; G
                  dc.b $d2 ; R
                  dc.b $c5 ; E
                  dc.b $d3 ; S
                  dc.b $d3 ; S
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $8d ; <newline>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $ce ; N
                  dc.b $c1 ; A
                  dc.b $cd ; M
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $be ; >
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $bc ; <
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $8d ; <newline>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $bc ; <
                  dc.b $d2 ; R
                  dc.b $af ; /
                  dc.b $d3 ; S
                  dc.b $be ; >
                  dc.b $a0 ; <blank>
                  dc.b $d4 ; T
                  dc.b $cf ; O
                  dc.b $a0 ; <blank>
                  dc.b $c1 ; A
                  dc.b $c2 ; B
                  dc.b $cf ; O
                  dc.b $d2 ; R
                  dc.b $d4 ; T
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $00 ; EndOfText
                  
                  dec $50                         ; screen row ($00 - $0f)
                  lda #$0b                        ;
                  sta $4f                         ; screen col ($00 - $1b)
                  
                  jsr InputControl                ;
                  beq .GoTitleLine                ; no name entered or run/stop
                  
                  jsr LookupSaveList              ; carry_clear=name not in list  carry_set=name in list
                  bcs .FillEntry                  ; name found in list - overwrite
                  
                  jsr FindFreeEntry               ;
                  bcs .FillEntry                  ; found
                  
                  jsr Beep                        ; save game list full
                  jsr Beep                        ; 
.GoTitleLine      jmp .TitleLine                  ;

.FillEntry        tay                             ; 
                  ldx #$00                        ;
.CpyName          lda CR_InputBuf,x               ;
                  sta CR_SavList,y                ;
                  iny                             ;
                  inx                             ;
                  cpx #$08                        ;
                  bcc .CpyName                    ;
                  
.CpyLevel         lda LR_LevelNoGame              ; 001-050
                  sta CR_SavList,y                ;
                  
.CpySavLevel      iny                             ;
                  lda CR_SaveNoDisk               ;
                  sta CR_SavList,y                ;
                  
.CpyLives         iny                             ;
                  lda LR_NumLives                 ; lrNumLives
                  sta CR_SavList,y                ;
                  
.CpyScore         iny                             ;
                  lda LR_ScoreHi                  ; lrScoreHigh
                  sta CR_SavList,y                ;
                  iny                             ;
                  lda LR_ScoreMidHi               ; lrScoreMidHigh
                  sta CR_SavList,y                ;
                  iny                             ;
                  lda LR_ScoreMidLo               ; lrScoreMidLow
                  sta CR_SavList,y                ;
                  iny                             ;
                  lda LR_ScoreLo                  ; lrScoreLow
                  sta CR_SavList,y                ;

                  jsr ChkUniquePlayId             ; 
                  
                  lda #LR_DiskWrite               ;
                  jsr ControlDiskOper             ; ac: $01=load $02=store
                  jsr ShowSaveList                ;
                  
                  lsr LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  
                  jmp Wait4User                   ; WaitSomeTime

.RestartLevelOne  jsr ClearHiresDisp              ; ClearDisplay20
                  lda CR_LevelColor               ; 
                  jsr ColourLevel                 ; 
                  jsr BaseLines                   ; 
                  
                  lda #$00                        ;
                  sta CR_NoFunction               ;
                  lda CR_SaveNoDisk               ;
                  sta LR_LevelNoDisk              ; 000-049
                  
                  lda #$ff                        ;
                  sta LR_LvlReload                ; 000-049 - force level reload from disk if <> LR_LevelNoDisk

SaveGameX         jmp LevelStart                  ; StartNewLevel
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
DelSaveListLine   jsr LookupSaveList              ; carry_clear=name not in list  carry_set=name in list
                  bcc .BeepBeep                   ; entry not found
                  
                  tay                             ; name position
.MoveUp           lda CR_SavList + CR_SavListRowLen,y  ;
                  sta CR_SavList,y                ;
                  iny                             ;
                  cpy #$a0                        ;
                  bcc .MoveUp                     ; overwrite entry found - move the whole list ome pos up equ delete
                  
                  jsr ChkUniquePlayId             ; 
                  
                  lda #LR_DiskWrite               ;
.Write            jsr ControlDiskOper             ; ac: $01=load $02=store
                  
                  clc                             ;
                  rts                             ;

.BeepBeep         jsr Beep                        ;
                  jsr Beep                        ;
                  
                  clc                             ;
DelSaveListLineX  rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
InputControl      lda #$c0                        ;
InputControlSpec  sta CR_InputControl             ; highscores/register

                  ldx #CR_InputBufLen             ; length
                  lda #$a0                        ; <blank>
.ClrInputBuffer   sta CR_InputBuf,x               ;
                  dex                             ;
                  bpl .ClrInputBuffer             ;
                  
                  inx                             ; $00
                  stx CR_InputBufPtr              ;
                  stx LR_KeyNew                   ; 
                  
.OutWaitKey       ldx CR_InputBufPtr              ; 
                  lda CR_InputBuf,x               ;
                  jsr GetChrSubst                 ;
                  jsr WaitKeyBlink                ;
                  
                  ldx #$00                        ;
                  stx LR_KeyNew                   ; reset
                  
.Chk_RS           cmp #$3f                        ; RUN/STOP
                  beq .RetBad                     ;
                  
                  jsr GetKeySubst                 ;
                  
                  bit CR_InputControl             ;
                  bpl .Chk_Return                 ; no serial number
                  
                  cmp #$b0                        ; lower key "0"
                  bcc .Chk_Return                 ;
                                                  ; handle $b0 - $b9 equ key 0-9
                  cmp #$ba                        ; lower key "9"
                  bcc .Store                      ;
                  
.Chk_Return       cmp #$8d                        ; <return> - end of edit
                  beq .Return                     ;
                  
.Chk_Up           cmp #$88                        ; <cursor up/down>
                  beq .CurUp                      ;
                  
.Chk_Right        cmp #$95                        ; <cursor left/right>
                  beq .CurRight                   ;
                  
.Chk_Blank        cmp #$a0                        ; <blank>
                  beq .Store                      ;
                  
                  bit CR_InputControl             ;
                  bvc .BeepBeep                   ;
                  
.Chk_Dot          cmp #$ae                        ; "."
                  beq .Store                      ;
                  
.Chk_A            cmp #$c1                        ; "A"
                  bcc .BeepBeep                   ;
                  
                  cmp #$db                        ; "Z" + 1
.Chk_Z            bcs .BeepBeep                   ;

.Store            ldx CR_InputBufPtr              ;
                  sta CR_InputBuf,x               ;
                  jsr PrepareChrOut               ;
                  
                  inc CR_InputBufPtr              ;
                  lda CR_InputBufPtr              ;
                  cmp CR_InputBufMax              ;
                  bcc .OutWaitKey                 ;
                  
                  dec CR_InputBufPtr              ;
                  dec $4f                         ; screen col ($00 - $1b)
                  jmp .OutWaitKey                 ;
                  
.Return           ldx CR_InputBufMax              ; 
.ChkBlanks        lda CR_InputBuf,x               ; 
                  cmp #$a0                        ; <blank>
                  bne .RetGood                    ; something was entered
                  
                  dex                             ;
                  bpl .ChkBlanks                  ; 
                  
.RetBad           sec                             ; <blank> name entry or RUN/STOP
                  ldx #$00                        ;
                  rts                             ;
                  
.RetGood          sec                             ;
                  ldx #$01                        ;
                  rts                             ;
                  
.CurUp            dec $4f                         ; screen col ($00 - $1b)
                  dec CR_InputBufPtr              ;
                  bpl .OutWaitKey                 ;
                  
                  inc $4f                         ; screen col ($00 - $1b)
                  inc CR_InputBufPtr              ;
                  jmp .BeepBeep                   ;
                  
.CurRight         ldx CR_InputBufPtr              ; 
                  inx                             ;
                  cpx CR_InputBufMax              ;
                  bcs .BeepBeep                   ;
                  
                  inc $4f                         ; screen col ($00 - $1b)
                  inc CR_InputBufPtr              ;
                  jmp .OutWaitKey                 ;
                  
.BeepBeep         jsr Beep                        ; 
                  jsr Beep                        ;
                  jmp .OutWaitKey                 ;
InputControlX     equ *                           ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
LookupSaveList    ldy #$00                        ; carry_clear=name not in list  carry_set=name in list ac=position
.ChkEntryI        ldx #$00                        ;
.ChkEntry         lda CR_SavList,y                ;
                  cmp CR_InputBuf,x               ;
                  bne .Differs                    ;
                  
                  iny                             ;
                  inx                             ;
                  cpx #CR_SavListIdLen            ;
                  bne .ChkEntry                   ;
                  
.Same             tya                             ; save name already existing
                  and #$f0                        ;
                  sec                             ; save name found and can be replaced
                  rts                             ;

.Differs          tya                             ; actual save name differs from entered name so check next entry
                  and #$f0                        ;
                  clc                             ;
                  adc #CR_SavListRowLen           ;
                  
                  tay                             ;
                  cmp #CR_SavListMaxLen           ;
.ChkNext          bne .ChkEntryI                  ;
                  
                  clc                             ; new save name
LookupSaveListX   rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
FindFreeEntry     ldy #$00                        ; carry_clear=list full  carry_set=free entry found  ac=position
.ChkEntryI        ldx #CR_SavListIdLen            ; 
                  lda #$a0                        ; <blank>
.ChkEntry         cmp LR_LvlDataSavLod,y          ;
                  bne .SetNextEntry               ;
                  
                  iny                             ;
                  dex                             ;
                  bne .ChkEntry                   ;
                  
.FreeEntry        tya                             ;
                  and #$f0                        ;
                  sec                             ;
                  rts                             ;
                  
.SetNextEntry     tya                             ;
                  and #$f0                        ;
                  clc                             ;
                  adc #CR_SavListRowLen           ;
                  tay                             ;
                  cmp #CR_SavListMaxLen           ; 
                  bne .ChkEntryI                  ;
                  
.ListFull         clc                             ;
                  rts                             ;

PrepWait4User     lsr LR_GameCtrl                 ; $00=Init $01=demo $02=play

FindFreeEntryX    jmp Wait4User                   ; WaitSomeTime
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
LoadGame          jsr LoadScoreBlock              ; 
                  bcs PrepWait4User               ;
                  
                  lda #$02                        ;
                  sta LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  
                  jsr SetUniquePlayId             ; SetUniquePlayId
                  jsr ShowSaveList                ;
                  
                  lda #$00                        ;
                  sta $4f                         ; screen col ($00 - $1b)
                  sta $50                         ; screen row ($00 - $0f)
                  jsr TextOut                     ; TextOut
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $cc ; L
                  dc.b $cf ; O
                  dc.b $c1 ; A
                  dc.b $c4 ; D
                  dc.b $a0 ; <blank>
                  dc.b $c1 ; A
                  dc.b $ce ; N
                  dc.b $c4 ; D
                  dc.b $a0 ; <blank>
                  dc.b $d0 ; P
                  dc.b $cc ; L
                  dc.b $c1 ; A
                  dc.b $d9 ; Y
                  dc.b $a0 ; <blank>
                  dc.b $c1 ; A
                  dc.b $a0 ; <blank>
                  dc.b $c7 ; G
                  dc.b $c1 ; A
                  dc.b $cd ; M
                  dc.b $c5 ; E
                  dc.b $8d ; <newline>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $ce ; N
                  dc.b $c1 ; A
                  dc.b $cd ; M
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $be ; <
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $bc ; >
                  dc.b $8d ; <newline>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $bc ; <
                  dc.b $d2 ; R
                  dc.b $af ; /
                  dc.b $d3 ; S
                  dc.b $be ; >
                  dc.b $a0 ; <blank>
                  dc.b $d4 ; T
                  dc.b $cf ; O
                  dc.b $a0 ; <blank>
                  dc.b $c1 ; A
                  dc.b $c2 ; B
                  dc.b $cf ; O
                  dc.b $d2 ; R
                  dc.b $d4 ; T
                  dc.b $00 ; <newline>
                  
                  lda #CR_DelSavColName-1         ; 
                  dec $50                         ; screen row ($00 - $0f)
                  sta $4f                         ; screen col ($00 - $1b)
                  
                  jsr InputControl                ;
                  bcc LoadGame                    ; 
                  beq PrepWait4User               ; 

                  jsr LookupSaveList              ; carry_clear=name not in list  carry_set=name in list
                  bcs .SetEntry                   ; name found in list

                  jsr Beep                        ; 
                  jsr Beep                        ;
                  jmp LoadGame                    ; 
                  
.SetEntry         clc                             ; name length
                  adc #CR_SavListIdLen            ; point behind entry name

                  tay                             ;
.GetLevel         lda CR_SavListLevelG - CR_SavListIdLen,y
                  sta LR_LevelNoGame              ; 001-050
                  
                  lda CR_SavListLevelD - CR_SavListIdLen,y
                  pha                             ; save CR_SavListLevelD because of a later list rewrite
                  
.GetLives         lda CR_SavListLives  - CR_SavListIdLen,y
                  sta LR_NumLives                 ; lrNumLives
                  
.DecLives         sec                             ; discount a live whith any load
                  sbc #$01                        ;
                  sta CR_SavListLives  - CR_SavListIdLen,y
                  
                  lda CR_SavListScHi   - CR_SavListIdLen,y
                  sta LR_ScoreHi                  ; lrScoreHigh
                  lda CR_SavListScMiHi - CR_SavListIdLen,y
                  sta LR_ScoreMidHi               ; lrScoreMidHigh
                  lda CR_SavListScMiLo - CR_SavListIdLen,y
                  sta LR_ScoreMidLo               ; lrScoreMidLow
                  lda CR_SavListScLo   - CR_SavListIdLen,y
                  sta LR_ScoreLo                  ; lrScoreLow
                  
                  lda LR_NumLives                 ; lrNumLives
                  cmp #$01                        ;
                  bne .ReinitGame                 ;
                  
                  jsr DelSaveListLine             ;
                  
.ReinitGame       jsr ChkUniquePlayId             ; ChkUniquePlayId

                  lda #LR_DiskWrite               ;
                  jsr ControlDiskOper             ; ac: $01=load $02=store
                  
                  jsr ClearHiresDisp              ; ClearDisplay20
                  jsr ClearHiresPrep              ; ClearDisplay40
                  
                  pla                             ; restore CR_SavListLevelD
                  sta LR_LevelNoDisk              ; 000-049
                  jsr SetNewColors                ; SetNewColors (new colors any 10th level)
                  
                  lda CR_LevelColor               ; lrNewLevelColor
                  jsr ColourLevel                 ; 
                  
                  lda #$00                        ;
                  sta CR_StatusColor              ; lrNewStatusColor
                  
                  lda #>LR_ScrnHiReDisp           ;
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  jsr BaseLines                   ; 
                  
                  lda #>LR_ScrnHiRePrep           ;
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  jsr BaseLines                   ; 
                  
                  jsr MelodyInit                  ; InitVictoryTune
                  
                  lda #$00                        ;
                  sta LR_CntSpeedLaps             ; 
                  sta LR_EnmyBirthCol             ;
                  
                  lda #LR_VolumeMax               ;
                  sta LR_Volume                   ; 
                  sta LR_LvlReload                ; 000-049 - force level reload from disk if <> LR_LevelNoDisk
                  jsr SetUniquePlayId             ; 
                  
LoadGameX         jmp LevelStart                  ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ClearHighScores   jsr ClearHiresDisp              ; 

.WaitKey          lda $c5                         ; C64: key value
                  cmp #$40                        ; no key pressed
                  bne .WaitKey                    ;
                  
                  lda #$00                        ; reset
                  sta LR_KeyNew                   ; 
                  
                  lda #>LR_ScrnHiReDisp           ;
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  
                  lda #HR_YellowCyan              ;
                  jsr ColourLevel                 ; 
                  
                  lda #$00                        ;
                  sta $4f                         ; screen col ($00 - $1b)
                  sta $50                         ; screen row ($00 - $0f)
                  jsr TextOut                     ; TextOut
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $d4 ; T
                  dc.b $c8 ; H
                  dc.b $c9 ; I
                  dc.b $d3 ; S
                  dc.b $a0 ; <blank>
                  dc.b $c3 ; C
                  dc.b $cc ; L
                  dc.b $c5 ; E
                  dc.b $c1 ; A
                  dc.b $d2 ; R
                  dc.b $d3 ; S
                  dc.b $a0 ; <Sblank>
                  dc.b $d4 ; T
                  dc.b $c8 ; H
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $c8 ; H
                  dc.b $c9 ; I
                  dc.b $c7 ; G
                  dc.b $c8 ; H
                  dc.b $8d ; <newline>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $d3 ; S
                  dc.b $c3 ; C
                  dc.b $cf ; O
                  dc.b $d2 ; R
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $c6 ; F
                  dc.b $c9 ; I
                  dc.b $cc ; L
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $cf ; O
                  dc.b $c6 ; F
                  dc.b $a0 ; <blank>
                  dc.b $c1 ; A
                  dc.b $cc ; L
                  dc.b $cc ; L
                  dc.b $8d ; <newline>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $c5 ; E
                  dc.b $ce ; N
                  dc.b $d4 ; T
                  dc.b $d2 ; R
                  dc.b $c9 ; I
                  dc.b $c5 ; E
                  dc.b $d3 ; S
                  dc.b $ae ; .
                  dc.b $8d ; <newline>
                  dc.b $8d ; <newline>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $c1 ; A
                  dc.b $d2 ; R
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $d9 ; Y
                  dc.b $cf ; O
                  dc.b $d5 ; U
                  dc.b $a0 ; <blank>
                  dc.b $d3 ; S
                  dc.b $d5 ; U
                  dc.b $d2 ; R
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $a8 ; (
                  dc.b $d9 ; Y
                  dc.b $af ; /
                  dc.b $ce ; N
                  dc.b $a9 ; )
                  dc.b $a0 ; <blank>
                  dc.b $00 ; EndOfText
                  
                  lda #$00                        ; 
                  jsr WaitKeyBlink                ;
                  
                  ldx #$00                        ; reset
                  stx LR_KeyNew                   ; 
                  
                  cmp #$19                        ; "y"
                  bne ClearHighScoresX            ;
                  
                  lda #$81                        ;
                  jsr GetPutHiScores              ; ($1100-$11ff) ac: $01=load $02=store 81= 82=
                  
                  ldy #$83                        ;
                  lda #$00                        ;
.ClearData        sta LR_LvlDataSavLod+$ff,y      ;
                  dey                             ;
                  bne .ClearData                  ;
                  
                  lsr LR_LevelNoDisk              ; 000-049
                  
                  lda #$82                        ;
                  jsr GetPutHiScores              ; ($1100-$11ff) ac: $01=load $02=store 81= 82=
                  
ClearHighScoresX  rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
CheckSaveList     lda CR_SavListId                ;
                  cmp #$c4                        ; "D"
                  bne ClrSaveList                 ; wrong id - clear and write back
                  
                  lda CR_SavListId+$01            ;
                  cmp #$ca                        ; "J"
                  bne ClrSaveList                 ; wrong id - clear and write back
                  
                  lda CR_SavListId+$02            ;
                  cmp #$c2                        ; "B"
                  bne ClrSaveList                 ; wrong id - clear and write back

CheckSaveListX    rts                             ; good list
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ClrSaveList       lda #$a0                        ; <blank> - wrong id - clear and write back
                  ldx #$00                        ;
.ClrLevelData     sta LR_LvlDataSavLod,x          ;
                  inx                             ;
                  bne .ClrLevelData               ;
                  
.SetID            lda #$c4                        ; "D"
                  sta CR_SavListId                ;
                  lda #$ca                        ; "J"
                  sta CR_SavListId+$01            ;
                  lda #$c2                        ; "B"
                  sta CR_SavListId+$02            ;
                  
.ClrLevelWrite    lda #LR_DiskWrite               ;
                  jsr ControlDiskOper             ; ac: $01=load $02=store
                  
ClrSaveListX      rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
LoadScoreBlock    lda #$02                        ;
                  sta LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  
                  lda #LR_DiskRead                ;
                  jsr GetPutHiScores              ; ($1100-$11ff) ac: $01=load $02=store 81= 82=
                  cmp #$00                        ;
                  bne LoadScoreBad                ;
                  
.LoadScoreGood    sec                             ;
                  rts                             ;
                  
LoadScoreBad      clc                             ; 
LoadScoreBlockX   rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
SplitScoreOut     jsr SplitScoreDigit             ;

                  lda LR_Digit10                  ; lrDec10
                  jsr PrepareDigitOut             ; Digits2Screen
                  
                  lda LR_Digit1                   ; lrDec1
                  jsr PrepareDigitOut             ; Digits2Screen
                  
SplitScoreOutX    rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
VictoryMsg        lda CR_DiskStatus               ; CR_DiskStatus
                  bmi LoadScoreBad                ; bad
                  
                  lda LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  lsr a                           ;
                  beq LoadScoreBad                ; 
                  
                  ldx #LR_LevelMsgLen             ; length victory msg
                  stx CR_Work                     ;
.GetMsgText       lda LR_LevelMsg,x               ; 
                  beq .SetNext                    ; don't move $00 - EndOfText leads to program abend
                  
.PutMsgText       sta TabMsgBuffer,x              ; 
.SetNext          dex                             ;
                  bpl .GetMsgText                 ; 
                  
                  lda #LR_BasLinRowStat           ; 
                  sta $50                         ; screen row ($00 - $0f)
                  lda #LR_BasLinColMsg            ;
                  sta $4f                         ; screen col ($00 - $1b)
                  jsr TextOut                     ; 
TabMsgBuffer      dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $00 ; EndOfText
                  
                  lda #HR_YellowYellow            ; 
                  sta CR_StatusColor              ; 
                  
                  ldx #LR_LevelMsgLenCo           ;
.SetMsgColor      sta LR_ScrnMultColor+$03aa,x    ; 
                  dex                             ;
                  bpl .SetMsgColor                ; 
                  
VictoryMsgX       rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
SetUniquePlayId   lda LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  lsr a                           ;
                  beq SetUniquePlayIdX            ; demo
                  
                  lda #LR_DiskRead                ;
                  jsr GetPutHiScores              ; ($1100-$11ff) ac: $01=load $02=store 81= 82=
                  
                  lda RASTER                      ; VIC 2 - $D012 equ Read: Raster Scan Line/ Write: Line for Raster IRQ
                  sta CR_UniquePID                ; 
                  sta CR_HiScoreUPID              ; unique play id disk store
                  
                  lda #LR_DiskWrite               ; 
.Write            jsr GetPutHiScores              ; ($1100-$11ff) ac: $01=load $02=store 81= 82=
                  
SetUniquePlayIdX  rts                             ; supiX
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ChkUniquePlayId   lda LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  lsr a                           ;
                  beq SetUniquePlayIdX            ; demo
                  
                  lda #LR_DiskRead                ;
                  jsr GetPutHiScores              ; ($1100-$11ff) ac: $01=load $02=store 81= 82=
                  
                  lda CR_HiScoreUPID              ; 
                  cmp CR_UniquePID                ; lrUniquePlayId
                  beq SetUniquePlayIdX            ; 
                  
                  jsr ClearHiresDisp              ; ClearDisplay20
                  
                  lda #>LR_ScrnHiReDisp           ;
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  
                  lda #HR_YellowCyan              ;
                  jsr ColourLevel                 ; 
                  
                  lda #$00                        ;
                  sta $50                         ; screen row ($00 - $0f)
                  sta $4f                         ; screen col ($00 - $1b)
                  jsr TextOut                     ; TextOut
                  dc.b $c4 ; D
                  dc.b $c9 ; I
                  dc.b $d3 ; S
                  dc.b $cb ; K
                  dc.b $a0 ; <blank>
                  dc.b $d3 ; S
                  dc.b $d7 ; W
                  dc.b $c1 ; A
                  dc.b $d0 ; P
                  dc.b $a0 ; <blank>
                  dc.b $ce ; N
                  dc.b $cf ; O
                  dc.b $d4 ; T
                  dc.b $a0 ; <blank>
                  dc.b $c1 ; A
                  dc.b $cc ; L
                  dc.b $cc ; L
                  dc.b $cf ; O
                  dc.b $d7 ; W
                  dc.b $c5 ; E
                  dc.b $c4 ; D
                  dc.b $ae ; .
                  dc.b $8d ; <newline>
                  dc.b $8d ; <newline>
                  dc.b $c8 ; H
                  dc.b $c9 ; I
                  dc.b $d4 ; T
                  dc.b $a0 ; <blank>
                  dc.b $c1 ; A
                  dc.b $ce ; N
                  dc.b $d9 ; Y
                  dc.b $a0 ; <blank>
                  dc.b $cb ; K
                  dc.b $c5 ; E
                  dc.b $d9 ; Y
                  dc.b $00 ; EndOfText
                  
                  lda #$00                        ;
                  jsr WaitKeyBlink                ;
                  
                  lda #$00                        ;
                  sta LR_KeyNew                   ; lrNewKey
                  
ChkUniquePlayIdX  jmp ColdStart                   ; ColdStart
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
SetNewColors      lda CR_DiskStatus               ; 
                  bmi .SetDefault                 ; bad
                  
                  lda LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  lsr a                           ;
                  beq .SetDefault                 ; 
                  
.GetColorPtrI     lda LR_LevelNoDisk              ; 000-049
                  ldx #$ff                        ;
.GetColorPtr      inx                             ; 
                  sec                             ;
                  sbc #$0a                        ;
                  bcs .GetColorPtr                ; 
                  
                  lda TabLevelColors,x            ; 
.SetLevelColor    sta CR_LevelColor               ; 

.SetEnemyColor    lsr a                           ; isolate enemy color
                  lsr a                           ;
                  lsr a                           ;
                  lsr a                           ;
                  jsr ColorSprites                ;
                  
.Exit             rts                             ; 
                  
.SetDefault       lda #HR_CyanRed                 ; 
                  jmp .SetLevelColor              ; 
SetNewColorsX     =*                              ; 
; ------------------------------------------------------------------------------------------------------------- ;
TabLevelColors    dc.b HR_CyanRed                 ; right nybble contains enemy sprite color
                  dc.b HR_GreenLtRed
                  dc.b HR_CyanOrange
                  dc.b HR_PurpleGreen
                  dc.b HR_PurpleLtBlue
; ------------------------------------------------------------------------------------------------------------- ;
TabLrDiskId       dc.b $44 ; d                    ; dane bigham
                  dc.b $41 ; a
                  dc.b $4e ; n
                  dc.b $45 ; e
                  dc.b $20 ; <blank>
                  dc.b $42 ; b
                  dc.b $49 ; i
                  dc.b $47 ; g
                  dc.b $48 ; h
                  dc.b $41 ; a
                  dc.b $4d ; m
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
InitLevel         stx LR_LevelCtrl                ; $00=prepared copy already at $4000-$5fff)

                  ldx #$ff                        ;
                  stx $03                         ; adr col lode runner
                  
                  inx                             ; 00
                  stx LR_NumXitLadders            ; # hidden ladders
                  stx LR_Gold2Get                 ; # gold
                  stx LR_EnmyNo                   ; # enemies
                  stx LR_NoEnemy2Move             ; # enemies to move
                  stx $54                         ;
                  stx $53                         ; disk level data offset
                  stx $1e                         ; left right nybble 00=right
                  stx $50                         ; screen row ($00 - $0f)
                  
                  txa                             ; $00
                  ldx #LR_TabHoleMax              ; 30
.HoleTime         sta LR_TabHoleOpenT,x           ; hole open time tab
                  dex                             ;
                  bpl .HoleTime                   ; 
                  
                  ldx #LR_TabEnemyBMax            ; max 6
.ENReBirthStep    sta LR_TabEnemyBirtT,x          ; enemy rebirth step time
                  dex                             ;
                  bpl .ENReBirthStep              ; 
                  
                  lda #LR_Life                    ; 
                  sta LR_Alive                    ; 
                  
                  lda LR_LevelNoDisk              ; 000-049
                  cmp LR_LvlReload                ; 000-049 - force level reload from disk if <> LR_LevelNoDisk
                  beq .SetSameLevel               ; 
                  
.NewLevel         lda #LR_DiskRead                ; 
                  jsr ControlDiskOper             ; ac: $01=load $02=store
                  
                  jsr ChkUniquePlayId             ; 
                  
                  lda CR_DiskStatus               ; 
                  bmi .SetSameLevel               ; 
                  
                  lda LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  lsr a                           ;
                  beq .SetSameLevel               ; 
                  
                  lda LR_LevelNoDisk              ; 000-049
                  cmp #CR_LevelNoMax              ; 
                  bcs .SetSameLevel               ; 
                  
                  ldx #CR_LevelDataMax            ; length level data
.FlipLevelData    lda LR_LvlDataSavLod-1,x        ; 
                  eor #$ff                        ; flip all bits
                  sta LR_LvlDataSavLod-1,x        ; 
                  dex                             ;
                  bne .FlipLevelData              ; 
                  
.SetSameLevel     lda LR_LevelNoDisk              ; 000-049
                  sta LR_LvlReload                ; 000-049 - force level reload from disk if <> LR_LevelNoDisk
                  
                  jsr SetNewColors                ; SetNewColors (new colors any 10th level)
                  
                  ldy $50                         ; screen row ($00 - $0f)
.ExpandDataI      lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09                         ; 
                  sta $0b                         ; 
                  lda TabExLvlDatRowH8,y          ; 
                  sta $0a                         ; ($09/$0a) point to expanded level data row pointer $0800-$09c3
                  lda TabExLvlDatRowHa,y          ; 
                  sta $0c                         ; ($09/$0a) point to expanded level data row pointer $0a00-$0bc3
                  
                  lda #$00                        ;
                  sta $4f                         ; screen col ($00 - $1b)
                  
.GetDataBytes     lda $1e                         ;  control left/right nybble to process  $00=right
                  lsr a                           ;
                  
                  ldy $53                         ; disk level data offset
                  lda LR_LvlDataSavLod,y          ; disk level data offset
                  bcs .LeftNybble                 ; carry possibly set by .Carry4RightLeft
                  
.RightNybble      and #$0f                        ; isolate right nybble
                  bpl .InitNybbleMark             ; always
                  
.LeftNybble       lsr a                           ; isolate left nybble
                  lsr a                           ;
                  lsr a                           ;
                  lsr a                           ;
                  
                  inc $53                         ; both nybbles processed so point to next byte
                  
.InitNybbleMark   inc $1e                         ; force carry set the next round by .Carry4RightLeft

                  ldy $4f                         ; screen col ($00 - $1b)
                  
                  cmp #LR_TileValid               ; valid byte range is $00-$09
                  bcc .PutDataBytes               ; lower
                  
.SetEmpty         lda #LR_TileEmpty               ; not valid so store a $00
                  
.PutDataBytes     sta ($09),y                     ; unpacked level data ($0800-$09c3)
.PutCtrlBytes     sta ($0b),y                     ; play level control data ($0a00-$0bc3)
                  
                  inc $4f                         ; screen col ($00 - $1b)
                  lda $4f                         ; screen col ($00 - $1b)
                  cmp #$1c                        ; $1b - max 27 cols
                  bcc .GetDataBytes               ; 
                  
                  inc $50                         ; screen row ($00 - $0f)
                  ldy $50                         ; screen row ($00 - $0f)
                  cpy #LR_ScrnMaxRows+1           ; $0f - max 15 rows
                  bcc .ExpandDataI                ; 
                  
.GoCheckLevel     jsr CheckLevel                  ; 
.NoError          bcc InitLevelX                  ; good

                  lda CR_DiskStatus               ; 
                  bpl GoColdStart                 ; 
                  
.LevelError       lda LR_LevelNoDisk              ; 000-049
                  beq GoColdStart                 ;
                  
                  ldx #$00                        ;
                  stx LR_LevelNoDisk              ; 000-049
                  
.ChkGameSpeed     lda LR_CntSpeedLaps             ; lrGameSpeed
                  cmp #LR_CntSpeedMax+1           ; max 9
                  bcs .SetFF                      ;
                  
                  inc LR_CntSpeedLaps             ; increase game speed
                  
.SetFF            dex                             ;
                  jmp InitLevel                   ; restart
                  
InitLevelX        rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
GoColdStart       jmp ColdStart
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ControlDiskOper   pha                             ; ac: 1=load 2=store
                  bpl .ChkGameCtrl                ; 
                  
                  pla                             ; $81/$82
                  and #$7f                        ;
                  pha                             ;
                  
                  jmp DiskRW                      ; 
                  
.ChkGameCtrl      lda LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  lsr a                           ;
                  beq .IsDemo                     ; 
                  
                  jmp DiskRW                      ; 
                  
.IsDemo           pla                             ; 
                  
                  lda LR_LevelNoDisk              ; 000-049
                  cmp #CR_LevelNoMaxDmo           ; max built in demo levels
                  bcc .SetLvlDataPtr              ; 

.RestartDemo      lda #$00                        ;
                  sta LR_LevelNoDisk              ; 000-049

.SetLvlDataPtr    clc                             ; 
                  adc #>TabDemoLvlData            ; .hbu000.
                  sta ..ModCpyDemoLvlH            ; modify load adress
                  
                  ldy #$00                        ;
.CpyDemoLvlData   lda TabDemoLvlData,y            ; 
..ModCpyDemoLvlH  equ *-1
                  sta LR_LvlDataSavLod,y          ;
                  iny                             ;
                  bne .CpyDemoLvlData             ; 
                  
ControlDiskOperX  rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
GetPutHiScores    tax                             ; save action $01=load $02=store
                  
                  lda LR_LevelNoDisk              ; 000-049
                  pha                             ; save actual disk level no
                  
.SetScoreBuffer   inc Mod_GetDiskByte             ; set to LR_ScoreSavLod
                  inc Mod_PutDiskByte             ; 
                  
                  lda #LR_LevelDiskScor           ; disk level 151 contains the high scores
                  sta LR_LevelNoDisk              ; 000-049
                  
                  txa                             ; restore action $01=load $02=store
                  jsr ControlDiskOper             ; 
                  
                  pla                             ; restore disk level no
                  sta LR_LevelNoDisk              ; 000-049
                  
.SetLevelBuffer   dec Mod_GetDiskByte             ; reset to LR_LvlDataSavLod
                  dec Mod_PutDiskByte             ; 
                  
                  ldy #LR_HiScoreIdLen            ; length lr disk id
                  lda #$00                        ;
                  sta $25                         ; 
.ChkDiskID        lda LR_HiScoreDiskId,y          ; DANE BIGHAM
                  sta CR_DiskStatus               ; 
                  and #$7f                        ; to lower
                  eor TabLrDiskId,y               ; dane bigham
                  ora $25                         ;
                  sta $25                         ;
                  dey                             ;
                  bpl .ChkDiskID                  ; 
                  
                  lda $25                         ;
                  beq .ChkDikStatus               ; 
                  
                  lda #$00                        ; 
                  lda #>LR_ScrnHiReDisp           ;
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  
                  lda #$00                        ;
                  sta $50                         ; screen row ($00 - $0f)
                  sta $4f                         ; screen col ($00 - $1b)
                  jsr ClearHiresDisp              ; 
                  
                  lda #HR_YellowCyan              ;
                  jsr ColourLevel                 ; 
                  jsr TextOut                     ; TextOut
                  dc.b $c4 ; D
                  dc.b $c9 ; I
                  dc.b $d3 ; S
                  dc.b $cb ; K
                  dc.b $c5 ; E
                  dc.b $d4 ; T
                  dc.b $d4 ; T
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $c9 ; I
                  dc.b $ce ; N
                  dc.b $a0 ; <blank>
                  dc.b $c4 ; D
                  dc.b $d2 ; R
                  dc.b $c9 ; I
                  dc.b $d6 ; V
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $c9 ; I
                  dc.b $d3 ; S
                  dc.b $8d ; <newline>
                  dc.b $ce ; N
                  dc.b $cf ; O
                  dc.b $d4 ; T
                  dc.b $a0 ; <blank>
                  dc.b $c1 ; A
                  dc.b $a0 ; <blank>
                  dc.b $cc ; L
                  dc.b $cf ; O
                  dc.b $c4 ; D
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $d2 ; R
                  dc.b $d5 ; U
                  dc.b $ce ; N
                  dc.b $ce ; N
                  dc.b $c5 ; E
                  dc.b $d2 ; R
                  dc.b $a0 ; <blank>
                  dc.b $c4 ; D
                  dc.b $c9 ; I
                  dc.b $d3 ; S
                  dc.b $cb ; K
                  dc.b $ae ; .
                  dc.b $00 ; EndOfText
                  
.WaitIRQI         lda #$4b                        ; init IRQ wait
                  sta LR_CountIRQs                ; lrWaitCounter  (inc any IRQ)
                  
.WaitIRQ          lda LR_CountIRQs                ; 
                  bne .WaitIRQ                    ;
                  
                  jmp ColdStart                   ; ColdStart

.Exit             rts                             ; 
                  
.ChkDikStatus     ldx #$03                        ; 
                  lda CR_DiskStatus               ; 
                  bmi .SavDiskStatus              ; bad
                  
                  ldx #$08                        ; 
                  
.SavDiskStatus    stx CR_ScoreOffset              ;

                  lda #LR_DiskMaster              ;
                  ldx LR_HiScoreDiskUM            ;
                  bne GetPutHiScoresX             ; 
                  
                  lda #LR_DiskData                ;
GetPutHiScoresX   rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
DiskRW            lda #$00                        ; GetPutDisk
                  sta SPENA                       ; VIC 2 - $D015 equ Sprite Enable
                  jsr CLALL                       ; KERNAL - $FFE7 equ Close all Files
                  
                  ldx #"0"                        ; 
                  lda LR_LevelNoDisk              ; 000-049
                  and #$0f                        ; isolate right nybble
                  cmp #$0a                        ;
                  bcc .PutSectorHi                ; lower 10
                  
                  ldx #"1"                        ; 
                  sec                             ;
                  sbc #$0a                        ; convert hex 0a-0f  to  bin 00-05
.PutSectorHi      stx Mod__BlkRWSecHi             ; u1:02 0 03 00 - Disk Sector Hi
                  clc                             ;
                  adc #"0"                        ; generate digit 0-9
                  sta Mod__BlkRWSecLo             ; u1:02 0 03 00 - Disk Sector Lo
                  
                  lda LR_LevelNoDisk              ; 000-049
                  lsr a                           ; isolate left nybble
                  lsr a                           ;
                  lsr a                           ;
                  lsr a                           ;
                  clc                             ;
                  adc #$03                        ; disk level data starts at Track 03 Sector 00
                  jsr ConvertHex2Dec              ; Hex2Dec  (1307=100 1308=10 1309=1)
                  
                  lda LR_Digit10                  ; 
                  clc                             ;
                  adc #"0"                        ; convert to string
                  sta Mod__BlkRWTrkHi             ; u1:02 0 03 00 - Disk Track Hi
                  
                  lda LR_Digit1                   ; lrDec1
                  clc                             ;
                  adc #"0"                        ; convert to string
                  sta Mod__BlkRWTrkLo             ; u1:02 0 03 00 - Disk Track Lo
                  
.SetNoFileNam     lda #$00                        ;
                  jsr SETNAM                      ; KERNAL - $FFBD equ Set Filename Parameters
                  
                  lda #$0f                        ; 15, 8 ,15 - command channel
                  ldx #$08                        ;
                  ldy #$0f                        ;
                  jsr SETLFS                      ; KERNAL - $FFBA equ Set Logical File Parameters
                  jsr OPEN                        ; KERNAL - $FFC0 equ Open a Logical File
                  bcs DiskError                   ; 
                  
                  lda #$01                        ; length file name
                  ldx #<FilNamHash                ; adr lo file name - #
                  ldy #>FilNamHash                ; adr hi file name - #
                  jsr SETNAM                      ; KERNAL - $FFBD equ Set Filename Parameters
                  
                  lda #$02                        ; 2 , 8, 2
                  ldx #$08                        ;
                  ldy #$02                        ;
                  jsr SETLFS                      ; KERNAL - $FFBA equ Set Logical File Parameters
                  jsr OPEN                        ; KERNAL - $FFC0 equ Open a Logical File
                  bcs DiskError                   ; 
                  
                  pla                             ; restore mode: $01=load $02=store
                  lsr a                           ;
.ReadBlock        bcs ExecDiskCmdRead             ; 
                  
                  lsr a                           ;
                  bcc .ClearDataI                 ; bad mode
                  
.WriteBlock       jmp ExecDiskCmdWrit             ; 
                  
.ClearDataI       ldy #LR_TileEmpty               ; 
                  tya                             ;
.ClearData        sta LR_ScoreSavLod,y            ; clear high score storage
                  sta LR_LvlDataSavLod,y          ; clear level storage
                  iny                             ;
                  bne .ClearData                  ; 
                  
                  lda #LR_LevelDiskMax            ; 149 blocks to write
                  sta LR_LevelNoDisk              ; 000-049
                  jsr CLALL                       ; KERNAL - $FFE7 equ Close all Files
                  
.PutClearedData   lda #LR_DiskWrite               ; 
                  jsr ControlDiskOper             ; ac: $01=load $02=store
                  
                  dec LR_LevelNoDisk              ; 000-049
                  lda LR_LevelNoDisk              ; 000-049
                  cmp #$ff                        ;
                  bne .PutClearedData             ; 
                  
                  ldy #LR_HiScoreIdLen            ; length lr id
.SetDiskID        lda TabLrDiskId,y               ; lr disk id=dane bigham
                  sta LR_HiScoreDiskId,y          ;
                  dey                             ;
                  bpl .SetDiskID                  ; 
                  
                  iny                             ; $00 - LR_DiskNoData
                  sty LR_HiScoreDiskUM            ; offset indicator store in high score block
                  
.PutClearedScore  lda #LR_DiskWrite               ; 
                  jsr GetPutHiScores              ; ($1100-$11ff) ac: $01=load $02=store 81= 82=
                  
DiskRWX           rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
DiskError         jsr ResetDisk                   ; 
                  jmp StartGraficOut              ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ExecDiskCmdRead   lda #"1"                        ; "1" - load command
                  sta Mod__BlkRWCmd               ; u1=read - u1:02 0 03 00
                  jsr CLRCHN                      ; KERNAL - $FFCC equ Restore Default Devices
                  
                  ldx #$0f                        ; 15 equ command channel
                  jsr CHKOUT                      ; KERNAL - $FFC9 equ Define an Output Channel
                  bcs DiskError                   ; 
                  
                  ldy #$00                        ;
.CmdOut           lda BlkRWCmdString,y            ; command string - u1:02 0 03 00
                  beq .GoChkDiskCC                ; <end of string>
                  jsr CHROUT                      ; KERNAL - $FFD2 equ Output a Character
                  iny                             ;
                  jmp .CmdOut                     ; 
                  
.GoChkDiskCC      jsr CheckDiskCC                 ; 
                  jsr CLRCHN                      ; KERNAL - $FFCC equ Restore Default Devices
                  ldx #$02                        ; 2 equ data channel
                  jsr CHKIN                       ; KERNAL - $FFC6 equ Define an Input Channel
                  bcs DiskError                   ; 
                  
                  jsr CHRIN                       ; KERNAL - $FFCF equ Input a Character
                  
                  ldy #$00                        ;
.ChrIn            jsr CHRIN                       ; KERNAL - $FFCF equ Input a Character
                  sta LR_LvlDataSavLod,y          ;
Mod_GetDiskByte     equ *-1
                  iny                             ;
                  bne .ChrIn                      ; 
                  
ExecDiskCmdReadX  jmp ResetDisk                   ; DiskCloseAll
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ExecDiskCmdWrit   lda #"2"                        ; "2" - store command
                  sta Mod__BlkRWCmd               ; u2=write - u1:02 0 03 00
                  jsr CLRCHN                      ; KERNAL - $FFCC equ Restore Default Devices
                  
                  ldx #$02                        ; 2 equ data channel
                  jsr CHKOUT                      ; KERNAL - $FFC9 equ Define an Output Channel
                  bcs DiskError                   ; 
                  
                  ldy #$00                        ;
.ChrOut           lda LR_LvlDataSavLod,y          ; get a data byte
Mod_PutDiskByte     equ *-1
                  jsr CHROUT                      ; KERNAL - $FFD2 equ Output a Character
                  iny                             ;
                  bne .ChrOut                     ; 
                  
                  jsr CLRCHN                      ; KERNAL - $FFCC equ Restore Default Devices
                  
                  ldx #$0f                        ; 15 equ command channel
                  jsr CHKOUT                      ; KERNAL - $FFC9 equ Define an Output Channel
                  
                  ldy #$00                        ;
.CmdOut           lda BlkRWCmdString,y            ; u2:02_0_tt_ss
                  beq .GoCheckDiskCC              ; <end of string>
                  
                  jsr CHROUT                      ; KERNAL - $FFD2 equ Output a Character
                  iny                             ;
                  jmp .CmdOut                     ; 

.GoCheckDiskCC    jsr CheckDiskCC                 ; 

ExecDiskCmdWritX  jmp ResetDisk                   ; DiskCloseAll
; ------------------------------------------------------------------------------------------------------------- ;
                  dc.b $00 ; 
FilNamHash        dc.b $23 ; #

BlkRWCmdString    dc.b $55 ; u
Mod__BlkRWCmd     dc.b $31 ; 1
                  dc.b $3a ; :
                  dc.b $30 ; 0
                  dc.b $32 ; 2
                  dc.b $20 ; <blank>
                  dc.b $30 ; 0
                  dc.b $20 ; <blank>
Mod__BlkRWTrkHi   dc.b $30 ; 0 - Track
Mod__BlkRWTrkLo   dc.b $33 ; 3 - Track
                  dc.b $20 ; <blank>
Mod__BlkRWSecHi   dc.b $30 ; 0 - Sector
Mod__BlkRWSecLo   dc.b $30 ; 0 - Sector
                  dc.b $0d ; <enter>
                  dc.b $00 ; EndOfCmd
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
CheckDiskCC       jsr CLRCHN                      ; KERNAL - $FFCC equ Restore Default Devices

                  ldx #$0f                        ; 15 - command channel
                  jsr CHKIN                       ; KERNAL - $FFC6 equ Define an Input Channel
                  jsr CHRIN                       ; KERNAL - $FFCF equ Input a Character
                  
                  sta $1e                         ;
                  jsr CHRIN                       ; KERNAL - $FFCF equ Input a Character
                  
                  ora $1e                         ;
                  sta $1e                         ;
.ChrIn            jsr CHRIN                       ; KERNAL - $FFCF equ Input a Character
                  cmp #$0d                        ; <return>
                  bne .ChrIn                      ; 
                  
                  lda $1e                         ; 
                  cmp #$30                        ; "0"
                  beq CheckDiskCCX                ; 
                  
                  jmp ColdStart                   ; error
                  
CheckDiskCCX      rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ResetDisk         lda #$0f                        ; 15 - command channel
                  jsr CLOSE                       ; KERNAL - $FFC3 equ Close a Logical File
                  
                  lda #$02                        ; 2 - data channel
                  jsr CLOSE                       ; KERNAL - $FFC3 equ Close a Logical File
                  
ResetDiskX        jmp CLALL                       ; KERNAL - $FFE7 equ Close all Files
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
CheckLevel        ldy #$0f                        ; max row
                  sty $50                         ; screen row ($00 - $0f)
                  
                  lda #$00                        ;
                  sta SPENA                       ; VIC 2 - $D015 equ Sprite Enable
                  
.SetLevelPtr      lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09                         ; 
                  sta $0b                         ; 
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a                         ; 
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c                         ; 
                  
                  ldy #LR_ScrnMaxCols             ; 
                  sty $4f                         ; screen col ($00 - $1b)
                  
.GetLevelByte     lda ($09),y                     ; unpacked level data ($0800-$09c3)

                  ldx LR_LevelCtrl                ; level display control  $00=prepared copy already at $4000-$5fff
                  beq .ToGoGfxOutPrep             ; 
                  
.ChkXitLadder     cmp #LR_TileLadderXit           ; hidden ladder
                  bne .ChkGold                    ; 
                  
                  ldx LR_NumXitLadders            ; # hidden ladders
                  cpx #CR_NumXitLdrsMax           ; max 45
                  bcs .SetEmptyByte               ; 
                  
.IncXitLadder     inc LR_NumXitLadders            ; count  - inc no of hidden ladders

.PutXitLadderAdr  inx                             ;
                  lda $50                         ; screen row ($00 - $0f)
                  sta CR_TabXitLdrRow,x           ; adr row hidden ladders tab
                  tya                             ;
                  sta CR_TabXitLdrCol,x           ; adr col hidden ladder tab
.SetEmptyByte     lda #$00                        ; blank for hidden ladder/enemy
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  sta ($0b),y                     ; play level control data ($0a00-$0bc3)
.ToGoGfxOutPrep   beq .GoGfxOutPrep               ; always

.ChkGold          cmp #LR_TileGold                ; 
                  bne .ChkEnemy                   ; 
                  
                  inc LR_Gold2Get                 ; count  - inc no of gold to get
                  bne .GoGfxOutPrep               ; always
                  
.ChkEnemy         cmp #LR_TileEnemy               ;
                  bne .ChkLodeRunner              ;
                  
                  ldx LR_EnmyNo                   ; number of enemies
                  cpx #LR_EnmyNoMax               ; max 5 enemies
                  bcs .SetEmptyByte               ; 
                  
.IncEnemy         inc LR_NoEnemy2Move             ; count - inc no of enemies to move
                  inc LR_EnmyNo                   ; count - inc no of enemies
                  
.PutEnemyData     inx                             ;
                  tya                             ;
.PutEnemyCol      sta LR_TabEnemyCol,x            ; adr col enemy
                  lda $50                         ; screen row ($00 - $0f)
.PutEnemyRow      sta LR_TabEnemyRow,x            ; adr row enemy

                  lda #$00                        ; 
.PutEnemyGold     sta LR_TabEnemyGold,x           ; enemy has gold tab
.PutEnemyNo       sta LR_TabEnemySprNo,x          ; actual enemy sprite number

                  lda #$02                        ; center to
                  sta LR_TabEnemyPosLR,x          ; enemy pos on image left/right tab
                  sta LR_TabEnemyPosUD,x          ; enemy pos on image up/down tab
                  
.ClrEnemyGfx      lda #$00                        ; 
                  sta ($0b),y                     ; play level control data ($0a00-$0bc3)
                  lda #$00                        ;
                  jsr ImageOut2Prep               ; output to preparation screen first ($4000)
                  
                  lda #LR_TileEnemy               ; 
.SetEnemyGfx      bne .GoGfxOutPrep               ; always
                  
.GoSetLevelPtr    bpl .SetLevelPtr                ; 
.GoGetLevelByte   bpl .GetLevelByte               ; 

.ChkLodeRunner    cmp #LR_TileLR                  ; 
                  bne .ChkTrap                    ; 
                  
                  ldx $03                         ; adr col lode runner
.ChkLodeRrExist   bpl .SetEmptyByte               ; one lr found already so blank out this one
                  
.SetLodeRrCol     sty $03                         ; adr col lode runner

                  ldx $50                         ; screen row ($00 - $0f)
.SetLodeRrRow     stx $04                         ; actual row lode runner
                  
.SetLodeRrCenter  ldx #$02                        ; center
                  stx $05                         ; lr pos on image left/right
                  stx $06                         ; lr pos on image up/down
                  
.SetLodeRrSprtNo  ldx #$08                        ;
                  stx $07                         ; lr sprite number
                  
                  lda #LR_TileEmpty               ;
                  sta ($0b),y                     ; clear lr in play level control data ($0a00-$0bc3)
                  lda #$00                        ;
                  jsr ImageOut2Prep               ; output to preparation screen first ($4000)
                  
                  lda #NoSprite_RuRi00            ; .hbu008.
.SetLodeRrGfx     bne .GoGfxOutPrep               ; always
                  
.ChkTrap          cmp #LR_TileWallTrap            ; 
                  bne .GoGfxOutPrep               ; 
                  
                  lda #LR_TileWallSoft            ; 
                  
.GoGfxOutPrep     jsr ImageOut2Prep               ; output to preparation screen first ($4000)

.SetPrevCol       dec $4f                         ; next screen col  (00-1b) bottom up
                  ldy $4f                         ; screen col ($00 - $1b)
                  bpl .GoGetLevelByte             ; 
                  
.SetPrevRow       dec $50                         ; next screen row  (00-0f) bottom up
                  ldy $50                         ; screen row ($00 - $0f)
                  bpl .GoSetLevelPtr              ; 
                  
                  lda LR_LevelCtrl                ; level display control  $00=prepared copy already at $4000-$5fff
                  beq ScreenPrep2Disp             ; copy prepared hires screen data to display screen
                  
                  lda $03                         ; adr col lode runner
                  bpl GoResetEnmyLodeR            ; lode runner tile found
                  
.SetError         sec                             ; error - no lode runner tile found
CheckLevelX       rts                             ; cldoErrX
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ScreenPrep2Disp   lda CR_LevelColor               ; lrNewLevelColor
                  jsr ColourLevel                 ; 
                  
.Init             lda #>LR_ScrnHiReDisp           ; to:   display hires screen
                  sta $12                         ;
                  lda #>LR_ScrnHiRePrep           ; from: prepare hires screen for direct output
                  sta $10                         ;
                  
                  lda #$00                        ;
                  sta $11                         ;
                  sta $0f                         ;
                  tay                             ;
.Copy             lda ($0f),y                     ; from 4000 - hidden screen
                  sta ($11),y                     ; to 2000 - display screen
                  iny                             ;
                  bne .Copy                       ; 
                  
                  inc $12                         ;
                  inc $10                         ;
                  
                  ldx $10                         ;
                  cpx #>(LR_ScrnHiRePrep + $2000) ; end of screen data $5fff reached
                  bcc .Copy                       ; 
                  
.SetNoError       clc                             ; no errors
ScreenPrep2DispX  rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ResetEnmyLodeR    lda #>LR_ScrnHiRePrep           ; 
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  jsr BaseLines                   ; 
                  jsr ScreenPrep2Disp             ; copy prepared hires screen data to display screen
                  
                  lda #>LR_ScrnHiReDisp           ;
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  
                  bne DoResetEnmyLodeR            ; always
                  
GoResetEnmyLodeR  jmp ResetEnmyLodeR              ;

                  beq ResetEnmyLodeR              ; 
                  
DoResetEnmyLodeR  ldy #LR_ScrnMaxRows             ; 
                  sty $50                         ; screen row ($00 - $0f)
                  
.SetLevelDataPtr  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09                         ; 
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a                         ; 
                  
.SetMaxCols       ldy #LR_ScrnMaxCols             ; $1b - max 27 cols
                  sty $4f                         ; screen col ($00 - $1b)
.GetData          lda ($09),y                     ; unpacked level data ($0800-$09c3)
.ChkLodeRunner    cmp #LR_TileLR                  ;
                  beq .SetBlank                   ; 
                  
.ChkEnemy         cmp #LR_TileEnemy               ;
                  bne .NextOutCol                 ; 
                  
.SetBlank         lda #LR_TileEmpty               ; blank substitution
                  jsr ImageOut2Prep               ; output to preparation screen first ($4000)
                  
.NextOutCol       dec $4f                         ; screen col ($00 - $1b)
                  ldy $4f                         ; screen col ($00 - $1b)
                  bpl .GetData                    ; 
                  
.NextOutRow       dec $50                         ; screen row ($00 - $0f)
                  ldy $50                         ; screen row ($00 - $0f)
                  bpl .SetLevelDataPtr            ; 
                  
                  clc                             ; no errors
ResetEnmyLodeRX   rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ChkNewHighScore   jsr CheckNewChamp               ; 

                  lda LR_ScoreLo                  ; 
                  ora LR_ScoreMidLo               ; 
                  ora LR_ScoreMidHi               ; 
                  ora LR_ScoreHi                  ; 
                  beq ChkNewHighScoreX            ; no scores if zero
                  
                  lda #LR_DiskRead                ;
                  jsr GetPutHiScores              ; ($1100-$11ff) ac: $01=load $02=store 81= 82=
                  beq ChkNewHighScoreX            ; 
                  
                  ldy #$00                        ;
.CopyScoreBlock   lda LR_ScoreSavLod,y            ; 
                  sta LR_HiScoreOld,y             ;
                  iny                             ;
                  bne .CopyScoreBlock             ; 
                  
                  ldy #$01                        ; start with entry 1
.Checks           jsr GetRowOffset                ;

                  txa                             ;
                  clc                             ;
                  adc CR_ScoreOffset              ;
                  tax                             ;
                  
.ChkLevel         lda LR_LevelNoGame              ; level reached - 001-050
                  cmp CR_HiScoreLevel - CR_HiScoreNamLen,x
                  bcc .NextEntry                  ; 
                  bne SetNewHighScore             ;
                  
.ChkScoreHi       lda LR_ScoreHi                  ; score reached
                  cmp CR_HiScoreHi - CR_HiScoreNamLen,x
                  bcc .NextEntry                  ; 
                  bne SetNewHighScore             ;
                  
.ChkScoreMidHi    lda LR_ScoreMidHi               ; 
                  cmp CR_HiScoreMidHi - CR_HiScoreNamLen,x
                  bcc .NextEntry                  ; 
                  bne SetNewHighScore             ;
                  
.ChkScoreMidLo    lda LR_ScoreMidLo               ; 
                  cmp CR_HiScoreMidLo - CR_HiScoreNamLen,x
                  bcc .NextEntry                  ; 
                  bne SetNewHighScore             ;
                  
.ChkScoreLo       lda LR_ScoreLo                  ; 
                  cmp CR_HiScoreLo - CR_HiScoreNamLen,x
                  bcc .NextEntry                  ; 
                  bne SetNewHighScore             ;
                  
.NextEntry        iny                             ; 
                  cpy #$0b                        ; max 10 entries
                  bcc .Checks                     ; lower - so next
                  
ChkNewHighScoreX  rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
SetNewHighScore   cpy #LR_HiScoreMaxIDs           ; no insertion for last entry
                  beq .Insert                     ; simply overwrite
                  
                  sty $29                         ; row offset of new entry
                  
                  ldy #LR_HiScoreMaxIDs-1         ; $0a - max entries to move
.MoveDownI        jsr GetRowOffset                ;

                  lda CR_ScoreOffset              ;
                  clc                             ;
                  adc #$05                        ;
                  sta $22                         ;
                  
                  sta ..ModMoveDownLo             ;
.MoveDown         lda LR_ScoreSavLod,x            ;
                  sta LR_ScoreSavLod,x            ;
..ModMoveDownLo   equ *-2
                  inx                             ;
                  dec $22                         ;
                  bne .MoveDown                   ;
                  
                  cpy $29                         ; row offset of new entry
                  beq .Insert                     ;
                  
                  dey                             ; number of new entry not reached
                  bne .MoveDownI                  ; move next entry
                  
.Insert           jsr GetRowOffset                ;

                  lda CR_ScoreOffset              ;
                  sta CR_InputBufPtr              ;
                  
.ClrName          lda #$a0                        ; <blank>
                  sta CR_HiScoreNam,x             ;
                  inx                             ;
                  dec CR_InputBufPtr              ;
                  bne .ClrName                    ;
                  
.SetLevel         lda LR_LevelNoGame              ; 001-050
                  sta CR_HiScoreLevel-CR_HiScoreNamLen,x
                  
.SetScore         lda LR_ScoreHi                  ; 
                  sta CR_HiScoreHi-CR_HiScoreNamLen,x
                  lda LR_ScoreMidHi               ; 
                  sta CR_HiScoreMidHi-CR_HiScoreNamLen,x
                  lda LR_ScoreMidLo               ; 
                  sta CR_HiScoreMidLo-CR_HiScoreNamLen,x
                  lda LR_ScoreLo                  ; 
                  sta CR_HiScoreLo-CR_HiScoreNamLen,x
                  
                  sty $39                         ;
                  jsr ShowHighScores              ; ShowScores
                  
                  lda $39                         ;
                  clc                             ;
                  adc #$04                        ;
                  sta $50                         ; screen row ($00 - $0f)
                  
                  ldx #$40                        ;
                  lda #$07                        ; column
                  ldy CR_DiskStatus               ; 
                  bmi .SetColumn                  ; bad
                  
                  sec                             ;
                  sbc #$03                        ; column-3
                  ldx #$c0                        ;
                  
.SetColumn        sta $4f                         ; screen col ($00 - $1b)

                  lda CR_ScoreOffset              ;
                  sta CR_InputBufMax              ;
                  txa                             ;
                  jsr InputControlSpec            ; 
                  
                  ldy $39                         ;
                  jsr GetRowOffset                ;                  
                  stx ..ModSetInputLo             ;
                  
                  ldx CR_ScoreOffset              ;
                  dex                             ;
.GetInput         lda CR_InputBuf,x               ;
                  sta LR_ScoreSavLod,x            ;
..ModSetInputLo   equ *-2
                  dex                             ;
                  bpl .GetInput                   ;
                  
                  ldy #$00                        ;
.Score2New        lda LR_ScoreSavLod,y            ;
                  sta LR_HiScoreNew,y             ;
                  iny                             ;
                  bne .Score2New                  ;
                  
.GetDiskScore     lda #LR_DiskRead                ;
                  jsr GetPutHiScores              ; ($1100-$11ff) ac: $01=load $02=store 81= 82=
                  beq .BadWaitUser                ;
                  
                  ldy #$00                        ;
.Score2Old        lda LR_ScoreSavLod,y            ;
                  cmp LR_HiScoreOld,y             ;
                  bne .ScoreFromOldI              ;
                  
                  iny                             ;
                  bne .Score2Old                  ;
                  
.ScoreFromNew     lda LR_HiScoreNew,y             ;
                  sta LR_ScoreSavLod,y            ;
                  iny                             ;
                  bne .ScoreFromNew               ;

.PutDiskScore     lda #LR_DiskWrite               ;
                  jsr GetPutHiScores              ; ($1100-$11ff) ac: $01=load $02=store 81= 82=
                  
.BadWaitUser      jmp Wait4User                   ; 

.ScoreFromOldI    ldy #$00                        ; 
.ScoreFromOld     lda LR_HiScoreOld,y             ;
                  sta LR_ScoreSavLod,y            ;
                  iny                             ;
                  bne .ScoreFromOld               ;
                  
SetNewHighScoreX  jmp Wait4User                   ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ShowHighScores    jsr ClearHiresDisp              ; 
                  lda #HR_YellowCyan              ;
                  jsr ColourLevel                 ; 
                  
                  lda #>LR_ScrnHiReDisp           ;
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  
                  lda #$00                        ;
                  sta $4f                         ; screen col ($00 - $1b)
                  sta $50                         ; screen row ($00 - $0f)
                  jsr TextOut                     ; TextOut
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $c3 ; C
                  dc.b $c8 ; H
                  dc.b $c1 ; A
                  dc.b $cd ; M
                  dc.b $d0 ; P
                  dc.b $c9 ; I
                  dc.b $cf ; O
                  dc.b $ce ; N
                  dc.b $d3 ; S
                  dc.b $c8 ; H
                  dc.b $c9 ; I
                  dc.b $d0 ; P
                  dc.b $a0 ; <blank>
                  dc.b $cc ; L
                  dc.b $cf ; O
                  dc.b $c4 ; D
                  dc.b $c5 ; E
                  dc.b $d2 ; R
                  dc.b $d5 ; U
                  dc.b $ce ; N
                  dc.b $ce ; N
                  dc.b $c5 ; E
                  dc.b $d2 ; R
                  dc.b $a0 ; <blank>
                  dc.b $8d ; <newline>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $c8 ; H
                  dc.b $c9 ; I
                  dc.b $c7 ; G
                  dc.b $c8 ; H
                  dc.b $a0 ; <blank>
                  dc.b $d3 ; S
                  dc.b $c3 ; C
                  dc.b $cf ; O
                  dc.b $d2 ; R
                  dc.b $c5 ; E
                  dc.b $d3 ; S
                  dc.b $8d ; <newline>
                  dc.b $8d ; <newline>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $ce ; N
                  dc.b $c1 ; A
                  dc.b $cd ; M
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $cc ; L
                  dc.b $c5 ; E
                  dc.b $d6 ; V
                  dc.b $c5 ; E
                  dc.b $cc ; L
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $d3 ; S
                  dc.b $c3 ; C
                  dc.b $cf ; O
                  dc.b $d2 ; R
                  dc.b $c5 ; E
                  dc.b $8d ; <newline>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $a0 ; <blank>
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $a0 ; <blank>
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $8d ; <newline>
                  dc.b $00 ; EndOfText
                  
                  lda #$01                        ;
                  sta $28                         ; actual rank
                  
.ShowScores       cmp #$0a                        ; 10
                  bne .Not10                      ;
                  
                  lda #$01                        ; rank 10  - start with "1"
                  jsr PrepareDigitOut             ; 
                  
                  lda #$00                        ;
                  jsr PrepareDigitOut             ;
                  jmp .SepRankName                ; seperator dot
                  
.Not10            lda #$a0                        ; rank 1-9 - start with " "
                  jsr PrepareChrOut               ;
                  
                  lda $28                         ; actual rank
                  jsr PrepareDigitOut             ; 
                  
.SepRankName      lda #$ae                        ; "."
                  jsr PrepareChrOut               ;
                  
                  ldy #$01                        ;
                  lda CR_DiskStatus               ; 
                  bpl .SetBlankCount1             ; good
                  
                  ldy #$04                        ;
                  
.SetBlankCount1   sty CR_InputBufPtr              ;

.FourOrOneBlank1  lda #$a0                        ; <blank>
                  jsr PrepareChrOut               ;
                  
                  dec CR_InputBufPtr              ;
                  bne .FourOrOneBlank1            ;
                  
                  ldy $28                         ; actual rank
                  jsr GetRowOffset                ;
                  
                  stx $29                         ; score board offset
                  lda CR_ScoreOffset              ;
                  sta CR_InputBufPtr              ;
                  
                  clc                             ;
                  adc $29                         ; score board offset
                  tay                             ;
                  lda LR_ScoreSavLod,y            ;
                  bne .EntryOut                   ;
                  
                  jmp .NewLine                    ;
                  
.EntryOut         ldy $29                         ; score board offset
                  lda LR_ScoreSavLod,y            ;
                  jsr PrepareChrOut               ;
                  
                  inc $29                         ; score board offset
                  dec CR_InputBufPtr              ;
                  bne .EntryOut                   ;
                  
                  ldy #$02                        ;
                  lda CR_DiskStatus               ; 
                  bpl .SetBlankCount2             ; good
                  
                  ldy #$04                        ;
                  
.SetBlankCount2   sty CR_InputBufPtr              ;

.FourOrOneBlank2  lda #$a0                        ; <blank>
                  jsr PrepareChrOut               ;
                  
                  dec CR_InputBufPtr              ;
                  bne .FourOrOneBlank2            ;
                  
                  ldy $29                         ; score board offset
.GetLevel         lda CR_HiScoreLevel-CR_HiScoreNamLen,y
                  jsr ConvertHex2Dec              ; Hex2Dec  (1307=100 1308=10 1309=1)
                  
.PutLevel         lda LR_Digit100                 ; 
                  jsr PrepareDigitOut             ; 
                  lda LR_Digit10                  ; 
                  jsr PrepareDigitOut             ; 
                  lda LR_Digit1                   ; 
                  jsr PrepareDigitOut             ; 
                  
.TwoBlanks        jsr TextOut                     ; TextOut
                  dc.b $a0                        ; <blank>
                  dc.b $a0                        ; <blank>
                  dc.b $00                        ; EndOfText
                  
.ScoreOut         ldy $29                         ; score board offset
                  lda CR_HiScoreHi-CR_HiScoreNamLen,y
                  jsr SplitScoreDigit             ;
                  
                  lda LR_Digit10                  ; 
                  jsr PrepareDigitOut             ; 
                  lda LR_Digit1                   ; 
                  jsr PrepareDigitOut             ; 
                  
                  ldy $29                         ; score board offset
                  lda CR_HiScoreMidHi-CR_HiScoreNamLen,y
                  jsr SplitScoreDigit             ;
                  
                  lda LR_Digit10                  ; 
                  jsr PrepareDigitOut             ; 
                  lda LR_Digit1                   ; 
                  jsr PrepareDigitOut             ;
                  
                  ldy $29                         ; score board offset
                  lda CR_HiScoreMidLo-CR_HiScoreNamLen,y
                  jsr SplitScoreDigit             ;
                  
                  lda LR_Digit10                  ; 
                  jsr PrepareDigitOut             ; 
                  lda LR_Digit1                   ; 
                  jsr PrepareDigitOut             ;
                  
                  ldy $29                         ; score board offset
                  lda CR_HiScoreLo-CR_HiScoreNamLen,y
                  jsr SplitScoreDigit             ;
                  
                  lda LR_Digit10                  ; 
                  jsr PrepareDigitOut             ; 
                  lda LR_Digit1                   ; 
                  jsr PrepareDigitOut             ;
                  
.NewLine          jsr SetNewLine                  ; 

                  inc $28                         ;
                  lda $28                         ;
                  cmp #LR_HiScoreMaxIDs+1         ;
                  bcs .GoOutTheBest               ;
                  
                  jmp .ShowScores                 ;
                  
.GoOutTheBest     lda #LR_BasLinRowStat           ; 
ShowHighScoresX   jmp OutTheBest                  ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
GetRowOffset      lda CR_DiskStatus               ; 
                  bpl .GetBad                     ; good
                  
.GetGood          ldx TabHiScRowPtrOk-1,y         ;                  
                  rts                             ;

.GetBad           ldx TabHiScRowPtrBad-1,y        ;
GetRowOffsetX     rts
; ------------------------------------------------------------------------------------------------------------- ;
TabHiScRowPtrOk   dc.b $00
                  dc.b $08
                  dc.b $10
                  dc.b $18
                  dc.b $20
                  dc.b $28
                  dc.b $30
                  dc.b $38
                  dc.b $40
                  dc.b $48
; ------------------------------------------------------------------------------------------------------------- ;
TabHiScRowPtrBad  dc.b $00
                  dc.b $0d
                  dc.b $1a
                  dc.b $27
                  dc.b $34
                  dc.b $41
                  dc.b $4e
                  dc.b $5b
                  dc.b $68
                  dc.b $75
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
OutTheBest        sta $50
                  lda CR_DiskStatus
                  bmi OutTheBestX                 ; bad
                  
                  lda CR_BestHi                   ; 
                  ora CR_BestMiHi                 ; 
                  ora CR_BestMiLo                 ;
                  ora CR_BestLo                   ;
                  beq OutTheBestX                 ; nobody passed the last level so far
                  
                  ldx #$00                        ;
                  stx CR_Work                     ;
                  stx $4f                         ; screen col ($00 - $1b)
                  stx $1e                         ;
                  
                  lda #>LR_ScrnHiReDisp           ;
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  
.HeroesMsgOut     lda CR_BestMsg,x                ; 
                  pha                             ;
                  
                  eor #$a0                        ; <blank>
                  ora $1e                         ;
                  sta $1e                         ;
                  
                  pla                             ;
                  jsr PrepareChrOut               ;
                  
                  inc CR_Work                     ;
                  ldx CR_Work                     ;
                  cpx #CR_BestMsgLen              ;
                  bcc .HeroesMsgOut               ; lower
                  
                  lda $1e                         ;
                  beq OutTheBestX                 ;
                  
                  inc $4f                         ; screen col ($00 - $1b)
                  
.HeroesScoreOut   lda CR_BestHi                   ;
                  jsr SplitScoreOut               ;
                  
                  lda CR_BestMiHi                 ;
                  jsr SplitScoreOut               ;
                  
                  lda CR_BestMiLo                 ;
                  jsr SplitScoreOut               ;
                  
                  lda CR_BestLo                   ;
                  jsr SplitScoreOut               ;
                  
OutTheBestX       rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TabHiScRowPtr_    dc.b $00                       ; not used
                  dc.b $00
                  dc.b $08
                  dc.b $10
                  dc.b $18
                  dc.b $20
                  dc.b $28
                  dc.b $30
                  dc.b $38
                  dc.b $40
                  dc.b $48
; ------------------------------------------------------------------------------------------------------------- ;
; GetKeySubst     Function: Substitute a value for allowed keys
;                 Parms   : ac=key value
;                 Returns : ac=key substitution with bit7 set
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
GetKeySubst       cmp #$82                        ;
                  bne .GetSubst                   ;
                  
                  lda #$07                        ;
                  
.GetSubst         tay                             ;
                  lda TabKeySubst,y               ;
                  ora #$80                        ;
                  
GetKeySubstX      rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TabKeySubst       equ *
KeyMatrixColBit0  dc.b $00 ; $00 - DELETE 
                  dc.b $0d ; $01 - RETURN
                  dc.b $15 ; $02 - CRSR_R
                  dc.b $ff ; $03 - F7
                  dc.b $ff ; $04 - F1
                  dc.b $ff ; $05 - F3
                  dc.b $ff ; $06 - F5
                  dc.b $08 ; $07 - CRSR_D
                  
KeyMatrixColBit1  dc.b $33 ; $08 - 3
                  dc.b $57 ; $09 - W
                  dc.b $41 ; $0a - A
                  dc.b $34 ; $0b - 4
                  dc.b $5a ; $0c - Z
                  dc.b $53 ; $0d - S
                  dc.b $45 ; $0e - E
                  dc.b $ff ; $0f - LSHIFT
                  
KeyMatrixColBit2  dc.b $35 ; $10 - 5
                  dc.b $52 ; $11 - R
                  dc.b $44 ; $12 - D
                  dc.b $36 ; $13 - 6
                  dc.b $43 ; $14 - C
                  dc.b $46 ; $15 - F
                  dc.b $54 ; $16 - T
                  dc.b $58 ; $17 - X
                  
KeyMatrixColBit3  dc.b $37 ; $18 - 7
                  dc.b $59 ; $19 - Y
                  dc.b $47 ; $1a - G
                  dc.b $38 ; $1b - 8
                  dc.b $42 ; $1c - B
                  dc.b $48 ; $1d - H
                  dc.b $55 ; $1e - U
                  dc.b $56 ; $1f - V
                  
KeyMatrixColBit4  dc.b $39 ; $20 - 9
                  dc.b $49 ; $21 - I
                  dc.b $4a ; $22 - J
                  dc.b $30 ; $23 - 0
                  dc.b $4d ; $24 - M
                  dc.b $4b ; $25 - K
                  dc.b $4f ; $26 - O
                  dc.b $4e ; $27 - N
                  
KeyMatrixColBit5  dc.b $2b ; $28 - +
                  dc.b $50 ; $29 - P
                  dc.b $4c ; $2a - L
                  dc.b $2d ; $2b - -
                  dc.b $2e ; $2c - .
                  dc.b $3a ; $2d - :
                  dc.b $ff ; $2e - @
                  dc.b $2c ; $2f - ,
                  
KeyMatrixColBit6  dc.b $5c ; $30 - LIRA
                  dc.b $2a ; $31 - *
                  dc.b $3b ; $32 - ;
                  dc.b $ff ; $33 - HOME
                  dc.b $ff ; $34 - RSHIFT
                  dc.b $3d ; $35 - =
                  dc.b $ff ; $36 - ^
                  dc.b $2f ; $37 - /
                  
KeyMatrixColBit7  dc.b $31 ; $38 - 1
                  dc.b $ff ; $39 - <-
                  dc.b $ff ; $3a - CTRL
                  dc.b $32 ; $3b - 2
                  dc.b $20 ; $3c - SPACE
                  dc.b $ff ; $3d - C=
                  dc.b $51 ; $3e - Q
                  dc.b $ff ; $3f - STOP
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
CheckNewChampXX   clc                             ; shortcut
                  rts                             ;

CheckNewChamp     jsr ChkUniquePlayId             ; 
                  
                  lda CR_DiskStatus               ; 
                  bmi CheckNewChampXX             ; bad
                  
                  lda LR_LevelNoGame              ; 001-050
                  cmp #CR_LevelNoMax              ; 051
                  bcc CheckNewChampXX             ; lower
                  
                  jsr ClearHiresDisp              ; 
                  
                  lda #>LR_ScrnHiReDisp           ;
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  
                  lda #HR_YellowCyan              ;
                  jsr ColourLevel                 ; 
                  
                  lda #$00                        ;
                  sta $4f                         ; screen col ($00 - $1b)
                  sta $50                         ; screen row ($00 - $0f)
                  jsr TextOut                     ; TextOut
                  dc.b $8d ; <newline>
                  dc.b $8d ; <newline>
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $a0 ; <blank>
                  dc.b $c3 ; C
                  dc.b $cf ; O
                  dc.b $ce ; N
                  dc.b $c7 ; G
                  dc.b $d2 ; R
                  dc.b $c1 ; A
                  dc.b $d4 ; T
                  dc.b $d5 ; U
                  dc.b $cc ; L
                  dc.b $c1 ; A
                  dc.b $d4 ; T
                  dc.b $c9 ; I
                  dc.b $cf ; O
                  dc.b $ce ; N
                  dc.b $d3 ; D
                  dc.b $a0 ; <blank>
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $8d ; <newline>
                  dc.b $8d ; <newline>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $d9 ; Y
                  dc.b $cf ; O
                  dc.b $d5 ; U
                  dc.b $a0 ; <blank>
                  dc.b $c1 ; A
                  dc.b $d2 ; R
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $c1 ; A
                  dc.b $8d ; <newline>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $cc ; L
                  dc.b $cf ; O
                  dc.b $c4 ; D
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $d2 ; R
                  dc.b $d5 ; U
                  dc.b $ce ; N
                  dc.b $ce ; N
                  dc.b $c5 ; E
                  dc.b $d2 ; R
                  dc.b $a0 ; <blank>
                  dc.b $c3 ; C
                  dc.b $c8 ; H
                  dc.b $c1 ; A
                  dc.b $cd ; M
                  dc.b $d0 ; P
                  dc.b $c9 ; I
                  dc.b $cf ; O
                  dc.b $ce ; N
                  dc.b $8d ; <newline>
                  dc.b $8d ; <newline>
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $a0 ; <blank>
                  dc.b $c3 ; C
                  dc.b $cf ; O
                  dc.b $ce ; N
                  dc.b $c7 ; G
                  dc.b $d2 ; R
                  dc.b $c1 ; A
                  dc.b $d4 ; T
                  dc.b $d5 ; U
                  dc.b $cc ; L
                  dc.b $c1 ; A
                  dc.b $d4 ; T
                  dc.b $c9 ; I
                  dc.b $cf ; O
                  dc.b $ce ; N
                  dc.b $d3 ; S
                  dc.b $a0 ; <blank>
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $ad ; -
                  dc.b $00 ; EndOfText
                  
.ChkOldSavHi      lda CR_BestHi                   ; saved old best score 
                  cmp LR_ScoreHi                  ; 
                  beq .ChkOldSavMidHi             ; 
                  bcs .GoSecPassword              ; 
                  
                  jmp .SuperMsgColorI             ; 
                  
.ChkOldSavMidHi   lda CR_BestMiHi                 ; 
                  cmp LR_ScoreMidHi               ; 
                  beq .ChkOldSavMidLo             ; 
                  bcs .GoSecPassword              ; 
                  
                  jmp .SuperMsgColorI             ; 
                  
.ChkOldSavMidLo   lda CR_BestMiLo                 ; 
                  cmp LR_ScoreMidLo               ; 
                  beq .ChkOldSavLo                ; 
                  bcs .GoSecPassword              ; 
                  
                  jmp .SuperMsgColorI             ; 
.ChkOldSavLo      lda CR_BestLo                   ; 
                  cmp LR_ScoreLo                  ; 
                  bcc .SuperMsgColorI             ; 
                  
.GoSecPassword    jmp .SecPassword                ; 

.SuperMsgColorI   lda #$20                        ; 
                  lda #HR_GreenGreen              ;
                  ldx #$a0                        ;
.SuperMsgColor    sta LR_ScrnMultColor+$00c8,x    ;
                  dex                             ;
                  bne .SuperMsgColor              ;
                  
                  lda #$00                        ;
                  sta $4f                         ; screen col ($00 - $1b)
                  lda #$09                        ;
                  sta $50                         ; screen row ($00 - $0f)
                  jsr TextOut                     ; TextOut
                  dc.b $d9 ; Y
                  dc.b $cf ; O
                  dc.b $d5 ; U
                  dc.b $d2 ; R
                  dc.b $a0 ; <blank>
                  dc.b $d3 ; S
                  dc.b $c3 ; C
                  dc.b $cf ; O
                  dc.b $d2 ; R
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $c9 ; I
                  dc.b $d3 ; S
                  dc.b $a0 ; <blank>
                  dc.b $d4 ; T
                  dc.b $c8 ; H
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $c2 ; B
                  dc.b $c5 ; E
                  dc.b $d3 ; S
                  dc.b $d4 ; T
                  dc.b $a0 ; <blank>
                  dc.b $c5 ; E
                  dc.b $d6 ; V
                  dc.b $c5 ; E
                  dc.b $d2 ; R
                  dc.b $8d ; <newline>
                  dc.b $8d ; <newline>
                  dc.b $a0 ; <blank>
                  dc.b $c5 ; E
                  dc.b $ce ; N
                  dc.b $d4 ; T
                  dc.b $c5 ; E
                  dc.b $d2 ; R
                  dc.b $a0 ; <blank>
                  dc.b $d9 ; Y
                  dc.b $cf ; O
                  dc.b $d5 ; U
                  dc.b $d2 ; R
                  dc.b $a0 ; <blank>
                  dc.b $d6 ; V
                  dc.b $c9 ; I
                  dc.b $c3 ; C
                  dc.b $d4 ; T
                  dc.b $cf ; O
                  dc.b $d2 ; R
                  dc.b $d9 ; Y
                  dc.b $a0 ; <blank>
                  dc.b $cd ; M
                  dc.b $c5 ; E
                  dc.b $d3 ; S
                  dc.b $d3 ; S
                  dc.b $c1 ; A
                  dc.b $c7 ; G
                  dc.b $c5 ; E
                  dc.b $8d ; <newline>
                  dc.b $8d ; <newline>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $be ; >
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $bc ; <
                  dc.b $00 ; EndOfText
                  
                  lda #$04                        ;
                  sta $4f                         ; screen col ($00 - $1b)
                  
                  lda #CR_BestMsgLen              ;
                  sta CR_InputBufMax              ;
                  jsr InputControl                ;
                  beq .SecPassword                ; 
                  
                  ldx #CR_BestMsgLen              ; 
.CpyMessage       lda CR_InputBuf,x               ; copy msg to high score data
                  sta CR_BestMsg,x                ; 
                  dex                             ;
                  bpl .CpyMessage                 ; 
                  
.CpyScore         lda LR_ScoreLo                  ; copy score to high score data
                  sta CR_BestLo                   ;
                  lda LR_ScoreMidLo               ; 
                  sta CR_BestMiLo                 ;
                  lda LR_ScoreMidHi               ; 
                  sta CR_BestMiHi                 ;
                  lda LR_ScoreHi                  ; 
                  sta CR_BestHi                   ;
                  
.SetScore         lda #LR_DiskWrite               ; write back high scoreblock
                  jsr GetPutHiScores              ; ac: $01=load $02=store 81= 82=
                  
.SecPassword      lda #$09                        ; "your score ..."
                  jsr ClearTheRow                 ;
                  
                  lda #$0b                        ; "Enter your ..."
                  jsr ClearTheRow                 ;
                  
                  lda #$0d                        ; <victory msg>
                  jsr ClearTheRow                 ;
                  
                  lda #$0a                        ;
                  sta $50                         ; screen row ($00 - $0f)
                  jsr TextOut                     ; TextOut
                  dc.b $8d ; <newline>
                  dc.b $c4 ; D
                  dc.b $cf ; O
                  dc.b $a0 ; <blank>
                  dc.b $d9 ; Y
                  dc.b $cf ; O
                  dc.b $d5 ; U
                  dc.b $a0 ; <blank>
                  dc.b $d7 ; W
                  dc.b $c1 ; A
                  dc.b $ce ; N
                  dc.b $d4 ; T
                  dc.b $a0 ; <blank>
                  dc.b $d4 ; T
                  dc.b $cf ; O
                  dc.b $a0 ; <blank>
                  dc.b $cb ; K
                  dc.b $ce ; N
                  dc.b $cf ; O
                  dc.b $d7 ; W
                  dc.b $a0 ; <blank>
                  dc.b $d9 ; Y
                  dc.b $cf ; O
                  dc.b $d5 ; U
                  dc.b $d2 ; R
                  dc.b $8d ; <newline>
                  dc.b $a0 ; <blank>
                  dc.b $d3 ; S
                  dc.b $c5 ; E
                  dc.b $c3 ; C
                  dc.b $d2 ; R
                  dc.b $c5 ; E
                  dc.b $d4 ; T
                  dc.b $a0 ; <blank>
                  dc.b $d0 ; P
                  dc.b $c1 ; A
                  dc.b $d3 ; S
                  dc.b $d3 ; S
                  dc.b $d7 ; W
                  dc.b $cf ; O
                  dc.b $d2 ; R
                  dc.b $c4 ; D
                  dc.b $a0 ; <blank>
                  dc.b $a8 ; (
                  dc.b $d9 ; Y
                  dc.b $af ; /
                  dc.b $ce ; N
                  dc.b $a9 ; )
                  dc.b $00 ; EndOfText
                  
                  lda #$00                        ;
                  jsr WaitKeyBlink                ;
                  
                  ldx #$00                        ;
                  stx LR_KeyNew                   ; 
                  
                  cmp #$19                        ; "y"
                  beq .GetRegKey                  ;
                  
                  sec                             ; 
.Exit             rts                             ; 
                  
.GetRegKey        lda #$0a                        ; 
                  sta $50                         ; screen row ($00 - $0f)
                  jsr TextOut                     ; TextOut
                  dc.b $8d ; <newline>
                  dc.b $c3 ; C
                  dc.b $c1 ; A
                  dc.b $d2 ; R
                  dc.b $c5 ; E
                  dc.b $c6 ; F
                  dc.b $d5 ; U
                  dc.b $cc ; L
                  dc.b $cc ; L
                  dc.b $d9 ; Y
                  dc.b $a0 ; <blank>
                  dc.b $d4 ; T
                  dc.b $d9 ; Y
                  dc.b $d0 ; P
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $c9 ; I
                  dc.b $ce ; N
                  dc.b $a0 ; <blank>
                  dc.b $d4 ; T
                  dc.b $c8 ; H
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $d3 ; S
                  dc.b $c5 ; E
                  dc.b $d2 ; R
                  dc.b $c9 ; I
                  dc.b $c1 ; A
                  dc.b $cc ; L
                  dc.b $8d ; <newline>
                  dc.b $ce ; N
                  dc.b $d5 ; U
                  dc.b $cd ; M
                  dc.b $c2 ; B
                  dc.b $c5 ; E
                  dc.b $d2 ; R
                  dc.b $a0 ; <blank>
                  dc.b $cf ; O
                  dc.b $ce ; N
                  dc.b $a0 ; <blank>
                  dc.b $d9 ; Y
                  dc.b $cf ; O
                  dc.b $d5 ; U
                  dc.b $d2 ; R
                  dc.b $a0 ; <blank>
                  dc.b $c3 ; C
                  dc.b $c8 ; H
                  dc.b $c1 ; A
                  dc.b $cd ; M
                  dc.b $d0 ; P
                  dc.b $c9 ; I
                  dc.b $cf ; O
                  dc.b $ce ; N
                  dc.b $d3 ; S
                  dc.b $c8 ; H
                  dc.b $c9 ; I
                  dc.b $d0 ; P
                  dc.b $8d ; <newline>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $d2 ; R
                  dc.b $c5 ; E
                  dc.b $c7 ; G
                  dc.b $c9 ; I
                  dc.b $d3 ; S
                  dc.b $d4 ; T
                  dc.b $d2 ; R
                  dc.b $c1 ; A
                  dc.b $d4 ; T
                  dc.b $c9 ; I
                  dc.b $cf ; O
                  dc.b $ce ; N
                  dc.b $a0 ; <blank>
                  dc.b $c3 ; C
                  dc.b $c1 ; A
                  dc.b $d2 ; R
                  dc.b $c4 ; D
                  dc.b $a0 ; <blank>
                  dc.b $8d ; <newline>
                  dc.b $8d ; <newline>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $be ; <
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $bc ; >
                  dc.b $00 ; EndOfText
                  
                  lda #$0b                        ;
                  sta $4f                         ; screen col ($00 - $1b)
                  
                  lda #CR_SerialNoLen             ;
                  sta CR_InputBufMax              ;
                  
                  lda #$80                        ;
                  jsr InputControlSpec            ;
                  
                  jsr ChkUniquePlayId             ; 
                  
.ChkCounter       lda CR_HiScoreCount             ; 
                  cmp #$02                        ;
                  bcs .OutSecPswd                 ;
                  
.IncCounter       inc CR_HiScoreCount             ; 
                  
.SetCounter       lda #LR_DiskWrite               ;
                  jsr GetPutHiScores              ; ac: $01=load $02=store 81= 82=
                  
                  ldx #$03                        ; omit the first digit
.GetSerial        lda CR_SerialNoPos2,x           ;
                  sec                             ;
                  sbc #$b0                        ; reset key value to $00-$09
.SetSerial        sta CR_SerialNoPos2,x           ;
                  dex                             ;
                  bpl .GetSerial                  ;
                  
.GetSecPswd       lda CR_SerialNoPos2             ;
                  clc                             ;
                  adc CR_SerialNoPos3             ;
                  tax                             ;
                  lda TabAncientLegend,x          ; Apple Commodore Atari
                  sta ..ModSecPswd02              ;
                  
                  lda CR_SerialNoPos3             ;
                  clc                             ;
                  adc CR_SerialNoPos4             ;
                  tax                             ;
                  lda TabAncientLegend,x          ; Apple Commodore Atari
                  sta ..ModSecPswd03              ;
                  
                  lda CR_SerialNoPos4             ;
                  clc                             ;
                  adc CR_SerialNoPos5             ;
                  tax                             ;
                  lda TabAncientLegend,x          ; Apple Commodore Atari
                  sta ..ModSecPswd04              ;
                  
                  lda CR_SerialNoPos5             ;
                  clc                             ;
                  adc CR_SerialNoPos2             ;
                  tax                             ;
                  lda TabAncientLegend,x          ; Apple Commodore Atari
                  sta ..ModSecPswd05              ;
                  
.OutSecPswd       jsr ClearHiresDisp              ; ClearDisplay20
                  lda #$06                        ;
                  sta $50                         ; screen row ($00 - $0f)
                  jsr TextOut                     ; TextOut
                  dc.b $8d ; <newline>
                  dc.b $c2 ; B
                  dc.b $c5 ; E
                  dc.b $cc ; L
                  dc.b $cf ; O
                  dc.b $d7 ; W
                  dc.b $a0 ; <blank>
                  dc.b $c9 ; I
                  dc.b $d3 ; S
                  dc.b $a0 ; <blank>
                  dc.b $d9 ; Y
                  dc.b $cf ; O
                  dc.b $d5 ; U
                  dc.b $d2 ; R
                  dc.b $a0 ; <blank>
                  dc.b $d5 ; U
                  dc.b $ce ; N
                  dc.b $c9 ; I
                  dc.b $d1 ; Q
                  dc.b $d5 ; U
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $d3 ; S
                  dc.b $c5 ; E
                  dc.b $c3 ; C
                  dc.b $d2 ; R
                  dc.b $c5 ; E
                  dc.b $d4 ; T
                  dc.b $8d ; <newline>
                  dc.b $d0 ; P
                  dc.b $c1 ; A
                  dc.b $d3 ; S
                  dc.b $d3 ; S
                  dc.b $d7 ; W
                  dc.b $cf ; O
                  dc.b $d2 ; R
                  dc.b $c4 ; D
                  dc.b $ae ; .
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $d7 ; W
                  dc.b $d2 ; R
                  dc.b $c9 ; I
                  dc.b $d4 ; T
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $c9 ; I
                  dc.b $d4 ; T
                  dc.b $a0 ; <blank>
                  dc.b $cf ; O
                  dc.b $ce ; N
                  dc.b $a0 ; <blank>
                  dc.b $d9 ; Y
                  dc.b $cf ; O
                  dc.b $d5 ; U
                  dc.b $d2 ; R
                  dc.b $8d ; <newline>
                  dc.b $d2 ; R
                  dc.b $c5 ; E
                  dc.b $c7 ; G
                  dc.b $c9 ; I
                  dc.b $d3 ; S
                  dc.b $d4 ; T
                  dc.b $d2 ; R
                  dc.b $c1 ; A
                  dc.b $d4 ; T
                  dc.b $c9 ; I
                  dc.b $cf ; O
                  dc.b $ce ; N
                  dc.b $a0 ; <blank>
                  dc.b $c3 ; C
                  dc.b $c1 ; A
                  dc.b $d2 ; R
                  dc.b $c4 ; D
                  dc.b $a0 ; <blank>
                  dc.b $d2 ; R
                  dc.b $c9 ; I
                  dc.b $c7 ; G
                  dc.b $c8 ; H
                  dc.b $d4 ; T
                  dc.b $a0 ; <blank>
                  dc.b $ce ; N
                  dc.b $cf ; O
                  dc.b $d7 ; W
                  dc.b $8d ; <newline>
                  dc.b $a0 ; <blank>
                  dc.b $c1 ; A
                  dc.b $ce ; N
                  dc.b $c4 ; D
                  dc.b $a0 ; <blank>
                  dc.b $cd ; M
                  dc.b $c1 ; A
                  dc.b $c9 ; I
                  dc.b $cc ; L
                  dc.b $a0 ; <blank>
                  dc.b $c9 ; I
                  dc.b $d4 ; T
                  dc.b $a0 ; <blank>
                  dc.b $d4 ; T
                  dc.b $cf ; O
                  dc.b $a0 ; <blank>
                  dc.b $c2 ; B
                  dc.b $d2 ; R
                  dc.b $cf ; O
                  dc.b $c4 ; D
                  dc.b $c5 ; E
                  dc.b $d2 ; R
                  dc.b $c2 ; B
                  dc.b $d5 ; U
                  dc.b $ce ; N
                  dc.b $c4 ; D
                  dc.b $8d ; <newline>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $c1 ; A
                  dc.b $d3 ; S
                  dc.b $a0 ; <blank>
                  dc.b $d3 ; S
                  dc.b $cf ; O
                  dc.b $cf ; O
                  dc.b $ce ; N
                  dc.b $a0 ; <blank>
                  dc.b $c1 ; A
                  dc.b $d3 ; S
                  dc.b $a0 ; <blank>
                  dc.b $d0 ; P
                  dc.b $cf ; O
                  dc.b $d3 ; S
                  dc.b $d3 ; S
                  dc.b $c9 ; I
                  dc.b $c2 ; B
                  dc.b $cc ; L
                  dc.b $c5 ; E
                  dc.b $8d ; <newline>
                  dc.b $8d ; <newline>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $be ; <
                  dc.b $c3 ; C
..ModSecPswd02    dc.b $d1 ; Q
..ModSecPswd03    dc.b $c1 ; A
..ModSecPswd04    dc.b $c4 ; D
..ModSecPswd05    dc.b $c9 ; I
                  dc.b $bc ; >
                  dc.b $8d ; <newline>
                  dc.b $8d ; <newline>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $c8 ; H
                  dc.b $c9 ; I
                  dc.b $d4 ; T
                  dc.b $a0 ; <blank>
                  dc.b $c1 ; A
                  dc.b $a0 ; <blank>
                  dc.b $cb ; K
                  dc.b $c5 ; E
                  dc.b $d9 ; Y
                  dc.b $a0 ; <blank>
                  dc.b $00 ; EndOfText
                  
                  lda #$00                        ;
                  jsr WaitKeyBlink                ;
                  
                  lda #$00                        ;
                  sta LR_KeyNew                   ;
                   
                  sec                             ;
CheckNewChampX    rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
TabAncientLegend  dc.b $c1 ; A
                  dc.b $d0 ; P
                  dc.b $d0 ; P
                  dc.b $cc ; L
                  dc.b $c5 ; E

                  dc.b $c3 ; C
                  dc.b $cf ; O
                  dc.b $cd ; M
                  dc.b $cd ; M
                  dc.b $cf ; O
                  dc.b $c4 ; D
                  dc.b $cf ; O
                  dc.b $d2 ; R
                  dc.b $c5 ; E

                  dc.b $c1 ; A
                  dc.b $d4 ; T
                  dc.b $c1 ; A
                  dc.b $d2 ; R
                  dc.b $c9 ; I
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MoveLodeRunner    lda #LR_GetGoldGot
                  sta LR_GetGold                  ; get gold  $00=just gets it
                  lda LR_Shoots                   ; $00=no $01=right $ff=left
                  beq .MoveLR
                  bpl .GoFireRightLR
                  
.GoFireLeftLR     jmp LRFireLeft
.GoFireRightLR    jmp LRFireRight
                  
.MoveLR           ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $03
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)  equ data under lr
                  cmp #NoTileLadder
                  beq .GoChkFallDown
                  
                  cmp #NoTilePole
                  bne .GetPosUD
                  
                  lda $06                         ; lr pos on image up/down
                  cmp #$02                        ; in middle of screen image
                  beq .GoChkFallDown
                  
.GetPosUD         lda $06                         ; lr pos on image up/down
                  cmp #$02                        ; in middle of screen image
                  bcc .SetFallDown
                  
                  ldy $04                         ; actual row lode runner
                  cpy #LR_ScrnMaxRows             ; $0f - max 15 rows
                  beq .GoChkFallDown              ; bottom reached
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8+1,y        ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  ldy $03                         ; adr column lode runner
                  lda ($09),y                     ; unpacked level data ($0800-$09c3) + 1
                  cmp #$00                        ; nothing
                  beq .SetFallDown
                  
                  cmp #NoTileEnemy
                  beq .GoChkFallDown
                  
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  beq .GoChkFallDown
                  
                  cmp #NoTileWallHard
                  beq .GoChkFallDown
                  
                  cmp #NoTileLadder
                  bne .SetFallDown
                  
.GoChkFallDown    jmp .EndFallDown
                  
.SetFallDown      lda #LR_Falls
                  sta LR_FallsDown                ; $00=fall $20=no fall $ff=init
                  dec LR_FallBeep
                  jsr GetLRGfxOff
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
                  lda #$07
                  ldx $08                         ; control shooter mode
                  bmi .SetSpriteNo
                  
                  lda #$0f
.SetSpriteNo      sta $07                         ; lr sprite number
                  jsr MovLRWaitPosX
                  
                  inc $06                         ; lr pos on image up/down
                  lda $06
                  cmp #$05                        ; max
                  bcs .InitPosUD
                  
                  jsr MovLRGold                   ; wait for center and handle the gold
                  jmp MovLRKill
                  
.InitPosUD        lda #$00
                  sta $06                         ; lr pos on image up/down
                  
                  ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  bne .Store
                  
                  lda #NoTileBlank                ; empty substitution
                  
.Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  inc $04                         ; actual row lode runner
                  ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $03                         ; adr column lode runner
                  lda #NoTileLodeRunner
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  jmp MovLRKill
                  
.EndFallDown      lda LR_FallsDown                ; $00=fall $20=no fall $ff=init
                  bne .Always
                  
.Always           lda #LR_FallsNo                 ; end
                  sta LR_FallsDown                ; $00=fall $20=no fall $ff=init
                  
                  jsr GetPlayCmd
                  
                  lda LR_JoyUpDo
.ChkMoveUp        cmp #LR_JoyMoveUp               ; move up
                  bne .ChkMoveDown
                  
.MoveUp           jsr MovLRUp
                  bcs .ChkMoveLeft
                  rts
                  
.ChkMoveDown      cmp #LR_JoyMoveDo               ; move down
                  bne .ChkFireLeft
.MoveDown         jsr LRMoveDown
                  bcs .ChkMoveLeft
                  rts
                  
.ChkFireLeft      cmp #LR_JoyFireLe               ; fire left
                  bne .ChkFireRight
.FireLeft         jsr MovLRFireLeft
                  bcs .ChkMoveLeft
                  rts
                  
.ChkFireRight     cmp #LR_JoyFireRi               ; fire right
                  bne .ChkMoveLeft
.FireRight        jsr MovLRFireRight
                  bcs .ChkMoveLeft
                  rts
                  
.ChkMoveLeft      lda LR_JoyLeRi
                  cmp #LR_JoyMoveLe               ; move left
                  bne .ChkMoveRight
                  
.MoveLeft         jmp MovLRLeft
                  
.ChkMoveRight     cmp #LR_JoyMoveRi               ; move right
                  bne MoveLodeRunnerX
.MoveRight        jmp LRMoveRight
                  
MoveLodeRunnerX   rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MovLRLeft         ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  ldx $05
                  cpx #$03
                  bcs MovLRLeftABit               ; not yet in center so MovLRLeftABit
                  
                  ldy $03                         ; adr column lode runner
                  beq MovLRLeftX
                  
                  dey
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #NoTileWallHard
                  beq MovLRLeftX
                  
                  cmp #NoTileWallWeak
                  beq MovLRLeftX
                  
                  cmp #NoTileWallTrap
                  bne MovLRLeftABit
                  
MovLRLeftX        rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MovLRLeftABit     jsr GetLRGfxOff
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
                  lda #$ff
                  sta $08                         ; control shooter mode
                  jsr MovLRWaitPosY
                  
                  dec $05                         ; lr pos on image left/right equ one step left
                  bpl .Gold                       ; move from actual to next left field not yet complete
                  
.NewField         ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  bne .Store
                  
                  lda #NoTileBlank                ; empty substitution
                  
.Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  dec $03                         ; adr column lode runner
                  dey
                  lda #NoTileLodeRunner
.SetLR            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  lda #$04                        ; max right to
                  sta $05                         ;   lr pos on image left/right
                  bne .SetNextPos                 ; always
                  
.Gold             jsr MovLRGold                   ; wait for center and handle the gold
                  
.SetNextPos       ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTilePole
                  beq .PoleImage
                  
.RunImage         lda #NoLR_RunLeMin              ; low image no
                  ldx #NoLR_RunLeMax              ; high image no
                  bne .OutImage
                  
.PoleImage        lda #NoLR_PoleLeMin             ; low image no
                  ldx #NoLR_PoleLeMax             ; high image no
.OutImage         jsr MovLRSetImg
                  
MovLRLeftABitX    jmp MovLRKill
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
LRMoveRight       ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldx $05                         ; lr pos on image left/right
                  cpx #$02
                  bcc MovLRRightABit              ; not yet in center so MovLRRightABit
                  
                  ldy $03                         ; adr column lode runner
                  cpy #LR_ScrnMaxCols             ; $1b - max 27 cols
                  beq LRMoveRightX
                  
                  iny
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #NoTileWallHard
                  beq LRMoveRightX
                  
                  cmp #NoTileWallWeak
                  beq LRMoveRightX
                  
                  cmp #NoTileWallTrap
                  bne MovLRRightABit
                  
LRMoveRightX      rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MovLRRightABit    jsr GetLRGfxOff
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
                  lda #$01
                  sta $08                         ; control shooter mode
                  jsr MovLRWaitPosY
                  
                  inc $05                         ; lr pos on image left/right
                  lda $05                         ; lr pos on image left/right
                  cmp #$05                        ; max
                  bcc .Gold
                  
                  ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  bne .Store
                  
                  lda #NoTileBlank                ; empty substitution
.Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  inc $03                         ; adr column lode runner
                  iny
                  lda #NoTileLodeRunner
.SetLR            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  lda #$00
                  sta $05                         ; lr pos on image left/right
                  beq .SetNextPos                 ; always
                  
.Gold             jsr MovLRGold                   ; wait for center and handle the gold
                  
.SetNextPos       ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTilePole
                  beq .PoleImage
                  
.RunImage         lda #NoLR_RunRiMin              ; low image no
                  ldx #NoLR_RunRiMax              ; high image no
                  bne .OutImage
                  
.PoleImage        lda #NoLR_PoleRiMin             ; low image no
                  ldx #NoLR_PoleRiMax             ; high image no
.OutImage         jsr MovLRSetImg
                  
MovLRRightABitX   jmp MovLRKill
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MovLRUp           ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3) equ data under lr
                  cmp #NoTileLadder
                  beq MovLRUpABit
                  
                  ldy $06                         ; lr pos on image up/down
                  cpy #$03                        ; in center
                  bcc MovUpXitSetCarry            ; no
                  
                  ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3) + 1 equ data below lr
                  cmp #NoTileLadder
                  beq MovUpGetGfxOff
                  
MovUpXitSetCarry  sec
MovLRUpX          rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MovLRUpABit       ldy $06                         ; lr pos on image up/down
                  cpy #$03                        ; in center
                  bcs MovUpGetGfxOff              ; equal/higher
                  
                  ldy $04                         ; actual row lode runner
                  beq MovUpXitSetCarry
                  
                  lda TabExLvlDatRowLo-1,y        ; expanded level data row pointer lo
                  sta $09
                  lda TabExLvlDatRowH8-1,y        ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $03                         ; adr column lode runner
                  lda ($09),y                     ; unpacked level data ($0800-$09c3) - 1 equ data above lr
                  cmp #NoTileWallWeak
                  beq MovUpXitSetCarry
                  
                  cmp #NoTileWallHard
                  beq MovUpXitSetCarry
                  
                  cmp #NoTileWallTrap
                  beq MovUpXitSetCarry
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MovUpGetGfxOff    jsr GetLRGfxOff
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
                  ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  jsr MovLRWaitPosX
                  
                  dec $06                         ; lr pos on image up/down
                  bpl MovUpDownGold
                  
                  ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  bne .Store
                  
                  lda #NoTileBlank                ; empty substitution
                  
.Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  dec $04                         ; actual row lode runner
                  ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $03                         ; adr column lode runner
                  lda #NoTileLodeRunner
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  lda #$04
                  sta $06                         ; lr pos on image up/down
                  bne MovUpDown                   ; always
                  
MovUpDownGold     jsr MovLRGold                   ; wait for center and handle the gold
                  
MovUpDown         lda #NoLR_LadderMin             ; low image no
                  ldx #NoLR_LadderMax             ; high image no
                  jsr MovLRSetImg
                  jsr MovLRKill
                  
                  clc
MovLRUpABitX      rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
LRMoveDown        ldy $06                         ; lr pos on image up/down
                  cpy #$02                        ; in center of screen image
                  bcc MovLRDownABit
                  
                  ldy $04                         ; actual row lode runner
                  cpy #LR_ScrnMaxRows             ; $0f - max 15 rows
                  bcs .XitSetCarry
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8+1,y        ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $03                         ; adr column lode runner
                  lda ($09),y                     ; unpacked level data ($0800-$09c3) + 1
                  cmp #NoTileWallHard
                  beq .XitSetCarry
                  
                  cmp #NoTileWallWeak
                  bne MovLRDownABit
                  
.XitSetCarry      sec
LRMoveDownX       rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MovLRDownABit     jsr GetLRGfxOff
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
                  ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  jsr MovLRWaitPosX
                  
                  inc $06                         ; lr pos on image up/down
                  lda $06                         ; lr pos on image up/down
                  cmp #$05                        ; center screen image
                  bcc .GoMovUpDownGold
                  
                  ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  bne .Store
                  
                  lda #NoTileBlank                ; empty substitution
                  
.Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  inc $04                         ; actual row lode runner
                  ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $03                         ; adr column lode runner
                  lda #NoTileLodeRunner
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  lda #$00
                  sta $06                         ; lr pos on image up/down
                  jmp MovUpDown
                  
.GoMovUpDownGold  jmp MovUpDownGold
                  
FireLeftNone      jmp OutLRFireLeftNo
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MovLRFireLeft     lda #LR_ShootsLe
                  sta LR_Shoots                   ; $00=no $01=right $ff=left
                  sta LR_JoyUpDo
                  sta LR_JoyLeRi
                  lda #$00
                  sta $54                         ; lr actual sprite number
                  
LRFireLeft        ldy $04                         ; actual row lode runner
                  cpy #LR_ScrnMaxRows             ; $0f - max 15 rows
                  bcs FireLeftNone                ; no walls left for shooting
                  
                  iny
                  jsr GetCtrlDataPtr
                  
                  ldy $03                         ; adr column lode runner
                  beq FireLeftNone                ; leftmost position
                  
                  dey
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #NoTileWallWeak
                  bne FireLeftNone
                  
                  ldy $04                         ; actual row lode runner
                  jsr GetCtrlDataPtr
                  
                  ldy $03                         ; adr column lode runner
                  dey
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #NoTileBlank                ; empty
                  bne OutLRFireLeft
                  
                  jsr GetLRGfxOff
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
                  jsr MovLRWaitPosX
                  jsr MovLRWaitPosY
                  
                  ldx $54                         ; lr actual sprite number
                  lda #$00
                  cpx #$06
                  bcs .StoreSpriteNo
                  
                  lda #$06
                  
.StoreSpriteNo    sta $07
                  jsr MovLRKill
                  
                  ldx $54                         ; lr actual sprite number
                  cpx #$0c
                  beq MovLRSetHoleLe
                  
                  cpx #$00
                  beq .GetShootImage2
                  
.GetShootImage1   lda TabShootNoSpark-1,x
                  pha
                  
                  ldx $03                         ; adr column lode runner
                  dex
                  ldy $04                         ; actual row lode runner
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row
                  
                  pla
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
                  ldx $54                         ; lr actual sprite number
.GetShootImage2   lda TabShootNoSpark,x
                  pha                             ; save image number
                  
                  ldx $03                         ; adr column lode runner
                  dex
                  stx $4f                         ; screen col  (00-1b)
                  
                  ldy $04                         ; actual row lode runner
                  sty $50                         ; screen row  (00-0f)
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row
                  
                  pla                             ; restore image number
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  
                  ldx $54                         ; lr actual sprite number
.GetMeltImage     lda TabShootMeltGrnd,x
                  inc $50                         ; screen row  (00-0f)
.PutMeltImage     jsr ImageOut2Disp               ; direct output to display screen
                  
                  inc $54                         ; lr actual sprite number
                  
                  clc
MovLRFireLeftX    rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
OutLRFireLeft     ldy $04                         ; actual row lode runner
                  iny                             ; +1
                  sty $50                         ; screen row  (00-0f)
                  ldy $03                         ; adr column lode runner
                  dey
                  sty $4f                         ; screen col  (00-1b)
                  
                  lda #NoTileWallWeak
                  jsr ImageOut2Disp               ; direct output to display screen
                  
                  ldx $54                         ; lr actual sprite number
                  beq OutLRFireLeftNo
                  
                  dex
.GetShootImage    lda TabShootNoSpark,x
                  pha
                  
                  ldy $04                         ; actual row lode runner
                  ldx $03                         ; adr column lode runner
                  dex
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row
                  
                  pla
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
OutLRFireLeftNo   lda #LR_ShootsNo
                  sta LR_Shoots                   ; $00=no $01=right $ff=left
                  
                  sec
OutLRFireLeftX    rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MovLRSetHoleLe    ldx $03                         ; adr column lode runner
                  dex
                  jmp MovLRSetHole
; ------------------------------------------------------------------------------------------------------------- ;
GoSetNoShoot      jmp SetNoShoot
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MovLRFireRight    lda #LR_ShootsRi
                  sta LR_Shoots                   ; $00=no $01=right $ff=left
                  sta LR_JoyUpDo
                  sta LR_JoyLeRi
                  lda #$0c
                  sta $54                         ; lr actual sprite number
                  
LRFireRight       ldy $04                         ; actual row lode runner
                  cpy #LR_ScrnMaxRows             ; $0f - max 15 rows
                  bcs GoSetNoShoot
                  
                  iny
                  jsr GetCtrlDataPtr
                  ldy $03                         ; adr column lode runner
                  cpy #LR_ScrnMaxCols             ; $1b - max 27 cols
                  bcs GoSetNoShoot
                  
                  iny
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #NoTileWallWeak
                  bne GoSetNoShoot
                  
                  ldy $04                         ; actual row lode runner
                  jsr GetCtrlDataPtr
                  
                  ldy $03                         ; adr column lode runner
                  iny
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #NoTileBlank                ; empty
                  bne MovLRFireNoHole
                  
                  jsr GetLRGfxOff
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  jsr MovLRWaitPosX
                  jsr MovLRWaitPosY
                  
                  ldx $54                         ; lr actual sprite number
                  lda #$08
                  cpx #$12
                  bcs .SetSprite
                  
                  lda #$0e
.SetSprite        sta $07                         ; lr sprite number
                  jsr MovLRKill
                  
                  ldx $54                         ; lr actual sprite number
                  cpx #$18
                  beq MovLRSetHoleRi
                  
                  cpx #$0c
                  beq .GetShootImage2
                  
.GetShootImage1   lda TabShootNoSpark-1,x
                  pha
                  
                  ldx $03                         ; adr column lode runner
                  inx
                  ldy $04                         ; actual row lode runner
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row
                  
                  pla
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
                  ldx $54                         ; lr actual sprite number
.GetShootImage2   lda TabShootNoSpark,x
                  pha
                  
                  ldx $03                         ; adr column lode runner
                  inx
                  stx $4f                         ; screen col  (00-1b)
                  ldy $04                         ; actual row lode runner
                  sty $50                         ; screen row  (00-0f)
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row
                  
                  pla
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  
                  inc $50                         ; screen row  (00-0f)
                  ldx $54
.GetMeltImage     lda TabShootMelt,x
.PutMeltImage     jsr ImageOut2Disp               ; direct output to display screen
                  
                  inc $54
                  clc
MovLRFireRightX   rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MovLRFireNoHole   ldy $04                         ; actual row lode runner
                  iny
                  sty $50                         ; screen row  (00-0f)
                  ldy $03                         ; adr column lode runner
                  iny
                  sty $4f                         ; screen col  (00-1b)
                  lda #NoTileWallWeak
                  jsr ImageOut2Disp               ; direct output to display screen
                  
                  ldx $54                         ; lr actual sprite number
                  cpx #$0c
                  beq SetNoShoot
                  
                  dex
.GetShootImage    lda TabShootNoSpark,x
                  pha
                  
                  ldx $03                         ; adr column lode runner
                  inx
                  ldy $04                         ; actual row lode runner
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row
                  
                  pla
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
SetNoShoot        lda #LR_ShootsNo
                  sta LR_Shoots                   ; $00=no $01=right $ff=left
                  
                  sec
MovLRFireNoHoleX  rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MovLRSetHoleRi    ldx $03
                  inx
                  jmp MovLRSetHole
; ------------------------------------------------------------------------------------------------------------- ;
TabSpriteNoLodeR  equ *
TabLR_RunLeMin    dc.b NoSprite_RuLe00 ; $00 - run    left 01    - have lode runner sprite numbers from $01-$11
                  dc.b NoSprite_RuLe01 ; $01 - run    left 02
TabLR_RunLeMax    dc.b NoSprite_RuLe02 ; $02 - run    left 03
TabLR_PoleLeMin   dc.b NoSprite_PoLe00 ; $03 - pole   left 01
                  dc.b NoSprite_PoLe01 ; $04 - pole   left 02
TabLR_PoleLeMax   dc.b NoSprite_PoLe02 ; $05 - pole   left 03
                  dc.b NoSprite_FireLe ; $06 - fire   left
                  dc.b NoSprite_FallLe ; $07 - fall   left
TabLR_RunRiMin    dc.b NoSprite_RuRi00 ; $08 - run    right 01
                  dc.b NoSprite_RuRi01 ; $09 - run    right 02
TabLR_RunRiMax    dc.b NoSprite_RuRi02 ; $0a - run    right 03
TabLR_PoleRiMin   dc.b NoSprite_PoRi00 ; $0b - pole   right 01
                  dc.b NoSprite_PoRi01 ; $0c - pole   right 02
TabLR_PoleRiMax   dc.b NoSprite_PoRi02 ; $0d - pole   right 03
                  dc.b NoSprite_FireRi ; $0e - fire   right
                  dc.b NoSprite_FallRi ; $0f - fall   right
TabLR_LadderMin   dc.b NoSprite_Ladr00 ; $10 - ladder up/down 01
TabLR_LadderMax   dc.b NoSprite_Ladr01 ; $11 - ladder up/down 02
; ------------------------------------------------------------------------------------------------------------- ;
NoLR_RunLeMin     equ TabLR_RunLeMin  - TabSpriteNoLodeR
NoLR_RunLeMax     equ TabLR_RunLeMax  - TabSpriteNoLodeR
NoLR_PoleLeMin    equ TabLR_PoleLeMin - TabSpriteNoLodeR
NoLR_PoleLeMax    equ TabLR_PoleLeMax - TabSpriteNoLodeR
NoLR_RunRiMin     equ TabLR_RunRiMin  - TabSpriteNoLodeR
NoLR_RunRiMax     equ TabLR_RunRiMax  - TabSpriteNoLodeR
NoLR_PoleRiMin    equ TabLR_PoleRiMin - TabSpriteNoLodeR
NoLR_PoleRiMax    equ TabLR_PoleRiMax - TabSpriteNoLodeR
NoLR_LadderMin    equ TabLR_LadderMin - TabSpriteNoLodeR
NoLR_LadderMax    equ TabLR_LadderMax - TabSpriteNoLodeR
; ------------------------------------------------------------------------------------------------------------- ;
TabShootNoSpark   dc.b NoShootSpark00 ; $00 - shoot spark 00
                  dc.b NoShootSpark00 ; $01 - shoot spark 00
                  dc.b NoShootSpark01 ; $02 - shoot spark 01
                  dc.b NoShootSpark01 ; $03 - shoot spark 01
                  dc.b NoShootSpark02 ; $04 - shoot spark 02
                  dc.b NoShootSpark02 ; $05 - shoot spark 02
                  dc.b NoShootSpark03 ; $06 - shoot spark 03
                  dc.b NoShootSpark03 ; $07 - shoot spark 03
                  dc.b NoTileBlank    ; $08 - tile empty
                  dc.b NoTileBlank    ; $09 - tile empty
                  dc.b NoTileBlank    ; $0a - tile empty
                  dc.b NoTileBlank    ; $0b - tile empty
; ------------------------------------------------------------------------------------------------------------- ;
TabShootMelt      dc.b NoShootMelt00  ; $00 - init melt above ground 01
                  dc.b NoShootMelt00  ; $01 - init melt above ground 02
                  dc.b NoShootMelt01  ; $02 - init melt above ground 01
                  dc.b NoShootMelt01  ; $03 - init melt above ground 02
                  dc.b NoShootSpark02 ; $04 - shoot spark 02
                  dc.b NoShootSpark02 ; $05 - shoot spark 02
                  dc.b NoShootSpark03 ; $06 - shoot spark 03
                  dc.b NoShootSpark03 ; $07 - shoot spark 03
                  dc.b NoTileBlank    ; $08 - tile empty
                  dc.b NoTileBlank    ; $09 - tile empty
                  dc.b NoTileBlank    ; $0a - tile empty
                  dc.b NoTileBlank    ; $0b - tile empty
; ------------------------------------------------------------------------------------------------------------- ;
TabShootMeltGrnd  dc.b NoShootMeltGr00 ; $00 - shoot melt ground 01
                  dc.b NoShootMeltGr00 ; $01 - shoot melt ground 01
                  dc.b NoShootMeltGr01 ; $02 - shoot melt ground 02
                  dc.b NoShootMeltGr01 ; $03 - shoot melt ground 02
                  dc.b NoShootMeltGr02 ; $04 - shoot melt ground 03
                  dc.b NoShootMeltGr02 ; $05 - shoot melt ground 03
                  dc.b NoShootMeltGr03 ; $06 - shoot melt ground 04
                  dc.b NoShootMeltGr03 ; $07 - shoot melt ground 04
                  dc.b NoShootMeltGr04 ; $08 - shoot melt ground 05
                  dc.b NoShootMeltGr04 ; $09 - shoot melt ground 05
                  dc.b NoShootMeltGr05 ; $0a - shoot melt ground 06
                  dc.b NoShootMeltGr05 ; $0b - shoot melt ground 06
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ContinueDemo      lda LR_KeyNew                   ; lrNewKey
                  bne .Kill                       ;
                  
                  lda CIAPRA                      ; CIA 1 - $DC00 equ Data Port A
                  and #$10                        ; isolate fire button
                  bne RunDemo                     ; no
                  
.Kill             lsr $59                         ; save LR_LevelNoGame
                  lsr LR_Alive                    ; kill LR immediately ends the level
                  
                  cmp #$aa                        ; 
                  beq .GoGetUserKey               ;
                  
                  cmp #$01                        ;
                  bne .SetLastLife                ;
                  
.GoGetUserKey     jmp GetUserKey                  ; 

.SetLastLife      lda #$01                        ; 
                  sta LR_NumLives                 ; last live used up ends the demo immediately
                  
ContinueDemoX     rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
RunDemo           lda $58                         ; duration demo move
                  bne .DoMove                     ; not ended yet
                  
                  ldy #$00                        ;
.GetMove          lda ($55),y                     ; demo data pointer
                  sta $57                         ; type of demo move  (l/r/u/d/fire)
                  
.GetTime          iny                             ;
                  lda ($55),y                     ; demo data pointer
                  sta $58                         ; duration demo move
                  
.IncMovePtr       lda $55                         ;
                  clc                             ;
                  adc #$02                        ;
                  sta $55                         ; demo data pointer low
                  lda $56                         ;
                  adc #$00                        ;
                  sta $56                         ; demo data pointer high
                  
.DoMove           lda $57                         ; type demo move  (l/r/u/d/fire)
                  and #$0f                        ; isolate right nybble for up/down moves
                  tax                             ;
                  lda TabDemoJoyActn,x            ; demo joystick action tab
.SetUpDo          sta LR_JoyUpDo                  ; 

                  lda $57                         ; type demo move  (l/r/u/d/fire)
                  lsr a                           ; isolate left nybble for left/right moves
                  lsr a                           ;
                  lsr a                           ;
                  lsr a                           ;
                  tax                             ;
                  lda TabDemoJoyActn,x            ;
.SetLeRi          sta LR_JoyLeRi                  ;

.DecTime          dec $58                         ; duration demo move

RunDemoX          rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TabDemoJoyActn    dc.b LR_JoyMoveUp ; 0 - $21=up
                  dc.b LR_JoyMoveLe ; 1 - $22=left
                  dc.b LR_JoyMoveDo ; 2 - $25=down
                  dc.b LR_JoyMoveRi ; 3 - $2a=right
                  dc.b LR_JoyFireRi ; 4 - $26=fire-right
                  dc.b LR_JoyFireLe ; 5 - $1e=fire-left
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
GetPlayCmd        lda LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  cmp #LR_GameDemo                ;
                  beq ContinueDemo                ;
                  
                  ldx LR_KeyNew                   ;
                  bne .ChkKeyI                    ; pressed
                  
                  lda LR_ControllerTyp            ; lrControl (ca=joystick  cb=keyboard)
                  cmp #LR_Keyboard                ;
                  beq GetPlayCmdX                 ;
                  
.GoChkJoyPort     jmp ChkJoyPort                  ;

.ChkKeyI          lda #LR_KeyNewNone              ; 
                  sta LR_KeyNew                   ; reset actual key
                  
                  stx $23                         ; save actual key
                  ldy #$ff                        ;
.ChkKey           iny                             ;
                  lda TabPlayCmdChr,y             ; in game keys tab  (RUN/STOP R A J K + - D ? ?)
                  beq .ChkCtrlType                ; was no legal command key
                  
                  cmp $23                         ;
                  bne .ChkKey                     ;
                  
                  tya                             ;
                  asl a                           ;
                  tay                             ;
.PrepareCmd       lda TabPlayCmdSub+1,y           ;
                  pha                             ;
                  lda TabPlayCmdSub,y             ;
                  pha                             ;
.DispatchCmd      rts                             ;

.ChkCtrlType      lda LR_ControllerTyp            ; lrControl (ca=joystick  cb=keyboard)
                  cmp #$ca                        ;
                  beq .GoChkJoyPort               ;
                  
                  ldx $23                         ;
                  stx LR_JoyUpDo                  ; 
                  stx LR_JoyLeRi                  ; 
                  
GetPlayCmdX       rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
IGC_Never         inc LR_CntSpeedLaps             ; speed up
                  inc LR_NumLives                 ; 
                  lsr LR_Alive                    ; kill lr

IGC_NeverX        rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
IGC_Pause         jsr GetAKey                     ;
                  cmp #$03                        ; F7
                  bne .Chk_RunStop                ;
                  
                  sta CR_Cheat                    ; set cheat mode after RUN/STP and F7
                  
.Chk_RunStop      cmp #$3f                        ; RUN/STOP
                  bne IGC_Pause                   ;
                  
IGC_PauseX        jmp GetPlayCmd                  ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
IGC_Quit          jmp GameOver                    ; mlGameOver
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
IGC_Suicide       lsr LR_Alive                    ; lrStillAlive  (0=killed)
                  
IGC_SuicideX      rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
IGC_SetJoy        lda #$ca                        ;
                  sta LR_ControllerTyp            ; lrControl (ca=joystick  cb=keyboard)
IGC_SetJoyX       jmp GetPlayCmd                  ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
IGC_SetKeyBd      lda #$cb                        ; 
                  sta LR_ControllerTyp            ; lrControl (ca=joystick  cb=keyboard)
IGC_SetKeyBdX     jmp GetPlayCmd                  ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
IGC_DecSpeed      lda LR_GameSpeed                ; lrGameSpeed
                  cmp #LR_SpeedMin                ;
                  beq LR_SpeedMaxX                ;
                  
                  dec LR_GameSpeed                ; lrGameSpeed
                  
IGC_DecSpeedX     jmp GetPlayCmd                  ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
IGC_IncSpeed      lda LR_GameSpeed                ; lrGameSpeed
                  cmp #LR_SpeedMax                ;
                  beq LR_SpeedMaxX                ;
                  
                  inc LR_GameSpeed                ; lrGameSpeed
                  
LR_SpeedMaxX      jmp GetPlayCmd                  ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
IGC_ShootMode     lda LR_ShootMode                ; lrShootMode
                  eor #$ff                        ;
                  sta LR_ShootMode                ; lrShootMode
IGC_ShootModeX    jmp GetPlayCmd                  ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ChkJoyPort        lda CIAPRA                      ; CIA 1 - $DC00 equ Data Port A
                  and #$10                        ; Bit 4: Joystick 2 - Fire   0=pressed
                  bne .ChkMoves                   ;
                  
.CheckMode        lda $08                         ;
                  eor LR_ShootMode                ;
                  bpl .FireLeft                   ;
                  
.FireRight        lda #LR_JoyFireRi               ; 
                  sta LR_JoyUpDo                  ; 
                  sta LR_JoyLeRi                  ; 
.FireRightX       rts                             ;
                  
.FireLeft         lda #LR_JoyFireLe               ; 
                  sta LR_JoyUpDo                  ; 
                  sta LR_JoyLeRi                  ; 
.FireLeftX        rts                             ;
                  
.ChkMoves         lda CIAPRA                      ; CIA 1 - $DC00 equ Data Port A
                  sta $1e                         ; SavCIA
                  
.ChkUpDown        and #$02                        ; Bit 1: Joystick 2 - Down   0=pressed
                  beq .SetDown                    ;
                  
                  lda $1e                         ; SavCIA
                  and #$01                        ; Bit 0: Joystick 2 - Up     0=pressed
                  beq .SetUp                      ;
                  
.NetNoneUpDown    ldx #LR_JoyMoveNone
                  stx LR_JoyUpDo
                  beq .ChkLeftRight               ; always
                  
.SetUp            ldx #$21                        ;
                  stx LR_JoyUpDo                  ; 
                  bne .ChkLeftRight               ; always
                  
.SetDown          ldx #$25                        ;
                  stx LR_JoyUpDo                  ; 
                  
.ChkLeftRight     lda $1e                         ; SavCIA
                  and #$08                        ; Bit 3: Joystick 2 - Right  0=pressed
                  beq .SetRight                   ;
                  
                  lda $1e                         ; SavCIA
                  and #$04                        ; Bit 2: Joystick 2 - Left   0=pressed
                  beq .SetLeft                    ;
                  
.SetNoneRiLeft    ldx #LR_JoyMoveNone             ;
                  stx LR_JoyLeRi                  ;
.SetNoneRiLeftX   rts                             ;
                  
.SetRight         ldx #LR_JoyMoveRi               ;
                  stx LR_JoyLeRi                  ;
.SetRightX        rts                             ;
                  
.SetLeft          ldx #LR_JoyMoveLe               ;
                  stx LR_JoyLeRi                  ;
                  
ChkJoyPortX       rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TabPlayCmdChr     dc.b $3f ; RUN/STOP
                  dc.b $91 ; R
                  dc.b $8a ; A
                  dc.b $a2 ; J
                  dc.b $a5 ; K
                  dc.b $2b ; +
                  dc.b $28 ; -
                  dc.b $92 ; D
                  dc.b $b9 ; arrow left
                  dc.b $b6 ; arrow up

                  dc.b $00 ; EndOfTab
; ------------------------------------------------------------------------------------------------------------- ;
TabPlayCmdSub     dc.w IGC_Pause       - 1 ; 
                  dc.w IGC_Quit        - 1 ; 
                  dc.w IGC_Suicide     - 1 ; 
                  dc.w IGC_SetJoy      - 1 ; 
                  dc.w IGC_SetKeyBd    - 1 ; 
                  dc.w IGC_IncSpeed    - 1 ; 
                  dc.w IGC_DecSpeed    - 1 ; 
                  dc.w IGC_ShootMode   - 1 ; - Toggle Shoot Mode
                  dc.w IGC_IncLives    - 1 ; 
                  dc.w IGC_IncLevel    - 1 ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
GetLRGfxOff       ldx $03                         ; adr col lode runner
                  ldy $05                         ; lr pos on image left/right
                  jsr GetXOff                     ;
                  
                  stx $23                         ; image number
                  ldy $04                         ; actual row lode runner
                  ldx $06                         ; lr pos on image up/down
                  jsr GetYOff                     ;
                  
                  ldx $07                         ; lr sprite number
                  lda TabSpriteNoLodeR,x          ; lr images tab
                  ldx $23                         ;
                  
GetLRGfxOffX      rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MovLRGold         lda $05                         ; lr pos on image left/right
                  cmp #$02                        ; centered
                  bne MovLRGoldX                  ; no
                  
                  lda $06                         ; lr pos on image up/down
                  cmp #$02                        ; centered
                  bne MovLRGoldX                  ; no
                  
                  ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b                         ; 
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c                         ; 
                  
                  ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileGold                 ; 
                  bne MovLRGoldX                  ; no
                  
                  lsr LR_GetGold                  ; get gold  $00=just gets it
                  ldx #$10                        ;
                  ldy #$20                        ;
                  lda #$04                        ;
                  jsr Randomizer                  ; GetRndNum (x=VicLow y=VicHigh a=RndLow)
                  sta .Rnd01                      ;
                  
                  lda #$04                        ;
                  jsr Randomizer                  ; GetRndNum (x=VicLow y=VicHigh a=RndLow)
                  sta .Rnd02                      ;
                  
                  lda #$04                        ;
                  jsr Randomizer                  ; GetRndNum (x=VicLow y=VicHigh a=RndLow)
                  sta .Rnd03                      ;
                  
                  lda #$04                        ;
                  jsr Randomizer                  ; GetRndNum (x=VicLow y=VicHigh a=RndLow)
                  sta .Rnd04                      ;
                  
                  jsr SetTune                     ; data must follow directly
                  dc.b $04                        ; tune time
.Rnd01            dc.b $00                        ; tune data pointer voice 2
                  dc.b $ff                        ; tune data pointer voice 3
                  dc.b $b0                        ; tune s/r/volume  (not used)
                                                  
                  dc.b $04                        ; tune time
.Rnd02            dc.b $00                        ; tune data pointer voice 2
                  dc.b $ff                        ; tune data pointer voice 3
                  dc.b $a0                        ; tune s/r/volume  (not used)
                                                  
                  dc.b $04                        ; tune time
.Rnd03            dc.b $00                        ; tune data pointer voice 2
                  dc.b $ff                        ; tune data pointer voice 3
                  dc.b $90                        ; tune s/r/volume  (not used)
                                                  
                  dc.b $04                        ; tune time
.Rnd04            dc.b $00                        ; tune data pointer voice 2
                  dc.b $ff                        ; tune data pointer voice 3
                  dc.b $a0                        ; tune s/r/volume  (not used)
                                                  
                  dc.b $00                        ; <EndOfTuneData>

.DecGoldToGet     dec LR_Gold2Get                 ;
                  ldy $04                         ; actual row lode runner
                  sty $50                         ; screen row ($00 - $0f)
                  ldy $03                         ; adr col lode runner
                  sty $4f                         ; screen col ($00 - $1b)
                  lda #$00                        ;
                  sta ($0b),y                     ; 
                  jsr ImageOut2Prep               ; output to preparation screen first ($4000)
                  
                  ldy $50                         ; screen row  (00-0f)
                  ldx $4f                         ; screen col  (00-1b)
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row
                  
                  lda #NoTileGold                 ;
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
                  ldy #$05                        ; gold gives 500 points
                  lda #$00                        ;
                  jsr Score2BaseLine              ;
                  
MovLRGoldX        rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MovLRSetImg       inc $07                         ; lr sprite number
                  cmp $07                         ; lr sprite number
                  bcc .ChkMax                     ; lower - check max
                  
.SetImg           sta $07                         ; lr sprite number
                  rts                             ;

.ChkMax           cpx $07                         ; lr sprite number
                  bcc .SetImg                     ;
                  
MovLRSetImgX      rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MovLRKill         jsr GetLRGfxOff                 ;
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  
                  lda $27                         ; sprite collision  $01=lr caught
                  beq MovLRKillX                  ;
                  
                  lda LR_GetGold                  ; get gold  $00=just gets it
                  beq MovLRKillX                  ;
                  
                  lsr LR_Alive                    ; $00=lr killed
                  
MovLRKillX        rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MovLRWaitPosX     lda $05                         ; lr pos on image left/right
                  cmp #$02                        ; center
                  bcc .IncPos                     ; lower
                  beq MovLRWaitPosXX              ;
                  
                  dec $05                         ; greater so dec lr pos on image left/right
                  jmp MovLRGold                   ; wait for center and handle the gold
                  
.IncPos           inc $05                         ; lr pos on image left/right
                  jmp MovLRGold                   ; wait for center and handle the gold
                  
MovLRWaitPosXX    rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MovLRWaitPosY     lda $06                         ; lr pos on image up/down
                  cmp #$02                        ; center
                  bcc .IncPos                     ; lower
                  beq MovLRWaitPosYX              ;
                  
                  dec $06                         ; greater so dec lr pos on image up/down
                  jmp MovLRGold                   ; wait for center and handle the gold
                  
.IncPos           inc $06                         ; lr pos on image up/down
                  jmp MovLRGold                   ; wait for center and handle the gold
                  
MovLRWaitPosYX    rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MovLRSetHole      lda #$00                        ;
                  sta LR_Shoots                   ; $00=no  $01=shoot right  $ff=shoot left
                  
                  ldy $04                         ; actual row lode runner
                  iny                             ;
                  stx $4f                         ; screen col ($00 - $1b)
                  sty $50                         ; screen row ($00 - $0f)
                  
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09                         ; 
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a                         ; 
                  
                  lda #NoTileBlank                ; empty
                  ldy $4f                         ; screen col  (00-1b)
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  jsr ImageOut2Disp               ; output directly to display screen ($2000)
                  
                  lda #NoTileBlank                ; empty
                  jsr ImageOut2Prep               ; output to preparation screen first ($4000)
                  
                  dec $50                         ; screen row ($00 - $0f)
                  lda #NoTileBlank                ; empty
                  jsr ImageOut2Disp               ; output directly to display screen ($2000)
                  
                  inc $50                         ; screen row ($00 - $0f)
                  ldx #$ff                        ;
.GetFreeSlot      inx                             ;
                  cpx #LR_TabHoleMax              ; $1e - max 30 slots
                  beq MovLRSetHoleX               ;
                  
                  lda LR_TabHoleOpenT,x           ; hole open time tab
                  bne .GetFreeSlot                ; already used - check next slot
                  
                  lda $50                         ; screen row  (00-0f)
                  sta LR_TabHoleRow,x             ; hole row tab
                  lda $4f                         ; screen col  (00-1b)
                  sta LR_TabHoleCol,x             ; hole column tab
                  
                  lda #LR_TabHoleOpenI            ;
                  sta LR_TabHoleOpenT,x           ; hole open time tab
                  
                  sec                             ;
MovLRSetHoleX     rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
IGC_IncLevel      lda C64_KeyFlag                 ; $01=shift $02=commodore $04=ctrl
                  and #$06                        ;
                  cmp #$06                        ; Ctrl+Commodore
                  bne IGC_IncLevelX               ;
                  
                  lda CR_Cheat                    ; cheat mode set after RUN/STOP and F7 and RUN/STOP
                  beq IGC_IncLevelX               ;
                  
                  inc LR_NumLives                 ; inc because of kill with lsr Lr_Alive
                  inc LR_LevelNoGame              ; 001-050
                  inc LR_LevelNoDisk              ; 000-049
                  
                  lsr LR_Alive                    ; $00=killed
                  
IGC_IncLevelX     rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
IGC_IncLives      lda C64_KeyFlag                 ; $01=shift $02=commodore $04=ctrl
                  and #$06                        ;
                  cmp #$06                        ; Ctrl+Commodore
                  bne IGC_IncLivesX               ;
                  
                  lda CR_Cheat                    ; cheat mode set after RUN/STOP and F7 and RUN/STOP
                  beq IGC_IncLivesX               ;
                  
                  inc LR_NumLives                 ; 
                  bne .LivesOut                   ; max 255
                  dec LR_NumLives                 ; lrNumLives
                  
.LivesOut         jsr Lives2BaseLine              ; StatusOutLives

IGC_IncLivesX     jmp GetPlayCmd                  ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MoveEnemies       ldx LR_EnmyNo                   ; number of enemies
                  beq MoveEnemiesX                ;
                  
                  inc $36                         ; pointer actual enemy cycles
                  ldy $36                         ;
                  cpy #$03                        ;
                  bcc .NextCycle                  ; lower $00-$02
                  
                  ldy #$00                        ;
                  sty $36                         ;
                  
.NextCycle        lda $32,y                       ; .hbu000. - load move cycles
                  sta $35                         ; enemy move control
.Cycle            lsr $35                         ; enemy move control
                  bcc .ChkCycle                   ;
                  
                  jsr MoveOneEnemy                ;
                  
                  lda LR_Alive                    ; $00=lr killed
                  beq MoveEnemiesX                ; exit if dead
                  
.ChkCycle         lda $35                         ; enemy move control
                  bne .Cycle                      ;
                  
MoveEnemiesX      rts
; ------------------------------------------------------------------------------------------------------------- ;
TabEnmyCycles1    dc.b $00 ; ........             ; LR_CntSpeedLaps ($00-$09) + LR_EnmyNo
TabEnmyCycles2    dc.b $00 ; ........
TabEnmyCycles3    dc.b $00 ; ........
                  
                  dc.b $00 ; ........
                  dc.b $01 ; .......#
                  dc.b $01 ; .......#
                  
                  dc.b $01 ; .......#
                  dc.b $01 ; .......#
                  dc.b $01 ; .......#
                  
                  dc.b $01 ; .......#
                  dc.b $03 ; ......##
                  dc.b $01 ; .......#
                  
                  dc.b $01 ; .......#
                  dc.b $03 ; ......##
                  dc.b $03 ; ......##
                  
                  dc.b $03 ; ......##
                  dc.b $03 ; ......##
                  dc.b $03 ; ......##
                  
                  dc.b $03 ; ......##
                  dc.b $03 ; ......##
                  dc.b $07 ; .....###
                  
                  dc.b $03 ; ......##
                  dc.b $07 ; .....###
                  dc.b $07 ; .....###
                  
                  dc.b $07 ; .....###
                  dc.b $07 ; .....###
                  dc.b $07 ; .....###
                  
                  dc.b $07 ; .....###
                  dc.b $07 ; .....###
                  dc.b $0f ; ....####
                  
                  dc.b $07 ; .....###
                  dc.b $0f ; ....####
                  dc.b $0f ; ....####
                  
                  dc.b $0f ; ....####
                  dc.b $0f ; ....####
                  dc.b $0f ; ....####
                  
                  dc.b $0f ; ....####
                  dc.b $0f ; ....####
                  dc.b $1f ; ...#####
                  
                  dc.b $0f ; ....####
                  dc.b $1f ; ...#####
                  dc.b $1f ; ...#####
                  
                  dc.b $1f ; ...#####
                  dc.b $1f ; ...#####
                  dc.b $1f ; ...#####
                  
                  dc.b $1f ; ...#####
                  dc.b $1f ; ...#####
                  dc.b $3f ; ..######
                  
                  dc.b $1f ; ...#####
                  dc.b $3f ; ..######
                  dc.b $3f ; ..######
                  
                  dc.b $3f ; ..######
                  dc.b $3f ; ..######
                  dc.b $3f ; ..######
                  
                  dc.b $3f ; ..######
                  dc.b $3f ; ..######
                  dc.b $7f ; .#######
                  
                  dc.b $3f ; ..######
                  dc.b $7f ; .#######
                  dc.b $7f ; .#######
                  
                  dc.b $7f ; .#######
                  dc.b $7f ; .#######
                  dc.b $7f ; .#######
; ------------------------------------------------------------------------------------------------------------- ;
TabSpriteNoEnemy  equ *
TabEN_RunLeMin    dc.b NoSprtMC_RuLe00 ; $00 - run    left 01       - have enemy sprite numbers from $00-$0f
                  dc.b NoSprtMC_RuLe01 ; $01 - run    left 02
TabEN_RunLeMax    dc.b NoSprtMC_RuLe02 ; $02 - run    left 03
TabEN_PoleLeMin   dc.b NoSprtMC_PoLe00 ; $03 - pole   left 01
                  dc.b NoSprtMC_PoLe01 ; $04 - pole   left 02
TabEN_PoleLeMax   dc.b NoSprtMC_PoLe02 ; $05 - pole   left 03
                  dc.b NoSprtMC_FallLe ; $06 - fall   left
TabEN_RunRiMin    dc.b NoSprtMC_RuRi00 ; $07 - run    right 01
                  dc.b NoSprtMC_RuRi01 ; $08 - run    right 02
TabEN_RunRiMax    dc.b NoSprtMC_RuRi02 ; $09 - run    right 03
TabEN_PoleRiMin   dc.b NoSprtMC_PoRi00 ; $0a - pole   right 01
                  dc.b NoSprtMC_PoRi01 ; $0b - pole   right 02
TabEN_PoleRiMax   dc.b NoSprtMC_PoRi02 ; $0c - pole   right 03
                  dc.b NoSprtMC_FallRi ; $0d - fall   right
TabEN_LadderMin   dc.b NoSprtMC_Ladr00 ; $0e - ladder up/down 01
TabEN_LadderMax   dc.b NoSprtMC_Ladr01 ; $0f - ladder up/down 02
; ------------------------------------------------------------------------------------------------------------- ;
NoEN_RunLeMin     equ TabEN_RunLeMin  - TabSpriteNoEnemy
NoEN_RunLeMax     equ TabEN_RunLeMax  - TabSpriteNoEnemy
NoEN_PoleLeMin    equ TabEN_PoleLeMin - TabSpriteNoEnemy
NoEN_PoleLeMax    equ TabEN_PoleLeMax - TabSpriteNoEnemy
NoEN_RunRiMin     equ TabEN_RunRiMin  - TabSpriteNoEnemy
NoEN_RunRiMax     equ TabEN_RunRiMax  - TabSpriteNoEnemy
NoEN_PoleRiMin    equ TabEN_PoleRiMin - TabSpriteNoEnemy
NoEN_PoleRiMax    equ TabEN_PoleRiMax - TabSpriteNoEnemy
NoEN_LadderMin    equ TabEN_LadderMin - TabSpriteNoEnemy
NoEN_LadderMax    equ TabEN_LadderMax - TabSpriteNoEnemy
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MoveOneEnemy      inc LR_NoEnemy2Move             ; select next enemy
                  ldx LR_EnmyNo                   ; number of enemies
                  cpx LR_NoEnemy2Move             ; # of enemy to move
                  bcs .GetStatus                  ; max not reached
                  
                  ldx #LR_NoEnemy2MvMin           ; reset to first enemy
                  stx LR_NoEnemy2Move             ; 
                  
.GetStatus        jsr GetEnemyStatus              ;

.ChkHoleTime      lda $19                         ; enemy time in hole
                  bmi EnemyHoleTimeUp             ; time is up
                  beq EnemyHoleTimeUp             ; time is up
                  
                  dec $19                         ; enemy time in hole
                  ldy $19                         ; enemy time in hole
                  
                  cpy #LR_EnmyShivStart           ;
                  bcs .GetEnemyNo                 ; greater/equal
                  
                  jmp ShiverEnemyOut              ; lower - do shiver
                  
.GetEnemyNo       ldx LR_NoEnemy2Move             ; # of enemy to move
                  lda LR_TabEnemyBirtT,x          ; enemy rebirth step time
                  beq GoGfxOutXit                 ;
                  
MoveOneEnemyX     jmp SavEnemyStatus              ;
; ------------------------------------------------------------------------------------------------------------- ;
GoGfxOutXit       jmp MoveEnemyGfxOutX            ; enemy sprite out and exit move
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
EnemyHoleTimeUp   ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b                         ; 
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c                         ; 
                  
                  ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  
                  cmp #NoTileLadder               ;
                  beq EnemyHoleTimeUpX            ; free again
                  
                  cmp #NoTilePole                 ;
                  bne .ChkCenterLow               ;
                  
.ChkCenter        lda $1b                         ; actual enemy pos on image up/down
                  cmp #$02                        ; centered
                  beq EnemyHoleTimeUpX            ; free again
                  
.ChkCenterLow     lda $1b                         ; actual enemy pos on image up/down
                  cmp #$02                        ; center
                  bcc MoveEnemyGfxOut             ; lower
                  
.ChkCenterHigh    ldy $16                         ; actual enemy row
                  cpy #LR_ScrnMaxRows             ; $0f - max 15 rows
                  beq EnemyHoleTimeUpX            ; free again
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $09                         ; 
                  sta $0b                         ; 
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c                         ; 
                  lda TabExLvlDatRowH8+1,y        ; expanded level data row pointer $0800-$09c3
                  sta $0a                         ; 
                  
                  ldy $15                         ; actual enemy col
                  lda ($09),y                     ; unpacked level data ($0800-$09c3) + 1
                  
                  cmp #NoTileBlank                ;
                  beq MoveEnemyGfxOut             ;
                  
                  cmp #NoTileLodeRunner           ;
                  beq MoveEnemyGfxOut             ;
                  
                  cmp #NoTileEnemy                ;
                  beq EnemyHoleTimeUpX            ;
                  
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3) + 1
                  cmp #NoTileWallWeak             ;
                  beq EnemyHoleTimeUpX            ;
                  
                  cmp #NoTileWallHard             ;
                  beq EnemyHoleTimeUpX            ; free again
                  
                  cmp #NoTileLadder               ;
                  bne MoveEnemyGfxOut             ;
                  
EnemyHoleTimeUpX  jmp MoveEnemy                   ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MoveEnemyGfxOut   jsr MovEnmyGetXYNo              ;
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  jsr CenterEnemyLR               ;
                  
                  lda #$06                        ; .honz fall left
                  
                  ldy $18                         ; actual enemy dir right/left  $ff=left  $01=right
                  bmi .SetEnemySprtNo             ;
                  
                  lda #$0d                        ; .honz fall right
                  
.SetEnemySprtNo   sta $17                         ; actual enemy sprite number

                  inc $1b                         ; actual enemy pos on image up/down
                  lda $1b                         ; actual enemy pos on image up/down
                  cmp #$05                        ; max
                  bcs B_81ba                      ;
                  
                  lda $1b                         ; actual enemy pos on image up/down
                  cmp #$02                        ; center
                  bne MoveEnemyGfxOutX            ; enemy sprite out and exit move
                  
.GoTakeGold       jsr EnmyTakeGold                ;
                  
                  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b                         ; 
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c                         ;
                  
                  ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  
                  cmp #NoTileWallWeak             ;
                  bne MoveEnemyGfxOutX            ;
                  
                  lda $19                         ; enemy time in hole
                  bpl .StoreHoleTime              ;
                  
                  dec LR_Gold2Get                 ; 
                  
.StoreHoleTime    lda LR_EnmyHoleTime             ; enemy time in hole
                  sta $19                         ; enemy time in hole
                  
.ScoreEnemyHole   ldy #$01                        ;
                  lda #$00                        ; score 100 points for a digged in enemy
                  jsr Score2BaseLine              ; 
                  
MoveEnemyGfxOutX  jsr MovEnmyGetXYNo              ;
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  jmp SavEnemyStatus              ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
B_81ba            lda #$00                        ;
                  sta $1b                         ; actual enemy pos on image up/down
                  
                  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  bne .Store
                  
                  lda #NoTileBlank
                  
.Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  inc $16                         ; actual enemy row
                  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $15                         ; actual enemy col
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
.ChkCatchLR       cmp #NoTileLodeRunner
                  bne .NoCatchLR
                  
.KillLR           lsr LR_Alive                    ; $00=lr killed
                  
.NoCatchLR        lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  bne .SetEnemyTile
                  
                  lda $19                         ; enemy time in hole
                  bpl .SetEnemyTile
                  
                  ldy $16                         ; actual enemy row
                  dey
                  sty $50                         ; screen row  (00-0f)
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $15                         ; actual enemy col
                  sty $4f                         ; screen col  (00-1b)
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
.ChkEmpty         cmp #NoTileBlank
                  beq .LeaveGold
                  
                  dec LR_Gold2Get
                  jmp .GetEnemyTilePtr            ; a piece of gold got lost
                  
.LeaveGold        lda #NoTileGold
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  sta ($0b),y                     ; play level control data ($0a00-$0bc3)
                  
.DisplayGold      jsr ImageOut2Prep               ; direct output to preparation screen
                  
                  ldy $50                         ; screen row  (00-0f)
                  ldx $4f                         ; screen col  (00-1b)
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row
                  
                  lda #NoTileGold
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  
.GetEnemyTilePtr  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  lda #LR_EnmyHoleTI              ; $00 - init
                  sta $19                         ; enemy time in hole
                  
                  ldy $15                         ; actual enemy col
.SetEnemyTile     lda #NoTileEnemy
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  jsr MovEnmyGetXYNo
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  
                  jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ShiverEnemyOut    cpy #LR_EnmyShivStop            ; move out if lower
                  bcc MoveEnemy
                  
                  jsr MovEnmyGetXYNo              ; Gold/Enemy/LR
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
                  ldy $19                         ; enemy time in hole
                  lda TabEnemyShiver-7,y          ; shiver the last hole seconds
                  sta $1a                         ; actual enemy pos on image left/right
                  
.ShiverOut        jsr MovEnmyGetXYNo
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  
ShiverEnemyOutX   jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
TabEnemyShiver    dc.b $02
                  dc.b $01
                  dc.b $02
                  dc.b $03
                  dc.b $02
                  dc.b $01
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MoveEnemy         ldx $15                         ; actual enemy col
                  ldy $16                         ; actual enemy row
                  jsr GetEnemyMoveDir             ;
                  
                  asl a                           ;
                  tay                             ;
                  lda TabEnemyMoveDir+1,y         ;
                  pha                             ;
                  lda TabEnemyMoveDir,y           ;
                  pha                             ;
                  
MoveEnemyX        rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TabEnemyMoveDir   dc.w SavEnemyStatus - 1
                  dc.w MoveEnemyLeft  - 1
                  dc.w MoveEnemyRight - 1
                  dc.w MoveEnemyUp    - 1
                  dc.w MoveEnemyDown  - 1
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MoveEnemyUpHole   lda $19                         ; enemy time in hole
                  beq MoveEnemyUpHoleX
                  bmi MoveEnemyUpHoleX
                  
                  inc $19                         ; enemy time in hole
MoveEnemyUpHoleX  jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MoveEnemyUp       ldy $1b                         ; actual enemy pos on image up/down
                  cpy #$03
                  bcs StepEnemyUp
                  
                  ldy $16                         ; actual enemy row
                  beq MoveEnemyUpHole             ; already already max up
                  
                  dey
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $15                         ; actual enemy col
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #NoTileWallWeak
                  beq MoveEnemyUpHole             ; blocked
                  
                  cmp #NoTileWallHard
                  beq MoveEnemyUpHole             ; blocked
                  
                  cmp #NoTileWallTrap
                  beq MoveEnemyUpHole             ; blocked
                  
                  cmp #NoTileEnemy
MoveEnemyUpX      beq MoveEnemyUpHole             ; blocked
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
StepEnemyUp       jsr MovEnmyGetXYNo
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  jsr CenterEnemyLR
                  
                  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  dec $1b                         ; actual enemy pos on image up/down
                  bpl GoEnemyTakeGold
                  
.GoEnemyDropGold  jsr EnmyDropGold
                  
                  ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  bne .Store
                  
                  lda #NoTileBlank
                  
.Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  dec $16                         ; actual enemy row
                  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $15                         ; actual enemy col
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
.ChkCatchLR       cmp #NoTileLodeRunner
                  bne .NoCatchLR
                  
.KillLR           lsr LR_Alive                    ; $00=lr killed
                  
.NoCatchLR        lda #NoTileEnemy
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  lda #$04
                  sta $1b                         ; actual enemy pos on image up/down
                  bne ChkEnemySprtRng
                  
GoEnemyTakeGold   jsr EnmyTakeGold
                  
ChkEnemySprtRng   lda #NoEN_LadderMin             ; .hbu008.
                  ldx #NoEN_LadderMax             ; .hbu008.
                  
                  jsr MovENSetImg                 ; increase sprite number and check range
                  jsr MovEnmyGetXYNo
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  
StepEnemyUpX      jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MoveEnemyDown     ldy $1b                         ; actual enemy pos on image up/down
                  cpy #$02
                  bcc StepEnemyDown
                  
                  ldy $16                         ; actual enemy row
                  cpy #LR_ScrnMaxRows
                  bcs MoveEnemyDownX              ; already max down
                  
                  iny
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $15                         ; actual enemy col
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #NoTileWallHard
                  beq MoveEnemyDownX              ; blocked
                  
                  cmp #NoTileEnemy
                  beq MoveEnemyDownX              ; blocked
                  
                  cmp #NoTileWallWeak             ; blocked
                  bne StepEnemyDown
                  
MoveEnemyDownX    jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
StepEnemyDown     jsr MovEnmyGetXYNo
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  jsr CenterEnemyLR
                  
                  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  inc $1b                         ; actual enemy pos on image up/down
                  lda $1b                         ; actual enemy pos on image up/down
                  cmp #$05
                  bcc StepEnemyDownX
                  
                  jsr EnmyDropGold
                  
                  ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  bne .Store
                  
                  lda #$00
.Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  inc $16                         ; actual enemy row
                  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $15                         ; actual enemy col
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
.ChkCatchLR       cmp #NoTileLodeRunner
                  bne .NoCatchLR
                  
.KillLR           lsr LR_Alive                    ; $00=lr killed
                  
.NoCatchLR        lda #NoTileEnemy
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  lda #$00
                  sta $1b                         ; actual enemy pos on image up/down
                  jmp ChkEnemySprtRng
                  
StepEnemyDownX    jmp GoEnemyTakeGold
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MoveEnemyLeft     ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldx $1a                         ; actual enemy pos on image left/right
                  cpx #$03
                  bcs StepEnemyLeft               ; equal or greater
                  
                  ldy $15                         ; actual enemy col
                  beq MoveEnemyLeftX              ; already max left
                  
.ChkLeft          dey
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #NoTileEnemy
                  beq MoveEnemyLeftX              ; blocked
                  
                  cmp #NoTileWallHard
                  beq MoveEnemyLeftX              ; blocked
                  
                  cmp #NoTileWallWeak
                  beq MoveEnemyLeftX              ; blocked
                  
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallTrap             ; blocked
                  bne StepEnemyLeft
                  
MoveEnemyLeftX    jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
StepEnemyLeft     jsr MovEnmyGetXYNo
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  jsr CenterEnemyUD
                  
                  lda #$ff
                  sta $18                         ; actual enemy dir right/left  $ff=left  $01=right
                  
                  dec $1a                         ; actual enemy pos on image left/right
                  bpl .GoTakeGold
                  
.GoDropGold       jsr EnmyDropGold
                  
                  ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  bne .Store
                  
                  lda #NoTileBlank
                  
.Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  dec $15                         ; actual enemy col
                  dey
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
.ChkCatchLR       cmp #NoTileLodeRunner
                  bne .NoCatchLR
                  
.KillLR           lsr LR_Alive                    ; $00=lr killed
                  
.NoCatchLR        lda #NoTileEnemy
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  lda #$04
                  sta $1a                         ; actual enemy pos on image left/right
                  bne .GetTile                    ; always
                  
.GoTakeGold       jsr EnmyTakeGold
                  
.GetTile          ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
.ChkPole          cmp #NoTilePole
                  beq .SetSpritePoleLe
                  
.SetSpriteRunLe   lda #NoEN_RunLeMin              ; .hbu008.
                  ldx #NoEN_RunLeMax              ; .hbu008
                  bne .DisplaySprite              ; always
                  
.SetSpritePoleLe  lda #NoEN_PoleLeMin             ; .hbu008.
                  ldx #NoEN_PoleLeMax             ; .hbu008.
                  
.DisplaySprite    jsr MovENSetImg                 ; increase sprite number and check range
                  jsr MovEnmyGetXYNo
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  
StepEnemyLeftX    jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MoveEnemyRight    ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldx $1a                         ; actual enemy pos on image left/right
                  cpx #$02
                  bcc StepEnemyRight
                  
                  ldy $15                         ; actual enemy col
                  cpy #LR_ScrnMaxCols
                  beq MoveEnemyRightX             ; already max right
                  
.ChkRight         iny
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #NoTileEnemy
                  beq MoveEnemyRightX             ; blocked
                  
                  cmp #NoTileWallHard
                  beq MoveEnemyRightX             ; blocked
                  
                  cmp #NoTileWallWeak
                  beq MoveEnemyRightX             ; blocked
                  
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallTrap             ; blocked
                  bne StepEnemyRight              ; Ladder/Pole/XitLadder/Gold/LR
                  
MoveEnemyRightX   jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
StepEnemyRight    jsr MovEnmyGetXYNo
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  jsr CenterEnemyUD
                  
                  lda #$01
                  sta $18                         ; actual enemy dir right/left  $ff=left  $01=right
                  
                  inc $1a                         ; actual enemy pos on image left/right
                  lda $1a                         ; actual enemy pos on image left/right
                  cmp #$05
                  bcc .GoTakeGold
                  
.GoDropGold       jsr EnmyDropGold
                  
                  ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  bne .Store
                  
                  lda #NoTileBlank
                  
.Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  inc $15                         ; actual enemy col
                  iny
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
.ChkCatchLR       cmp #NoTileLodeRunner
                  bne .NoCatchLR
                  
.KillLR           lsr LR_Alive                    ; $00=lr killed
                  
.NoCatchLR        lda #NoTileEnemy
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  lda #$00
                  sta $1a                         ; actual enemy pos on image left/right
                  beq .GetTile
                  
.GoTakeGold       jsr EnmyTakeGold
                  
.GetTile          ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTilePole
                  beq .SetSpritePoleRi
                  
.SetSpriteRunRi   lda #NoEN_RunRiMin              ; .hbu008.
                  ldx #NoEN_RunRiMax              ; .hbu008.
                  bne .DisplaySprite
                  
.SetSpritePoleRi  lda #NoEN_PoleRiMin             ; .hbu008.
                  ldx #NoEN_PoleRiMax             ; .hbu008.
                  
.DisplaySprite    jsr MovENSetImg                 ; increase sprite number and check range
                  jsr MovEnmyGetXYNo
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  
StepEnemyRightX   jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
GetEnemyMoveDir   stx $28                         ; actual enemy work col
                  sty $29                         ; actual enemy work row
                  
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b                         ; 
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c                         ; 
                  
                  ldy $28                         ; actual enemy work col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  
                  cmp #NoTileWallWeak             ;
                  bne TstRowEnmyLR                ;
                  
                  lda $19                         ; enemy time in hole
                  beq TstRowEnmyLR                ;   is up
                  bmi TstRowEnmyLR                ;   is up
                  
                  lda #LR_EnemyMoveUp             ;
                  rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
TstRowEnmyLR      ldy $29                         ; actual enemy work row
                  cpy $04                         ; actual row lode runner
                  beq BothOnSameRow               ;
                  
TstRowEnmyLRX     jmp BothOnDiffRow               ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
BothOnSameRow     ldy $28                         ; actual enemy work col
                  sty $2a                         ; save actual enemy work col
                  
                  cpy $03                         ; actual col lode runner
BothOnSameRowX    bcs EnemyOnRiOfLR               ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
EnemyOnLeOfLR     inc $2a                         ; save actual enemy work col

                  ldy $29                         ; actual enemy work row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b                         ;
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c                         ; 
                  
                  ldy $2a                         ; save actual enemy work col
.GetTileRi        lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileLadder               ;
                  beq .ChkLRReached               ; 
                  
                  cmp #NoTilePole                 ;
                  beq .ChkLRReached               ;
                  
                  ldy $29                         ; actual enemy work row
                  cpy #LR_ScrnMaxRows             ;
                  beq .ChkLRReached               ; bottom reached
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b                         ;
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c                         ; 
                  
                  ldy $2a                         ; save actual enemy work col
.GetTileRiDo      lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileBlank                ;
                  beq BothOnDiffRow               ; 
                  
                  cmp #NoTileWallTrap             ;
                  beq BothOnDiffRow               ;
                  
.ChkLRReached     ldy $2a                         ; save actual enemy work col
                  cpy $03                         ; actual col lode runner
                  bne EnemyOnLeOfLR               ;
                  
                  lda #LR_EnemyMoveRi             ; 
                  
EnemyOnLeOfLRX    rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
EnemyOnRiOfLR     dec $2a                         ; save actual enemy work col

                  ldy $29                         ; actual enemy work row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b                         ;
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c                         ; 
                  
                  ldy $2a                         ; save actual enemy work col
.GetTileLe        lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #$03                        ;
                  beq .ChkLRReached               ; 
                  
                  cmp #NoTilePole                 ;
                  beq .ChkLRReached               ;
                  
                  ldy $29                         ; actual enemy work row
                  cpy #LR_ScrnMaxRows             ;
                  beq .ChkLRReached               ;
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b                         ;
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c                         ; 
                  
                  ldy $2a                         ; save actual enemy work col
.GetTileLeDo      lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileBlank                ;
                  beq BothOnDiffRow               ; 
                  
                  cmp #NoTileWallTrap             ;
                  beq BothOnDiffRow               ;
                  
.ChkLRReached     ldy $2a                         ; save actual enemy work col
                  cpy $03                         ; actual col lode runner
                  bne EnemyOnRiOfLR               ;
                  
                  lda #LR_EnemyMoveLe             ; 
                  
EnemyOnRiOfLRX    rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
BothOnDiffRow     lda #LR_EnemyMoveNo             ;
                  sta $2b                         ; actual enemy move direction
                  lda #$ff                        ; init
                  sta $2c                         ; move direction indicator
                  
                  ldx $28                         ; actual enemy work col
                  ldy $29                         ; actual enemy work row
                  
                  jsr GetEnmyPossLR               ;
                  jsr GetEnmyPossUD               ;
                  jsr TestColLeft                 ;
                  jsr TestColRight                ;
                  
                  lda $2b                         ; actual enemy move direction
BothOnDiffRowX    rts                             ; 
BothOnDiffRowXX   rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
TestColLeft       ldy $2d                         ; actual enemy possible col left
                  cpy $28                         ; actual enemy work col
                  beq BothOnDiffRowXX
                  
                  ldy $29                         ; actual enemy work row
                  cpy #$0f
                  beq .ChkWorkRow
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $2d                         ; actual enemy possible col left
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  beq .ChkWorkRow
                  
                  cmp #NoTileWallHard
                  beq .ChkWorkRow
                  
                  ldx $2d                         ; actual enemy possible col left
                  ldy $29                         ; actual enemy work row
                  jsr FindEnmyMoveUD1             ; ac=target row
                  
                  ldx $2d                         ; actual enemy possible col left
                  jsr GetDirIndicator
                  
                  cmp $2c                         ; move direction indicator
                  bcs .ChkWorkRow
                  
.SetNewInd01      sta $2c                         ; move direction indicator
                  
.SetDirLeft01     lda #LR_EnemyMoveLe
                  sta $2b                         ; actual enemy move direction
                  
.ChkWorkRow       ldy $29                         ; actual enemy work row
                  beq .IncColLeft
                  
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $2d                         ; actual enemy possible col left
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
.GetTileLe        cmp #NoTileLadder
                  bne .IncColLeft
                  
                  ldy $29                         ; actual enemy work row
                  ldx $2d                         ; actual enemy possible col left
                  jsr FindEnmyMoveUD0
                  
                  ldx $2d                         ; actual enemy possible col left
                  jsr GetDirIndicator
                  
                  cmp $2c                         ; move direction indicator
                  bcs .IncColLeft
                  
.SetNewInd02      sta $2c                         ; move direction indicator
                  
.SetDirLeft02     lda #LR_EnemyMoveLe
                  sta $2b                         ; actual enemy move direction
                  
.IncColLeft       inc $2d                         ; actual enemy possible col left
                  jmp TestColLeft
                  
TestColLeftX      rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
TestColRight      ldy $2e                         ; actual enemy possible col right
                  cpy $28                         ; actual enemy work col
                  beq TestColLeftX                ; max left
                  
                  ldy $29                         ; actual enemy work row
                  cpy #LR_ScrnMaxRows
                  beq .ChkMaxUp                   ; max down reached
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $2e                         ; actual enemy possible col right
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
.ChkTileRowDo     cmp #NoTileWallWeak
                  beq .ChkMaxUp
                  
                  cmp #NoTileWallHard
                  beq .ChkMaxUp
                  
                  ldx $2e                         ; actual enemy possible col right
                  ldy $29                         ; actual enemy work row
                  jsr FindEnmyMoveUD1             ; ac=target row
                  
                  ldx $2e                         ; actual enemy possible col right
                  jsr GetDirIndicator
                  
                  cmp $2c                         ; move direction indicator
                  bcs .ChkMaxUp
                  
.SetNewInd01      sta $2c                         ; move direction indicator
                  
.SetDirRight01    lda #LR_EnemyMoveRi
                  sta $2b                         ; actual enemy move direction
                  
.ChkMaxUp         ldy $29                         ; actual enemy work row
                  beq .DecColRight                ; max up reached - exit
                  
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $2e                         ; actual enemy possible col right
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileLadder
                  bne .DecColRight
                  
                  ldy $29                         ; actual enemy work row
                  ldx $2e                         ; actual enemy possible col right
                  jsr FindEnmyMoveUD0
                  
                  ldx $2e                         ; actual enemy possible col right
                  jsr GetDirIndicator
                  
                  cmp $2c                         ; move direction indicator
                  bcs .DecColRight
                  
.SetNewInd02      sta $2c                         ; move direction indicator
                  
.SetDirRight02    lda #LR_EnemyMoveRi
                  sta $2b                         ; actual enemy move direction
                  
.DecColRight      dec $2e                         ; actual enemy possible col right
TestColRightX     jmp TestColRight
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
GetEnmyPossUD     ldy $29                         ; actual enemy work row
                  cpy #LR_ScrnMaxRows
                  beq .ChkTopOfScreen             ; already on bottom of screen
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $28                         ; actual enemy work col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  beq .ChkTopOfScreen
                  
                  cmp #NoTileWallHard
                  beq .ChkTopOfScreen
                  
                  ldx $28                         ; actual enemy work col
                  ldy $29                         ; actual enemy work row
                  jsr FindEnmyMoveUD1             ; ac=target row
                  
                  ldx $28                         ; actual enemy work col
                  jsr GetDirIndicator
                  
                  cmp $2c                         ; move direction indicator
                  bcs .ChkTopOfScreen
                  
.SetNewIndDo      sta $2c                         ; move direction indicator
                  
.SetDirDown       lda #LR_EnemyMoveDo
                  sta $2b                         ; actual enemy move direction
                  
.ChkTopOfScreen   ldy $29                         ; actual enemy work row
                  beq GetEnmyPossUDX
                  
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $28                         ; actual enemy work col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileLadder
                  bne GetEnmyPossUDX
                  
                  ldx $28                         ; actual enemy work col
                  ldy $29                         ; actual enemy work row
                  jsr FindEnmyMoveUD0
                  
                  ldx $28                         ; actual enemy work col
                  jsr GetDirIndicator
                  
                  cmp $2c                         ; move direction indicator
                  bcs GetEnmyPossUDX
                  
.SetNewIndUp      sta $2c                         ; move direction indicator
                  
.SetDirUp         lda #LR_EnemyMoveUp
                  sta $2b                         ; actual enemy move direction
                  
GetEnmyPossUDX    rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
GetDirIndicator   sta $1e                         ; save target row
                  
.ChkRowLR         cmp $04                         ; actual row lode runner
                  bne .NotOnRowLR
                  
.SameLR           cpx $15                         ; actual enemy col
                  bcc .Lower                      ; lower
                  
                  txa
                  sec
                  sbc $15                         ; actual enemy col
                  rts
                  
.Lower            stx $1e                         ; actual enemy possible col left to save target row
                  lda $15                         ; actual enemy col
                  sec
                  sbc $1e                         ; save target row
                  rts
                  
.NotOnRowLR       bcc .AboveLR
                  
.BelowLR          sec
                  sbc $04                         ; actual row lode runner
                  clc
                  adc #$64 * 2                    ; $c8
                  rts
                  
.AboveLR          lda $04                         ; actual row lode runner
                  sec
                  sbc $1e                         ; save target row
                  clc
                  adc #$64
                  
GetDirIndicatorX  rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
RetTargetRow2     lda $31                         ; target row from work row
                  
RetTargetRow2X    rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
FindEnmyMoveUD0   sty $31                         ; target row from work row
                  stx $30                         ; target col from work col or possible col ri/le
                  
.ChkNextTileUp0   lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $30                         ; target col from work col or possible col ri/le
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileLadder
                  bne RetTargetRow2               ; exit
                  
.SetTargetRowUp   dec $31                         ; target row from work row
                  
                  ldy $30                         ; target col from work col or possible col ri/le
                  beq .ChkMaxColRi                ; already max left
                  
                  dey
                  
.GetTileLe        lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  beq .SetSavTargRowLe
                  
                  cmp #NoTileWallHard
                  beq .SetSavTargRowLe
                  
                  cmp #NoTileLadder
                  beq .SetSavTargRowLe
                  
                  ldy $31                         ; target row from work row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $30                         ; target col from work col or possible col ri/le
                  
                  dey
                  
.GetTileUpLe      lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTilePole
                  bne .ChkMaxColRi
                  
.SetSavTargRowLe  ldy $31                         ; target row from work row
                  sty $2f                         ; save target row from work row
                  cpy $04                         ; actual row lode runner
                  bcc RetSavTargetRow
                  beq RetSavTargetRow
                  
.ChkMaxColRi      ldy $30                         ; target col from work col or possible col ri/le
                  cpy #LR_ScrnMaxCols
                  beq .ChkTop
                  
                  ldy $31                         ; target row from work row
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $30                         ; target col from work col or possible col ri/le
                  iny
                  
.GetTileRi        lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  beq .SetSavTargRow
                  
                  cmp #NoTileWallHard
                  beq .SetSavTargRow
                  
                  cmp #NoTileLadder
                  beq .SetSavTargRow
                  
                  ldy $31                         ; target row from work row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $30                         ; target col from work col or possible col ri/le
                  iny
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTilePole
                  bne .ChkTop
                  
.SetSavTargRow    ldy $31                         ; target row from work row
                  sty $2f                         ; save target row from work row
                  cpy $04                         ; actual row lode runner
                  bcc RetSavTargetRow
                  beq RetSavTargetRow
                  
.ChkTop           ldy $31                         ; target row from work row
                  cpy #$01
                  bcc .RetTargetRow
                  
.GoCheckNext      jmp .ChkNextTileUp0
                  
.RetTargetRow     tya
                  
FindEnmyMoveUD0X  rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
RetSavTargetRow   lda $2f                         ; save target row from work row
                  
RetSavTargetRowX  rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
RetTargetRow      lda $31                         ; target row from work row
                  
RetTargetRowX     rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
FindEnmyMoveUD1   sty $31                         ; target row from work row
                  stx $30                         ; target col from work col or possible col ri/le
                  
.ChkNextTileUp1   lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $30                         ; target col from work col or possible col ri/le
.TileUnderFoot    lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  beq RetTargetRow
                  
                  cmp #NoTileWallHard
                  beq RetTargetRow
                  
                  ldy $31                         ; target row from work row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $30                         ; target col from work col or possible col ri/le
.TileLeRi         lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileBlank
                  beq .ChkRows
                  
                  cpy #$00                        ; max left
                  beq .ChkCols
                  
                  dey
                  
.TileNextLe       lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTilePole
                  beq .SetTargetRowLe
                  
                  ldy $31                         ; target row from work row
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $30                         ; target col from work col or possible col ri/le
                  dey
.TileUnderFootLe  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  beq .SetTargetRowLe
                  
                  cmp #NoTileWallHard
                  beq .SetTargetRowLe
                  
                  cmp #NoTileLadder
                  bne .ChkCols
                  
.SetTargetRowLe   ldy $31                         ; target row from work row
                  sty $2f                         ; save target row from work row
                  cpy $04                         ; actual row lode runner
                  bcs .RetTargetRow               ; still above of LR
                  
.ChkCols          ldy $30                         ; target col from work col or possible col ri/le
                  cpy #LR_ScrnMaxCols
                  bcs .ChkRows                    ; max right reached
                  
                  iny
                  
.TileNextRi       lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTilePole
                  beq .SetTargetRowRi
                  
                  ldy $31                         ; target row from work row
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $30                         ; target col from work col or possible col ri/le
                  iny
.TileUnderFootRi  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  beq .SetTargetRowRi
                  
                  cmp #NoTileLadder
                  beq .SetTargetRowRi
                  
                  cmp #NoTileWallHard
                  bne .ChkRows
                  
.SetTargetRowRi   ldy $31                         ; target row from work row
                  sty $2f                         ; save target row from work row
                  cpy $04                         ; actual row lode runner
                  bcs .RetTargetRow               ; still above of LR
                  
.ChkRows          inc $31                         ; target row from work row
                  ldy $31                         ; target row from work row
                  cpy #LR_ScrnMaxRows+1
                  bcs .RetMaxRow                  ; max reached
                  
.GoCheckNext      jmp .ChkNextTileUp1
                  
.RetMaxRow        lda #LR_ScrnMaxRows
.FindEnmyMoveUD1  rts
                  
.RetTargetRow     lda $2f                         ; save target row from work row
FindEnmyMoveUD1X  rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
GetEnmyPossLR     stx $2d                         ; actual enemy possible col left
                  stx $2e                         ; actual enemy possible col right
                  sty $20                         ; save actual enemy work row
                  
.GetNextColLeft   lda $2d                         ; actual enemy possible col left
                  beq .GetNextColRight            ; max left reached
                  
                  ldy $20                         ; save actual enemy work row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $2d                         ; actual enemy possible col left
                  dey                             ; get tile one left from
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
.ChkLeftTile      cmp #NoTileWallWeak
                  beq .GetNextColRight
                  
                  cmp #NoTileWallHard
                  beq .GetNextColRight
                  
                  cmp #NoTileLadder
                  beq .SetNextColLeft
                  
                  cmp #NoTilePole
                  beq .SetNextColLeft
                  
                  ldy $20                         ; save actual enemy work row
                  cpy #LR_ScrnMaxRows
                  beq .SetNextColLeft
                  
.ChkLeftDownTile  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $2d                         ; actual enemy possible col left
                  dey                             ; get tile one left/down from
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  beq .SetNextColLeft
                  
                  cmp #NoTileWallHard
                  beq .SetNextColLeft
                  
                  cmp #NoTileLadder
                  bne .SetOneLeft
                  
.SetNextColLeft   dec $2d                         ; actual enemy possible col left
                  bpl .GetNextColLeft
                  
.SetOneLeft       dec $2d                         ; actual enemy possible col left
                  
.GetNextColRight  lda $2e                         ; actual enemy possible col right
                  cmp #LR_ScrnMaxCols             ; $1b - max col right
                  beq GetEnmyPossLRX              ; exit
                  
                  ldy $20                         ; save actual enemy work row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $2e                         ; actual enemy possible col right
                  iny                             ; try one tile right from
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #NoTileWallWeak
                  beq GetEnmyPossLRX              ; exit
                  
                  cmp #NoTileWallHard
                  beq GetEnmyPossLRX              ; exit
                  
                  cmp #NoTileLadder
                  beq .SetNextColRight
                  
                  cmp #NoTilePole
                  beq .SetNextColRight
                  
                  ldy $20                         ; save actual enemy work row
                  cpy #LR_ScrnMaxRows
                  beq .SetNextColRight
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $2e                         ; actual enemy possible col right
                  iny                             ; try one tile right from
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  beq .SetNextColRight
                  
                  cmp #NoTileWallHard
                  beq .SetNextColRight
                  
                  cmp #NoTileLadder
                  bne .SetOneRight
                  
.SetNextColRight  inc $2e                         ; actual enemy possible col right
                  bpl .GetNextColRight
                  
.SetOneRight      inc $2e                         ; actual enemy possible col right
                  
GetEnmyPossLRX    rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MovEnmyGetXYNo    ldx $15                         ; actual enemy col
                  ldy $1a                         ; actual enemy pos on image left/right
                  jsr GetXOff
                  
                  stx $23                         ; image number
                  
                  ldy $16                         ; actual enemy row
                  ldx $1b                         ; actual enemy pos on image up/down
                  jsr GetYOff
                  
                  ldx $17                         ; actual enemy sprite number
                  lda TabSpriteNoEnemy,x          ; enemy move images
                  
                  ldx $23                         ; image number
                  
MovEnmyGetXYNoX   rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
EnmyTakeGold      lda $1a                         ; actual enemy pos on image left/right
                  cmp #$02
                  bne EnmyTakeGoldX
                  
                  lda $1b                         ; actual enemy pos on image up/down
                  cmp #$02
                  bne EnmyTakeGoldX
                  
                  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileGold
                  bne EnmyTakeGoldX               ; no gold on level tile
                  
                  lda $19                         ; enemy time in hole
                  bmi EnmyTakeGoldX
                  
                  lda #$ff
                  sec
                  sbc LR_EnmyBirthCol             ; pointer: enemy rebirth column
                  sta $19                         ; enemy time in hole
                  
                  lda #NoTileBlank                ; clear gold in
                  sta ($0b),y                     ; play level control data ($0a00-$0bc3)
                  
                  ldy $16                         ; actual enemy row
                  sty $50                         ; screen row  (00-0f)
                  ldy $15                         ; actual enemy col
                  sty $4f                         ; screen col  (00-1b)
                  jsr ImageOut2Prep               ; direct output to preparation screen
                  
                  ldy $50                         ; screen row  (00-0f)
                  ldx $4f                         ; screen col  (00-1b)
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row
                  
                  lda #NoTileGold
                  jmp ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
EnmyTakeGoldX     rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
EnmyDropGold      lda $19                         ; enemy time in hole
                  bpl EnmyDropGoldX
                  
                  inc $19                         ; enemy time in hole
                  bne EnmyDropGoldX
                  
                  ldy $16                         ; actual enemy row
                  sty $50                         ; screen row  (00-0f)
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $15                         ; actual enemy col
                  sty $4f                         ; screen col  (00-1b)
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileBlank
                  bne .NotEmpty
                  
                  lda #NoTileGold
                  sta ($0b),y                     ; play level control data ($0a00-$0bc3)
                  jsr ImageOut2Prep               ; direct output to preparation screen
                  
                  ldy $50                         ; screen row  (00-0f)
                  ldx $4f                         ; screen col  (00-1b)
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row
                  
                  lda #NoTileGold
                  jmp ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  
.NotEmpty         dec $19                         ; enemy time in hole
EnmyDropGoldX     rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
MovENSetImg       inc $17                         ; actual enemy sprite number
.ChkMin           cmp $17                         ; actual enemy sprite number
                  bcc .ChkMax
                  
.SetSpriteNo      sta $17                         ; actual enemy sprite number
                  rts
                  
.ChkMax           cpx $17                         ; actual enemy sprite number
                  bcc .SetSpriteNo
                  
MovENSetImgX      rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
CenterEnemyLR     lda $1a                         ; actual enemy pos on image left/right
                  cmp #$02                        ; center
                  bcc .Inc1a                      ; lower
                  beq CenterEnemyLRX               ; in center
                  
.Dec1a            dec $1a                         ; back left a bit
                  jmp EnmyTakeGold
                  
.Inc1a            inc $1a                         ; back right a bit
                  jmp EnmyTakeGold
                  
CenterEnemyLRX    rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
CenterEnemyUD     lda $1b                         ; actual enemy pos on image up/down
                  cmp #$02                        ; center
                  bcc .Inc1b                      ; lower
                  beq CenterEnemyUDX              ; in center
                  
.Dec1b            dec $1b                         ; back up a bit
                  jmp EnmyTakeGold
                  
.Inc1b            inc $1b                         ; back down a bit
                  jmp EnmyTakeGold
                  
CenterEnemyUDX    rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
SavEnemyStatus    ldx LR_NoEnemy2Move             ; # of enemy to move
                  
                  lda $15                         ; actual enemy col
                  sta LR_TabEnemyCol,x            ; adr column enemies
                  lda $16                         ; actual enemy row
                  sta LR_TabEnemyRow,x            ; adr row enemies
                  lda $1a                         ; actual enemy pos on image left/right
                  sta LR_TabEnemyPosLR,x          ; enemy pos on image left/right tab
                  lda $1b                         ; actual enemy pos on image up/down
                  sta LR_TabEnemyPosUD,x          ; enemy pos on image up/down tab
                  lda $19                         ; enemy time in hole
                  sta LR_TabEnemyGold,x           ; enemy has gold tab
                  lda $18                         ; actual enemy dir right/left  $ff=left  $01=right
                  sta LR_TabEnemySpr__,x          ;
                  lda $17                         ; actual enemy sprite number
                  sta LR_TabEnemySprNo,x          ; actual enemy sprite number
                  
SavEnemyStatusX   rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
GetEnemyStatus    ldx LR_NoEnemy2Move             ; # of enemy to move
                  
                  lda LR_TabEnemyCol,x            ; adr column enemies
                  sta $15                         ; enemy col
                  lda LR_TabEnemyRow,x            ; adr row enemies
                  sta $16                         ; actual enemy row
                  lda LR_TabEnemyPosLR,x          ; enemy pos on image left/right tab
                  sta $1a                         ; actual enemy pos on image left/right
                  lda LR_TabEnemyPosUD,x          ; enemy pos on image up/down tab
                  sta $1b                         ; actual enemy pos on image up/down
                  lda LR_TabEnemySprNo,x          ; actual enemy sprite number
                  sta $17                         ; actual enemy sprite number
                  lda LR_TabEnemySpr__,x          ;
                  sta $18                         ; actual enemy dir right/left  $ff=left  $01=right
                  lda LR_TabEnemyGold,x           ; enemy has gold tab
                  sta $19                         ; enemy time in hole
                  
GetEnemyStatusX   rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
CloseHoles        jsr EnemyRebirth                ;
                  
                  inc LR_EnmyBirthCol             ; pointer: enemy rebirth column
.ChkBirthCol      lda LR_EnmyBirthCol             ; pointer: enemy rebirth column
                  cmp #LR_EnmyBColMax             ; $1c - max 28
                  bcc .ChkHoles
                  
                  lda #$00                        ; reset
                  sta LR_EnmyBirthCol             ; pointer: enemy rebirth column
                  
.ChkHoles         ldx #LR_TabHoleMax              ; max 30 open holes
.GetNextHoleTime  lda LR_TabHoleOpenT,x           ; hole open time tab
                  stx $52                         ; open holes time pointer
                  bne .DecHoleTime
                  
                  jmp .SetNextHoleTime            ; set next hole time
                  
.DecHoleTime      dec LR_TabHoleOpenT,x           ; open holes counter
                  beq .HoleOpenTimeOut            ; open time out - so close
                  
                  lda LR_TabHoleCol,x             ; hole column tab
                  sta $4f                         ; screen col  (00-1b)
                  lda LR_TabHoleRow,x             ; hole row tab
                  sta $50                         ; screen row  (00-0f)
                  
                  lda LR_TabHoleOpenT,x           ; hole open time tab
.ChkClose1stStep  cmp #LR_TabHoleOpenT1           ; first step close
                  bne .ChkClose2ndStep            ;  already passed
                  
                  lda #NoCloseHole00              ; close hole 1st step
.CloseStepOut     jsr ImageOut2Prep               ; direct output to preparation screen
                  
                  ldx $4f                         ; screen col  (00-1b)
                  ldy $50                         ; screen row  (00-0f)
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row
                  
                  lda #$00
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
.GoSetNextHT      jmp .SetNextHoleTime            ; set next hole time
                  
.ChkClose2ndStep  cmp #LR_TabHoleOpenT2           ; second step close
                  bne .GoSetNextHT                ;  already passed
                  
                  lda #NoCloseHole01              ; close hole 2nd step
                  bne .CloseStepOut               ; always
                  
.HoleOpenTimeOut  ldx $52                         ; open holes time pointer
                  ldy LR_TabHoleRow,x             ; hole row tab
                  sty $50                         ; screen row  (00-0f)
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy LR_TabHoleCol,x             ; hole column tab
                  sty $4f                         ; screen col  (00-1b)
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #$00
                  bne .ChkHoleLR                  ; closed hole was not emty
                  
                  jmp .CloseWithWall
                  
.ChkHoleLR        cmp #NoTileLodeRunner
                  bne .ChkHoleEnemy
                  
                  lsr LR_Alive                    ; $00=lr killed
                  
.ChkHoleEnemy     cmp #NoTileEnemy
                  beq .ReviveEnemy
                  
.ChkHoleGold      cmp #NoTileGold
                  bne .GoCloseWithWall
                  dec LR_Gold2Get
                  
.GoCloseWithWall  jmp .CloseWithWall
                  
.ReviveEnemy      lda #NoTileWallWeak
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  sta ($0b),y                     ; play level control data ($0a00-$0bc3)
                  jsr ImageOut2Disp               ; direct output to display screen
                  
                  lda #NoTileWallWeak
                  jsr ImageOut2Prep               ; direct output to preparation screen
                  
                  ldx LR_EnmyNo                   ; number of enemies
.ChkEnemyCol      lda LR_TabEnemyCol,x            ; adr column enemies
                  cmp $4f                         ; screen col  (00-1b)
                  beq .ChkEnemyRow
                  
                  jmp .SetNextEnemy
                  
.ChkEnemyRow      lda LR_TabEnemyRow,x            ; adr row enemies
                  cmp $50                         ; screen row  (00-0f)
                  bne .SetNextEnemy
                  
                  lda TabEnemyDisab,x             ; disable enemy sprite tab
                  and SPENA                       ; VIC 2 - $D015 equ Sprite Enable
                  sta SPENA                       ; VIC 2 - $D015 equ Sprite Enable
                  lda LR_TabEnemyGold,x           ; enemy has gold tab
                  bpl .ResetValues
                  
                  dec LR_Gold2Get                 ; enemy still had gold
                  
.ResetValues      lda #$7f                        ; reset
                  sta LR_TabEnemyGold,x           ; enemy has gold tab entry
                  stx LR_NoEnemy2Move             ; # of enemy to move
                  jsr GetEnemyStatus
                  jsr MovEnmyGetXYNo
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
                  ldx LR_NoEnemy2Move             ; # of enemy to move
                  ldy #$01                        ; start with top row
                  sty $50                         ; screen row  (00-0f)
.FindRebirthPosI  ldy $50                         ; screen row  (00-0f)
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy LR_EnmyBirthCol             ; pointer: enemy rebirth column
.FindRebirthPos   lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileBlank                ; empty
                  beq .SetRebirthPos              ; found
                  
                  inc LR_EnmyBirthCol             ; pointer: enemy rebirth column
                  ldy LR_EnmyBirthCol             ; pointer: enemy rebirth column
                  cpy #LR_ScrnMaxCols+1           ; $1b - max 27 cols
                  bcc .FindRebirthPos
                  
                  inc $50                         ; screen row  (00-0f)
                  lda #$00
                  sta LR_EnmyBirthCol             ; pointer: enemy rebirth column
                  beq .FindRebirthPosI            ; always
                  
.SetRebirthPos    tya
                  sta LR_TabEnemyCol,x            ; adr column enemies
                  lda $50                         ; screen row  (00-0f)
                  sta LR_TabEnemyRow,x            ; adr row enemies
                  lda #LR_TabEnemyBirt1+1
                  sta LR_TabEnemyBirtT,x          ; enemy rebirth step time
                  lda #$02
                  sta LR_TabEnemyPosUD,x          ; enemy pos on image up/down tab
                  sta LR_TabEnemyPosLR,x          ; enemy pos on image left/right tab
                  lda #$00
                  sta LR_TabEnemySprNo,x          ; actual enemy sprite number
                  ldy #$01
                  lda #$00                        ; score 100 points
                  jsr Score2BaseLine
                  jmp .SetNextHoleTime            ; set next hole time
                  
.SetNextEnemy     dex
                  beq .CloseWithWall
                  jmp .ChkEnemyCol
                  
.CloseWithWall    lda #NoTileWallWeak
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  jsr ImageOut2Disp               ; direct output to display screen
                  
                  lda #NoTileWallWeak
                  jsr ImageOut2Prep               ; direct output to preparation screen
                  
.SetNextHoleTime  ldx $52                         ; open holes time pointer
                  dex
                  bmi CloseHolesX                 ; all open holes processed
                  
                  jmp .GetNextHoleTime
                  
CloseHolesX       rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
EnemyRebirth      ldx LR_EnmyNo                   ; number of enemies
                  beq CloseHolesX                 ;
                  
.GetEnemyNumber   lda LR_NoEnemy2Move             ; # of enemy to move
                  pha                             ; save
                  
.GetNextStepTime  lda LR_TabEnemyBirtT,x          ; enemy rebirth step time
                  beq .SetNextStepTime            ; not dead
                  
                  stx LR_NoEnemy2Move             ; # of enemy to move
                  jsr GetEnemyStatus              ;
                  
                  lda #$7f                        ; no gold
                  sta LR_TabEnemyGold,x           ; enemy has gold tab
                  
                  lda LR_TabEnemyCol,x            ; adr column enemies
                  sta $4f                         ; screen col  (00-1b)
                  lda LR_TabEnemyRow,x            ; adr row enemies
                  sta $50                         ; screen row  (00-0f)
                  
.DecBirthTime     dec LR_TabEnemyBirtT,x          ; enemy rebirth step time
                  beq .RebirthReadyEN             ;
                  
.ChkBirth1stStep  lda LR_TabEnemyBirtT,x          ; enemy rebirth step time
                  cmp #LR_TabEnemyBirt1           ; first step rebirth
                  bne .ChkBirth2ndStep            ;   already passed
                  
                  lda #NoReviveEnemy00            ; rebirth 1st step
                  jsr ImageOut2Prep               ; output to preparation screen first ($4000)
                  jsr MovEnmyGetXYNo              ;
                  
                  lda #NoReviveEnemy00            ; rebirth 1st step
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  jmp .GetNextEnemy               ;
                  
.ChkBirth2ndStep  cmp #LR_TabEnemyBirt2           ; second step rebirth
                  bne .SetNextStepTime            ;
                  
                  lda #NoReviveEnemy01            ; rebirth 2nd step
                  jsr ImageOut2Prep               ; output to preparation screen first ($4000)
                  jsr MovEnmyGetXYNo              ;
                  
                  lda #NoReviveEnemy01            ; rebirth 2nd step
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  
.GetNextEnemy     ldx LR_NoEnemy2Move             ; # of enemy to move
.SetNextStepTime  dex                             ;
                  bne .GetNextStepTime            ;
                  
                  pla                             ; restore
                  sta LR_NoEnemy2Move             ; # of enemy to move
                  
.RebirthExit      rts                             ;

.RebirthReadyEN   ldy $50                         ; screen row  (00-0f)
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09                         ; 
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a                         ; 
                  
                  ldx LR_NoEnemy2Move             ; # of enemy to move
                  inc LR_TabEnemyBirtT,x          ; enemy rebirth step time
                  ldy $4f                         ; screen col  (00-1b)
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  bne .SetNextStepTime            ;
                  
                  lda #NoTileEnemy                ;
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  lda #NoTileBlank                ; empty
                  jsr ImageOut2Prep               ; output to preparation screen first ($4000)
                  
                  lda #NoTileBlank                ; empty
                  jsr ImageOut2Disp               ; output directly to display screen ($2000)
                  
                  lda #$00                        ;
                  ldx LR_NoEnemy2Move             ; # of enemy to move
                  sta LR_TabEnemyGold,x           ; enemy has gold tab
                  sta LR_TabEnemyBirtT,x          ; enemy rebirth step time
                  
                  lda #NoTileEnemy                ;
                  jsr ImageOut2Disp               ; output directly to display screen ($2000)
                  
                  ldx LR_NoEnemy2Move             ; # of enemy to move
                  lda TabEnemyEnab,x              ; enable enemy sprite tab
                  ora SPENA                       ; VIC 2 - $D015 equ Sprite Enable
                  sta SPENA                       ; VIC 2 - $D015 equ Sprite Enable
                  jmp .SetNextStepTime            ;
EnemyRebirthX     equ *
; ------------------------------------------------------------------------------------------------------------- ;
TabEnemyEnab      dc.b $00 ; ........
                  dc.b $04 ; .....#..
                  dc.b $08 ; ....#...
                  dc.b $10 ; ...#....
                  dc.b $40 ; .#......
                  dc.b $80 ; #.......
; ------------------------------------------------------------------------------------------------------------- ;
TabEnemyDisab     dc.b $00 ; ........
                  dc.b $fb ; #####.##
                  dc.b $f7 ; ####.###
                  dc.b $ef ; ###.####
                  dc.b $bf ; #.######
                  dc.b $7f ; .#######
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ClearHiresBoth    jsr ClearHiresDisp              ; ClearDisplay20
                  jsr ClearHiresPrep              ; ClearDisplay40
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
BaseLines         ldx #$22                        ; length of separator line

.SeparatorLine    lda $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  cmp #>LR_ScrnHiRePrep           ; hires preparation screen
                  beq .HiResPrepare               ; 
                  
.HiResDisplay     lda #$0a                        ; grafic byte for
                  sta LR_StatsLinLeD01            ;   left end 0
                  sta LR_StatsLinLeD02            ;   left end 1
                  sta LR_StatsLinLeD03            ;   left end 2
                  sta LR_StatsLinLeD04            ;   left end 3
                  lda #$a0                        ; grafic byte for
.HiResDispReX     sta LR_StatsLinRiD01            ;   right end 0
                  sta LR_StatsLinRiD02            ;   right end 1
                  sta LR_StatsLinRiD03            ;   right end 2
                  sta LR_StatsLinRiD04            ;   right end 3
.HiResDispMid     ldy #$03                        ; 
                  lda #$aa                        ; grafic byte middle part seperation line
.HiResDispMidPut  sta LR_StatsLinMiD,y            ; middle part 0-3
..ModDispMidLo    equ *-2
..ModDispMidHi    equ *-1
                  dey                             ;
                  bpl .HiResDispMidPut            ; store next middle part 0-3
                  
.HiResDispNext    lda ..ModDispMidLo              ; 
                  clc                             ;
                  adc #$08                        ; next position
                  sta ..ModDispMidLo              ;
                  bcc .HiResDispDec               ; 
                  inc ..ModDispMidHi              ;
                  
.HiResDispDec     dex                             ; 
                  bne .HiResDispMid               ; 
                  
                  lda #>LR_StatsLinMiD            ; restore old values
                  sta ..ModDispMidHi              ;
                  lda #<LR_StatsLinMiD
                  sta ..ModDispMidLo              ;
                  bne .InfoLine                   ; always
                  
.HiResPrepare     lda #$0a                        ; grafic byte left end seperation line
                  sta LR_StatsLinLeP01            ;   left end 0
                  sta LR_StatsLinLeP02            ;   left end 1
                  sta LR_StatsLinLeP03            ;   left end 2
                  sta LR_StatsLinLeP04            ;   left end 3
                  lda #$a0                        ; grafic byte right end seperation line
.HiResPrepRiX     sta LR_StatsLinRiP01            ;   right end 0
                  sta LR_StatsLinRiP02            ;   right end 1
                  sta LR_StatsLinRiP03            ;   right end 2
                  sta LR_StatsLinRiP04            ;   right end 3
.HiResPrepMid     ldy #$03                        ;
                  lda #$aa                        ; grafic byte middle part seperation line
.HiResPrepMidPut  sta LR_StatsLinMiP,y            ; 
..ModPrepMidLo    equ *-2
..ModPrepMidHi    equ *-1
                  dey                             ;
                  bpl .HiResPrepMidPut            ;
                  
                  lda ..ModPrepMidLo              ;
                  clc                             ;
                  adc #$08                        ; next position
                  sta ..ModPrepMidLo              ;
                  bcc .HiResPrepDec               ;
                  inc ..ModPrepMidHi              ;
                  
.HiResPrepDec     dex                             ;
                  bne .HiResPrepMid               ;
                  
                  lda #>LR_StatsLinMiP            ; restore old values
                  sta ..ModPrepMidHi              ;
                  lda #<LR_StatsLinMiP            ;
                  sta ..ModPrepMidLo              ;
                  
.InfoLine         lda #LR_BasLinRowStat           ; 
                  sta $50                         ; screen row ($00 - $0f)
                  lda #$00                        ; 
                  sta $4f                         ; screen col ($00 - $1b)
                  jsr TextOut                     ; TextOut
                  dc.b $d3 ; S
                  dc.b $c3 ; C
                  dc.b $cf ; O
                  dc.b $d2 ; R
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $cd ; M
                  dc.b $c5 ; E
                  dc.b $ce ; N
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $cc ; L
                  dc.b $c5 ; E
                  dc.b $d6 ; V
                  dc.b $c5 ; E
                  dc.b $cc ; L
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $a0 ; <blank>
                  dc.b $00 ; EndOfText
                  
                  jsr Lives2BaseLine              ; 
                  jsr Level2BaseLine              ; 
                  
                  lda #$00                        ; no score to add
                  tay                             ; no score to add
                  
BaseLinesX        jmp Score2BaseLine              ; AddDisplayScore (ac=1s yr=100s) - display only - no score to add
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
Lives2BaseLine    lda CR_StatusColor              ; 
                  bne Level2BaseLineX             ; 
                  
                  lda LR_NumLives                 ; 
                  ldx #LR_BasLinColLve            ;
                  
ValueToBaseLine   stx $4f                         ; screen col ($00 - $1b)
                  jsr ConvertHex2Dec              ; Hex2Dec  (1307=100 1308=10 1309=1)
                  
                  lda #LR_BasLinRowStat           ;
                  sta $50                         ; screen row ($00 - $0f)
                  
                  lda LR_Digit100                 ; 
                  jsr PrepareDigitOut             ; 
                  
                  lda LR_Digit10                  ; 
                  jsr PrepareDigitOut             ; 
                  
                  lda LR_Digit1                   ; 
ValueToBaseLineX  jmp PrepareDigitOut             ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
Level2BaseLine    lda LR_LevelNoGame              ; 001-050
                  ldx #LR_BasLinColLvl            ;
                  bne ValueToBaseLine             ;
                  
                  lda #$14                        ;
                  sta $4f                         ; screen col ($00 - $1b)
                  lda #$10                        ;
                  sta $50                         ; screen row ($00 - $0f)
                  jsr TextOut                     ; TextOut
                  dc.b $cc                       ; LEVEL
                  dc.b $c5
                  dc.b $d6
                  dc.b $c5
                  dc.b $cc
                  dc.b $00
                  
                  jmp Level2BaseLine              ;

Level2BaseLineX   rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
Score2BaseLine    clc                             ; AddDisplayScore (ac=1s yr=100s)

                  sed                             ;
                  
                  adc LR_ScoreLo                  ; lrScoreLow
                  sta LR_ScoreLo                  ; lrScoreLow
                  tya                             ;
                  adc LR_ScoreMidLo               ; lrScoreMidLow
                  sta LR_ScoreMidLo               ; lrScoreMidLow
                  lda #$00                        ;
                  adc LR_ScoreMidHi               ; lrScoreMidHigh
                  sta LR_ScoreMidHi               ; lrScoreMidHigh
                  lda #$00                        ;
                  adc LR_ScoreHi                  ; lrScoreHigh
                  sta LR_ScoreHi                  ; lrScoreHigh
                  
                  cld                             ;
                  
                  lda #LR_BasLinColScr            ; 
                  sta $4f                         ; screen col ($00 - $1b)
                  lda #LR_BasLinRowStat            ;
                  sta $50                         ; screen row ($00 - $0f)
                  
                  lda LR_ScoreHi                  ; lrScoreHigh
                  jsr SplitScoreDigit             ;
                  
                  lda LR_Digit1                   ; use only right nybble discard left nybble
                  jsr PrepareDigitOut             ; 
                  
                  lda LR_ScoreMidHi               ; 
                  jsr SplitScoreDigit             ;
                  
                  lda LR_Digit10                  ; 
                  jsr PrepareDigitOut             ; 
                  lda LR_Digit1                   ; 
                  jsr PrepareDigitOut             ; 
                  
                  lda LR_ScoreMidLo               ; 
                  jsr SplitScoreDigit             ;
                  
                  lda LR_Digit10                  ; 
                  jsr PrepareDigitOut             ; 
                  lda LR_Digit1                   ; 
                  jsr PrepareDigitOut             ;                   
                  lda LR_ScoreLo                  ; 
                  jsr SplitScoreDigit             ;
                  
                  lda LR_Digit10                  ; 
                  jsr PrepareDigitOut             ; 
                  lda LR_Digit1                   ; 
Score2BaseLineX   jmp PrepareDigitOut             ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
SplitScoreDigit   sta LR_Digit10                  ; lrDec10

                  and #$0f                        ;
                  sta LR_Digit1                   ; lrDec1
                  lda LR_Digit10                  ; lrDec10
                  lsr a                           ;
                  lsr a                           ;
                  lsr a                           ;
                  lsr a                           ;
                  sta LR_Digit10                  ; lrDec10

SplitScoreDigitX  rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ConvertHex2Dec    ldx #$00                        ; 
                  stx LR_Digit10                  ; digit 10 part
                  stx LR_Digit100                 ; digit 100 part
                  
.Chk100           cmp #$64                        ; 100
                  bcc .Chk10                      ; lower
                  
                  inc LR_Digit100                 ; count number of hundreds
                  sbc #$64                        ; 100
                  bne .Chk100                     ;
                   
.Chk10            cmp #$0a                        ; 10
                  bcc .Chk1                       ; 
                  
                  inc LR_Digit10                  ; count number of tens
                  sbc #$0a                        ;
                  bne .Chk10                      ; try for the next 10
                  
.Chk1             sta LR_Digit1                   ; count number of ones

ConvertHex2DecX   rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
PrepareDigitOut   clc                             ; 
                  adc #NoDigitsMin                ; .hbu008.  map to digit image data numbers
                  
                  ldx $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  cpx #>LR_ScrnHiRePrep           ;
                  beq .Out2Prepare                ; 
                  
.Out2Display      jsr ImageOut2Disp               ; output directly to display screen ($2000)
                  inc $4f                         ; screen col ($00 - $1b)
                  rts                             ;

.Out2Prepare      jsr ImageOut2Prep               ; output to preparation screen first ($4000)
                  inc $4f                         ; screen col ($00 - $1b)
PrepareDigitOutX  rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
SetChrSubst_0_9   sec                             ;
                  sbc #$75                        ;

SetChrSubst_0_9X  rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
GetChrSubst       cmp #$b0                        ; key "0"
                  bcc .Chk_A_Z                    ;
                  
                  cmp #$ba                        ;
                  bcc SetChrSubst_0_9             ; key "9"
                  
.Chk_A_Z          cmp #$c1                        ; "A"
                  bcc .ChkSpecial                 ;
                  
                  cmp #$db                        ; "Z" + 1
                  bcc .SubstChr                   ;
                  
.ChkSpecial       ldx #$e2 - NoImages             ; .hbu008. - $7b - substitution - $00
                  cmp #$a0                        ; <blank>
                  beq .SetSpecial                 ;
                  
                  ldx #$db                        ;
                  cmp #$be                        ; ">"
                  beq .SetSpecial                 ;
                  
                  inx                             ;
                  cmp #$ae                        ; "."
                  beq .SetSpecial                 ;
                  
                  inx                             ;
                  cmp #$a8                        ; "("
                  beq .SetSpecial                 ;
                  
                  inx                             ;
                  cmp #$a9                        ; ")"
                  beq .SetSpecial                 ;
                  
                  inx                             ;
                  cmp #$af                        ; "/"
                  beq .SetSpecial                 ;
                  
                  inx                             ;
                  cmp #$ad                        ; "-"
                  beq .SetSpecial                 ;
                  
                  inx                             ;
                  cmp #$bc                        ; "<"
                  beq .SetSpecial                 ;
                  
                  lda #$10                        ;
                  rts                             ;
                  
.SetSpecial       txa                             ;
.SubstChr         sec                             ;
                  sbc #$e2 - NoImages             ; .hbu008 - map to chr image data numbers
                  
GetChrSubstX      rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
PrepareChrOut     cmp #$8d                        ; <newline>
                  beq SetNewLine                  ; 
                  
                  jsr GetChrSubst                 ;
                  
                  ldx $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  cpx #>LR_ScrnHiRePrep           ;
                  beq .OutToPrepare               ;
                  
.OutToDisplay     jsr ImageOut2Disp               ; output directly to display screen ($2000)
                  inc $4f                         ; screen col ($00 - $1b)
                  rts                             ;
                  
.OutToPrepare     jsr ImageOut2Prep               ; output to preparation screen first ($4000)
                  inc $4f                         ; screen col ($00 - $1b)
                  rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
SetNewLine        inc $50                         ; screen row ($00 - $0f)
                  lda #$00                        ;
                  sta $4f                         ; screen col ($00 - $1b)

SetNewLineX       rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ClearTheRow       sta $50                         ; screen row ($00 - $0f)
                  lda #$00                        ;
                  sta $4f                         ; screen col ($00 - $1b)
                  
                  lda #LR_ScrnMaxCols+1           ;
                  sta CR_Work                     ;
.WipeOut          lda #$a0                        ; <blank>
                  jsr PrepareChrOut               ;
                  
                  dec CR_Work                     ;
                  bne .WipeOut                    ;
                  
ClearTheRowX      rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
TextOut           pla                             ; pull the text start address from the stack
                  sta $13                         ;
                  pla                             ;
                  sta $14                         ;
                  bne .SetNext                    ; always
                  
.GetNext          ldy #$00                        ; 
                  lda ($13),y                     ;
                  beq .PrepXit                    ; zero as text end
                  
.ImageOut         jsr PrepareChrOut               ;

.SetNext          inc $13                         ; 
                  bne .GetNext                    ;
                  
                  inc $14                         ;
                  bne .GetNext                    ;
                  
.PrepXit          lda $14                         ; push the text end address to the stack
                  pha                             ;
                  lda $13                         ; 
                  pha                             ;
                  
TextOutX          rts                             ; as return address
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
Beep              sei                             ;

                  lda #$60                        ; beep
                  sta FREHI1                      ; SID - $D401 equ Oscillator 1 Frequency Control (High Byte)
                  ldy #$38                        ;
                  ldx #$00                        ; init wait
.Wait             dex                             ;
                  bne .Wait                       ;
                  dey                             ;
                  bne .Wait                       ;
                  sty FREHI1                      ; SID - $D401 equ Oscillator 1 Frequency Control (High Byte)
                  
                  cli                             ;
                  
BeepX             rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
WaitKeyBlink      sta CR_WaitImageNo              ; save byte under cursor

.WaitBlank        lda #$00                        ; init wait for action timer
                  sta CR_WaitTimeLo               ;
                  lda #$0a                        ;
                  sta CR_WaitTimeHi               ;
                  
                  lda #$00                        ;
                  ldx CR_WaitImageNo              ;
                  bne .Out                        ;
                  
.GetBlankImg      lda #$0a                        ; image big reverse cursor

.Out              jsr ImageOut2Disp               ; output directly to display screen ($2000)

.WaitUser1        jsr ChkUserAction               ; check user input - carry_set=yes carry_clear=no
                  bcs .GotUserKey                 ;
                  
                  dec CR_WaitTimeLo               ;
                  bne .WaitUser1                  ;
                  dec CR_WaitTimeHi               ;
                  bne .WaitUser1                  ;
                  
.WaitImage        lda CR_WaitImageNo              ; get image number unter cursor
                  jsr ImageOut2Disp               ; output directly to display screen ($2000)

                  lda #$00                        ; init wait for action timer
                  sta CR_WaitTimeLo               ;
                  lda #$0a                        ;
                  sta CR_WaitTimeHi               ;
                  
.WaitUser2        jsr ChkUserAction               ; check user input - carry_set=yes carry_clear=no
                  bcs .GotUserKey                 ;
                  
                  dec CR_WaitTimeLo               ;
                  bne .WaitUser2                  ;
                  dec CR_WaitTimeHi               ;
                  bne .WaitUser2                  ;
                  
                  jmp .WaitBlank                  ;
                  
.GotUserKey       pha                             ; save key

.RestoreImage     lda CR_WaitImageNo              ; redisplay chr under cursor in case of got in blank blink phase
                  jsr ImageOut2Disp               ; output directly to display screen ($2000)
                  
                  pla                             ; restore key
WaitKeyBlinkX     rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ChkUserAction     lda CIAPRA                      ; CIA 1 - $DC00 equ Data Port A
                  and #$0f                        ; isolate - port a:  bit4=fire  bit3=right  bit2=left  bit1=down  bit0=up
                  eor #$0f                        ;
                  bne .SetUserAction              ; 
                  
                  lda CIAPRA                      ; CIA 1 - $DC00 equ Data Port A
                  and #$10                        ;
                  beq .SetUserAction              ;
                  
                  lda LR_KeyNew                   ; lrNewKey
                  bne .SetUserAction              ;
                  
.SetNoUserAction  clc                             ; indicate no user action
                  rts                             ; 
                  
.SetUserAction    sec                             ; indicate user action
ChkUserActionX    rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ImageOut2Disp     sta $23                         ; image number
                  lda #>LR_ScrnHiReDisp           ;
                  bne ImageOut                    ; always
                  
ImageOut2Prep     sta $23                         ; image number
                  lda #>LR_ScrnHiRePrep           ;
                  
ImageOut          sta $24                         ; target output  $20=$2000 $40=$4000

                  ldy $50                         ; screen row ($00 - $0f)
                  ldx $4f                         ; screen col ($00 - $1b)
                  jsr GetColRowGfxOff             ; 
                  sty $20                         ; row offset
                  
                  jsr SetSpritePos                ;
                  jsr GetOutGfxPosAdd             ; xr=VIC Sprite XPOS offset
                  stx $41                         ; image position number  (bits 0-1 of $4f substitution)
                  
                  lda TabInsImageLe,x             ; insert image left tab  (4 different image positions)
                  sta $25                         ; isolate right grafic part
                  lda TabInsImageRi,x             ; insert image right tab (4 different image positions)
                  sta $26                         ; isolate left grafic part

.GetImage         jsr GetImageBytes               ; stored from $5b-$7b

.SetHeight        lda #$0b                        ; 11 - hight of each image
                  sta $22                         ; image hight
                  
                  ldx #$00                        ;
                  lda $41                         ; image position number  (bits 0-1 of $4f substitution)
                  cmp #$05                        ; $05 impossible
                  bcs ImageOutBig                 ; never called
                  
.ImageOut         ldy $20                         ; grafic row substitution
                  jsr GetOutGfxPtr                ;
                  
                  ldy #$00
                  lda ($0f),y                     ; get grafic screen image byte
                  and $25                         ; clear the right grafic part
                  ora $5b,x                       ; insert new image byte
                  sta ($0f),y                     ; write grafic screen image byte
                  
                  inx                             ; point to next image byte
                  ldy #$08                        ; insert right part of image into right part of screen image
                  lda ($0f),y                     ; get grafic screen image byte
                  and $26                         ; clear the left grafic part
                  ora $5b,x                       ; insert new image byte
                  sta ($0f),y                     ; write grafic screen image byte
                  
                  inx                             ;
                  inx                             ;
                  
                  inc $20                         ; grafic row substitution
                  dec $22                         ; image hight
                  bne .ImageOut                   ;
                  
ImageOutX         rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ImageOutBig       ldy $20                         ; grafic row substitution
                  jsr GetOutGfxPtr                ;
                  
                  ldy #$00
                  lda ($0f),y                     ; get grafic screen image byte
                  and $25                         ; clear the right grafic part
                  ora $5b,x                       ; insert new image byte
                  sta ($0f),y                     ; write grafic screen image byte
                  
                  inx                             ; point to next image byte
                  ldy #$08                        ; insert into right part of screen image
                  lda $5b,x                       ; get new image byte
                  sta ($0f),y                     ; write grafic screen image byte
                  
                  inx                             ; point to next image byte
                  ldy #$10                        ;
                  lda ($0f),y                     ; get grafic screen image byte
                  and $26                         ; clear the left grafic part
                  ora $5b,x                       ; overlay new image byte
                  sta ($0f),y                     ; write grafic screen image byte
                  
                  inx                             ;
                  inc $20                         ; grafic row substitution
                  dec $22                         ; image hight
                  bne ImageOutBig                 ;
                  
ImageOutBigX      rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TabInsImageLe     dc.b $00 ; ........
                  dc.b $c0 ; ##......
                  dc.b $f0 ; ####....
                  dc.b $fc ; ######..
; ------------------------------------------------------------------------------------------------------------- ;
TabInsImageRi     dc.b $3f ; ..######
                  dc.b $0f ; ....####
                  dc.b $03 ; ......##
                  dc.b $00 ; ........
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ImageGameClear    sty $20                         ; grafic row substitution
                  sta $23                         ; image number
                  jsr GetOutGfxPosAdd             ;
                  
                  sta $21                         ; low byte grafic tab addition
                  stx $41                         ; image position number  (bits 0-1 of $4f substitution)
                  jsr GetImageBytes               ;
                  
                  ldx #$0b                        ;
                  stx $22                         ; image hight
                  
                  ldx #$00                        ;
                  
                  lda $41                         ; image position number  (bits 0-1 of $4f substitution)
                  cmp #$05                        ; $05 impossible
                  bcs ImageGameClrBig             ;
                  
.UpdateOut        ldy $20                         ; grafic row substitution
                  jsr GetMoveGfxPtr               ;
                  
                  ldy #$00                        ; image left part
                  
.Get1st           lda $5b,x                       ; image byte
                  eor #$ff                        ;
                  and ($0f),y                     ; screen grafic pointer byte
                  ora ($11),y                     ; hidden grafic pointer byte
.Put1st           sta ($0f),y                     ; screen grafic pointer byte

                  inx                             ;
                  
                  ldy #$08                        ; image right part
                  
.Get2nd           lda $5b,x                       ; image byte
                  eor #$ff                        ;
                  and ($0f),y                     ; screen grafic pointer byte
                  ora ($11),y                     ; hidden grafic pointer byte
.Put2nd           sta ($0f),y                     ; screen grafic pointer byte

.Ign3rd           inx                             ; 3rd imge byte always $00 - ignore
                  inx                             ;
                  
                  inc $20                         ; grafic row substitution
                  
                  dec $22                         ; image hight
                  bne .UpdateOut                  ;
                  
ImageGameClearX   rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ImageGameClrBig   ldy $20                         ; grafic row substitution
                  jsr GetMoveGfxPtr               ;
                  
                  ldy #$00                        ; image left part
                  
.Get1st           lda $5b,x                       ; image byte
                  eor #$ff                        ;
                  and ($0f),y                     ; screen grafic pointer byte
                  ora ($11),y                     ; hidden grafic pointer byte
.Put1st           sta ($0f),y                     ; screen grafic pointer byte

                  inx                             ; point to next image byte
                  
                  ldy #$08                        ; image mid part
                  
.Get2nd           lda $5b,x                       ; image byte
                  eor #$ff                        ;
                  and ($0f),y                     ; screen grafic pointer byte
                  ora ($11),y                     ; hidden grafic pointer byte
.Put2nd           sta ($0f),y                     ; screen grafic pointer byte

                  inx                             ; point to next image byte
                  
                  ldy #$10                        ;
                  
                  lda $5b,x                       ; image right part
                  eor #$ff                        ;
                  and ($0f),y                     ; screen grafic pointer byte
                  ora ($11),y                     ; hidden grafic pointer byte
.Put3rd           sta ($0f),y                     ; screen grafic pointer byte

                  inx                             ; point to next image byte
                  
                  inc $20                         ; grafic row substitution
                  
                  dec $22                         ; image hight
                  bne ImageGameClrBig             ;
                  
ImageGameClrBigX  rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ImageGameSet      sty $20                         ; grafic row substitution
                  sta $23                         ; image number
                  jsr SetSpritePos                ; xr=VIC Sprite XPOS offset
                  jsr GetOutGfxPosAdd             ;
                  
                  sta $21                         ; low byte grafic tab addition
                  stx $41                         ; image position number  (bits 0-1 of 4f substitution)
                  
.GetImage         jsr GetImageBytes               ; stored from $5b-$7b

                  lda #$0b                        ;
                  sta $22                         ; image hight
                  
                  ldx #$00                        ;
                  stx $27                         ; clear sprite collision  $01=lr caught
                  
                  lda $41                         ;
                  cmp #$05                        ;
                  bcs ImageGameSetBig             ;
                  
.SpriteOut        ldy $20                         ; grafic row substitution
                  jsr GetMoveGfxPtr               ;
                  
                  ldy #$00                        ; first image half
                  
.Get1st           lda $5b,x                       ; image byte
                  ora ($0f),y                     ; screen grafic pointer byte
.Set1st           sta ($0f),y                     ; screen grafic pointer byte

                  inx                             ; image byte pointer
                  
                  ldy #$08                        ; second image half
                  
.Get2nd           lda $5b,x                       ; image byte
                  ora ($0f),y                     ; screen grafic pointer byte
.Set2nd           sta ($0f),y                     ; screen grafic pointer byte

.Ign3rd           inx                             ; 3rd imge byte always $00 - ignore
                  inx                             ;
                  
                  inc $20                         ; grafic row substitution
                  
                  dec $22                         ; image hight
                  bne .SpriteOut                  ;
                  
ImageGameSetX     rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ImageGameSetBig   ldy $20                         ; grafic row substitution
                  jsr GetMoveGfxPtr               ;
                  
                  ldy #$00                        ; first image half
                  
.Get1st           lda $5b,x                       ; image byte
                  ora ($0f),y                     ; screen grafic pointer byte
.Set1st           sta ($0f),y                     ; screen grafic pointer byte

                  inx                             ; image byte pointer
                  
                  ldy #$08                        ; second image half
                  
.Get2nd           lda $5b,x                       ; image byte
                  ora ($0f),y                     ; screen grafic pointer byte
.Set2nd           sta ($0f),y                     ; screen grafic pointer byte

                  inx                             ; image byte pointer
                  
                  ldy #$10                        ;
                  
.Get3rd           lda $5b,x                       ; image byte
                  ora ($0f),y                     ; screen grafic pointer byte
.Set3rd           sta ($0f),y                     ; screen grafic pointer byte

                  inx                             ; image byte pointer
                  
                  inc $20                         ; grafic row substitution
                  
                  dec $22                         ; image hight
                  bne ImageGameSetBig             ;
                  
ImageGameSetBigX  rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
; GetImageBytes   Function: Contruct an 11*3 Byte Image at Zero Page $5b-$7b
;                 Parms   : xr - bit0/bit1 isolated from TabSubstCol of GetColRowGfxOff
;                 Returns : 
;                 ID      : .hbu008.
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
GetImageBytes     stx SavImageColType             ; save image column type - 4 differerent positions
                  
                  lda #$00
                  sta $0e
                  ldx $23                         ; image number
.GetImageAdr      dex
                  bmi .SetImageAdr                ; ready
                  
                  clc                             ; calc image data offset
                  adc #DatImageLen
                  bcc .GetImageAdr
                  inc $0e                         ; set high offset
                  jmp .GetImageAdr                ; next round
                  
.SetImageAdr      sta $0d                         ; set low  offset
                  
                  lda #<DatImages                 ; add image data start address
                  clc
                  adc $0d
                  sta $0d
                  lda #>DatImages
                  adc $0e
                  sta $0e                         ; ($0d/$0e) - points to image data
                  
                  ldy #DatImageLen-1              ; image data lenght machine form
.GetImageByte1    lda ($0d),y                     ; get an image row (3 bytes)
.PutImageByte1    sta $5b,y
                  dey
                  
.GetImageByte2    lda ($0d),y
.PutImageByte2    sta $5b,y
                  dey
                  
.GetImageByte3    lda ($0d),y                     ; always zero so far - but neccessary
.PutImageByte3    sta $5b,y
                  
                  tya                             ; care for different addressing mode
                  tax
                  
.ChkImageType     lda SavImageColType             ; test image column type
                  beq .SetImageNext               ; no   shift for type $00
                  cmp #$01
                  beq .ShiftImageRow2             ; 2bit shift for type $01
                  cmp #$02
                  beq .ShiftImageRow4             ; 4bit shift for type $02
                  
.ShiftImageRow6   lsr $5b,x                       ; 6bit shift for type $03
                  inx
                  ror $5b,x
                  dex
                  lsr $5b,x
                  inx
                  ror $5b,x
                  dex
.ShiftImageRow4   lsr $5b,x
                  inx
                  ror $5b,x
                  dex
                  lsr $5b,x
                  inx
                  ror $5b,x
                  dex
.ShiftImageRow2   lsr $5b,x
                  inx
                  ror $5b,x
                  dex
                  lsr $5b,x
                  inx
                  ror $5b,x
                  
.SetImageNext     dey
                  bpl .GetImageByte1              ; next image data row triplet
                  
GetImageBytesX    rts
; ------------------------------------------------------------------------------------------------------------- ;
SavImageColType   dc.b $00
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
SetSpritePos      lda LR_SprtPosCtrl              ; control sprite pos init  $00=init
                  bne SetSpritePosX               ;
                  
                  lda $23                         ; image number
                  cmp #NoSprites+1                ; .hbu008. - first half of images ($00-$39) only
                  bcs SetSpritePosX               ;
                  
                  tay                             ;
                  lda TabSpriteGame,y             ; image substitution tab
                  bmi SetSpritePosX               ; image not to be substituted
                  beq .SavOffset                  ;
                  
                  sta $23                         ; substitute numbered MC image with game image
                  
.SavOffset        stx $21                         ; grafic xr offset from GetColRowGfxOff
                  jsr CopySpriteData              ; xr=sprite number * 2
                  
.SetSpriteXPos    lda $21                         ; grafic xr offset from GetColRowGfxOff
                  clc                             ;
                  adc #$0c                        ; 12
                  asl a                           ; *2
                  and #$f8                        ; clear bits 0-2
                  sta SP0X,x                      ; VIC 2 - $D000 equ Sprite 0 PosX
                  bcc .ClrSpriteXPosHi            ; no x pos msb so ClearSpritesXMSB
                  
.SetSpriteXPosHi  lda TabSetSprtMSB,x             ; sprite set x pos msb tab
                  ora MSIGX                       ; VIC 2 - $D010 equ MSBs Sprites 0-7 PosX
                  sta MSIGX                       ; VIC 2 - $D010 equ MSBs Sprites 0-7 PosX
                  jmp .SetSpriteYPos              ;
                  
.ClrSpriteXPosHi  lda TabClrSprtMSB,x             ; sprite clear x pos msb tab
                  and MSIGX                       ; VIC 2 - $D010 equ MSBs Sprites 0-7 PosX
                  sta MSIGX                       ; VIC 2 - $D010 equ MSBs Sprites 0-7 PosX
                  
.SetSpriteYPos    lda $20                         ; 
                  clc                             ;
                  adc #$32                        ;
                  sta SP0Y,x                      ; VIC 2 - $D001 equ Sprite 0 PosY
                  
                  lda SPSPCL                      ; VIC 2 - $D01E equ Sprite/Sprite Collision
                  and #$01                        ; isolate bit 0
                  sta $27                         ; sprite collision  1=lr caught
                  
                  pla                             ; discard return address
                  pla                             ;
                  
SetSpritePosX     rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TabSetSprtMSB     dc.b $01 ; .......#  set   - sprite x pos msb tab
TabClrSprtMSB     dc.b $fe ; #######.  clear - sprite x pos msb tab
                  
                  dc.b $02 ; ......#.  set   - sprite x pos msb tab
                  dc.b $fd ; ######.#  clear - sprite x pos msb tab
                  
                  dc.b $04 ; .....#..  set   - sprite x pos msb tab
                  dc.b $fb ; #####.##  clear - sprite x pos msb tab
                  
                  dc.b $08 ; ....#...  set   - sprite x pos msb tab
                  dc.b $f7 ; ####.###  clear - sprite x pos msb tab
                  
                  dc.b $10 ; ...#....  set   - sprite x pos msb tab
                  dc.b $ef ; ###.####  clear - sprite x pos msb tab
                  
                  dc.b $20 ; ..#.....  set   - sprite x pos msb tab
                  dc.b $df ; ##.#####  clear - sprite x pos msb tab
                  
                  dc.b $40 ; .#......  set   - sprite x pos msb tab
                  dc.b $bf ; #.######  clear - sprite x pos msb tab
                  
                  dc.b $80 ; #.......  set   - sprite x pos msb tab
                  dc.b $7f ; .#######  clear - sprite x pos msb tab
; ------------------------------------------------------------------------------------------------------------- ;
; TabSpriteGame   Function: Game sprite substitution table
;                         : All entries correspond to their positions in DatImages
;                         : Sprite $00 entries will be positionally corrected
;                         : Sprite $ff entries will be ignored
;                         : Sprite $nn entries will replace their corresponding position number
;                 Parms   : ac=Sprite ID
;                 Returns : 
; ------------------------------------------------------------------------------------------------------------- ;
TabSpriteGame     dc.b $ff                       ; $00 (not_used)
                  dc.b $ff                       ; $01 (not_used)
                  dc.b $ff                       ; $02 (not_used)
                  dc.b $ff                       ; $03 (not_used)
                  dc.b $ff                       ; $04 (not_used)
                  dc.b $ff                       ; $05 (not_used)
                  dc.b $ff                       ; $06 (not_used)
                  dc.b $ff                       ; $07 (not_used)
                  dc.b NoSprite_RuLe00           ; $08 - enemy      - replace MC tile in game mode
                  dc.b $00                       ; $09 - LodeRunner - if set to NoSprite_RuRi00 - lr is mispaced in many levels - why??
                  dc.b $ff                       ; $0a (not_used)
                  dc.b $00                       ; $0b --> sprite run    left  01
                  dc.b $00                       ; $0c --> sprite run    left  02
                  dc.b $00                       ; $0d --> sprite run    left  03
                  dc.b $00                       ; $0e --> sprite ladder u/d   01
                  dc.b $00                       ; $0f --> sprite fire   left    
                  dc.b $00                       ; $10 --> sprite run    right 01 .hbu008.
                  dc.b $00                       ; $11 --> sprite run    right 02
                  dc.b $00                       ; $12 --> sprite run    right 03
                  dc.b $00                       ; $13 --> sprite ladder u/d   02
                  dc.b $00                       ; $14 --> sprite fall   left    
                  dc.b $00                       ; $15 --> sprite fall   right   
                  dc.b $00                       ; $16 --> sprite pole   right 01
                  dc.b $00                       ; $17 --> sprite pole   right 02
                  dc.b $00                       ; $18 --> sprite pole   right 03
                  dc.b $00                       ; $19 --> sprite pole   left  01
                  dc.b $00                       ; $1a --> sprite pole   left  02
                  dc.b $00                       ; $1b --> sprite pole   left  03
                  dc.b $ff                       ; $1c (not_used)
                  dc.b $ff                       ; $1d (not_used)
                  dc.b $ff                       ; $1e (not_used)
                  dc.b $ff                       ; $1f (not_used)
                  dc.b $ff                       ; $20 (not_used)
                  dc.b $ff                       ; $21 (not_used)
                  dc.b $ff                       ; $22 (not_used)
                  dc.b $ff                       ; $23 (not_used)
                  dc.b $ff                       ; $24 (not_used)
                  dc.b $ff                       ; $25 (not_used)
                  dc.b $00                       ; $26 --> sprite fire   right
                  dc.b $ff                       ; $27 (not_used)
                  dc.b $ff                       ; $28 (not_used)
                  dc.b NoSprite_RuRi00           ; $29 - 
                  dc.b NoSprite_RuRi01           ; $2a - 
                  dc.b NoSprite_RuRi02           ; $2b - 
                  dc.b NoSprite_RuLe01           ; $2c - 
                  dc.b NoSprite_RuLe02           ; $2d - 
                  dc.b NoSprite_PoRi00           ; $2e - 
                  dc.b NoSprite_PoRi01           ; $2f - 
                  dc.b NoSprite_PoRi02           ; $30 - 
                  dc.b NoSprite_PoLe00           ; $31 - 
                  dc.b NoSprite_PoLe01           ; $32 - 
                  dc.b NoSprite_PoLe02           ; $33 - 
                  dc.b NoSprite_Ladr00           ; $34 - 
                  dc.b NoSprite_Ladr01           ; $35 - 
                  dc.b NoSprite_FallRi           ; $36 - 
                  dc.b NoSprite_FallLe           ; $37 - 
                  dc.b $ff                       ; $38 (not_used)
                  dc.b $ff                       ; $39 (not_used)
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
CopySpriteData    pha                             ; save image id

                  lda $21                         ; grafic xr offset from GetColRowGfxOff
                  and #$03                        ; isolate bit 0-1
                  tax                             ;
                  jsr GetImageBytes               ; stored from $5b-$7b
                  
                  pla                             ; restore image id
                  beq .CopyDataI                  ; lode runner
                  
                  lda LR_NoEnemy2Move             ; # of enemy to move
                  
.CopyDataI        tax                             ;
                  lda TabSprtDatPtrLo,x           ; sprite data pos low tab
                  sta ..ModMovSprtDatL            ; modify store address low
                  lda TabSprtDatPtrHi,x           ; sprite data pos high tab
                  sta ..ModMovSprtDatH            ; modify store address high
                  
                  lda TabSpriteNum,x              ; sprite number tab
                  tax                             ;
                  
                  ldy #$20                        ; 32
.CopyData         lda $5b,y                       ; .hbu000. - image has 33 bytes
.MoveSprtDat      sta .MoveSprtDat,y              ; store it to correct sprite data storage  ($0c00-$0dff)
..ModMovSprtDatL  equ *-2
..ModMovSprtDatH  equ *-1
                  dey                             ;
                  bpl .CopyData                   ;
                  
                  txa                             ;
                  asl a                           ; *2 - gives VIC sprite XPOS offset
                  tax                             ;
                  
CopySpriteDataX   rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TabSprtDatPtrLo   dc.b <LR_SpriteData00          ; sprite data pos low tab
                  dc.b <LR_SpriteData01
                  dc.b <LR_SpriteData02
                  dc.b <LR_SpriteData03
                  dc.b <LR_SpriteData04
                  dc.b <LR_SpriteData05
; ------------------------------------------------------------------------------------------------------------- ;
TabSprtDatPtrHi   dc.b >LR_SpriteData00          ; sprite data pos high tab
                  dc.b >LR_SpriteData01
                  dc.b >LR_SpriteData02
                  dc.b >LR_SpriteData03
                  dc.b >LR_SpriteData04
                  dc.b >LR_SpriteData05
; ------------------------------------------------------------------------------------------------------------- ;
TabSpriteNum      dc.b $00                       ; filler  - LR_NoEnemy2Move counter from 1-5
                  dc.b $02                       ; enemy 1 - color table pos
                  dc.b $03                       ; enemy 2 - color table pos
                  dc.b $04                       ; enemy 3 - color table pos
                  dc.b $06                       ; enemy 4 - color table pos
                  dc.b $07                       ; enemy 5 - color table pos
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
GetColRowGfxOff   lda TabSubstRow,y               ; tab: Row2Screen
                  pha                             ;
                  lda TabSubstCol,x               ; tab: Col2Screen
                  tax                             ;
                  pla                             ;
                  tay                             ;
                  
GetColRowGfxOffX  rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
TabSubstRow       dc.b $00 ; 00                  ; game row positions
                  dc.b $0b ; 01
                  dc.b $16 ; 02
                  dc.b $21 ; 03
                  dc.b $2c ; 04
                  dc.b $37 ; 05
                  dc.b $42 ; 06
                  dc.b $4d ; 07
                  dc.b $58 ; 08
                  dc.b $63 ; 09
                  dc.b $6e ; 0a
                  dc.b $79 ; 0b
                  dc.b $84 ; 0c
                  dc.b $8f ; 0d
                  dc.b $9a ; 0e
                  dc.b $a5 ; 0f
                  dc.b $b5 ; 10
; ------------------------------------------------------------------------------------------------------------- ;
TabSubstCol       dc.b $0a ; 01: ....#.   #.   - rightmost two bits isolated for GetImageBytes - position type 0-3
                  dc.b $0f ; 02: ....##   ##
                  dc.b $14 ; 03: ...#.#   ..
                  dc.b $19 ; 04: ...##.   .#
                  dc.b $1e ; 05: ...###   #.
                  dc.b $23 ; 06: ..#...   ##
                  dc.b $28 ; 07: ..#.#.   ..
                  dc.b $2d ; 08: ..#.##   .#
                  dc.b $32 ; 09: ..##..   #.
                  dc.b $37 ; 0a: ..##.#   ##
                  dc.b $3c ; 0b: ..####   ..
                  dc.b $41 ; 0c: .#....   .#
                  dc.b $46 ; 0d: .#...#   #.
                  dc.b $4b ; 0e: .#..#.   ##
                  dc.b $50 ; 0f: .#.#..   ..
                  dc.b $55 ; 10: .#.#.#   .#
                  dc.b $5a ; 11: .#.##.   #.
                  dc.b $5f ; 12: .#.###   ##
                  dc.b $64 ; 13: .##..#   ..
                  dc.b $69 ; 14: .##.#.   .#
                  dc.b $6e ; 15: .##.##   #.
                  dc.b $73 ; 16: .###..   ##
                  dc.b $78 ; 17: .####.   ..
                  dc.b $7d ; 18: .#####   .#
                  dc.b $82 ; 19: #.....   #.
                  dc.b $87 ; 1a: #....#   ##
                  dc.b $8c ; 1b: #...##   ..
                  dc.b $91 ; 1c: #..#..   .#
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
GetXOff           tya                             ;
                  pha                             ; 
                  jsr GetColRowGfxOff             ;
                  
                  pla                             ;
                  tay                             ;
                  txa                             ;
                  clc                             ;
                  adc TabOffsetsX,y               ;
                  tax                             ;
                  
GetXOffX          rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TabOffsetsX       dc.b $fe ; -2
                  dc.b $ff ; -1
                  dc.b $00 ;  0
                  dc.b $01 ; +1
                  dc.b $02 ; +2
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
GetYOff           txa                             ;
                  pha                             ;
                  jsr GetColRowGfxOff             ;
                  
                  pla                             ;
                  tax                             ;
                  tya                             ;
                  clc                             ;
                  adc TabOffsetsY,x               ;
                  tay                             ;
                  rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TabOffsetsY       dc.b $fb ; -4
                  dc.b $fd ; -2
                  dc.b $00 ;  0
                  dc.b $02 ; +2
                  dc.b $04 ; +4
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
GetOutGfxPosAdd   lda #$00
                  sta CR_GfxAddHi                 ; init high grafic add
                                                                                    
                  txa                                                               
                  pha                             ; save xr
                  and #$03                        ; isolate bit 0-1
                  tax                                                               
                  pla                             ; restore xr
                                                                                    
                  asl a                           ; *2
                  rol CR_GfxAddHi                 ; save carry in high grafic add
                  and #$f8                        ; kill bits 0-2
                  sta CR_GfxAddLo                 ;   of low grafic add

GetOutGfxPosAddX  rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
GetCtrlDataPtr    lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09                         ; 
                  sta $0b                         ; 
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a                         ; 
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c                         ; 

GetCtrlDataPtrX   rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
GetOutGfxPtrClr   lda #$00                        ;
                  sta CR_GfxAddLo                 ;
                  sta CR_GfxAddHi                 ;

GetOutGfxPtr      lda LR_TabOffHiresLo,y          ; offset grafic output low
                  clc                             ;
                  adc CR_GfxAddLo                 ; low grafic add
                  sta $0f                         ; screen grafic low pointer
                  lda LR_TabOffHiresHi,y          ; offset grafic output high
                  adc CR_GfxAddHi                 ; high grafic add
                  ora $24                         ; graphic output  (20=2000-2fff  40=4000-4fff)
                  sta $10                         ; screen grafic high pointer
                  
GetOutGfxPtrX     rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
GetMoveGfxPtr     lda LR_TabOffHiresLo,y          ; offset grafic output low
                  clc
                  adc CR_GfxAddLo                 ; low grafic add
                  sta $0f                         ; screen grafic low pointer
                  sta $11                         ; hidden grafic low pointer
                  
                  lda LR_TabOffHiresHi,y          ; offset grafic output high
                  adc CR_GfxAddHi                 ; high grafic add
                  ora #>LR_ScrnHiReDisp            ; $20 - point to $2000-$3fff  (display screen)
                  sta $10                         ; screen grafic high pointer
                  eor #>LR_ScrnHiReDisp + >LR_ScrnHiRePrep ; $60 - point to $4000-$5fff  (hidden screen)
                  sta $12                         ; hidden grafic high pointer
                  
GetMoveGfxPtrX    rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ClearHiresDisp    lda #>LR_ScrnHiReDisp           ; $2000-$3fff - hires display screen
                  
                  ldx #$00                        ; disable all sprites
                  stx SPENA                       ; VIC 2 - $D015 equ Sprite Enable
                  
                  ldx #>(LR_ScrnHiReDisp + $2000) ; $40 - upper border
                  bne ClearScrn                   ; always
                  
ClearHiresPrep    lda #>LR_ScrnHiRePrep           ; $40=$4000-$5fff  copy of screen  (hidden setup/copy to $2000)
                  ldx #>(LR_ScrnHiRePrep + $2000) ; $60 - upper border
                  
ClearScrn         sta $10                         ; screen grafic high pointer
                  ldy #$00
                  sty $0f                         ; screen grafic low pointer
                  
                  tya
                  
.Clear            sta ($0f),y                     ; screen grafic pointer byte
                  iny                             ; next byte
                  bne .Clear
                  
                  inc $10                         ; next block
                  cpx $10                         ; upper border
                  bne .Clear                      ; not reached
                  
ClearScrnX        rts
; ------------------------------------------------------------------------------------------------------------- ;
TabExLvlDatRowLo  dc.b $00                       ; expanded level data row pointer lo
                  dc.b $1c
                  dc.b $38
                  dc.b $54
                  dc.b $70
                  dc.b $8c
                  dc.b $a8
                  dc.b $c4
                  dc.b $e0
                  
                  dc.b $00
                  dc.b $1c
                  dc.b $38
                  dc.b $54
                  dc.b $70
                  dc.b $8c
                  dc.b $a8
; ------------------------------------------------------------------------------------------------------------- ;
TabExLvlDatRowH8  dc.b $08                       ; expanded level data row pointer $0800-$09c3
                  dc.b $08
                  dc.b $08
                  dc.b $08
                  dc.b $08
                  dc.b $08
                  dc.b $08
                  dc.b $08
                  dc.b $08
                  
                  dc.b $09
                  dc.b $09
                  dc.b $09
                  dc.b $09
                  dc.b $09
                  dc.b $09
                  dc.b $09
; ------------------------------------------------------------------------------------------------------------- ;
TabExLvlDatRowHa  dc.b $0a                       ; expanded level data row pointer $0a00-$0bc3
                  dc.b $0a
                  dc.b $0a
                  dc.b $0a
                  dc.b $0a
                  dc.b $0a
                  dc.b $0a
                  dc.b $0a
                  dc.b $0a
                  
                  dc.b $0b
                  dc.b $0b
                  dc.b $0b
                  dc.b $0b
                  dc.b $0b
                  dc.b $0b
                  dc.b $0b
; ------------------------------------------------------------------------------------------------------------- ;
; ShowExitLadders Function: Show secret ladders if all gold is collected
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
ShowExitLadders   lda #$00
                  sta CR_TabXitLdrCol             ; init not empty mark
                  
                  ldx LR_NumXitLadders            ; # hidden ladders
                  stx WrkXitLadders               ; # hidden ladders to display
.Ladders          ldx WrkXitLadders               ; # hidden ladders to display
                  beq .ExitCheckGold              ; finished
                  
                  lda CR_TabXitLdrCol,x           ; adr column hidden ladder tab
                  bmi .DecLadderCount             ; already cleared
                  
                  sta $4f                         ; screen col  (00-1b)
                  lda CR_TabXitLdrRow,x           ; adr row hidden ladders tab
                  sta $50                         ; screen row  (00-0f)
                  tay
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $4f                         ; screen col  (00-1b)
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  bne .SetNotEmpty                ; position not empty
                  
.LadderOutCtrl    lda #LR_TileLadder
                  sta ($0b),y                     ; play level control data ($0a00-$0bc3)
                  
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  bne .LadderOutDisp              ; not empty
                  
.LadderOutData    lda #LR_TileLadder
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
.LadderOutDisp    lda #LR_TileLadder
                  jsr ImageOut2Prep               ; output to preparation screen first ($4000)
                  
                  ldx $4f                         ; screen col  (00-1b)
                  ldy $50                         ; screen row  (00-0f)
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row
                  
                  lda #LR_TileLadder
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  
.ClrTabXitLadder  ldx WrkXitLadders               ; # hidden ladders to display
                  lda #$ff
                  sta CR_TabXitLdrCol,x           ; clear adr column hidden ladder tab
                  bmi .DecLadderCount             ; always
                  
.SetNotEmpty      lda #$01
                  sta CR_TabXitLdrCol             ; set not empty mark
                  
.DecLadderCount   dec WrkXitLadders               ; # hidden ladders to display
                  jmp .Ladders
                  
.ExitCheckGold    lda CR_TabXitLdrCol             ; not empty mark
                  bne ShowExitLaddersX            ; not set
                  
                  dec LR_Gold2Get
                  
ShowExitLaddersX  rts
; ------------------------------------------------------------------------------------------------------------- ;
WrkXitLadders     dc.b $00
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
GetAKey           lda LR_KeyNew                   ; 
                  beq GetAKey                     ;
                  
                  ldx #$00                        ;
                  stx LR_KeyNew                   ; 
                  
GetAKeyX          rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
FlipGmeOverSign   lda #$01                        ; fastest
                  sta WrkSignSpinSpeed            ; 
                  lda #$20                        ;
                  sta $24                         ;
.FlipSign         jsr FlipSignPhase05             ; 
                  jsr FlipSignPhase04             ;
                  jsr FlipSignPhase03             ;
                  jsr FlipSignPhase02             ;
                  jsr FlipSignPhase01             ;
                  jsr FlipSignPhase00             ;
                  jsr FlipSignPhase01             ;
                  jsr FlipSignPhase02             ;
                  jsr FlipSignPhase03             ;
                  jsr FlipSignPhase04             ;
                  jsr FlipSignPhase05             ;
                  jsr FlipSignPhase0a             ;
                  jsr FlipSignPhase09             ;
                  jsr FlipSignPhase08             ;
                  jsr FlipSignPhase07             ;
                  jsr FlipSignPhase06             ;
                  jsr FlipSignPhase07             ;
                  jsr FlipSignPhase08             ;
                  jsr FlipSignPhase09             ;
                  jsr FlipSignPhase0a             ;

                  lda WrkSignSpinSpeed            ; 
                  cmp #$64                        ; slowest
                  bcc .FlipSign                   ; 

                  jsr FlipSignPhase05             ;
                  jsr FlipSignPhase04             ;
                  jsr FlipSignPhase03             ;
                  jsr FlipSignPhase02             ;
                  jsr FlipSignPhase01             ;
                  jsr FlipSignPhase00             ;
                  clc                             ;
                  rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
FlipSignPhase00   jsr FlipSignOut
                  dc.b NoSignLine00
                  dc.b NoSignLine01
                  dc.b NoSignLine02
                  dc.b NoSignLine03
                  dc.b NoSignLine04
                  dc.b NoSignLine05
                  dc.b NoSignLine06
                  dc.b NoSignLine07
                  dc.b NoSignLine08
                  dc.b NoSignLine09
                  dc.b NoSignLine0a
                  dc.b NoSignLine02
                  dc.b NoSignLine01
                  dc.b NoSignLine00
FlipSignPhase01   jsr FlipSignOut
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine01
                  dc.b NoSignLine02
                  dc.b NoSignLine03
                  dc.b NoSignLine04
                  dc.b NoSignLine05
                  dc.b NoSignLine07
                  dc.b NoSignLine09
                  dc.b NoSignLine0a
                  dc.b NoSignLine02
                  dc.b NoSignLine01
                  dc.b NoSignLine00
                  dc.b NoSignLine00
FlipSignPhase02   jsr FlipSignOut
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine01
                  dc.b NoSignLine02
                  dc.b NoSignLine03
                  dc.b NoSignLine04
                  dc.b NoSignLine09
                  dc.b NoSignLine0a
                  dc.b NoSignLine02
                  dc.b NoSignLine01
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
FlipSignPhase03   jsr FlipSignOut
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine01
                  dc.b NoSignLine02
                  dc.b NoSignLine03
                  dc.b NoSignLine0a
                  dc.b NoSignLine02
                  dc.b NoSignLine01
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
FlipSignPhase04   jsr FlipSignOut
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine01
                  dc.b NoSignLine03
                  dc.b NoSignLine0a
                  dc.b NoSignLine01
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
FlipSignPhase05   jsr FlipSignOut
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine01
                  dc.b NoSignLine01
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
FlipSignPhase06   jsr FlipSignOut
                  dc.b NoSignLine00
                  dc.b NoSignLine01
                  dc.b NoSignLine02
                  dc.b NoSignLine0a
                  dc.b NoSignLine09
                  dc.b NoSignLine08
                  dc.b NoSignLine07
                  dc.b NoSignLine06
                  dc.b NoSignLine05
                  dc.b NoSignLine04
                  dc.b NoSignLine03
                  dc.b NoSignLine02
                  dc.b NoSignLine01
                  dc.b NoSignLine00
FlipSignPhase07   jsr FlipSignOut
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine01
                  dc.b NoSignLine02
                  dc.b NoSignLine0a
                  dc.b NoSignLine09
                  dc.b NoSignLine07
                  dc.b NoSignLine05
                  dc.b NoSignLine04
                  dc.b NoSignLine03
                  dc.b NoSignLine02
                  dc.b NoSignLine01
                  dc.b NoSignLine00
                  dc.b NoSignLine00
FlipSignPhase08   jsr FlipSignOut
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine01
                  dc.b NoSignLine02
                  dc.b NoSignLine0a
                  dc.b NoSignLine09
                  dc.b NoSignLine04
                  dc.b NoSignLine03
                  dc.b NoSignLine02
                  dc.b NoSignLine01
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
FlipSignPhase09   jsr FlipSignOut
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine01
                  dc.b NoSignLine02
                  dc.b NoSignLine0a
                  dc.b NoSignLine03
                  dc.b NoSignLine02
                  dc.b NoSignLine01
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
FlipSignPhase0a   jsr FlipSignOut
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine01
                  dc.b NoSignLine0a
                  dc.b NoSignLine03
                  dc.b NoSignLine01
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
                  dc.b NoSignLine00
; ------------------------------------------------------------------------------------------------------------- ;
;   Line00: ................................................................................................
;   Line01: ....#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.......
;   Line02: ..#.......................................................................................#.....
;   Line03: ..#...#.#.#.#...#.#.#...#.#.#.#.#...#.#.#.#.......#.#.#.#...#.#...#...#.#.#.#...#.#.#.#...#.....
;   Line04: ..#...#.....#...#...#...#.#.#...#...#.#...........#...#.#...#.#...#...#.#.#.#...#.....#...#.....
;   Line05: ..#...#.........#...#...#...#...#...#.#...........#...#.#...#.#...#...#.#.......#.....#...#.....
;   Line06: ..#...#.........#...#...#...#...#...#.#.#.#.......#...#.#...#.#...#...#.#.#.....#.#.#.#...#.....
;   Line07: ..#...#...#.#...#.#.#...#...#...#...#.#.#.#.......#.....#...#.#...#...#.........#.#.#.....#.....
;   Line08: ..#...#.....#...#...#...#...#...#...#.............#.....#...#.#.#.#...#.........#.#.#.....#.....
;   Line09: ..#...#.....#...#...#...#...#...#...#.............#.....#.....#.#.....#.........#.#...#...#.....
;   Line0a: ..#...#.#.#.#...#...#...#...#...#...#.#.#.#.......#.#.#.#.....#.......#.#.#.#...#.....#...#.....
; ------------------------------------------------------------------------------------------------------------- ;
DataSignLine00    dc.b $00 ; ................................................................................................
                  dc.b $00 ;
                  dc.b $00 ;
                  dc.b $00 ;
                  dc.b $00 ;
                  dc.b $00 ;
                  dc.b $00 ;
                  dc.b $00 ;
                  dc.b $00 ;
                  dc.b $00 ;
                  dc.b $00 ;
                  dc.b $00 ;
                  
DataSignLine01    dc.b $0a ; ....#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.......
                  dc.b $aa ;
                  dc.b $aa ;
                  dc.b $aa ;
                  dc.b $aa ;
                  dc.b $aa ;
                  dc.b $aa ;
                  dc.b $aa ;
                  dc.b $aa ;
                  dc.b $aa ;
                  dc.b $aa ;
                  dc.b $80 ;
                  
DataSignLine02    dc.b $20 ; ..#.......................................................................................#.....
                  dc.b $00 ;
                  dc.b $00 ;
                  dc.b $00 ;
                  dc.b $00 ;
                  dc.b $00 ;
                  dc.b $00 ;
                  dc.b $00 ;
                  dc.b $00 ;
                  dc.b $00 ;
                  dc.b $00 ;
                  dc.b $20 ;
                  
DataSignLine03    dc.b $22 ; ..#...#.#.#.#...#.#.#...#.#.#.#.#...#.#.#.#.......#.#.#.#...#.#...#...#.#.#.#...#.#.#.#...#.....
                  dc.b $a8 ;
                  dc.b $a8 ;
                  dc.b $aa ;
                  dc.b $8a ;
                  dc.b $a0 ;
                  dc.b $2a ;
                  dc.b $8a ;
                  dc.b $22 ;
                  dc.b $a8 ;
                  dc.b $aa ;
                  dc.b $20 ;
                  
DataSignLine04    dc.b $22 ; ..#...#.....#...#...#...#.#.#...#...#.#...........#...#.#...#.#...#...#.#.#.#...#.....#...#.....
                  dc.b $08 ;
                  dc.b $88 ;
                  dc.b $a8 ;
                  dc.b $8a ;
                  dc.b $00 ;
                  dc.b $22 ;
                  dc.b $8a ;
                  dc.b $22 ;
                  dc.b $a8 ;
                  dc.b $82 ;
                  dc.b $20 ;
                  
DataSignLine05    dc.b $22 ; ..#...#.........#...#...#...#...#...#.#...........#...#.#...#.#...#...#.#.......#.....#...#.....
                  dc.b $00 ;
                  dc.b $88 ;
                  dc.b $88 ;
                  dc.b $8a ;
                  dc.b $00 ;
                  dc.b $22 ;
                  dc.b $8a ;
                  dc.b $22 ;
                  dc.b $80 ;
                  dc.b $82 ;
                  dc.b $20 ;
                  
DataSignLine06    dc.b $22 ; ..#...#.........#...#...#...#...#...#.#.#.#.......#...#.#...#.#...#...#.#.#.....#.#.#.#...#.....
                  dc.b $00 ;
                  dc.b $88 ;
                  dc.b $88 ;
                  dc.b $8a ;
                  dc.b $a0 ;
                  dc.b $22 ;
                  dc.b $8a ;
                  dc.b $22 ;
                  dc.b $a0 ;
                  dc.b $aa ;
                  dc.b $20 ;
                  

DataSignLine07    dc.b $22 ; ..#...#...#.#...#.#.#...#...#...#...#.#.#.#.......#.....#...#.#...#...#.........#.#.#.....#.....
                  dc.b $28 ;
                  dc.b $a8 ;
                  dc.b $88 ;
                  dc.b $8a ;
                  dc.b $a0 ;
                  dc.b $20 ;
                  dc.b $8a ;
                  dc.b $22 ;
                  dc.b $00 ;
                  dc.b $a8 ;
                  dc.b $20 ;
                  
DataSignLine08    dc.b $22 ; ..#...#.....#...#...#...#...#...#...#.............#.....#...#.#.#.#...#.........#.#.#.....#.....
                  dc.b $08 ;
                  dc.b $88 ;
                  dc.b $88 ;
                  dc.b $88 ;
                  dc.b $00 ;
                  dc.b $20 ;
                  dc.b $8a ;
                  dc.b $a2 ;
                  dc.b $00 ;
                  dc.b $a8 ;
                  dc.b $20 ;
                  
DataSignLine09    dc.b $22 ; ..#...#.....#...#...#...#...#...#...#.............#.....#.....#.#.....#.........#.#...#...#.....
                  dc.b $08 ;
                  dc.b $88 ;
                  dc.b $88 ;
                  dc.b $88 ;
                  dc.b $00 ;
                  dc.b $20 ;
                  dc.b $82 ;
                  dc.b $82 ;
                  dc.b $00 ;
                  dc.b $a2 ;
                  dc.b $20 ;
                  
DataSignLine0a    dc.b $22 ; ..#...#.#.#.#...#...#...#...#...#...#.#.#.#.......#.#.#.#.....#.......#.#.#.#...#.....#...#.....
                  dc.b $a8 ;
                  dc.b $88 ;
                  dc.b $88 ;
                  dc.b $8a ;
                  dc.b $a0 ;
                  dc.b $2a ;
                  dc.b $82 ;
                  dc.b $02 ;
                  dc.b $a8 ;
                  dc.b $a2 ;
                  dc.b $20 ;
; ------------------------------------------------------------------------------------------------------------- ;
TabSignDataAdr    =*                              ; flip data address tab
TabSignDataLen    equ DataSignLine01-DataSignLine00 ; line data length
                  
ObjLine00         dc.w DataSignLine00 - TabSignDataLen - $02
ObjLine01         dc.w DataSignLine01 - TabSignDataLen - $02
ObjLine02         dc.w DataSignLine02 - TabSignDataLen - $02
ObjLine03         dc.w DataSignLine03 - TabSignDataLen - $02
ObjLine04         dc.w DataSignLine04 - TabSignDataLen - $02
ObjLine05         dc.w DataSignLine05 - TabSignDataLen - $02
ObjLine06         dc.w DataSignLine06 - TabSignDataLen - $02
ObjLine07         dc.w DataSignLine07 - TabSignDataLen - $02
ObjLine08         dc.w DataSignLine08 - TabSignDataLen - $02
ObjLine09         dc.w DataSignLine09 - TabSignDataLen - $02
ObjLine0a         dc.w DataSignLine0a - TabSignDataLen - $02
                  
NoSignLine00      equ (DataSignLine00 - DataSignLine00) / TabSignDataLen
NoSignLine01      equ (DataSignLine01 - DataSignLine00) / TabSignDataLen
NoSignLine02      equ (DataSignLine02 - DataSignLine00) / TabSignDataLen
NoSignLine03      equ (DataSignLine03 - DataSignLine00) / TabSignDataLen
NoSignLine04      equ (DataSignLine04 - DataSignLine00) / TabSignDataLen
NoSignLine05      equ (DataSignLine05 - DataSignLine00) / TabSignDataLen
NoSignLine06      equ (DataSignLine06 - DataSignLine00) / TabSignDataLen
NoSignLine07      equ (DataSignLine07 - DataSignLine00) / TabSignDataLen
NoSignLine08      equ (DataSignLine08 - DataSignLine00) / TabSignDataLen
NoSignLine09      equ (DataSignLine09 - DataSignLine00) / TabSignDataLen
NoSignLine0a      equ (DataSignLine0a - DataSignLine00) / TabSignDataLen
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
FlipSignOut       pla                             ; start adr of data array is the return adr
                  sta $0d
                  pla
                  sta $0e
                  
                  ldy #$50
                  sty $50                         ; screen row  (00-0f)
                  bne .SetSignPtr                 ; always
                  
.SetGfxPtr        jsr GetOutGfxPtrClr             ; ($0f/$10) pointer
                  
                  ldy #$00
                  lda ($0d),y                     ; get sign control byte
                  asl a                           ; *2
                  tax
                  lda TabSignDataAdr,x            ; flip data address tab
                  sta ..ModGetDataLo              ; modify load cmd low
                  lda TabSignDataAdr+1,x          ; flip data address tab + 1
                  sta ..ModGetDataHi              ; modify load cmd high
                  
                  ldy #$70
                  sty $20                         ; grafic row substitution
                  
                  ldy #TabSignDataLen+2           ; $0e - sign data lenght
                  sty $1e
                  
.FlipSign         ldy $1e
                  inc $1e
.GetSignData      lda .GetSignData,y              ; get sign data byte
..ModGetDataLo    equ *-2
..ModGetDataHi    equ *-1
                  lsr a                           ; *2
                  ldy $20                         ; grafic row substitution
                  sta ($0f),y                     ; screen grafic pointer byte
                  tya
                  clc
                  adc #$08                        ; point to next position
                  sta $20                         ; grafic row substitution
                  
                  ldy $1e
                  cpy #$1a                        ; max
                  bcc .FlipSign
                  
.SetSignPtr       jsr FlipSignIncPtr
                  
                  inc $50                         ; screen row  (00-0f)
                  ldy $50                         ; screen row  (00-0f)
                  cpy #$5f                        ; max
                  bcc .SetGfxPtr
                  
                  ldx WrkSignSpinSpeed            ; flip sign spin speed
                  ldy #$ff
.Wait             dey
                  bne .Wait
                  dex
                  bne .Wait
                  
                  inc WrkSignSpinSpeed            ; flip sign spin speed so wait longer the next time
                  lda CIAPRA                      ; CIA 1 - $DC00 equ Data Port A
                  and #$10                        ; isolate fire
                  beq FlipSignFinish              ; pressed
                  
                  lda LR_KeyNew                   ; actual key
                  bne FlipSignFinish              ; pressed some
                  
FlipSignOutX      rts
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
FlipSignFinish    pla                             ; pull return address from stack
                  pla
                  
                  sec
FlipSignFinishX   rts
; ------------------------------------------------------------------------------------------------------------- ;
WrkSignSpinSpeed  dc.b $00
; ------------------------------------------------------------------------------------------------------------- ;
                  subroutine
FlipSignIncPtr    inc $0d
                  bne FlipSignIncPtrX
                  inc $0e
                  
FlipSignIncPtrX   rts
; ------------------------------------------------------------------------------------------------------------- ;
TabDemoLvlMoves   dc.b $44
                  dc.b $01
                  dc.b $33
                  dc.b $03
                  dc.b $11
                  dc.b $06
                  dc.b $33
                  dc.b $27
                  dc.b $00
                  dc.b $1d
                  dc.b $33
                  dc.b $2d
                  dc.b $11
                  dc.b $1f
                  dc.b $55
                  dc.b $01
                  dc.b $11
                  dc.b $03
                  dc.b $44
                  dc.b $01
                  dc.b $22
                  dc.b $04
                  dc.b $44
                  dc.b $01
                  dc.b $22
                  dc.b $13
                  dc.b $11
                  dc.b $0b
                  dc.b $55
                  dc.b $01
                  dc.b $33
                  dc.b $0a
                  dc.b $22
                  dc.b $1f
                  dc.b $00
                  dc.b $13
                  dc.b $44
                  dc.b $01
                  dc.b $00
                  dc.b $33
                  dc.b $33
                  dc.b $05
                  dc.b $44
                  dc.b $01
                  dc.b $33
                  dc.b $03
                  dc.b $11
                  dc.b $09
                  dc.b $00
                  dc.b $9d
                  dc.b $33
                  dc.b $31
                  dc.b $44
                  dc.b $01
                  dc.b $11
                  dc.b $04
                  dc.b $44
                  dc.b $01
                  dc.b $11
                  dc.b $09
                  dc.b $33
                  dc.b $10
                  dc.b $44
                  dc.b $01
                  dc.b $11
                  dc.b $04
                  dc.b $44
                  dc.b $01
                  dc.b $11
                  dc.b $10
                  dc.b $33
                  dc.b $0b
                  dc.b $44
                  dc.b $01
                  dc.b $11
                  dc.b $05
                  dc.b $44
                  dc.b $01
                  dc.b $11
                  dc.b $0e
                  dc.b $33
                  dc.b $0b
                  dc.b $44
                  dc.b $01
                  dc.b $11
                  dc.b $05
                  dc.b $44
                  dc.b $01
                  dc.b $11
                  dc.b $14
                  dc.b $33
                  dc.b $0b
                  dc.b $44
                  dc.b $01
                  dc.b $11
                  dc.b $04
                  dc.b $44
                  dc.b $01
                  dc.b $11
                  dc.b $13
                  dc.b $33
                  dc.b $0b
                  dc.b $44
                  dc.b $01
                  dc.b $11
                  dc.b $05
                  dc.b $44
                  dc.b $01
                  dc.b $11
                  dc.b $10
                  dc.b $33
                  dc.b $08
                  dc.b $44
                  dc.b $01
                  dc.b $11
                  dc.b $21
                  dc.b $33
                  dc.b $03
                  dc.b $22
                  dc.b $46
                  dc.b $33
                  dc.b $03
                  dc.b $11
                  dc.b $0b
                  dc.b $55
                  dc.b $01
                  dc.b $33
                  dc.b $07
                  dc.b $55
                  dc.b $01
                  dc.b $66
                  dc.b $05
                  dc.b $33
                  dc.b $01
                  dc.b $55
                  dc.b $01
                  dc.b $33
                  dc.b $04
                  dc.b $55
                  dc.b $01
                  dc.b $66
                  dc.b $bd
                  dc.b $11
                  dc.b $0e
                  dc.b $44
                  dc.b $01
                  dc.b $22
                  dc.b $04
                  dc.b $44
                  dc.b $01
                  dc.b $66
                  dc.b $04
                  dc.b $33
                  dc.b $08
                  dc.b $00
                  dc.b $04
                  dc.b $33
                  dc.b $05
                  dc.b $00
                  dc.b $7e
                  dc.b $11
                  dc.b $22
                  dc.b $00
                  dc.b $0e
                  dc.b $11
                  dc.b $19
                  dc.b $55
                  dc.b $01
                  dc.b $33
                  dc.b $05
                  dc.b $55
                  dc.b $01
                  dc.b $33
                  dc.b $04
                  dc.b $55
                  dc.b $01
                  dc.b $11
                  dc.b $07
                  dc.b $44
                  dc.b $01
                  dc.b $22
                  dc.b $04
                  dc.b $44
                  dc.b $01
                  dc.b $66
                  dc.b $03
                  dc.b $00
                  dc.b $0e
                  dc.b $11
                  dc.b $03
                  dc.b $33
                  dc.b $1e
                  dc.b $00
                  dc.b $47
                  dc.b $11
                  dc.b $2a
                  dc.b $00
                  dc.b $07
                  dc.b $55
                  dc.b $01
                  dc.b $11
                  dc.b $36
                  dc.b $33
                  dc.b $04
                  dc.b $55
                  dc.b $01
                  dc.b $11
                  dc.b $03
                  dc.b $33
                  dc.b $2c
                  dc.b $00
                  dc.b $0d
                  dc.b $33
                  dc.b $11
                  dc.b $11
                  dc.b $04
                  dc.b $00
                  dc.b $0b
                  dc.b $55
                  dc.b $01
                  dc.b $22
                  dc.b $04
                  dc.b $44
                  dc.b $01
                  dc.b $33
                  dc.b $0d
                  dc.b $00
                  dc.b $03
                  dc.b $33
                  dc.b $17
                  dc.b $11
                  dc.b $0f
                  dc.b $00
                  dc.b $03
                  dc.b $11
                  dc.b $21
                  dc.b $00
                  dc.b $0f
                  dc.b $33
                  dc.b $12
                  dc.b $00
                  dc.b $0f
                  dc.b $33
                  dc.b $0a
                  dc.b $00
                  dc.b $5a
                  dc.b $33
                  dc.b $19
                  dc.b $00
                  dc.b $0a
                  dc.b $44
                  dc.b $01
                  dc.b $66
                  dc.b $02
                  dc.b $33
                  dc.b $03
                  dc.b $11
                  dc.b $06
                  dc.b $33
                  dc.b $22
                  dc.b $55
                  dc.b $01
                  dc.b $33
                  dc.b $03
                  dc.b $55
                  dc.b $01
                  dc.b $33
                  dc.b $04
                  dc.b $55
                  dc.b $01
                  dc.b $66
                  dc.b $1f
                  dc.b $00
                  dc.b $1a
                  dc.b $33
                  dc.b $22
                  dc.b $55
                  dc.b $01
                  dc.b $33
                  dc.b $04
                  dc.b $55
                  dc.b $01
                  dc.b $11
                  dc.b $15
                  dc.b $44
                  dc.b $01
                  dc.b $66
                  dc.b $7b
                  dc.b $10
                  dc.b $1f
                  dc.b $60
                  dc.b $07
                  dc.b $30
                  dc.b $09
                  dc.b $36
                  dc.b $33
                  dc.b $66
                  dc.b $04
                  dc.b $10
                  dc.b $09
                  dc.b $16
                  dc.b $08
                  dc.b $12
                  dc.b $01
                  dc.b $62
                  dc.b $0c
                  dc.b $32
                  dc.b $01
                  dc.b $36
                  dc.b $32
                  dc.b $44
                  dc.b $01
                  dc.b $16
                  dc.b $0b
                  dc.b $44
                  dc.b $01
                  dc.b $16
                  dc.b $09
                  dc.b $44
                  dc.b $01
                  dc.b $10
                  dc.b $2c
                  dc.b $60
                  dc.b $04
                  dc.b $30
                  dc.b $03
                  dc.b $36
                  dc.b $0a
                  dc.b $44
                  dc.b $01
                  dc.b $16
                  dc.b $05
                  dc.b $44
                  dc.b $01
                  dc.b $36
                  dc.b $03
                  dc.b $44
                  dc.b $01
                  dc.b $36
                  dc.b $03
                  dc.b $44
                  dc.b $01
                  dc.b $66
                  dc.b $03
                  dc.b $36
                  dc.b $03
                  dc.b $55
                  dc.b $01
                  dc.b $36
                  dc.b $08
                  dc.b $55
                  dc.b $01
                  dc.b $66
                  dc.b $4c
                  dc.b $16
                  dc.b $09
                  dc.b $10
                  dc.b $15
                  dc.b $44
                  dc.b $01
                  dc.b $10
                  dc.b $2f
                  dc.b $16
                  dc.b $09
                  dc.b $12
                  dc.b $03
                  dc.b $16
                  dc.b $12
                  dc.b $66
                  dc.b $02
                  dc.b $36
                  dc.b $06
                  dc.b $66
                  dc.b $2d
                  dc.b $55
                  dc.b $01
                  dc.b $16
                  dc.b $03
                  dc.b $10
                  dc.b $1c
                  dc.b $55
                  dc.b $01
                  dc.b $16
                  dc.b $03
                  dc.b $44
                  dc.b $01
                  dc.b $36
                  dc.b $03
                  dc.b $32
                  dc.b $15
                  dc.b $36
                  dc.b $0b
                  dc.b $30
                  dc.b $0b
                  dc.b $60
                  dc.b $0c
                  dc.b $44
                  dc.b $01
                  dc.b $62
                  dc.b $0d
                  dc.b $12
                  dc.b $02
                  dc.b $16
                  dc.b $0d
                  dc.b $44
                  dc.b $01
                  dc.b $66
                  dc.b $20
                  dc.b $36
                  dc.b $04
                  dc.b $30
                  dc.b $17
                  dc.b $36
                  dc.b $1e
                  dc.b $44
                  dc.b $01
                  dc.b $36
                  dc.b $2f
                  dc.b $30
                  dc.b $08
                  dc.b $60
                  dc.b $03
                  dc.b $10
                  dc.b $22
                  dc.b $16
                  dc.b $1b
                  dc.b $66
                  dc.b $26
                  dc.b $55
                  dc.b $07
                  dc.b $16
                  dc.b $03
                  dc.b $55
                  dc.b $01
                  dc.b $66
                  dc.b $1d
                  dc.b $16
                  dc.b $02
                  dc.b $10
                  dc.b $85
                  dc.b $60
                  dc.b $02
                  dc.b $30
                  dc.b $03
                  dc.b $36
                  dc.b $03
                  dc.b $32
                  dc.b $0f
                  dc.b $36
                  dc.b $03
                  dc.b $30
                  dc.b $0c
                  dc.b $36
                  dc.b $20
                  dc.b $66
                  dc.b $01
                  dc.b $16
                  dc.b $0a
                  dc.b $60
                  dc.b $06
                  dc.b $66
                  dc.b $02
                  dc.b $36
                  dc.b $08
                  dc.b $30
                  dc.b $05
                  dc.b $60
                  dc.b $02
                  dc.b $66
                  dc.b $02
                  dc.b $16
                  dc.b $08
                  dc.b $10
                  dc.b $01
                  dc.b $60
                  dc.b $06
                  dc.b $66
                  dc.b $01
                  dc.b $36
                  dc.b $08
                  dc.b $30
                  dc.b $04
                  dc.b $60
                  dc.b $03
                  dc.b $66
                  dc.b $01
                  dc.b $16
                  dc.b $08
                  dc.b $10
                  dc.b $02
                  dc.b $60
                  dc.b $03
                  dc.b $30
                  dc.b $01
                  dc.b $36
                  dc.b $08
                  dc.b $30
                  dc.b $03
                  dc.b $60
                  dc.b $03
                  dc.b $16
                  dc.b $09
                  dc.b $10
                  dc.b $02
                  dc.b $60
                  dc.b $03
                  dc.b $30
                  dc.b $03
                  dc.b $36
                  dc.b $07
                  dc.b $30
                  dc.b $03
                  dc.b $60
                  dc.b $02
                  dc.b $10
                  dc.b $02
                  dc.b $16
                  dc.b $08
                  dc.b $10
                  dc.b $01
                  dc.b $60
                  dc.b $02
                  dc.b $30
                  dc.b $02
                  dc.b $36
                  dc.b $0a
                  dc.b $30
                  dc.b $02
                  dc.b $60
                  dc.b $02
                  dc.b $10
                  dc.b $03
                  dc.b $16
                  dc.b $04
                  dc.b $10
                  dc.b $03
                  dc.b $60
                  dc.b $05
                  dc.b $30
                  dc.b $02
                  dc.b $36
                  dc.b $07
                  dc.b $66
                  dc.b $16
                  dc.b $36
                  dc.b $02
                  dc.b $66
                  dc.b $33
                  dc.b $55
                  dc.b $01
                  dc.b $36
                  dc.b $05
                  dc.b $55
                  dc.b $01
                  dc.b $36
                  dc.b $04
                  dc.b $55
                  dc.b $01
                  dc.b $36
                  dc.b $03
                  dc.b $55
                  dc.b $01
                  dc.b $36
                  dc.b $03
                  dc.b $55
                  dc.b $01
                  dc.b $66
                  dc.b $a9
                  dc.b $62
                  dc.b $0c
                  dc.b $66
                  dc.b $07
                  dc.b $60
                  dc.b $0f
                  dc.b $55
                  dc.b $01
                  dc.b $66
                  dc.b $18
                  dc.b $16
                  dc.b $2a
                  dc.b $55
                  dc.b $01
                  dc.b $16
                  dc.b $03
                  dc.b $66
                  dc.b $01
                  dc.b $60
                  dc.b $07
                  dc.b $66
                  dc.b $03
                  dc.b $36
                  dc.b $03
                  dc.b $30
                  dc.b $1b
                  dc.b $36
                  dc.b $08
                  dc.b $44
                  dc.b $01
                  dc.b $66
                  dc.b $18
                  dc.b $36
                  dc.b $0f
                  dc.b $66
                  dc.b $08
                  dc.b $44
                  dc.b $01
                  dc.b $66
                  dc.b $38
                  dc.b $30
                  dc.b $0e
                  dc.b $66
                  dc.b $11
                  dc.b $60
                  dc.b $04
                  dc.b $66
                  dc.b $49
                  dc.b $37

                  dc.b $03
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $30
                  dc.b $03
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $33
                  dc.b $07
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $30
                  dc.b $03
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $37
                  dc.b $03
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $30
                  dc.b $03
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $33
                  dc.b $07
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $30
                  dc.b $03
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $37
                  dc.b $03
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $30
                  dc.b $03
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $33
                  dc.b $07
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $30
                  dc.b $03
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $37
                  dc.b $03
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $30
                  dc.b $03
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $09
                  dc.b $00
                  dc.b $33
                  dc.b $07
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $30
                  dc.b $03
                  dc.b $00
                  dc.b $30
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $03
                  dc.b $00
                  dc.b $30
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $d1
                  dc.b $d5
                  dc.b $a0
                  dc.b $a4
                  dc.b $b1
                  dc.b $c3
                  dc.b $b3
                  dc.b $b5
                  dc.b $8d
                  dc.b $f9
                  dc.b $f4
                  dc.b $e1
                  dc.b $e2
                  dc.b $ec
                  dc.b $e5
                  dc.b $a0
                  dc.b $c5
                  dc.b $d1
                  dc.b $d5
                  dc.b $a0
                  dc.b $a4
                  dc.b $b1
                  dc.b $c3
                  dc.b $b5
                  dc.b $b1
                  dc.b $8d
                  dc.b $e2
                  dc.b $f9
                  dc.b $f4
                  dc.b $e1
                  dc.b $e2
                  dc.b $ec
                  dc.b $e5
                  dc.b $a0
                  dc.b $c5
                  dc.b $d1
                  dc.b $d5
                  dc.b $a0
                  dc.b $a4
                  dc.b $b1
                  dc.b $c3
                  dc.b $b6
                  dc.b $b2
                  dc.b $8d
                  dc.b $e2
                  dc.b $e9
                  dc.b $f4
                  dc.b $e1
                  dc.b $e2
                  dc.b $ec
                  dc.b $e5
                  dc.b $a0
                  dc.b $c5
                  dc.b $d1
                  dc.b $d5
                  dc.b $a0
                  dc.b $a4
                  dc.b $b1
                  dc.b $c3
                  dc.b $b7
                  dc.b $c5
                  dc.b $8d
                  dc.b $f8
                  dc.b $e2
                  dc.b $f9
                  dc.b $f4
                  dc.b $e1
                  dc.b $e2
                  dc.b $ec
                  dc.b $e5
                  dc.b $a0
                  dc.b $c5
                  dc.b $d1
                  dc.b $d5
                  dc.b $a0
                  dc.b $a4
                  dc.b $b1
                  dc.b $c3
                  dc.b $b9
                  dc.b $c1
                  dc.b $8d
                  dc.b $f8
                  dc.b $e2
                  dc.b $e9
                  dc.b $f4
                  dc.b $e1
                  dc.b $e2
                  dc.b $ec
                  dc.b $e5
                  dc.b $a0
                  dc.b $c5
                  dc.b $d1
                  dc.b $d5
                  dc.b $a0
                  dc.b $a4
                  dc.b $b1
                  dc.b $c4
                  dc.b $b2
                  dc.b $b6
                  dc.b $8d
                  dc.b $e2
                  dc.b $ef
                  dc.b $ef
                  dc.b $f4
                  dc.b $a0
                  dc.b $c5
                  dc.b $d1
                  dc.b $d5
                  dc.b $a0
                  dc.b $a4
                  dc.b $b1
                  dc.b $c4
                  dc.b $c2
                  dc.b $b2
                  dc.b $8d
                  dc.b $f3
                  dc.b $e3
                  dc.b $ef
                  dc.b $f2
                  dc.b $e5
                  dc.b $e2
                  dc.b $f5
                  dc.b $e6
                  dc.b $a0
                  dc.b $c5
                  dc.b $d1
                  dc.b $d5
                  dc.b $a0
                  dc.b $a4
                  dc.b $b1
                  dc.b $c6
                  dc.b $b0
                  dc.b $b0
                  dc.b $8d
                  dc.b $e3
                  dc.b $e8
                  dc.b $e1
                  dc.b $f2
                  dc.b $e4
                  dc.b $e1
                  dc.b $f4
                  dc.b $e1
                  dc.b $a0
                  dc.b $c5
                  dc.b $d1
                  dc.b $d5
                  dc.b $a0
                  dc.b $a4
                  dc.b $c1
                  dc.b $c4
                  dc.b $b0
                  dc.b $b0
                  dc.b $8d
                  dc.b $8d
                  dc.b $f2
                  dc.b $f7
                  dc.b $f4
                  dc.b $f3
                  dc.b $f0
                  dc.b $e1
                  dc.b $f2
                  dc.b $ed
                  dc.b $a0
                  dc.b $c5
                  dc.b $d1
                  dc.b $d5
                  dc.b $a0
                  dc.b $a4
                  dc.b $c2
                  dc.b $b7
                  dc.b $c5
                  dc.b $b8
                  dc.b $8d
                  dc.b $f2
                  dc.b $f7
                  dc.b $f4
                  dc.b $f3
                  dc.b $f6
                  dc.b $ef
                  dc.b $ec
                  dc.b $ed
                  dc.b $a0
                  dc.b $c5
                  dc.b $d1
                  dc.b $d5
                  dc.b $a0
                  dc.b $a4
                  dc.b $c2
                  dc.b $b7
                  dc.b $c5
                  dc.b $c2
                  dc.b $8d
                  dc.b $f2
                  dc.b $f7
                  dc.b $f4
                  dc.b $f3
                  dc.b $f4
                  dc.b $f2
                  dc.b $e3
                  dc.b $eb
                  dc.b $a0
                  dc.b $c5
                  dc.b $d1
                  dc.b $d5
                  dc.b $a0
                  dc.b $a4
                  dc.b $c2
                  dc.b $b7
                  dc.b $c5
                  dc.b $c3
                  dc.b $8d
                  dc.b $f2
                  dc.b $f7
                  dc.b $f4
                  dc.b $f3
                  dc.b $f3
                  dc.b $e5
                  dc.b $e3
                  dc.b $f4
                  dc.b $a0
                  dc.b $c5
                  dc.b $d1
                  dc.b $d5
                  dc.b $a0
                  dc.b $a4
                  dc.b $c2
                  dc.b $b7
                  dc.b $c5
                  dc.b $c4
                  dc.b $8d
                  dc.b $f2
                  dc.b $f7
                  dc.b $f4
                  dc.b $f3
                  dc.b $e2
                  dc.b $f5
                  dc.b $e6
                  dc.b $e6
                  dc.b $a0
                  dc.b $c5
                  dc.b $d1
                  dc.b $d5
                  dc.b $a0
                  dc.b $a4
                  dc.b $c2
                  dc.b $b7
                  dc.b $c6
                  dc.b $b0
                  dc.b $8d
                  dc.b $f2
                  dc.b $f7
                  dc.b $f4
                  dc.b $f3
                  dc.b $e3
                  dc.b $ed
                  dc.b $ee
; ------------------------------------------------------------------------------------------------------------- ;
TabDemoLvlData    equ *
TabDemoLvl01      dc.b $09                       ; data demo level 01
                  dc.b $81
                  dc.b $88
                  dc.b $18
                  dc.b $00
                  dc.b $00
                  dc.b $07
                  dc.b $00
                  dc.b $70
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $11
                  dc.b $41
                  dc.b $44
                  dc.b $14
                  dc.b $13
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $61
                  dc.b $11
                  dc.b $11
                  dc.b $01
                  dc.b $00
                  dc.b $00
                  dc.b $01
                  dc.b $00
                  dc.b $10
                  dc.b $13
                  dc.b $00
                  dc.b $00
                  dc.b $04
                  dc.b $00
                  dc.b $60
                  dc.b $00
                  dc.b $04
                  dc.b $40
                  dc.b $00
                  dc.b $00
                  dc.b $07
                  dc.b $00
                  dc.b $10
                  dc.b $13
                  dc.b $13
                  dc.b $11
                  dc.b $16
                  dc.b $11
                  dc.b $71
                  dc.b $11
                  dc.b $10
                  dc.b $01
                  dc.b $11
                  dc.b $11
                  dc.b $01
                  dc.b $00
                  dc.b $10
                  dc.b $13
                  dc.b $13
                  dc.b $17
                  dc.b $16
                  dc.b $11
                  dc.b $11
                  dc.b $17
                  dc.b $01
                  dc.b $11
                  dc.b $10
                  dc.b $33
                  dc.b $00
                  dc.b $00
                  dc.b $10
                  dc.b $13
                  dc.b $13
                  dc.b $10
                  dc.b $06
                  dc.b $00
                  dc.b $10
                  dc.b $71
                  dc.b $11
                  dc.b $10
                  dc.b $01
                  dc.b $33
                  dc.b $00
                  dc.b $00
                  dc.b $30
                  dc.b $13
                  dc.b $13
                  dc.b $11
                  dc.b $06
                  dc.b $00
                  dc.b $00
                  dc.b $11
                  dc.b $17
                  dc.b $01
                  dc.b $11
                  dc.b $33
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $13
                  dc.b $00
                  dc.b $06
                  dc.b $00
                  dc.b $00
                  dc.b $10
                  dc.b $71
                  dc.b $11
                  dc.b $10
                  dc.b $11
                  dc.b $01
                  dc.b $00
                  dc.b $10
                  dc.b $11
                  dc.b $13
                  dc.b $00
                  dc.b $06
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $11
                  dc.b $17
                  dc.b $01
                  dc.b $22
                  dc.b $22
                  dc.b $22
                  dc.b $22
                  dc.b $22
                  dc.b $11
                  dc.b $16
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $03
                  dc.b $10
                  dc.b $71
                  dc.b $11
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $16
                  dc.b $37
                  dc.b $01
                  dc.b $00
                  dc.b $03
                  dc.b $00
                  dc.b $11
                  dc.b $10
                  dc.b $07
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $31
                  dc.b $16
                  dc.b $00
                  dc.b $01
                  dc.b $00
                  dc.b $03
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $31
                  dc.b $11
                  dc.b $11
                  dc.b $22
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $13
                  dc.b $31
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $30
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $01
                  dc.b $00
                  dc.b $10
                  dc.b $30
                  dc.b $07
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $30
                  dc.b $00
                  dc.b $00
                  dc.b $53
                  dc.b $03
                  dc.b $70
                  dc.b $11
                  dc.b $11
                  dc.b $71
                  dc.b $30
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $51
                  dc.b $13
                  dc.b $00
                  dc.b $00
                  dc.b $c4 ; D
                  dc.b $c9 ; I
                  dc.b $c4 ; D
                  dc.b $a0 ; <blank>
                  dc.b $d9 ; Y
                  dc.b $cf ; O
                  dc.b $d5 ; U
                  dc.b $a0 ; <blank>
                  dc.b $c7 ; G
                  dc.b $c5 ; E
                  dc.b $d4 ; T
                  dc.b $a0 ; <blank>
                  dc.b $d4 ; T
                  dc.b $c8 ; H
                  dc.b $c1 ; A
                  dc.b $d4 ; T
                  dc.b $00 ; 
                  dc.b $00 ; 
                  dc.b $cc ; L
                  dc.b $cf ; O
                  dc.b $c4 ; D
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $d2 ; T
                  dc.b $d5 ; U
                  dc.b $ce ; N
                  dc.b $ce ; N
                  dc.b $c5 ; E
                  dc.b $52 ; r
                  dc.b $00 ; 
; ------------------------------------------------------------------------------------------------------------- ;
TabDemoLvl02      dc.b $09
                  dc.b $81
                  dc.b $88
                  dc.b $18
                  dc.b $00
                  dc.b $00
                  dc.b $07
                  dc.b $00
                  dc.b $70
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $11
                  dc.b $41
                  dc.b $44
                  dc.b $14
                  dc.b $13
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $61
                  dc.b $11
                  dc.b $11
                  dc.b $01
                  dc.b $00
                  dc.b $00
                  dc.b $01
                  dc.b $00
                  dc.b $10
                  dc.b $13
                  dc.b $00
                  dc.b $00
                  dc.b $04
                  dc.b $00
                  dc.b $60
                  dc.b $00
                  dc.b $04
                  dc.b $40
                  dc.b $00
                  dc.b $00
                  dc.b $07
                  dc.b $00
                  dc.b $10
                  dc.b $13
                  dc.b $13
                  dc.b $11
                  dc.b $16
                  dc.b $11
                  dc.b $71
                  dc.b $11
                  dc.b $10
                  dc.b $01
                  dc.b $11
                  dc.b $11
                  dc.b $01
                  dc.b $00
                  dc.b $10
                  dc.b $13
                  dc.b $13
                  dc.b $17
                  dc.b $16
                  dc.b $11
                  dc.b $11
                  dc.b $17
                  dc.b $01
                  dc.b $11
                  dc.b $10
                  dc.b $33
                  dc.b $00
                  dc.b $00
                  dc.b $10
                  dc.b $13
                  dc.b $13
                  dc.b $10
                  dc.b $06
                  dc.b $00
                  dc.b $10
                  dc.b $71
                  dc.b $11
                  dc.b $10
                  dc.b $01
                  dc.b $33
                  dc.b $00
                  dc.b $00
                  dc.b $30
                  dc.b $13
                  dc.b $13
                  dc.b $11
                  dc.b $06
                  dc.b $00
                  dc.b $00
                  dc.b $11
                  dc.b $17
                  dc.b $01
                  dc.b $11
                  dc.b $33
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $13
                  dc.b $00
                  dc.b $06
                  dc.b $00
                  dc.b $00
                  dc.b $10
                  dc.b $71
                  dc.b $11
                  dc.b $10
                  dc.b $11
                  dc.b $01
                  dc.b $00
                  dc.b $10
                  dc.b $11
                  dc.b $13
                  dc.b $00
                  dc.b $06
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $11
                  dc.b $17
                  dc.b $01
                  dc.b $22
                  dc.b $22
                  dc.b $22
                  dc.b $22
                  dc.b $22
                  dc.b $11
                  dc.b $16
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $03
                  dc.b $10
                  dc.b $71
                  dc.b $11
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $16
                  dc.b $37
                  dc.b $01
                  dc.b $00
                  dc.b $03
                  dc.b $00
                  dc.b $11
                  dc.b $10
                  dc.b $07
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $31
                  dc.b $16
                  dc.b $00
                  dc.b $01
                  dc.b $00
                  dc.b $03
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $31
                  dc.b $11
                  dc.b $11
                  dc.b $22
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $13
                  dc.b $31
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $30
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $01
                  dc.b $00
                  dc.b $10
                  dc.b $30
                  dc.b $07
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $30
                  dc.b $00
                  dc.b $00
                  dc.b $53
                  dc.b $03
                  dc.b $70
                  dc.b $11
                  dc.b $11
                  dc.b $71
                  dc.b $30
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $11
                  dc.b $51
                  dc.b $13
                  dc.b $00
                  dc.b $00
                  dc.b $c4 ; D
                  dc.b $c9 ; I
                  dc.b $c4 ; D
                  dc.b $a0 ; <blank>
                  dc.b $d9 ; Y
                  dc.b $cf ; O
                  dc.b $d5 ; U
                  dc.b $a0 ; <blank>
                  dc.b $c7 ; G
                  dc.b $c5 ; E
                  dc.b $d4 ; T
                  dc.b $a0 ; <blank>
                  dc.b $d4 ; T
                  dc.b $c8 ; H
                  dc.b $c1 ; A
                  dc.b $d4 ; T
                  dc.b $00 ; 
                  dc.b $00 ; 
                  dc.b $cc ; L
                  dc.b $cf ; O
                  dc.b $c4 ; D
                  dc.b $c5 ; E
                  dc.b $a0 ; <blank>
                  dc.b $d2 ; T
                  dc.b $d5 ; U
                  dc.b $ce ; N
                  dc.b $ce ; N
                  dc.b $c5 ; E
                  dc.b $52 ; r
                  dc.b $00 ; 
; ------------------------------------------------------------------------------------------------------------- ;
MelodyMaxNo       dc.b $09
MelodyMinHight    dc.b $02
MelodyMaxHight    dc.b $0c
TabMelodyPtr      dc.w TabMelody00
                  dc.w TabMelody01
                  dc.w TabMelody02
                  dc.w TabMelody03
                  dc.w TabMelody04
                  dc.w TabMelody05
                  dc.w TabMelody06
                  dc.w TabMelody07
                  dc.w TabMelody08
                  dc.w TabMelody09
                  dc.w TabMelody0a               ; $00 - not used
                  dc.w TabMelody0a
                  dc.w TabMelody0a
                  dc.w TabMelody0a
                  dc.w TabMelody0a
; ------------------------------------------------------------------------------------------------------------- ;
TabVocsFreqDatLo  dc.b $00
                  dc.b $e1
                  dc.b $68
                  dc.b $f7
                  dc.b $8f
                  dc.b $30
                  dc.b $da
                  dc.b $8f
                  dc.b $4e
                  dc.b $18
                  dc.b $ef
                  dc.b $d2
                  dc.b $c3
                  dc.b $c3
                  dc.b $d1
                  dc.b $ef
                  dc.b $1f
                  dc.b $60
                  dc.b $b5
                  dc.b $1e
                  dc.b $9c
                  dc.b $31
                  dc.b $df
                  dc.b $a5
                  dc.b $87
                  dc.b $86
                  dc.b $a2
                  dc.b $df
                  dc.b $3e
                  dc.b $c1
                  dc.b $6b
                  dc.b $3c
                  dc.b $39
                  dc.b $63
                  dc.b $be
                  dc.b $4b
                  dc.b $0f
                  
TabVocsFreqDatHi  dc.b $00
                  dc.b $08
                  dc.b $09
                  dc.b $09
                  dc.b $0a
                  dc.b $0b
                  dc.b $0b
                  dc.b $0c
                  dc.b $0d
                  dc.b $0e
                  dc.b $0e
                  dc.b $0f
                  dc.b $10
                  dc.b $11
                  dc.b $12
                  dc.b $13
                  dc.b $15
                  dc.b $16
                  dc.b $17
                  dc.b $19
                  dc.b $1a
                  dc.b $1c
                  dc.b $1d
                  dc.b $1f
                  dc.b $21
                  dc.b $23
                  dc.b $25
                  dc.b $27
                  dc.b $2a
                  dc.b $2c
                  dc.b $2f
                  dc.b $32
                  dc.b $35
                  dc.b $38
                  dc.b $3b
                  dc.b $3f
                  dc.b $43

TabMelody09       dc.b $04
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $08
                  dc.b $07
                  dc.b $ff
                  dc.b $a0
                  dc.b $08
                  dc.b $0c
                  dc.b $ff
                  dc.b $a0
                  dc.b $08
                  dc.b $10
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $13
                  dc.b $ff
                  dc.b $d0
                  dc.b $0c
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $08
                  dc.b $10
                  dc.b $ff
                  dc.b $a0
                  dc.b $06
                  dc.b $13
                  dc.b $ff
                  dc.b $d0
                  dc.b $06
                  dc.b $13
                  dc.b $ff
                  dc.b $a0
                  dc.b $06
                  dc.b $13
                  dc.b $ff
                  dc.b $70
                  dc.b $10
                  dc.b $13
                  dc.b $ff
                  dc.b $40
                  dc.b $10
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00

TabMelody05       dc.b $04
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $04
                  dc.b $13
                  dc.b $ff
                  dc.b $c0
                  dc.b $04
                  dc.b $12
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $11
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $10
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $0f
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $14
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $13
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $12
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $13
                  dc.b $ff
                  dc.b $d0
                  dc.b $04
                  dc.b $12
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $11
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $10
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $0f
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $10
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $11
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $12
                  dc.b $ff
                  dc.b $a0
                  dc.b $03
                  dc.b $13
                  dc.b $ff
                  dc.b $d0
                  dc.b $03
                  dc.b $13
                  dc.b $ff
                  dc.b $a0
                  dc.b $03
                  dc.b $13
                  dc.b $ff
                  dc.b $70
                  dc.b $04
                  dc.b $13
                  dc.b $ff
                  dc.b $40
                  dc.b $10
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  
TabMelody02       dc.b $04
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $05
                  dc.b $02
                  dc.b $1c
                  dc.b $a0
                  dc.b $05
                  dc.b $04
                  dc.b $17
                  dc.b $a0
                  dc.b $05
                  dc.b $05
                  dc.b $15
                  dc.b $a0
                  dc.b $05
                  dc.b $07
                  dc.b $13
                  dc.b $a0
                  dc.b $05
                  dc.b $09
                  dc.b $11
                  dc.b $a0
                  dc.b $05
                  dc.b $0b
                  dc.b $10
                  dc.b $a0
                  dc.b $05
                  dc.b $0c
                  dc.b $0c
                  dc.b $a0
                  dc.b $05
                  dc.b $10
                  dc.b $0b
                  dc.b $a0
                  dc.b $05
                  dc.b $11
                  dc.b $09
                  dc.b $a0
                  dc.b $05
                  dc.b $13
                  dc.b $07
                  dc.b $a0
                  dc.b $05
                  dc.b $15
                  dc.b $05
                  dc.b $a0
                  dc.b $05
                  dc.b $17
                  dc.b $04
                  dc.b $a0
                  dc.b $05
                  dc.b $1c
                  dc.b $02
                  dc.b $a0
                  dc.b $10
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  
TabMelody06       dc.b $04
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $04
                  dc.b $0c
                  dc.b $ff
                  dc.b $c0
                  dc.b $08
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $04
                  dc.b $07
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $06
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $07
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $08
                  dc.b $ff
                  dc.b $a0
                  dc.b $08
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $04
                  dc.b $07
                  dc.b $ff
                  dc.b $a0
                  dc.b $08
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $0c
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $04
                  dc.b $17
                  dc.b $11
                  dc.b $a0
                  dc.b $08
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $04
                  dc.b $18
                  dc.b $10
                  dc.b $a0
                  dc.b $10
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  
TabMelody08       dc.b $04
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $03
                  dc.b $07
                  dc.b $ff
                  dc.b $a0
                  dc.b $01
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $03
                  dc.b $07
                  dc.b $ff
                  dc.b $a0
                  dc.b $01
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $03
                  dc.b $07
                  dc.b $ff
                  dc.b $a0
                  dc.b $05
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $03
                  dc.b $07
                  dc.b $ff
                  dc.b $a0
                  dc.b $01
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $03
                  dc.b $07
                  dc.b $ff
                  dc.b $a0
                  dc.b $01
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $03
                  dc.b $07
                  dc.b $ff
                  dc.b $a0
                  dc.b $05
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $03
                  dc.b $07
                  dc.b $ff
                  dc.b $a0
                  dc.b $01
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $03
                  dc.b $07
                  dc.b $ff
                  dc.b $a0
                  dc.b $01
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $03
                  dc.b $0c
                  dc.b $ff
                  dc.b $b0
                  dc.b $05
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $03
                  dc.b $0e
                  dc.b $ff
                  dc.b $b0
                  dc.b $05
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $03
                  dc.b $10
                  dc.b $ff
                  dc.b $b0
                  dc.b $05
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $03
                  dc.b $07
                  dc.b $ff
                  dc.b $a0
                  dc.b $01
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $03
                  dc.b $07
                  dc.b $ff
                  dc.b $a0
                  dc.b $01
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $03
                  dc.b $07
                  dc.b $ff
                  dc.b $a0
                  dc.b $05
                  dc.b $00
                  dc.b $00
                  dc.b $a0
                  dc.b $03
                  dc.b $07
                  dc.b $ff
                  dc.b $a0
                  dc.b $01
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $03
                  dc.b $07
                  dc.b $ff
                  dc.b $a0
                  dc.b $01
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $03
                  dc.b $07
                  dc.b $ff
                  dc.b $a0
                  dc.b $05
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $03
                  dc.b $0c
                  dc.b $ff
                  dc.b $a0
                  dc.b $01
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $03
                  dc.b $10
                  dc.b $ff
                  dc.b $a0
                  dc.b $01
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $03
                  dc.b $0e
                  dc.b $ff
                  dc.b $b0
                  dc.b $05
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $03
                  dc.b $0b
                  dc.b $ff
                  dc.b $b0
                  dc.b $05
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $03
                  dc.b $07
                  dc.b $ff
                  dc.b $b0
                  dc.b $10
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  
TabMelody03       dc.b $04
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $04
                  dc.b $07
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $0c
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $10
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $13
                  dc.b $ff
                  dc.b $d0
                  dc.b $08
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $02
                  dc.b $13
                  dc.b $ff
                  dc.b $a0
                  dc.b $02
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $04
                  dc.b $13
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $04
                  dc.b $10
                  dc.b $ff
                  dc.b $d0
                  dc.b $08
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $02
                  dc.b $10
                  dc.b $ff
                  dc.b $a0
                  dc.b $02
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $04
                  dc.b $10
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $04
                  dc.b $0c
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $04
                  dc.b $10
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $04
                  dc.b $0c
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $06
                  dc.b $07
                  dc.b $ff
                  dc.b $d0
                  dc.b $06
                  dc.b $07
                  dc.b $ff
                  dc.b $a0
                  dc.b $06
                  dc.b $07
                  dc.b $ff
                  dc.b $70
                  dc.b $06
                  dc.b $07
                  dc.b $ff
                  dc.b $50
                  dc.b $10
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  
TabMelody00       dc.b $04
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $02
                  dc.b $13
                  dc.b $10
                  dc.b $d0
                  dc.b $06
                  dc.b $13
                  dc.b $10
                  dc.b $a0
                  dc.b $08
                  dc.b $11
                  dc.b $0e
                  dc.b $a0
                  dc.b $06
                  dc.b $10
                  dc.b $0c
                  dc.b $a0
                  dc.b $02
                  dc.b $10
                  dc.b $0c
                  dc.b $40
                  dc.b $08
                  dc.b $10
                  dc.b $0c
                  dc.b $a0
                  dc.b $08
                  dc.b $11
                  dc.b $0e
                  dc.b $a0
                  dc.b $06
                  dc.b $10
                  dc.b $0c
                  dc.b $a0
                  dc.b $02
                  dc.b $10
                  dc.b $0c
                  dc.b $40
                  dc.b $08
                  dc.b $0e
                  dc.b $07
                  dc.b $a0
                  dc.b $08
                  dc.b $10
                  dc.b $0c
                  dc.b $a0
                  dc.b $06
                  dc.b $0e
                  dc.b $07
                  dc.b $a0
                  dc.b $02
                  dc.b $0e
                  dc.b $07
                  dc.b $40
                  dc.b $04
                  dc.b $0e
                  dc.b $07
                  dc.b $d0
                  dc.b $04
                  dc.b $0e
                  dc.b $07
                  dc.b $b0
                  dc.b $04
                  dc.b $0e
                  dc.b $07
                  dc.b $a0
                  dc.b $04
                  dc.b $0e
                  dc.b $07
                  dc.b $90
                  dc.b $04
                  dc.b $0e
                  dc.b $07
                  dc.b $80
                  dc.b $04
                  dc.b $0e
                  dc.b $07
                  dc.b $70
                  dc.b $08
                  dc.b $0e
                  dc.b $07
                  dc.b $a0
                  dc.b $08
                  dc.b $10
                  dc.b $0c
                  dc.b $a0
                  dc.b $06
                  dc.b $0e
                  dc.b $07
                  dc.b $a0
                  dc.b $02
                  dc.b $0e
                  dc.b $07
                  dc.b $40
                  dc.b $04
                  dc.b $0e
                  dc.b $07
                  dc.b $d0
                  dc.b $04
                  dc.b $0e
                  dc.b $07
                  dc.b $b0
                  dc.b $04
                  dc.b $0e
                  dc.b $07
                  dc.b $a0
                  dc.b $04
                  dc.b $0e
                  dc.b $07
                  dc.b $90
                  dc.b $04
                  dc.b $0e
                  dc.b $07
                  dc.b $80
                  dc.b $04
                  dc.b $0e
                  dc.b $07
                  dc.b $70
                  dc.b $04
                  dc.b $0e
                  dc.b $07
                  dc.b $60
                  dc.b $04
                  dc.b $0e
                  dc.b $07
                  dc.b $50
                  dc.b $04
                  dc.b $0e
                  dc.b $07
                  dc.b $40
                  dc.b $04
                  dc.b $0e
                  dc.b $07
                  dc.b $30
                  dc.b $08
                  dc.b $0e
                  dc.b $07
                  dc.b $20
                  dc.b $10
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  
TabMelody04       dc.b $04
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $04
                  dc.b $10
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $13
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $18
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $15
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $11
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $0e
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $13
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $11
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $0e
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $0c
                  dc.b $ff
                  dc.b $a0
                  dc.b $0c
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $02
                  dc.b $18
                  dc.b $ff
                  dc.b $a0
                  dc.b $02
                  dc.b $13
                  dc.b $ff
                  dc.b $a0
                  dc.b $02
                  dc.b $10
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $0c
                  dc.b $ff
                  dc.b $a0
                  dc.b $10
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  
TabMelody07       dc.b $04
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $04
                  dc.b $18
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $17
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $16
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $15
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $14
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $13
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $12
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $11
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $10
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $0f
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $0e
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $0d
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $0c
                  dc.b $ff
                  dc.b $a0
                  dc.b $0c
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $02
                  dc.b $0c
                  dc.b $ff
                  dc.b $a0
                  dc.b $02
                  dc.b $10
                  dc.b $ff
                  dc.b $a0
                  dc.b $02
                  dc.b $13
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $18
                  dc.b $ff
                  dc.b $a0
                  dc.b $10
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  
TabMelody01       dc.b $04
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $04
                  dc.b $10
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $13
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $18
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $13
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $10
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $13
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $18
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $13
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $15
                  dc.b $ff
                  dc.b $d0
                  dc.b $04
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $02
                  dc.b $11
                  dc.b $ff
                  dc.b $a0
                  dc.b $02
                  dc.b $11
                  dc.b $ff
                  dc.b $80
                  dc.b $04
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $02
                  dc.b $11
                  dc.b $ff
                  dc.b $a0
                  dc.b $02
                  dc.b $11
                  dc.b $ff
                  dc.b $80
                  dc.b $0c
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $04
                  dc.b $12
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $15
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $1f
                  dc.b $0f
                  dc.b $a0
                  dc.b $04
                  dc.b $15
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $12
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $15
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $1f
                  dc.b $0f
                  dc.b $a0
                  dc.b $04
                  dc.b $15
                  dc.b $ff
                  dc.b $a0
                  dc.b $04
                  dc.b $17
                  dc.b $ff
                  dc.b $d0
                  dc.b $04
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $02
                  dc.b $13
                  dc.b $ff
                  dc.b $a0
                  dc.b $02
                  dc.b $13
                  dc.b $ff
                  dc.b $80
                  dc.b $04
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $02
                  dc.b $13
                  dc.b $ff
                  dc.b $a0
                  dc.b $02
                  dc.b $13
                  dc.b $ff
                  dc.b $80
                  dc.b $10
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  dc.b $00
                  
TabMelody0a       dc.b $00
; ------------------------------------------------------------------------------------------------------------- ;
DatImages         equ *                                   ; .hbu008. - start address for number calculations
; ------------------------------------------------------------------------------------------------------------- ;
DatTile0          dc.b %00000000, %00000000, %00000000 ; ........................ free space
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................

DatTile1          dc.b %10101000, %10000000, %00000000 ; #.#.#...#............... MC shootable (weak) wall
                  dc.b %10101000, %10000000, %00000000 ; #.#.#...#...............
                  dc.b %10101000, %10000000, %00000000 ; #.#.#...#...............
                  dc.b %10101000, %10000000, %00000000 ; #.#.#...#...............
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10001010, %10000000, %00000000 ; #...#.#.#...............
                  dc.b %10001010, %10000000, %00000000 ; #...#.#.#...............
                  dc.b %10001010, %10000000, %00000000 ; #...#.#.#...............
                  dc.b %10001010, %10000000, %00000000 ; #...#.#.#...............
                  dc.b %10001010, %10000000, %00000000 ; #...#.#.#...............
                  dc.b %00000000, %00000000, %00000000 ; ........................

DatTile2          dc.b %10101010, %10000000, %00000000 ; #.#.#.#.#............... MC non shootable (solid) wall
                  dc.b %10101010, %10000000, %00000000 ; #.#.#.#.#...............
                  dc.b %10101010, %10000000, %00000000 ; #.#.#.#.#...............
                  dc.b %10101010, %10000000, %00000000 ; #.#.#.#.#...............
                  dc.b %10101010, %10000000, %00000000 ; #.#.#.#.#...............
                  dc.b %10101010, %10000000, %00000000 ; #.#.#.#.#...............
                  dc.b %10101010, %10000000, %00000000 ; #.#.#.#.#...............
                  dc.b %10101010, %10000000, %00000000 ; #.#.#.#.#...............
                  dc.b %10101010, %10000000, %00000000 ; #.#.#.#.#...............
                  dc.b %10101010, %10000000, %00000000 ; #.#.#.#.#...............
                  dc.b %00000000, %00000000, %00000000 ; ........................

DatTile3          dc.b %11000011, %00000000, %00000000 ; ##....##................ MC ladder
                  dc.b %11000011, %00000000, %00000000 ; ##....##................
                  dc.b %11111111, %00000000, %00000000 ; ########................
                  dc.b %11000011, %00000000, %00000000 ; ##....##................
                  dc.b %11000011, %00000000, %00000000 ; ##....##................
                  dc.b %11000011, %00000000, %00000000 ; ##....##................
                  dc.b %11000011, %00000000, %00000000 ; ##....##................
                  dc.b %11111111, %00000000, %00000000 ; ########................
                  dc.b %11000011, %00000000, %00000000 ; ##....##................
                  dc.b %11000011, %00000000, %00000000 ; ##....##................
                  dc.b %11000011, %00000000, %00000000 ; ##....##................

DatTile4          dc.b %00000000, %00000000, %00000000 ; ........................ MC pole
                  dc.b %11111111, %11000000, %00000000 ; ##########..............
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................

DatTile5          dc.b %10101010, %10000000, %00000000 ; #.#.#.#.#............... MC trap wall
                  dc.b %10101010, %10000000, %00000000 ; #.#.#.#.#...............
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00111111, %00000000, %00000000 ; ..######................
                  dc.b %00001100, %00000000, %00000000 ; ....##..................
                  dc.b %00001100, %00000000, %00000000 ; ....##..................
                  dc.b %00001100, %00000000, %00000000 ; ....##..................
                  dc.b %00001100, %00000000, %00000000 ; ....##..................
                  dc.b %10101010, %10000000, %00000000 ; #.#.#.#.#...............
                  dc.b %10101010, %10000000, %00000000 ; #.#.#.#.#...............
                  dc.b %00000000, %00000000, %00000000 ; ........................

DatTile6          dc.b %11000000, %00000000, %00000000 ; ##...................... MC hidden exit ladder
                  dc.b %11000000, %00000000, %00000000 ; ##......................
                  dc.b %11111111, %00000000, %00000000 ; ########................
                  dc.b %11000011, %00000000, %00000000 ; ##....##................
                  dc.b %00000011, %00000000, %00000000 ; ......##................
                  dc.b %00000011, %00000000, %00000000 ; ......##................
                  dc.b %00000011, %00000000, %00000000 ; ......##................
                  dc.b %11000011, %00000000, %00000000 ; ##....##................
                  dc.b %11111111, %00000000, %00000000 ; ########................
                  dc.b %11000000, %00000000, %00000000 ; ##......................
                  dc.b %11000000, %00000000, %00000000 ; ##......................

DatTile7          dc.b %00000000, %00000000, %00000000 ; ........................ MC gold
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %11111111, %00000000, %00000000 ; ########................
                  dc.b %11101011, %00000000, %00000000 ; ###.#.##................
                  dc.b %11101011, %00000000, %00000000 ; ###.#.##................
                  dc.b %11101011, %00000000, %00000000 ; ###.#.##................
                  dc.b %11111111, %00000000, %00000000 ; ########................
                  dc.b %00000000, %00000000, %00000000 ; ........................

DatSprtMC_RuLe00  equ *
DatTile8          dc.b %00000100, %00000000, %00000000 ; .....#.................. MC blue enemy
                  dc.b %00010100, %00000000, %00000000 ; ...#.#..................
                  dc.b %00010100, %00000000, %00000000 ; ...#.#..................
                  dc.b %00000100, %00000000, %00000000 ; .....#..................
                  dc.b %00010101, %00000000, %00000000 ; ...#.#.#................
                  dc.b %01000100, %01000000, %00000000 ; .#...#...#..............
                  dc.b %00000100, %00000000, %00000000 ; .....#..................
                  dc.b %00010101, %00000000, %00000000 ; ...#.#.#................
                  dc.b %00010101, %01000000, %00000000 ; ...#.#.#.#..............
                  dc.b %00010000, %00000000, %00000000 ; ...#....................
                  dc.b %00010000, %00000000, %00000000 ; ...#....................

DatTile9          dc.b %00001100, %00000000, %00000000 ; ....##..................  .hbu008. MC white lode runner 
                  dc.b %00001111, %00000000, %00000000 ; ....####................
                  dc.b %00001111, %00000000, %00000000 ; ....####................
                  dc.b %00001100, %00000000, %00000000 ; ....##..................
                  dc.b %00111111, %00000000, %00000000 ; ..######................
                  dc.b %11001100, %11000000, %00000000 ; ##..##..##..............
                  dc.b %00001100, %00000000, %00000000 ; ....##..................
                  dc.b %00111111, %00000000, %00000000 ; ..######................
                  dc.b %11111111, %00000000, %00000000 ; ########................
                  dc.b %00000011, %00000000, %00000000 ; ......##................
                  dc.b %00000011, %00000000, %00000000 ; ......##................
; ------------------------------------------------------------------------------------------------------------------------------- ;
DatImage0a        equ *
DatCursorBlank    dc.b %11111111, %11000000, %00000000 ; ##########.............. big reverse cursor
                  dc.b %11111111, %11000000, %00000000 ; ##########..............
                  dc.b %11111111, %11000000, %00000000 ; ##########..............
                  dc.b %11111111, %11000000, %00000000 ; ##########..............
                  dc.b %11111111, %11000000, %00000000 ; ##########..............
                  dc.b %11111111, %11000000, %00000000 ; ##########..............
                  dc.b %11111111, %11000000, %00000000 ; ##########..............
                  dc.b %11111111, %11000000, %00000000 ; ##########..............
                  dc.b %11111111, %11000000, %00000000 ; ##########..............
                  dc.b %11111111, %11000000, %00000000 ; ##########..............
                  dc.b %11111111, %11000000, %00000000 ; ##########..............
; ------------------------------------------------------------------------------------------------------------------------------- ;
DatImage0b        equ *
DatSprite_RuLe00  dc.b %00010000, %00000000, %00000000 ; ...#.................... run    left 01
                  dc.b %00111000, %00000000, %00000000 ; ..###................... set to $00 in TabSpriteGame
                  dc.b %00111000, %00000000, %00000000 ; ..###...................
                  dc.b %00011100, %00000000, %00000000 ; ...###..................
                  dc.b %00111011, %00000000, %00000000 ; ..###.##................
                  dc.b %11001101, %10000000, %00000000 ; ##..##.##...............
                  dc.b %00001100, %00000000, %00000000 ; ....##..................
                  dc.b %00011100, %00000000, %00000000 ; ...###..................
                  dc.b %00110111, %10000000, %00000000 ; ..##.####...............
                  dc.b %00110000, %00000000, %00000000 ; ..##....................
                  dc.b %00110000, %00000000, %00000000 ; ..##....................
DatImage0c        equ *
DatSprite_RuLe01  dc.b %00010000, %00000000, %00000000 ; ...#.................... run    left 02
                  dc.b %00111000, %00000000, %00000000 ; ..###................... set to $00 in TabSpriteGame
                  dc.b %00111000, %00000000, %00000000 ; ..###...................
                  dc.b %00011000, %00000000, %00000000 ; ...##...................
                  dc.b %00011100, %00000000, %00000000 ; ...###..................
                  dc.b %00111110, %00000000, %00000000 ; ..#####.................
                  dc.b %11011110, %00000000, %00000000 ; ##.####.................
                  dc.b %00111000, %00000000, %00000000 ; ..###...................
                  dc.b %00111100, %00000000, %00000000 ; ..####..................
                  dc.b %00001110, %00000000, %00000000 ; ....###.................
                  dc.b %00001100, %00000000, %00000000 ; ....##..................
DatImage0d        equ *
DatSprite_RuLe02  dc.b %00010000, %00000000, %00000000 ; ...#.................... run    left 03
                  dc.b %00111000, %00000000, %00000000 ; ..###................... set to $00 in TabSpriteGame
                  dc.b %00111000, %00000000, %00000000 ; ..###...................
                  dc.b %00011000, %00000000, %00000000 ; ...##...................
                  dc.b %01011110, %00000000, %00000000 ; .#.####.................
                  dc.b %01111011, %00000000, %00000000 ; .####.##................
                  dc.b %00011000, %00000000, %00000000 ; ...##...................
                  dc.b %00111100, %00000000, %00000000 ; ..####..................
                  dc.b %01100110, %00000000, %00000000 ; .##..##.................
                  dc.b %01100011, %00000000, %00000000 ; .##...##................
                  dc.b %00000011, %00000000, %00000000 ; ......##................
DatImage0e        equ *
DatSprite_Ladr00  dc.b %00001100, %00000000, %00000000 ; ....##.................. ladder up/down 01
                  dc.b %00001100, %01000000, %00000000 ; ....##...#.............. set to $00 in TabSpriteGame
                  dc.b %00001111, %11000000, %00000000 ; ....######..............
                  dc.b %01001110, %00000000, %00000000 ; .#..###.................
                  dc.b %01111110, %00000000, %00000000 ; .######.................
                  dc.b %00001110, %00000000, %00000000 ; ....###.................
                  dc.b %00001110, %00000000, %00000000 ; ....###.................
                  dc.b %00011011, %00000000, %00000000 ; ...##.##................
                  dc.b %00011011, %10000000, %00000000 ; ...##.###...............
                  dc.b %00011000, %00000000, %00000000 ; ...##...................
                  dc.b %00111000, %00000000, %00000000 ; ..###...................
DatImage0f        equ *
DatSprite_FireLe  dc.b %00000010, %00000000, %00000000 ; ......#................. fire   left
                  dc.b %00000111, %00000000, %00000000 ; .....###................ set to $00 in TabSpriteGame
                  dc.b %00000111, %00000000, %00000000 ; .....###................
                  dc.b %00000011, %00000000, %00000000 ; ......##................
                  dc.b %00001111, %11000000, %00000000 ; ....######..............
                  dc.b %01011011, %01000000, %00000000 ; .#.##.##.#..............
                  dc.b %01000011, %00000000, %00000000 ; .#....##................
                  dc.b %00000111, %00000000, %00000000 ; .....###................
                  dc.b %00001101, %10000000, %00000000 ; ....##.##...............
                  dc.b %00001101, %10000000, %00000000 ; ....##.##...............
                  dc.b %00001101, %10000000, %00000000 ; ....##.##...............
DatImage10        equ *
DatSprite_RuRi00  dc.b %00000010, %00000000, %00000000 ; ......#................. .hbu008. - run    right 01
                  dc.b %00000111, %00000000, %00000000 ; .....###................ set to $00 in TabSpriteGame
                  dc.b %00000111, %00000000, %00000000 ; .....###................
                  dc.b %00001110, %00000000, %00000000 ; ....###.................
                  dc.b %00110111, %00000000, %00000000 ; ..##.###................
                  dc.b %01101100, %11000000, %00000000 ; .##.##..##..............
                  dc.b %00001100, %00000000, %00000000 ; ....##..................
                  dc.b %00001110, %00000000, %00000000 ; ....###.................
                  dc.b %01111011, %00000000, %00000000 ; .####.##................
                  dc.b %00000011, %00000000, %00000000 ; ......##................
                  dc.b %00000011, %00000000, %00000000 ; ......##................
DatImage11        equ *
DatSprite_RuRi01  dc.b %00000010, %00000000, %00000000 ; ......#................. run    right 02
                  dc.b %00000111, %00000000, %00000000 ; .....###................ set to $00 in TabSpriteGame
                  dc.b %00000111, %00000000, %00000000 ; .....###................
                  dc.b %00000110, %00000000, %00000000 ; .....##.................
                  dc.b %00001110, %00000000, %00000000 ; ....###.................
                  dc.b %00011111, %00000000, %00000000 ; ...#####................
                  dc.b %00011110, %11000000, %00000000 ; ...####.##..............
                  dc.b %00000111, %00000000, %00000000 ; .....###................
                  dc.b %00001111, %00000000, %00000000 ; ....####................
                  dc.b %00011100, %00000000, %00000000 ; ...###..................
                  dc.b %00001100, %00000000, %00000000 ; ....##..................
DatImage12        equ *
DatSprite_RuRi02  dc.b %00000010, %00000000, %00000000 ; ......#................. run    right 03
                  dc.b %00000111, %00000000, %00000000 ; .....###................ set to $00 in TabSpriteGame
                  dc.b %00000111, %00000000, %00000000 ; .....###................
                  dc.b %00000110, %00000000, %00000000 ; .....##.................
                  dc.b %00011110, %10000000, %00000000 ; ...####.#...............
                  dc.b %00110111, %10000000, %00000000 ; ..##.####...............
                  dc.b %00000110, %00000000, %00000000 ; .....##.................
                  dc.b %00001111, %00000000, %00000000 ; ....####................
                  dc.b %00011001, %10000000, %00000000 ; ...##..##...............
                  dc.b %00110001, %10000000, %00000000 ; ..##...##...............
                  dc.b %00110000, %00000000, %00000000 ; ..##....................
DatImage13        equ *
DatSprite_Ladr01  dc.b %00001100, %00000000, %00000000 ; ....##.................. ladder up/down 02
                  dc.b %10001100, %00000000, %00000000 ; #...##.................. set to $00 in TabSpriteGame
                  dc.b %11111100, %00000000, %00000000 ; ######..................
                  dc.b %00011100, %10000000, %00000000 ; ...###..#...............
                  dc.b %00011111, %10000000, %00000000 ; ...######...............
                  dc.b %00011100, %00000000, %00000000 ; ...###..................
                  dc.b %00011100, %00000000, %00000000 ; ...###..................
                  dc.b %00110110, %00000000, %00000000 ; ..##.##.................
                  dc.b %01110110, %00000000, %00000000 ; .###.##.................
                  dc.b %00000110, %00000000, %00000000 ; .....##.................
                  dc.b %00000111, %00000000, %00000000 ; .....###................
DatImage14        equ *
DatSprite_FallLe  dc.b %01100100, %11000000, %00000000 ; .##..#..##.............. fall   left
                  dc.b %01101110, %11000000, %00000000 ; .##.###.##.............. set to $00 in TabSpriteGame
                  dc.b %01101110, %11000000, %00000000 ; .##.###.##..............
                  dc.b %00111111, %10000000, %00000000 ; ..#######...............
                  dc.b %00000110, %00000000, %00000000 ; .....##.................
                  dc.b %00000110, %00000000, %00000000 ; .....##.................
                  dc.b %00011110, %00000000, %00000000 ; ...####.................
                  dc.b %00110110, %00000000, %00000000 ; ..##.##.................
                  dc.b %00110110, %00000000, %00000000 ; ..##.##.................
                  dc.b %00110110, %00000000, %00000000 ; ..##.##.................
                  dc.b %00000110, %00000000, %00000000 ; .....##.................
DatImage15        equ *
DatSprite_FallRi  dc.b %11001001, %10000000, %00000000 ; ##..#..##............... fall   right
                  dc.b %11011101, %10000000, %00000000 ; ##.###.##............... set to $00 in TabSpriteGame
                  dc.b %11011101, %10000000, %00000000 ; ##.###.##...............
                  dc.b %01111111, %00000000, %00000000 ; .#######................
                  dc.b %00011000, %00000000, %00000000 ; ...##...................
                  dc.b %00011000, %00000000, %00000000 ; ...##...................
                  dc.b %00011110, %00000000, %00000000 ; ...####.................
                  dc.b %00011011, %00000000, %00000000 ; ...##.##................
                  dc.b %00011011, %00000000, %00000000 ; ...##.##................
                  dc.b %00011011, %00000000, %00000000 ; ...##.##................
                  dc.b %00011000, %00000000, %00000000 ; ...##...................
DatImage16        equ *
DatSprite_PoRi00  dc.b %01100001, %10000000, %00000000 ; .##....##............... pole   right 01
                  dc.b %01100001, %10000000, %00000000 ; .##....##............... set to $00 in TabSpriteGame
                  dc.b %01101101, %10000000, %00000000 ; .##.##.##...............
                  dc.b %01101111, %00000000, %00000000 ; .##.####................
                  dc.b %00111100, %00000000, %00000000 ; ..####..................
                  dc.b %00011000, %00000000, %00000000 ; ...##...................
                  dc.b %00011000, %00000000, %00000000 ; ...##...................
                  dc.b %01111000, %00000000, %00000000 ; .####...................
                  dc.b %11011000, %00000000, %00000000 ; ##.##...................
                  dc.b %11011000, %00000000, %00000000 ; ##.##...................
                  dc.b %10110000, %00000000, %00000000 ; #.##....................
DatImage17        equ *
DatSprite_PoRi01  dc.b %00000110, %00000000, %00000000 ; .....##................. pole   right 02
                  dc.b %00000110, %00000000, %00000000 ; .....##................. set to $00 in TabSpriteGame
                  dc.b %00011110, %00000000, %00000000 ; ...####.................
                  dc.b %00011100, %00000000, %00000000 ; ...###..................
                  dc.b %01111000, %00000000, %00000000 ; .####...................
                  dc.b %11011000, %00000000, %00000000 ; ##.##...................
                  dc.b %00011000, %00000000, %00000000 ; ...##...................
                  dc.b %00111000, %00000000, %00000000 ; ..###...................
                  dc.b %01101100, %00000000, %00000000 ; .##.##..................
                  dc.b %01101100, %00000000, %00000000 ; .##.##..................
                  dc.b %01101100, %00000000, %00000000 ; .##.##..................
DatImage18        equ *
DatSprite_PoRi02  dc.b %00011000, %00000000, %00000000 ; ...##................... pole   right 03
                  dc.b %00011000, %00000000, %00000000 ; ...##................... set to $00 in TabSpriteGame
                  dc.b %00011110, %00000000, %00000000 ; ...####.................
                  dc.b %00001110, %11000000, %00000000 ; ....###.##..............
                  dc.b %00000111, %10000000, %00000000 ; .....####...............
                  dc.b %00000110, %00000000, %00000000 ; .....##.................
                  dc.b %00000110, %00000000, %00000000 ; .....##.................
                  dc.b %00001110, %00000000, %00000000 ; ....###.................
                  dc.b %00011011, %00000000, %00000000 ; ...##.##................
                  dc.b %00011011, %00000000, %00000000 ; ...##.##................
                  dc.b %00011011, %00000000, %00000000 ; ...##.##................
DatImage19        equ *
DatSprite_PoLe00  dc.b %01100001, %10000000, %00000000 ; .##....##............... pole   left 01
                  dc.b %01100001, %10000000, %00000000 ; .##....##............... set to $00 in TabSpriteGame
                  dc.b %01101101, %10000000, %00000000 ; .##.##.##...............
                  dc.b %00111101, %10000000, %00000000 ; ..####.##...............
                  dc.b %00001111, %00000000, %00000000 ; ....####................
                  dc.b %00000110, %00000000, %00000000 ; .....##.................
                  dc.b %00000110, %00000000, %00000000 ; .....##.................
                  dc.b %00000111, %10000000, %00000000 ; .....####...............
                  dc.b %00000110, %11000000, %00000000 ; .....##.##..............
                  dc.b %00000110, %11000000, %00000000 ; .....##.##..............
                  dc.b %00000011, %01000000, %00000000 ; ......##.#..............
DatImage1a        equ *
DatSprite_PoLe01  dc.b %00011000, %00000000, %00000000 ; ...##................... pole   left 02
                  dc.b %00011000, %00000000, %00000000 ; ...##................... set to $00 in TabSpriteGame
                  dc.b %00011110, %00000000, %00000000 ; ...####.................
                  dc.b %00001110, %00000000, %00000000 ; ....###.................
                  dc.b %00000111, %10000000, %00000000 ; .....####...............
                  dc.b %00000110, %11000000, %00000000 ; .....##.##..............
                  dc.b %00000110, %00000000, %00000000 ; .....##.................
                  dc.b %00000111, %00000000, %00000000 ; .....###................
                  dc.b %00001101, %10000000, %00000000 ; ....##.##...............
                  dc.b %00001101, %10000000, %00000000 ; ....##.##...............
                  dc.b %00001101, %10000000, %00000000 ; ....##.##...............
DatImage1b        equ *
DatSprite_PoLe02  dc.b %00000110, %00000000, %00000000 ; .....##................. pole   left 03
                  dc.b %00000110, %00000000, %00000000 ; .....##................. set to $00 in TabSpriteGame
                  dc.b %00011110, %00000000, %00000000 ; ...####.................
                  dc.b %11011100, %00000000, %00000000 ; ##.###..................
                  dc.b %01111000, %00000000, %00000000 ; .####...................
                  dc.b %00011000, %00000000, %00000000 ; ...##...................
                  dc.b %00011000, %00000000, %00000000 ; ...##...................
                  dc.b %00011100, %00000000, %00000000 ; ...###..................
                  dc.b %00110110, %00000000, %00000000 ; ..##.##.................
                  dc.b %00110110, %00000000, %00000000 ; ..##.##.................
                  dc.b %00110110, %00000000, %00000000 ; ..##.##.................
; ------------------------------------------------------------------------------------------------------------------------------- ;
DatImage1c        equ *
DatShootSpark00   dc.b %00000000, %00000000, %00000000 ; ........................ shooting spark 01
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00001000, %00000000, %00000000 ; ....#...................
                  dc.b %00000010, %01000000, %00000000 ; ......#..#..............
                  dc.b %00100000, %01000000, %00000000 ; ..#......#..............
                  dc.b %00001001, %00000000, %00000000 ; ....#..#.................
                  dc.b %00000001, %00000000, %00000000 ; .......#................
DatImage1d        equ *
DatShootSpark01   dc.b %00000000, %00000000, %00000000 ; ........................ shooting spark 02
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00001000, %00000000, %00000000 ; ....#...................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %10000000, %00000000 ; ........#...............
                  dc.b %10000000, %00000000, %00000000 ; #.......................
                  dc.b %00100000, %00000000, %00000000 ; ..#.....................
                  dc.b %00001010, %01000000, %00000000 ; ....#.#..#..............
                  dc.b %00100001, %01000000, %00000000 ; ..#....#.#..............
                  dc.b %00001001, %00000000, %00000000 ; ....#..#................
DatImage1e        equ *
DatShootSpark02   dc.b %00001000, %00000000, %00000000 ; ....#................... shooting spark 03
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10001000, %00000000, %00000000 ; #...#...................
                  dc.b %00000000, %10000000, %00000000 ; ........#...............
                  dc.b %10000000, %00000000, %00000000 ; #.......................
                  dc.b %00100000, %00000000, %00000000 ; ..#.....................
                  dc.b %00000010, %00000000, %00000000 ; ......#.................
DatImage1f        equ *
DatShootSpark03   dc.b %00000000, %00000000, %00000000 ; ........................ shooting spark 04
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00001000, %00000000, %00000000 ; ....#...................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10000000, %00000000, %00000000 ; #.......................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %10000000, %00000000 ; ........#...............
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
; ------------------------------------------------------------------------------------------------------------------------------- ;
DatImage20        equ *
DatShootMeltGr00  dc.b %10100100, %10000000, %00000000 ; #.#..#..#.............. shoot melt ground 01
                  dc.b %10101000, %10000000, %00000000 ; #.#.#...#...............
                  dc.b %10101000, %10000000, %00000000 ; #.#.#...#...............
                  dc.b %10101000, %10000000, %00000000 ; #.#.#...#...............
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10001010, %10000000, %00000000 ; #...#.#.#...............
                  dc.b %10001010, %10000000, %00000000 ; #...#.#.#...............
                  dc.b %10001010, %10000000, %00000000 ; #...#.#.#...............
                  dc.b %10001010, %10000000, %00000000 ; #...#.#.#...............
                  dc.b %10001010, %10000000, %00000000 ; #...#.#.#...............
                  dc.b %00000000, %00000000, %00000000 ; ........................
DatImage21        equ *
DatShootMeltGr01  dc.b %00000100, %00000000, %00000000 ; .....#.................. shoot melt ground 02
                  dc.b %00010100, %00000000, %00000000 ; ...#.#..................
                  dc.b %10000000, %10000000, %00000000 ; #.......#...............
                  dc.b %10101000, %10000000, %00000000 ; #.#.#...#...............
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10001010, %10000000, %00000000 ; #...#.#.#...............
                  dc.b %10001010, %10000000, %00000000 ; #...#.#.#...............
                  dc.b %10001010, %10000000, %00000000 ; #...#.#.#...............
                  dc.b %10001010, %10000000, %00000000 ; #...#.#.#...............
                  dc.b %10001010, %10000000, %00000000 ; #...#.#.#...............
                  dc.b %00000000, %00000000, %00000000 ; ........................
DatImage22        equ *
DatShootMeltGr02  dc.b %00000000, %00000000, %00000000 ; ........................ shoot melt ground 03
                  dc.b %00000100, %00000000, %00000000 ; .....#..................
                  dc.b %00010100, %00000000, %00000000 ; ...#.#..................
                  dc.b %10010100, %10000000, %00000000 ; #..#.#..#...............
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10001010, %10000000, %00000000 ; #...#.#.#...............
                  dc.b %10001010, %10000000, %00000000 ; #...#.#.#...............
                  dc.b %10001010, %10000000, %00000000 ; #...#.#.#...............
                  dc.b %10001010, %10000000, %00000000 ; #...#.#.#...............
                  dc.b %10001010, %10000000, %00000000 ; #...#.#.#...............
                  dc.b %00000000, %00000000, %00000000 ; ........................
DatImage23        equ *
DatShootMeltGr03  dc.b %00000000, %00000000, %00000000 ; ........................ shoot melt ground 04
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000100, %00000000, %00000000 ; .....#..................
                  dc.b %00010100, %00000000, %00000000 ; ...#.#..................
                  dc.b %00010101, %00000000, %00000000 ; ...#.#.#................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10001010, %10000000, %00000000 ; #...#.#.#...............
                  dc.b %10001010, %10000000, %00000000 ; #...#.#.#...............
                  dc.b %10001010, %10000000, %00000000 ; #...#.#.#...............
                  dc.b %00000000, %00000000, %00000000 ; ........................
DatImage24        equ *
DatShootMeltGr04  dc.b %00000000, %00000000, %00000000 ; ........................ shoot melt ground 05
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000100, %00000000, %00000000 ; .....#..................
                  dc.b %00000101, %00000000, %00000000 ; .....#.#................
                  dc.b %10010101, %00000000, %00000000 ; #..#.#.#................
                  dc.b %10000000, %00000000, %00000000 ; #.......................
                  dc.b %10001010, %10000000, %00000000 ; #...#.#.#...............
                  dc.b %00000000, %00000000, %00000000 ; ........................
DatImage25        equ *
DatShootMeltGr05  dc.b %00000000, %00000000, %00000000 ; ........................ shoot melt ground 06
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000100, %00000000, %00000000 ; .....#..................
                  dc.b %00010100, %00000000, %00000000 ; ...#.#..................
                  dc.b %00010101, %00000000, %00000000 ; ...#.#.#................
                  dc.b %00000000, %00000000, %00000000 ; ........................
; ------------------------------------------------------------------------------------------------------------------------------- ;
DatImage26        equ *
DatSprite_FireRi  dc.b %00001000, %00000000, %00000000 ; ....#................... fire   right
                  dc.b %00011100, %00000000, %00000000 ; ...###.................. set to $00 in TabSpriteGame
                  dc.b %00011100, %00000000, %00000000 ; ...###..................
                  dc.b %00011000, %00000000, %00000000 ; ...##...................
                  dc.b %01111110, %00000000, %00000000 ; .######.................
                  dc.b %01011011, %01000000, %00000000 ; .#.##.##.#..............
                  dc.b %00011000, %01000000, %00000000 ; ...##....#..............
                  dc.b %00011100, %00000000, %00000000 ; ...###..................
                  dc.b %00110110, %00000000, %00000000 ; ..##.##.................
                  dc.b %00110110, %00000000, %00000000 ; ..##.##.................
                  dc.b %00110110, %00000000, %00000000 ; ..##.##.................
; ------------------------------------------------------------------------------------------------------------------------------- ;
DatImage27        equ *
DatShootMelt00    dc.b %00000000, %00000000, %00000000 ; ........................ shoot projectile starts melting 01
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00001000, %00000000, %00000000 ; ....#...................
                  dc.b %00100010, %00000000, %00000000 ; ..#...#.................
                  dc.b %01001000, %00000000, %00000000 ; .#..#...................
                  dc.b %01010000, %10000000, %00000000 ; .#.#....#...............
                  dc.b %00010000, %00000000, %00000000 ; ...#....................
DatImage28        equ *
DatShootMelt01    dc.b %00000000, %00000000, %00000000 ; ........................ shoot projectile starts melting 02
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00001000, %00000000, %00000000 ; ....#...................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %10000000, %00000000 ; ........#...............
                  dc.b %10100000, %00000000, %00000000 ; #.#.....................
                  dc.b %01000000, %00000000, %00000000 ; .#......................
                  dc.b %01001010, %00000000, %00000000 ; .#..#.#.................
                  dc.b %00010001, %00000000, %00000000 ; ...#...#................
                  dc.b %00010001, %00000000, %00000000 ; ...#...#................
; ------------------------------------------------------------------------------------------------------------------------------- ;
DatImage29        equ *
DatSprtMC_RuRi00  dc.b %00000010, %00000000, %00000000 ; ......#................. run    right 01
                  dc.b %00000101, %00000000, %00000000 ; .....#.#................ set to it's no in TabSpriteGame - to be replaced
                  dc.b %00000101, %00000000, %00000000 ; .....#.#................
                  dc.b %00000100, %00000000, %00000000 ; .....#..................
                  dc.b %00010101, %00000000, %00000000 ; ...#.#.#................
                  dc.b %01000100, %01000000, %00000000 ; .#...#...#..............
                  dc.b %00001100, %00000000, %00000000 ; ....##..................
                  dc.b %00001110, %00000000, %00000000 ; ....###.................
                  dc.b %01111011, %00000000, %00000000 ; .####.##................
                  dc.b %00000011, %00000000, %00000000 ; ......##................
                  dc.b %00000011, %00000000, %00000000 ; ......##................
DatImage2a        equ *
DatSprtMC_RuRi01  dc.b %00000010, %00000000, %00000000 ; ......#................. run    right 02
                  dc.b %00000101, %00000000, %00000000 ; .....#.#................ set to it's no in TabSpriteGame - to be replaced
                  dc.b %00000101, %00000000, %00000000 ; .....#.#................
                  dc.b %00000100, %00000000, %00000000 ; .....#..................
                  dc.b %00010100, %00000000, %00000000 ; ...#.#..................
                  dc.b %00010101, %00000000, %00000000 ; ...#.#.#................
                  dc.b %00000110, %01000000, %00000000 ; .....##..#..............
                  dc.b %00000111, %00000000, %00000000 ; .....###................
                  dc.b %00001111, %00000000, %00000000 ; ....####................
                  dc.b %00011100, %00000000, %00000000 ; ...###..................
                  dc.b %00001100, %00000000, %00000000 ; ....##..................
DatImage2b        equ *
DatSprtMC_RuRi02  dc.b %00000010, %00000000, %00000000 ; ......#................. run    right 03
                  dc.b %00000101, %00000000, %00000000 ; .....#.#................ set to it's no in TabSpriteGame - to be replaced
                  dc.b %00000101, %00000000, %00000000 ; .....#.#................
                  dc.b %00000100, %00000000, %00000000 ; .....#..................
                  dc.b %00010101, %00000000, %00000000 ; ...#.#.#................
                  dc.b %01000101, %00000000, %00000000 ; .#...#.#................
                  dc.b %00000110, %00000000, %00000000 ; .....##.................
                  dc.b %00001111, %00000000, %00000000 ; ....####................
                  dc.b %00011001, %10000000, %00000000 ; ...##..##...............
                  dc.b %00110001, %10000000, %00000000 ; ..##...##...............
                  dc.b %00110000, %00000000, %00000000 ; ..##....................
DatImage2c        equ *
DatSprtMC_RuLe01  dc.b %00001000, %00000000, %00000000 ; ....#................... run    left 02
                  dc.b %00010100, %00000000, %00000000 ; ...#.#.................. set to it's no in TabSpriteGame - to be replaced
                  dc.b %00010100, %00000000, %00000000 ; ...#.#..................
                  dc.b %00000100, %00000000, %00000000 ; .....#..................
                  dc.b %00000101, %00000000, %00000000 ; .....#.#................
                  dc.b %00010101, %00000000, %00000000 ; ...#.#.#................
                  dc.b %01001100, %00000000, %00000000 ; .#..##..................
                  dc.b %00011100, %00000000, %00000000 ; ...###..................
                  dc.b %00011110, %00000000, %00000000 ; ...####.................
                  dc.b %00000111, %00000000, %00000000 ; .....###................
                  dc.b %00000110, %00000000, %00000000 ; .....##.................
DatImage2d        equ *
DatSprtMC_RuLe02  dc.b %00001000, %00000000, %00000000 ; ....#................... run    left 03
                  dc.b %00010100, %00000000, %00000000 ; ...#.#.................. set to it's no in TabSpriteGame - to be replaced
                  dc.b %00010100, %00000000, %00000000 ; ...#.#..................
                  dc.b %00000100, %00000000, %00000000 ; .....#..................
                  dc.b %00010101, %00000000, %00000000 ; ...#.#.#................
                  dc.b %00010100, %01000000, %00000000 ; ..#.#...#...............
                  dc.b %00001100, %00000000, %00000000 ; ....##..................
                  dc.b %00011110, %00000000, %00000000 ; ...####.................
                  dc.b %00110011, %00000000, %00000000 ; ..##..##................
                  dc.b %00110001, %10000000, %00000000 ; ..##...##...............
                  dc.b %00000001, %10000000, %00000000 ; .......##...............
DatImage2e        equ *
DatSprtMC_PoRi00  dc.b %01000001, %00000000, %00000000 ; .#.....#................ pole   right 01
                  dc.b %01000001, %00000000, %00000000 ; .#.....#................ set to it's no in TabSpriteGame - to be replaced
                  dc.b %01000101, %00000000, %00000000 ; .#...#.#................
                  dc.b %01000101, %00000000, %00000000 ; .#...#.#................
                  dc.b %00010100, %00000000, %00000000 ; ...#.#..................
                  dc.b %00011000, %00000000, %00000000 ; ...##...................
                  dc.b %00010000, %00000000, %00000000 ; ...#....................
                  dc.b %01111000, %00000000, %00000000 ; .####...................
                  dc.b %11011000, %00000000, %00000000 ; ##.##...................
                  dc.b %11011000, %00000000, %00000000 ; ##.##...................
                  dc.b %10110000, %00000000, %00000000 ; #.##....................
DatImage2f        equ *
DatSprtMC_PoRi01  dc.b %00000100, %00000000, %00000000 ; .....#.................. pole   right 02
                  dc.b %00000100, %00000000, %00000000 ; .....#.................. set to it's no in TabSpriteGame - to be replaced
                  dc.b %00010100, %00000000, %00000000 ; ...#.#..................
                  dc.b %00010100, %00000000, %00000000 ; ...#.#..................
                  dc.b %01010000, %00000000, %00000000 ; .#.#....................
                  dc.b %01010000, %00000000, %00000000 ; .#.#....................
                  dc.b %00010000, %00000000, %00000000 ; ...#....................
                  dc.b %00111000, %00000000, %00000000 ; ..###...................
                  dc.b %01101100, %00000000, %00000000 ; .##.##..................
                  dc.b %01101100, %00000000, %00000000 ; .##.##..................
                  dc.b %01101100, %00000000, %00000000 ; .##.##..................
DatImage30        equ *
DatSprtMC_PoRi02  dc.b %00010000, %00000000, %00000000 ; ...#.................... pole   right 03
                  dc.b %00010000, %00000000, %00000000 ; ...#.................... set to it's no in TabSpriteGame - to be replaced
                  dc.b %00010100, %00000000, %00000000 ; ...#.#..................
                  dc.b %00000100, %01000000, %00000000 ; .....#...#..............
                  dc.b %00000101, %00000000, %00000000 ; .....#.#................
                  dc.b %00000100, %00000000, %00000000 ; .....#..................
                  dc.b %00000100, %00000000, %00000000 ; .....#..................
                  dc.b %00001110, %00000000, %00000000 ; ....###.................
                  dc.b %00011011, %00000000, %00000000 ; ...##.##................
                  dc.b %00011011, %00000000, %00000000 ; ...##.##................
                  dc.b %00011011, %00000000, %00000000 ; ...##.##................
DatImage31        equ *
DatSprtMC_PoLe00  dc.b %01000001, %00000000, %00000000 ; .#.....#................ pole   left 01
                  dc.b %01000001, %00000000, %00000000 ; .#.....#................ set to it's no in TabSpriteGame - to be replaced
                  dc.b %01010001, %00000000, %00000000 ; .#.#...#................
                  dc.b %01010001, %00000000, %00000000 ; .#.#...#................
                  dc.b %00010100, %00000000, %00000000 ; ...#.#..................
                  dc.b %00000100, %00000000, %00000000 ; .....#..................
                  dc.b %00000100, %00000000, %00000000 ; .....#..................
                  dc.b %00001111, %00000000, %00000000 ; ....####................
                  dc.b %00001101, %10000000, %00000000 ; ....##.##..............
                  dc.b %00001101, %10000000, %00000000 ; ....##.##..............
                  dc.b %00000110, %10000000, %00000000 ; .....##..#..............
DatImage32        equ *
DatSprtMC_PoLe01  dc.b %00010000, %00000000, %00000000 ; ...#.................... pole   left 02
                  dc.b %00010000, %00000000, %00000000 ; ...#.................... set to it's no in TabSpriteGame - to be replaced
                  dc.b %00010100, %00000000, %00000000 ; ...#.#..................
                  dc.b %00010100, %00000000, %00000000 ; ...#.#..................
                  dc.b %00000101, %00000000, %00000000 ; .....#.#................
                  dc.b %00000101, %00000000, %00000000 ; .....#.#................
                  dc.b %00000100, %00000000, %00000000 ; .....#..................
                  dc.b %00000111, %00000000, %00000000 ; .....###................
                  dc.b %00001101, %10000000, %00000000 ; ....##.##...............
                  dc.b %00001101, %10000000, %00000000 ; ....##.##...............
                  dc.b %00001101, %10000000, %00000000 ; ....##.##...............
DatImage33        equ *
DatSprtMC_PoLe02  dc.b %00000100, %00000000, %00000000 ; .....#.................. pole   left 03
                  dc.b %00000100, %00000000, %00000000 ; .....#.................. set to it's no in TabSpriteGame - to be replaced
                  dc.b %00010100, %00000000, %00000000 ; ...#.#..................
                  dc.b %00010000, %00000000, %00000000 ; ...#....................
                  dc.b %01010000, %00000000, %00000000 ; .#.#....................
                  dc.b %00010000, %00000000, %00000000 ; ...#....................
                  dc.b %00010000, %00000000, %00000000 ; ...#....................
                  dc.b %00011100, %00000000, %00000000 ; ...###..................
                  dc.b %00110110, %00000000, %00000000 ; ..##.##.................
                  dc.b %00110110, %00000000, %00000000 ; ..##.##.................
                  dc.b %00110110, %00000000, %00000000 ; ..##.##.................
DatImage34        equ *
DatSprtMC_Ladr00  dc.b %00000100, %00000000, %00000000 ; .....#.................. ladder up/down 01
                  dc.b %00000100, %01000000, %00000000 ; .....#...#.............. set to it's no in TabSpriteGame - to be replaced
                  dc.b %00000101, %01000000, %00000000 ; .....#.#.#..............
                  dc.b %01000100, %00000000, %00000000 ; .#...#..................
                  dc.b %01010100, %00000000, %00000000 ; .#.#.#..................
                  dc.b %00000100, %00000000, %00000000 ; .....#..................
                  dc.b %00001110, %00000000, %00000000 ; ....###.................
                  dc.b %00011011, %00000000, %00000000 ; ...##.##................
                  dc.b %00011011, %10000000, %00000000 ; ...##.###...............
                  dc.b %00011000, %00000000, %00000000 ; ...##...................
                  dc.b %00111000, %00000000, %00000000 ; ..###...................
DatImage35        equ *
DatSprtMC_Ladr01  dc.b %00000100, %00000000, %00000000 ; .....#.................. ladder up/down 02
                  dc.b %10000100, %00000000, %00000000 ; #....#.................. set to it's no in TabSpriteGame - to be replaced
                  dc.b %11010100, %00000000, %00000000 ; ##.#.#..................
                  dc.b %00010100, %10000000, %00000000 ; ...#.#..#...............
                  dc.b %00010101, %10000000, %00000000 ; ...#.#.##...............
                  dc.b %00010100, %00000000, %00000000 ; ...#.#..................
                  dc.b %00011100, %00000000, %00000000 ; ...###..................
                  dc.b %00110110, %00000000, %00000000 ; ..##.##.................
                  dc.b %01110110, %00000000, %00000000 ; .###.##.................
                  dc.b %00000110, %00000000, %00000000 ; .....##.................
                  dc.b %00000111, %00000000, %00000000 ; .....###................
DatImage36        equ *
DatSprtMC_FallRi  dc.b %01000100, %01000000, %00000000 ; .#...#...#.............. fall   right
                  dc.b %01000100, %01000000, %00000000 ; .#...#...#.............. set to it's no in TabSpriteGame - to be replaced
                  dc.b %01000100, %01000000, %00000000 ; .#...#...#..............
                  dc.b %00010101, %00000000, %00000000 ; ...#.#.#...............
                  dc.b %00000100, %00000000, %00000000 ; .....#..................
                  dc.b %00000100, %00000000, %00000000 ; .....#..................
                  dc.b %00001111, %00000000, %00000000 ; ...####.................
                  dc.b %00001101, %10000000, %00000000 ; ...##.##................
                  dc.b %00001101, %10000000, %00000000 ; ...##.##................
                  dc.b %00001101, %10000000, %00000000 ; ...##.##................
                  dc.b %00001100, %00000000, %00000000 ; ...##...................
DatImage37        equ *
DatSprtMC_FallLe  dc.b %01000100, %10000000, %00000000 ; .#...#...#.............. fall   left
                  dc.b %01000100, %10000000, %00000000 ; .#...#...#.............. set to it's no in TabSpriteGame - to be replaced
                  dc.b %01000100, %10000000, %00000000 ; .#...#...#..............
                  dc.b %00010101, %00000000, %00000000 ; ...#.#.#................
                  dc.b %00000100, %00000000, %00000000 ; .....#..................
                  dc.b %00000100, %00000000, %00000000 ; .....#..................
                  dc.b %00011110, %00000000, %00000000 ; ...####.................
                  dc.b %00110110, %00000000, %00000000 ; ..##.##.................
                  dc.b %00110110, %00000000, %00000000 ; ..##.##.................
                  dc.b %00110110, %00000000, %00000000 ; ..##.##.................
                  dc.b %00000110, %00000000, %00000000 ; .....##.................
; ------------------------------------------------------------------------------------------------------------------------------- ;
; Separation number used in TabSpriteGame of SetSpritePos
; ------------------------------------------------------------------------------------------------------------------------------- ;
DatSpritesX       equ *
; ------------------------------------------------------------------------------------------------------------------------------- ;
DatImage38        equ *
DatCloseHole00    dc.b %00000000, %00000000, %00000000 ; ........................ MC close holes 1st step
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10000000, %10000000, %00000000 ; #.......#...............
                  dc.b %10000000, %10000000, %00000000 ; #.......#...............
                  dc.b %00000000, %00000000, %00000000 ; ........................
DatImage39        equ *
DatCloseHole01    dc.b %00000000, %00000000, %00000000 ; ........................ MC close holes 2nd step
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10000000, %10000000, %00000000 ; #.......#...............
                  dc.b %10000000, %10000000, %00000000 ; #.......#...............
                  dc.b %10000000, %10000000, %00000000 ; #.......#...............
                  dc.b %10000000, %10000000, %00000000 ; #.......#...............
                  dc.b %00000000, %00000000, %00000000 ; ........................
; ------------------------------------------------------------------------------------------------------------------------------- ;
DatImage3a        equ *
DatReviveEnemy00  dc.b %00000000, %00000000, %00000000 ; ........................ MC rebirth 1st step
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00010100, %00000000, %00000000 ; ...#.#..................
                  dc.b %01010101, %00000000, %00000000 ; .#.#.#.#................
                  dc.b %00000000, %00000000, %00000000 ; ........................
DatImage3b        equ *
DatReviveEnemy01  dc.b %00000000, %00000000, %00000000 ; ........................ MC rebirth 2nd step
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00010100, %00000000, %00000000 ; ...#.#..................
                  dc.b %01010101, %00000000, %00000000 ; .#.#.#.#................
                  dc.b %01010101, %00000000, %00000000 ; .#.#.#.#................
                  dc.b %00000000, %00000000, %00000000 ; ........................
; ------------------------------------------------------------------------------------------------------------------------------- ;
DatImage3c        equ *
DatDig0           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %01010101, %00000000, %00000000 ; .#.#.#.#................
                  dc.b %01000001, %00000000, %00000000 ; .#.....#................
                  dc.b %01000001, %00000000, %00000000 ; .#.....#................
                  dc.b %01000001, %00000000, %00000000 ; .#.....#................
                  dc.b %01000101, %00000000, %00000000 ; .#...#.#................
                  dc.b %01000101, %00000000, %00000000 ; .#...#.#................
                  dc.b %01000101, %00000000, %00000000 ; .#...#.#................
                  dc.b %01010101, %00000000, %00000000 ; .#.#.#.#................
DatImage3d        equ *
DatDig1           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00010100, %00000000, %00000000 ; ...#.#..................
                  dc.b %00010100, %00000000, %00000000 ; ...#.#..................
                  dc.b %00000100, %00000000, %00000000 ; .....#..................
                  dc.b %00000100, %00000000, %00000000 ; .....#..................
                  dc.b %00000100, %00000000, %00000000 ; .....#..................
                  dc.b %00000100, %00000000, %00000000 ; .....#..................
                  dc.b %00010101, %00000000, %00000000 ; ...#.#.#................
                  dc.b %00010101, %00000000, %00000000 ; ...#.#.#................
DatImage3e        equ *
DatDig2           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %01010101, %00000000, %00000000 ; .#.#.#.#................
                  dc.b %01000001, %00000000, %00000000 ; .#.....#................
                  dc.b %00000001, %00000000, %00000000 ; .......#................
                  dc.b %01010101, %00000000, %00000000 ; .#.#.#.#................
                  dc.b %01000000, %00000000, %00000000 ; .#......................
                  dc.b %01000000, %00000000, %00000000 ; .#......................
                  dc.b %01000101, %00000000, %00000000 ; .#...#.#................
                  dc.b %01010101, %00000000, %00000000 ; .#.#.#.#................
DatImage3f        equ *
DatDig3           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %01010101, %00000000, %00000000 ; .#.#.#.#................
                  dc.b %01000001, %00000000, %00000000 ; .#.....#................
                  dc.b %00000001, %00000000, %00000000 ; .......#................
                  dc.b %00010101, %00000000, %00000000 ; ...#.#.#................
                  dc.b %00000001, %00000000, %00000000 ; .......#................
                  dc.b %00000001, %00000000, %00000000 ; .......#................
                  dc.b %01000001, %00000000, %00000000 ; .#.....#................
                  dc.b %01010101, %00000000, %00000000 ; .#.#.#.#................
DatImage40        equ *
DatDig4           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %01010001, %00000000, %00000000 ; .#.#...#................
                  dc.b %01010001, %00000000, %00000000 ; .#.#...#................
                  dc.b %01010001, %00000000, %00000000 ; .#.#...#................
                  dc.b %01010101, %00000000, %00000000 ; .#.#.#.#................
                  dc.b %00000001, %00000000, %00000000 ; .......#................
                  dc.b %00000001, %00000000, %00000000 ; .......#................
                  dc.b %00000001, %00000000, %00000000 ; .......#................
                  dc.b %00000001, %00000000, %00000000 ; .......#................
DatImage41        equ *
DatDig5           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %01010101, %00000000, %00000000 ; .#.#.#.#................
                  dc.b %01000000, %00000000, %00000000 ; .#......................
                  dc.b %01000000, %00000000, %00000000 ; .#......................
                  dc.b %01010101, %00000000, %00000000 ; .#.#.#.#................
                  dc.b %00000101, %00000000, %00000000 ; .....#.#................
                  dc.b %00000101, %00000000, %00000000 ; .....#.#................
                  dc.b %00000101, %00000000, %00000000 ; .....#.#................
                  dc.b %01010101, %00000000, %00000000 ; .#.#.#.#................
DatImage42        equ *
DatDig6           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %01010101, %00000000, %00000000 ; .#.#.#.#................
                  dc.b %01000001, %00000000, %00000000 ; .#.....#................
                  dc.b %01000000, %00000000, %00000000 ; .#......................
                  dc.b %01000000, %00000000, %00000000 ; .#......................
                  dc.b %01010101, %00000000, %00000000 ; .#.#.#.#................
                  dc.b %01000101, %00000000, %00000000 ; .#...#.#................
                  dc.b %01000101, %00000000, %00000000 ; .#...#.#................
                  dc.b %01010101, %00000000, %00000000 ; .#.#.#.#................
DatImage43        equ *
DatDig7           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %01010101, %00000000, %00000000 ; .#.#.#.#................
                  dc.b %00000101, %00000000, %00000000 ; .....#.#................
                  dc.b %00000101, %00000000, %00000000 ; .....#.#................
                  dc.b %00000101, %00000000, %00000000 ; .....#.#................
                  dc.b %00010100, %00000000, %00000000 ; ...#.#..................
                  dc.b %00010000, %00000000, %00000000 ; ...#....................
                  dc.b %00010000, %00000000, %00000000 ; ...#....................
                  dc.b %00010000, %00000000, %00000000 ; ...#....................
DatImage44        equ *
DatDig8           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00010101, %00000000, %00000000 ; ...#.#.#................
                  dc.b %00010001, %00000000, %00000000 ; ...#...#................
                  dc.b %00010001, %00000000, %00000000 ; ...#...#................
                  dc.b %01010101, %00000000, %00000000 ; .#.#.#.#................
                  dc.b %01000001, %00000000, %00000000 ; .#.....#................
                  dc.b %01000001, %00000000, %00000000 ; .#.....#................
                  dc.b %01000001, %00000000, %00000000 ; .#.....#................
                  dc.b %01010101, %00000000, %00000000 ; .#.#.#.#................
DatImage45        equ *
DatDig9           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %01010101, %00000000, %00000000 ; .#.#.#.#................
                  dc.b %01000001, %00000000, %00000000 ; .#.....#................
                  dc.b %01000001, %00000000, %00000000 ; .#.....#................
                  dc.b %01010101, %00000000, %00000000 ; .#.#.#.#................
                  dc.b %00000101, %00000000, %00000000 ; .....#.#................
                  dc.b %00000101, %00000000, %00000000 ; .....#.#................
                  dc.b %00000101, %00000000, %00000000 ; .....#.#................
                  dc.b %00000101, %00000000, %00000000 ; .....#.#................
; ------------------------------------------------------------------------------------------------------------------------------- ;
DatImage46        equ *
DatChrA           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00101010, %00000000, %00000000 ; ..#.#.#.................
                  dc.b %00100010, %00000000, %00000000 ; ..#...#.................
                  dc.b %00100010, %00000000, %00000000 ; ..#...#.................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10001010, %00000000, %00000000 ; #...#.#.................
                  dc.b %10001010, %00000000, %00000000 ; #...#.#.................
DatImage47        equ *
DatChrB           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10101000, %00000000, %00000000 ; #.#.#...................
                  dc.b %10001000, %00000000, %00000000 ; #...#...................
                  dc.b %10001000, %00000000, %00000000 ; #...#...................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
DatImage48        equ *
DatChrC           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000000, %00000000, %00000000 ; #.......................
                  dc.b %10000000, %00000000, %00000000 ; #.......................
                  dc.b %10100000, %00000000, %00000000 ; #.#.....................
                  dc.b %10100000, %00000000, %00000000 ; #.#.....................
                  dc.b %10100010, %00000000, %00000000 ; #.#...#.................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
DatImage49        equ *
DatChrD           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10101000, %00000000, %00000000 ; #.#.#...................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10100010, %00000000, %00000000 ; #.#...#.................
                  dc.b %10100010, %00000000, %00000000 ; #.#...#.................
                  dc.b %10100010, %00000000, %00000000 ; #.#...#.................
                  dc.b %10101000, %00000000, %00000000 ; #.#.#...................
DatImage4a        equ *
DatChrE           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %10100000, %00000000, %00000000 ; #.#.....................
                  dc.b %10100000, %00000000, %00000000 ; #.#.....................
                  dc.b %10101000, %00000000, %00000000 ; #.#.#...................
                  dc.b %10000000, %00000000, %00000000 ; #.......................
                  dc.b %10000000, %00000000, %00000000 ; #.......................
                  dc.b %10000000, %00000000, %00000000 ; #.......................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
DatImage4b        equ *
DatChrF           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %10100000, %00000000, %00000000 ; #.#.....................
                  dc.b %10100000, %00000000, %00000000 ; #.#.....................
                  dc.b %10101000, %00000000, %00000000 ; #.#.#...................
                  dc.b %10000000, %00000000, %00000000 ; #.......................
                  dc.b %10000000, %00000000, %00000000 ; #.......................
                  dc.b %10000000, %00000000, %00000000 ; #.......................
                  dc.b %10000000, %00000000, %00000000 ; #.......................
DatImage4c        equ *
DatChrG           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000000, %00000000, %00000000 ; #.......................
                  dc.b %10000000, %00000000, %00000000 ; #.......................
                  dc.b %10001010, %00000000, %00000000 ; #...#.#.................
                  dc.b %10001010, %00000000, %00000000 ; #...#.#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
DatImage4d        equ *
DatChrH           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %10100010, %00000000, %00000000 ; #.#...#.................
                  dc.b %10100010, %00000000, %00000000 ; #.#...#.................
                  dc.b %10100010, %00000000, %00000000 ; #.#...#.................
                  dc.b %10100010, %00000000, %00000000 ; #.#...#.................
DatImage4e        equ *
DatChrI           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00100000, %00000000, %00000000 ; ..#.....................
                  dc.b %00100000, %00000000, %00000000 ; ..#.....................
                  dc.b %00100000, %00000000, %00000000 ; ..#.....................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
DatImage4f        equ *
DatChrJ           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00001000, %00000000, %00000000 ; ....#...................
                  dc.b %00001000, %00000000, %00000000 ; ....#...................
                  dc.b %00001000, %00000000, %00000000 ; ....#...................
                  dc.b %00001010, %00000000, %00000000 ; ....#.#.................
                  dc.b %00001010, %00000000, %00000000 ; ....#.#.................
                  dc.b %00001010, %00000000, %00000000 ; ....#.#.................
                  dc.b %10001010, %00000000, %00000000 ; #...#.#.................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
DatImage50        equ *
DatChrK           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10001010, %00000000, %00000000 ; #...#.#.................
                  dc.b %10001000, %00000000, %00000000 ; #...#...................
                  dc.b %10101000, %00000000, %00000000 ; #.#.#...................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %10100010, %00000000, %00000000 ; #.#...#.................
                  dc.b %10100010, %00000000, %00000000 ; #.#...#.................
                  dc.b %10100010, %00000000, %00000000 ; #.#...#.................
DatImage51        equ *
DatChrL           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10000000, %00000000, %00000000 ; #.......................
                  dc.b %10000000, %00000000, %00000000 ; #.......................
                  dc.b %10000000, %00000000, %00000000 ; #.......................
                  dc.b %10000000, %00000000, %00000000 ; #.......................
                  dc.b %10100000, %00000000, %00000000 ; #.#.....................
                  dc.b %10100000, %00000000, %00000000 ; #.#.....................
                  dc.b %10100000, %00000000, %00000000 ; #.#.....................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
DatImage52        equ *
DatChrM           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10100010, %00000000, %00000000 ; #.#...#.................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
DatImage53        equ *
DatChrN           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10100010, %00000000, %00000000 ; #.#...#.................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %10001010, %00000000, %00000000 ; #...#.#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
DatImage54        equ *
DatChrO           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %10001010, %00000000, %00000000 ; #...#.#.................
                  dc.b %10001010, %00000000, %00000000 ; #...#.#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
DatImage55        equ *
DatChrP           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %10100000, %00000000, %00000000 ; #.#.....................
                  dc.b %10100000, %00000000, %00000000 ; #.#.....................
                  dc.b %10100000, %00000000, %00000000 ; #.#.....................
                  dc.b %10100000, %00000000, %00000000 ; #.#.....................
DatImage56        equ *
DatChrQ           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %10001010, %00000000, %00000000 ; #...#.#.................
                  dc.b %10001010, %00000000, %00000000 ; #...#.#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10001000, %00000000, %00000000 ; #...#...................
                  dc.b %10100010, %00000000, %00000000 ; #.#...#.................
DatImage57        equ *
DatChrR           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %10101000, %00000000, %00000000 ; #.#.#...................
                  dc.b %10101000, %00000000, %00000000 ; #.#.#...................
                  dc.b %10100010, %00000000, %00000000 ; #.#...#.................
                  dc.b %10100010, %00000000, %00000000 ; #.#...#.................
DatImage58        equ *
DatChrS           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000000, %00000000, %00000000 ; #.......................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %00001010, %00000000, %00000000 ; ....#.#.................
                  dc.b %00001010, %00000000, %00000000 ; ....#.#.................
                  dc.b %10001010, %00000000, %00000000 ; #...#.#.................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
DatImage59        equ *
DatChrT           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %00100000, %00000000, %00000000 ; ..#.....................
                  dc.b %00100000, %00000000, %00000000 ; ..#.....................
                  dc.b %00100000, %00000000, %00000000 ; ..#.....................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
DatImage5a        equ *
DatChrU           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10100010, %00000000, %00000000 ; #.#...#.................
                  dc.b %10100010, %00000000, %00000000 ; #.#...#.................
                  dc.b %10100010, %00000000, %00000000 ; #.#...#.................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
DatImage5b        equ *
DatChrV           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10100010, %00000000, %00000000 ; #.#...#.................
                  dc.b %10100010, %00000000, %00000000 ; #.#...#.................
                  dc.b %10100010, %00000000, %00000000 ; #.#...#.................
                  dc.b %10100010, %00000000, %00000000 ; #.#...#.................
                  dc.b %10100010, %00000000, %00000000 ; #.#...#.................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %00100000, %00000000, %00000000 ; ..#.....................
DatImage5c        equ *
DatChrW           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %10100010, %00000000, %00000000 ; #.#...#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
DatImage5d        equ *
DatChrX           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
DatImage5e        equ *
DatChrY           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10001010, %00000000, %00000000 ; #...#.#.................
                  dc.b %10001010, %00000000, %00000000 ; #...#.#.................
                  dc.b %10001010, %00000000, %00000000 ; #...#.#.................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
DatImage5f        equ *
DatChrZ           dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %10000010, %00000000, %00000000 ; #.....#.................
                  dc.b %00001000, %00000000, %00000000 ; ....#...................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %10000000, %00000000, %00000000 ; #.......................
                  dc.b %10001010, %00000000, %00000000 ; #...#.#.................
                  dc.b %10101010, %00000000, %00000000 ; #.#.#.#.................
; ------------------------------------------------------------------------------------------------------------------------------- ;
DatImage60        equ *
DatSpcBrRi        dc.b %00000000, %00000000, %00000000 ; ........................ right bracket
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10000000, %00000000, %00000000 ; #.......................
                  dc.b %10100000, %00000000, %00000000 ; #.#.....................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %00001010, %00000000, %00000000 ; ....#.#.................
                  dc.b %00001010, %00000000, %00000000 ; ....#.#.................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %10100000, %00000000, %00000000 ; #.#.....................
                  dc.b %10000000, %00000000, %00000000 ; #.......................
DatImage61        equ *
DatSpcDot         dc.b %00000000, %00000000, %00000000 ; ........................ period
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
DatImage62        equ *
DatSpcPaLe        dc.b %00000000, %00000000, %00000000 ; ........................ left parenthesis
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %10100000, %00000000, %00000000 ; #.#.....................
                  dc.b %10100000, %00000000, %00000000 ; #.#.....................
                  dc.b %10100000, %00000000, %00000000 ; #.#.....................
                  dc.b %10100000, %00000000, %00000000 ; #.#.....................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
DatImage63        equ *
DatSpcPaRi        dc.b %00000000, %00000000, %00000000 ; ........................ right parenthesis
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %00001010, %00000000, %00000000 ; ....#.#.................
                  dc.b %00001010, %00000000, %00000000 ; ....#.#.................
                  dc.b %00001010, %00000000, %00000000 ; ....#.#.................
                  dc.b %00001010, %00000000, %00000000 ; ....#.#.................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
DatImage64        equ *
DatSpcSlash       dc.b %00000000, %00000000, %00000000 ; ........................ slash
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000010, %00000000, %00000000 ; ......#.................
                  dc.b %00000010, %00000000, %00000000 ; ......#.................
                  dc.b %00001000, %00000000, %00000000 ; ....#...................
                  dc.b %00001000, %00000000, %00000000 ; ....#...................
                  dc.b %00100000, %00000000, %00000000 ; ..#.....................
                  dc.b %00100000, %00000000, %00000000 ; ..#.....................
                  dc.b %10000000, %00000000, %00000000 ; #.......................
                  dc.b %10000000, %00000000, %00000000 ; #.......................
DatImage65        equ *
DatSpcHyp         dc.b %00000000, %00000000, %00000000 ; ........................ hyphen
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %10101010, %10000000, %00000000 ; #.#.#.#.#...............
                  dc.b %10101010, %10000000, %00000000 ; #.#.#.#.#...............
                  dc.b %10101010, %10000000, %00000000 ; #.#.#.#.#...............
                  dc.b %10101010, %10000000, %00000000 ; #.#.#.#.#...............
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
DatImage66        equ *
DatSpcBrRLe       dc.b %00000000, %00000000, %00000000 ; ........................ left bracket
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000000, %00000000, %00000000 ; ........................
                  dc.b %00000010, %00000000, %00000000 ; ......#.................
                  dc.b %00001010, %00000000, %00000000 ; ....#.#.................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %10100000, %00000000, %00000000 ; #.#.....................
                  dc.b %10100000, %00000000, %00000000 ; #.#.....................
                  dc.b %00101000, %00000000, %00000000 ; ..#.#...................
                  dc.b %00001010, %00000000, %00000000 ; ....#.#.................
                  dc.b %00000010, %00000000, %00000000 ; ......#.................
; ------------------------------------------------------------------------------------------------------------- ;
DatImagesX        equ *                                   ; .hbu008. - end address for number calculations
; ------------------------------------------------------------------------------------------------------------- ;
DatImageLen       equ (DatTile1 - DatTile0)                             ; length  image data
NoImages          equ (DatImagesX        - DatImages) / DatImageLen     ; overall image numbers for GetChrSubst
NoSprites         equ (DatSpritesX       - DatImages) / DatImageLen + 1 ; sprite  image numbers for SetSpritePos
; ------------------------------------------------------------------------------------------------------------- ;
NoTileBlank       equ (DatTile0          - DatImages) / DatImageLen ; level tiles
NoTileWallWeak    equ (DatTile1          - DatImages) / DatImageLen
NoTileWallHard    equ (DatTile2          - DatImages) / DatImageLen
NoTileLadder      equ (DatTile3          - DatImages) / DatImageLen
NoTilePole        equ (DatTile4          - DatImages) / DatImageLen
NoTileWallTrap    equ (DatTile5          - DatImages) / DatImageLen
NoTileLadderSec   equ (DatTile6          - DatImages) / DatImageLen
NoTileGold        equ (DatTile7          - DatImages) / DatImageLen
NoTileEnemy       equ (DatTile8          - DatImages) / DatImageLen
NoTileLodeRunner  equ (DatTile9          - DatImages) / DatImageLen
;
NoTileNumMin      equ NoTileBlank
NoTileNumMax      equ NoTileLodeRunner
; ------------------------------------------------------------------------------------------------------------- ;
NoCursorBlank     equ (DatCursorBlank    - DatImages) / DatImageLen ; input blank cursor
; ------------------------------------------------------------------------------------------------------------- ;
NoSprite_RuLe00   equ (DatSprite_RuLe00  - DatImages) / DatImageLen ; sprite images
NoSprite_RuLe01   equ (DatSprite_RuLe01  - DatImages) / DatImageLen
NoSprite_RuLe02   equ (DatSprite_RuLe02  - DatImages) / DatImageLen
NoSprite_Ladr00   equ (DatSprite_Ladr00  - DatImages) / DatImageLen
NoSprite_FireLe   equ (DatSprite_FireLe  - DatImages) / DatImageLen
NoSprite_RuRi00   equ (DatSprite_RuRi00  - DatImages) / DatImageLen
NoSprite_RuRi01   equ (DatSprite_RuRi01  - DatImages) / DatImageLen
NoSprite_RuRi02   equ (DatSprite_RuRi02  - DatImages) / DatImageLen
NoSprite_Ladr01   equ (DatSprite_Ladr01  - DatImages) / DatImageLen
NoSprite_FallLe   equ (DatSprite_FallLe  - DatImages) / DatImageLen
NoSprite_FallRi   equ (DatSprite_FallRi  - DatImages) / DatImageLen
NoSprite_PoRi00   equ (DatSprite_PoRi00  - DatImages) / DatImageLen
NoSprite_PoRi01   equ (DatSprite_PoRi01  - DatImages) / DatImageLen
NoSprite_PoRi02   equ (DatSprite_PoRi02  - DatImages) / DatImageLen
NoSprite_PoLe00   equ (DatSprite_PoLe00  - DatImages) / DatImageLen
NoSprite_PoLe01   equ (DatSprite_PoLe01  - DatImages) / DatImageLen
NoSprite_PoLe02   equ (DatSprite_PoLe02  - DatImages) / DatImageLen
; ------------------------------------------------------------------------------------------------------------- ;
NoShootSpark00    equ (DatShootSpark00   - DatImages) / DatImageLen ; lode runner shootings
NoShootSpark01    equ (DatShootSpark01   - DatImages) / DatImageLen
NoShootSpark02    equ (DatShootSpark02   - DatImages) / DatImageLen
NoShootSpark03    equ (DatShootSpark03   - DatImages) / DatImageLen
NoShootMeltGr00   equ (DatShootMeltGr00  - DatImages) / DatImageLen
NoShootMeltGr01   equ (DatShootMeltGr01  - DatImages) / DatImageLen
NoShootMeltGr02   equ (DatShootMeltGr02  - DatImages) / DatImageLen
NoShootMeltGr03   equ (DatShootMeltGr03  - DatImages) / DatImageLen
NoShootMeltGr04   equ (DatShootMeltGr04  - DatImages) / DatImageLen
NoShootMeltGr05   equ (DatShootMeltGr05  - DatImages) / DatImageLen
NoSprite_FireRi   equ (DatSprite_FireRi  - DatImages) / DatImageLen
NoShootMelt00     equ (DatShootMelt00    - DatImages) / DatImageLen
NoShootMelt01     equ (DatShootMelt01    - DatImages) / DatImageLen
; ------------------------------------------------------------------------------------------------------------- ;
NoSprtMC_RuRi00   equ (DatSprtMC_RuRi00  - DatImages) / DatImageLen ; multi color sprite images
NoSprtMC_RuRi01   equ (DatSprtMC_RuRi01  - DatImages) / DatImageLen
NoSprtMC_RuRi02   equ (DatSprtMC_RuRi02  - DatImages) / DatImageLen
NoSprtMC_RuLe00   equ (DatSprtMC_RuLe00  - DatImages) / DatImageLen
NoSprtMC_RuLe01   equ (DatSprtMC_RuLe01  - DatImages) / DatImageLen
NoSprtMC_RuLe02   equ (DatSprtMC_RuLe02  - DatImages) / DatImageLen
NoSprtMC_PoRi00   equ (DatSprtMC_PoRi00  - DatImages) / DatImageLen
NoSprtMC_PoRi01   equ (DatSprtMC_PoRi01  - DatImages) / DatImageLen
NoSprtMC_PoRi02   equ (DatSprtMC_PoRi02  - DatImages) / DatImageLen
NoSprtMC_PoLe00   equ (DatSprtMC_PoLe00  - DatImages) / DatImageLen
NoSprtMC_PoLe01   equ (DatSprtMC_PoLe01  - DatImages) / DatImageLen
NoSprtMC_PoLe02   equ (DatSprtMC_PoLe02  - DatImages) / DatImageLen
NoSprtMC_Ladr00   equ (DatSprtMC_Ladr00  - DatImages) / DatImageLen
NoSprtMC_Ladr01   equ (DatSprtMC_Ladr01  - DatImages) / DatImageLen
NoSprtMC_FallRi   equ (DatSprtMC_FallRi  - DatImages) / DatImageLen
NoSprtMC_FallLe   equ (DatSprtMC_FallLe  - DatImages) / DatImageLen
; ------------------------------------------------------------------------------------------------------------- ;
NoCloseHole00     equ (DatCloseHole00    - DatImages) / DatImageLen ; wall closing steps
NoCloseHole01     equ (DatCloseHole01    - DatImages) / DatImageLen
; ------------------------------------------------------------------------------------------------------------- ;
NoReviveEnemy00   equ (DatReviveEnemy00  - DatImages) / DatImageLen ; enemy revive steps
NoReviveEnemy01   equ (DatReviveEnemy01  - DatImages) / DatImageLen
; ------------------------------------------------------------------------------------------------------------- ;
NoDig0            equ (DatDig0           - DatImages) / DatImageLen ; digits
NoDig1            equ (DatDig1           - DatImages) / DatImageLen
NoDig2            equ (DatDig2           - DatImages) / DatImageLen
NoDig3            equ (DatDig3           - DatImages) / DatImageLen
NoDig4            equ (DatDig4           - DatImages) / DatImageLen
NoDig5            equ (DatDig5           - DatImages) / DatImageLen
NoDig6            equ (DatDig6           - DatImages) / DatImageLen
NoDig7            equ (DatDig7           - DatImages) / DatImageLen
NoDig8            equ (DatDig8           - DatImages) / DatImageLen
NoDig9            equ (DatDig9           - DatImages) / DatImageLen
;
NoDigitsMin       equ NoDig0
NoDigitsMax       equ NoDig9
; ------------------------------------------------------------------------------------------------------------- ;
NoChrA            equ (DatChrA           - DatImages) / DatImageLen ; characters
NoChrB            equ (DatChrB           - DatImages) / DatImageLen
NoChrC            equ (DatChrC           - DatImages) / DatImageLen
NoChrD            equ (DatChrD           - DatImages) / DatImageLen
NoChrE            equ (DatChrE           - DatImages) / DatImageLen
NoChrF            equ (DatChrF           - DatImages) / DatImageLen
NoChrG            equ (DatChrG           - DatImages) / DatImageLen
NoChrH            equ (DatChrH           - DatImages) / DatImageLen
NoChrI            equ (DatChrI           - DatImages) / DatImageLen
NoChrJ            equ (DatChrJ           - DatImages) / DatImageLen
NoChrK            equ (DatChrK           - DatImages) / DatImageLen
NoChrL            equ (DatChrL           - DatImages) / DatImageLen
NoChrM            equ (DatChrM           - DatImages) / DatImageLen
NoChrN            equ (DatChrN           - DatImages) / DatImageLen
NoChrO            equ (DatChrO           - DatImages) / DatImageLen
NoChrP            equ (DatChrP           - DatImages) / DatImageLen
NoChrQ            equ (DatChrQ           - DatImages) / DatImageLen
NoChrR            equ (DatChrR           - DatImages) / DatImageLen
NoChrS            equ (DatChrS           - DatImages) / DatImageLen
NoChrT            equ (DatChrT           - DatImages) / DatImageLen
NoChrU            equ (DatChrU           - DatImages) / DatImageLen
NoChrV            equ (DatChrV           - DatImages) / DatImageLen
NoChrW            equ (DatChrW           - DatImages) / DatImageLen
NoChrX            equ (DatChrX           - DatImages) / DatImageLen
NoChrY            equ (DatChrY           - DatImages) / DatImageLen
NoChrZ            equ (DatChrZ           - DatImages) / DatImageLen
; ------------------------------------------------------------------------------------------------------------- ;
NoSpcBrRi         equ (DatSpcBrRi        - DatImages) / DatImageLen ; special characters
NoSpcDot          equ (DatSpcDot         - DatImages) / DatImageLen
NoSpcPaLe         equ (DatSpcPaLe        - DatImages) / DatImageLen
NoSpcPaRi         equ (DatSpcPaRi        - DatImages) / DatImageLen
NoSpcSlash        equ (DatSpcSlash       - DatImages) / DatImageLen
NoSpcHyp          equ (DatSpcHyp         - DatImages) / DatImageLen
NoSpcBrRLe        equ (DatSpcBrRLe       - DatImages) / DatImageLen
; ------------------------------------------------------------------------------------------------------------- ;
