; ------------------------------------------------------------------------------------------------------------- ;
; Championship Lode Runner - IT.PRG
; ------------------------------------------------------------------------------------------------------------- ;
; Memory Map
; ------------------------------------------------------------------------------------------------------------- ;
; $0000 - $00ff:  Zero Page Values
; $0200 - $02ff:  <not used>
; $0300 - $03ff:  <not used>
; $0400 - $04f7:  Multi Color Screen
; $04f8 - $04ff:  Sprite Pointers
; $0800 - $09c3:  expanded level data row pointer
; $0a00 - $0bc3:  expanded level data row pointer - play level control
; $0c00 - $0cff:  Sprite Store 01
; $0d00 - $0dff:  Sprite Store 02
; $0e00 - $0ec7:  Tab Offsets HiRes Lo
; $0f00 - $0fc7:  Tab Offsets HiRes Hi
; $1000 - $10ff:  Level Data Save/Load
; $1100 - $11ff:  High Score Save/Load
; $1200 - $12ff:  Tables for Dynamic Value
; $1300 - $133b:  In Game Variables
; $1400 - $1fff:  Data Start Graphic
; $2000 - $3fff:  HighRes Display Screen
; $4000 - $5fff:  HighRes Prepare Screen
; $c000 - $c0ff:  Tunes Play Time
; $c100 - $c1ff:  Tunes Data Ptr Voice 2
; $c200 - $c2ff:  Tunes Data Ptr Voice 3
; $c300 - $c3ff:  Tunes Sustain/Release/Volume (not used)
; $c800 - $c8ff:  High Score Work Old
; $c900 - $c9ff:  High Score Work New
; ------------------------------------------------------------------------------------------------------------- ;
                  * = $6000                       ; Start address
; ------------------------------------------------------------------------------------------------------------- ;
; compiler settings                                                                                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  incdir   ..\..\inc      

C64CIA1           include  cia1.asm               ; Complex Interface Adapter (CIA) #1 Registers  $DC00-$DC0F
C64CIA2           include  cia2.asm               ; Complex Interface Adapter (CIA) #2 Registers  $DD00-$DD0F
C64SID            include  sid.asm                ; Sound Interface Device (SID) Registers        $D400-$D41C
C64VicII          include  vic.asm                ; Video Interface Chip (VIC-II) Registers       $D000-$D02E
C64Kernel         include  kernel.asm             ; Kernel Vectors
C64Colors         include  color.asm              ; Colour RAM Address / Colours
;
InGameVars        include  inc\LR_Vars.asm        ; Game Variables
InZeroPageVars    include  inc\LR_Zpg.asm         ; Zero Page Variables
; ------------------------------------------------------------------------------------------------------------- ;
Start             lda #$00                        ;
                  sta CR_Cheat                    ;
                  sta LR_Volume                   ; 
                  
                  lda #LR_Joystick                ;
                  sta LR_ControllerTyp            ; ca=joystick  cb=keyboard
                  
                  jsr ColdStartInit               ; ColdStartInit
                  
                  lda #LR_DiskRead                ; 
                  jsr GetPutHiScores              ; ($1100-$11ff) ac: $01=load $02=store 81= 82=
; ------------------------------------------------------------------------------------------------------------- ;
ColdStart         lda #LR_VolumeMax               ;
                  sta LR_Volume                   ; 
                  sta LR_FallsDown                ; $00=fall $20=no fall $ff=init
                  sta LR_DeathTune                ; 
                  sta LR_ShootMode                ; 
                  
                  lda #$00                        ;
                  sta CR_StatusColor              ; 
                  sta CR_NoUse                    ;
                  sta LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  sta LR_PtrTuneToPlay            ; 
                  sta LR_Shoots                   ; $00=no  $01=shoot right  $ff=shoot left
                  sta LR_DeathTune                ; 
                  sta LR_KeyNew                   ; 
                  sta LR_KeyOld                   ; 
                  sta LR_SprtPosCtrl              ;
                  
                  lda #>LR_LvlDataSavLod          ; $10 - Target: $1000-$10ff
                  sta Mod_GetDiskByte             ; set disk get to $1000 - DiskLevel
                  sta Mod_PutDiskByte             ; set disk put to $1000 - DiskLevel
                  
                  sta LR_Random                   ; last RND beam pos
                  
                  lda $c5                         ; C64: key value
                  sta LR_KeyOld                   ; 
                  lda #$40                        ; reset: $40=no key pressed
                  sta $c5                         ;
                  
                  lda #LR_SpeedNormal             ; wait 5 interupts before next move  (normal speed)
                  sta LR_GameSpeed                ; 
                  
                  lda #LR_GameStart               ;
                  sta LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  jmp StartGraficOut              ; 
; ------------------------------------------------------------------------------------------------------------- ;
GameStart         lda #$00                        ; 
                  sta LR_ScoreLo                  ; scores
                  sta LR_ScoreMidLo               ; 
                  sta LR_ScoreMidHi               ; 
                  sta LR_ScoreHi                  ; 
                  sta LR_CntSpeedLaps             ; 
                  sta CR_NoFunction               ;
                  sta LR_EnmyBirthCol             ;
                  sta $58                         ; reset duration demo move for possible next demo rounds
                  
                  lda #<TabDemoLvlMoves           ; .hbu000.
                  sta $55                         ;
                  lda #>TabDemoLvlMoves           ;
                  sta $56                         ;
                  
                  sta LR_LvlReload                ; reload if <> LR_LevelNoDisk
                  
                  lda #LR_NumLivesInit            ;
                  sta LR_NumLives                 ; 
                  
                  lda #>LR_ScrnHiReDisp           ; $20
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  jsr MelodyInit                  ; init victory tune
                  jsr InitBothScreens             ; both gfx screens  +  status lines
                  jsr SetNewColors                ; SetNewColors (new colors any 10th level)

                  lda CR_LevelColor               ; lrNewLevelColor
                  jsr ColourLevel                 ; 
                  jsr SetUniquePlayId             ; SetUniquePlayId
; ------------------------------------------------------------------------------------------------------------- ;
LevelStart        lda #$00                        ; 
                  sta CR_StatusColor              ; lrNewStatusColor
                  
                  ldx #LR_LevelLoad               ; force new copy from disk
                  jsr InitLevel                   ; InitLevel
                  
                  sta LR_PtrTuneToPlay            ; lrScoreToPlay
                  sta LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  
                  ldy LR_EnmyNo                   ; 
                  lda TabEnmyEnab,y               ; 
                  sta SPENA                       ; VIC 2 - $D015 = Sprite Enable
                  
                  lda #$00                        ;
                  sta LR_JoyUpDo                  ; 
                  sta LR_JoyLeRi                  ; 
                  
                  lda LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  lsr a                           ;
                  beq MainLoopInit                ; 
                  
_SetLrBlack       lda SPENA                       ; VIC 2 - $D015 = Sprite Enable  <snlWaitUser>  (flicker sprite 0 meanwhile)
                  and #$fe                        ;    switch off lode runner sprite
                  sta SPENA                       ; VIC 2 - $D015 = Sprite Enable
                  
                  ldy #$90                        ; init wait
                  ldx #$00                        ;
_WaitLrBlack      dex                             ; 
                  jsr ChkUserAction               ; check user input - carry_set=yes carry_clear=no
                  bcs _StartLr                    ; 
                  bne _WaitLrBlack                ; 
                  dey                             ;
                  bne _WaitLrBlack                ; 
                  
_SetLrWhite       lda SPENA                       ; VIC 2 - $D015 = Sprite Enable
                  ora #$01                        ;   switch on lode runner sprite
                  sta SPENA                       ; VIC 2 - $D015 = Sprite Enable
                  
                  ldy #$90                        ; init wait
                  ldx #$00                        ;
_WaitLrWhite      dex                             ; 
                  jsr ChkUserAction               ; check user input - carry_set=yes carry_clear=no
                  bcs _StartLr                    ; 
                  bne _WaitLrWhite                ; 
                  
                  dey                             ;
                  bne _WaitLrWhite                ; 
                  jmp _SetLrBlack                 ; 
                  
_StartLr          lda SPENA                       ; VIC 2 - $D015 = Sprite Enable <snlGo>
                  ora #$01                        ;   switch on lode runner sprite
                  sta SPENA                       ; VIC 2 - $D015 = Sprite Enable
                  lda LR_KeyNew                   ; 
_Chr_S            cmp #$8d                        ; ctrl+s
                  bne MainLoopInit                ; 
                  
_GoSaveGame       jsr SaveGame                    ; save a game only before player starts the level
                  
                  ldy LR_EnmyNo                   ; 
                  lda TabEnmyEnab,y               ; 
                  sta SPENA                       ; VIC 2 - $D015 = Sprite Enable
; ------------------------------------------------------------------------------------------------------------- ;
MainLoopInit      ldx #LR_ShootsNo                ; 
                  stx LR_Shoots                   ; $00=no  $01=shoot right  $ff=shoot left
                  
                  lda LR_CntSpeedLaps             ; 
                  clc                             ;
                  adc LR_EnmyNo                   ; 
                  tay                             ;
                  
                  ldx TabOffEnmyCycles,y          ; offsets enemy move cycles tab
                  lda TabEnmyCycles1,x            ; enemy move cycles tab
                  sta $32                         ;
                  lda TabEnmyCycles2,x            ; enemy move cycles tab + 1
                  sta $33                         ;
                  lda TabEnmyCycles3,x            ; enemy move cycles tab + 2
                  sta $34                         ;
                  
                  ldy LR_CntSpeedLaps             ; lrGameSpeed
                  lda TabEnmyHoleTime,y           ; time in hole tab
                  sta LR_EnmyHoleTime             ; enemy time in hole
; ------------------------------------------------------------------------------------------------------------- ;
; The Game Main Loop
; ------------------------------------------------------------------------------------------------------------- ;
MainLoop          jsr MoveLodeRunner              ; MoveLodeRunner      <MainLoop>
                  lda LR_Alive                    ; 
_ChkLRAccident    beq _ChkLRTrapped               ; lr accident
                  
_ChkGold4Tune     lda LR_GoldToGet                ; 
                  bne _ChkLrPos                   ; some gold left
                  
_Victory          jsr VictoryTuneCopy             ; prepare melody
                  jsr ShowExitLadders             ; display exit ladders
                  jsr VictoryMsg                  ; show level victory msg
                  
_ChkLrPos         lda $04                         ; actual row lode runner
                  bne _GoCloseHoles               ; lr not on top of the screen
                  
                  lda $06                         ; lr pos on image up/down
                  cmp #$02                        ; $02=center of screen image
                  bne _GoCloseHoles               ; lr not centerd
                  
_ChkGold4Finish   lda LR_GoldToGet                ; lr fully on top of the screen and
                  beq LevelComplete               ; got all gold
                  cmp #$ff                        ;
                  beq LevelComplete               ; got all gold plus one
                  
_GoCloseHoles     jsr CloseHoles                  ; 

                  lda LR_Alive                    ; 
_ChkLRTrapped     beq LrDeath                     ; lr trapped

_GoMoveEnemies    jsr MoveEnemies                 ; 

                  lda LR_Alive                    ; 
_ChkLRCaught      beq LrDeath                     ; lr caught
                  
_DelayGame        lda LR_CountIRQs                ; wait counter - inc during each IRQ
                  cmp LR_GameSpeed                ; 
                  bcc _DelayGame                  ; lower
                  
_SetWait          lda #LR_IRQsDflt                ; reinit wait cycle time
                  sta LR_CountIRQs                ; wait counter - inc during each IRQ
                  
MainLoopX         jmp MainLoop                    ; 
; ------------------------------------------------------------------------------------------------------------- ;
LevelComplete     inc LR_LevelNoGame              ; 001-050
                  inc LR_LevelNoDisk              ; 000-049

_FinishTunes      lda LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  cmp LR_PtrTuneToPlay            ; lrScoreToPlay
                  bne _FinishTunes                ; wait until all melodies have finished
                  
                  jsr SetNextMelody               ; 
                  
                  inc LR_NumLives                 ; get one extra chance for each completed level
                  bne _ScoreTuneI                 ; 
                  dec LR_NumLives                 ; max 255
                  
_ScoreTuneI       lda #CR_SoreValSub              ; 
                  sta $2f                         ;
                  
                  sei                             ; no interrupts
                  
_ScoreTuneNext    lda #LR_SoreValStart            ; 
                  sec                             ;
                  sbc $2f                         ;
                  sta FREHI1                      ; SID - $D401 = Oscillator 1 Frequency Control (High Byte)
                  ldy #$2c                        ; 
_ScoreTuneSetX    ldx #$00                        ; 
_ScoreTuneWaitX   dex                             ; 
                  bne _ScoreTuneWaitX             ; 
                  
                  dey                             ;
                  bne _ScoreTuneSetX              ; 
                  
                  sty FREHI1                      ; SID - $D401 = Oscillator 1 Frequency Control (High Byte)
                  tya                             ; 00
                  iny                             ; 01
                  jsr Score2BaseLine              ; AddDisplayScore (ac=1s yr=100s)
                  
                  dec $2f                         ;
                  bpl _ScoreTuneNext              ; 20 loops for 2000 points
                  
                  cli                             ; reallow interrupts
                  
                  lda CR_DiskStatus               ; 
_ChkDiskStatus    bmi GoLevelStart                ; bad
                  
                  lda LR_LevelNoGame              ; 001-050
                  cmp #CR_LevelNoMax              ; 051
_ChkMaxLevel      bcc GoLevelStart                ; start a new level

_GoGameOver       jmp GameOver                    ; finish after last level

GoLevelStart      jmp LevelStart                  ; 
; ------------------------------------------------------------------------------------------------------------- ;
LrDeath           dec LR_NumLives                 ; 
                  
                  lda LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  lsr a                           ;
_ChkDemo          bne LrDeathTune                 ; was game
                  
LrDeathX          jmp SetVolume                   ; 
; ------------------------------------------------------------------------------------------------------------- ;
LrDeathTune       lda #LR_DeathTuneVal            ; 
                  sta LR_DeathTune                ; 

_WaitGameTune     lda LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  cmp LR_PtrTuneToPlay            ; 
                  bne _WaitGameTune               ; wait for all in game tunes to be finished
                  
                  lda #LR_ShootsNo                ; 
                  sta LR_Shoots                   ; $00=no  $01=shoot right  $ff=shoot left
                  
                  lda #LR_FallsNo                 ;
                  sta LR_FallsDown                ; $00=fall $20=no fall $ff=init
                  jsr Lives2BaseLine              ; StatusOutLives
                  
_WaitDeathTune    lda LR_DeathTune                ; lrDeadTune      <mlWaitDeadTune>
                  bne _WaitDeathTune              ; wait for death tune to be finished
                  
                  lda LR_NumLives                 ; 
_ChkGameOver      bne GoLevelStart                ; 
; ------------------------------------------------------------------------------------------------------------- ;
GameOver          jsr ChkNewHighScore             ; 
                  jsr CheckNewChamp               ; 
                  bcs Wait4User                   ; new champ => WaitSomeTime
                  
                  jsr FlipGmeOverSign             ; 
; ------------------------------------------------------------------------------------------------------------- ;
Wait4User         ldx #$ff                        ; 
                  ldy #$ff                        ;
                  bcs _SetWaitLoops               ; user break during flip => wstSetLoops
                  
                  lda #$00                        ;
                  sta LR_KeyNew                   ; 
                  
_SetWaitLoops     lda #$03                        ;       <wstSetLoops>
                  sta $50                         ; screen row ($00 - $0f)
                  
GetUserKey        lda CIAPRA                      ; CIA 1 - $DC00 = Data Port A - cia#1 port a (joyport2):  bit4=fire  bit3=right  bit2=left  bit1=down  bit0=up
                  and #$10                        ; isolate fire button
                  beq GameRestart                 ; =>GameRestartInit
                  
_GetKey           lda LR_KeyNew                   ; lrNewKey
_Chk_L            cmp #$aa                        ; CTRL+l
                  bne _Chk_Enter                  ; 
                  
                  jsr LoadGame                    ; => LoadPlayGame
                  
_Chk_Enter        cmp #$01                        ; ENTER      <wfukNext>
                  beq GoScores                    ; => mlScores
                  
_Chk_C            cmp #$94                        ; CTRL+c
                  beq GoClrHighScores             ; => ClearHighScore
                  
_Chk_Space        cmp #$3c                        ; SPACE
                  beq GameRestart                 ; => GameRestartInit
                  
_Wait             dex                             ; wait x
                  bne GetUserKey                  ; 
                  dey                             ; wait y
                  bne GetUserKey                  ; 
                  dec $50                         ; wait a (screen row ($00 - $0f))
                  bne GetUserKey                  ; 
                  
                  lda LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  bne ChkDemo                     ; 
                  
                  ldx #LR_GameDemo                ;
                  stx LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  
                  stx LR_LevelNoGame              ; 001-050
                  stx $59                         ; save LR_LevelNoGame
                  stx LR_Cheated                  ;
                  
                  ldx LR_Volume                   ; lrVolume
                  stx Mod__Volume                 ;
                  
                  lda #$00                        ;
                  sta LR_Volume                   ; lrVolume
                  sta LR_LevelNoDisk              ; 000-049
                  
Wait4UserX        jmp GameStart                   ; 
; ------------------------------------------------------------------------------------------------------------- ;
SetVolume         lda #$00                        ; 
Mod__Volume       = *-1
                  sta LR_Volume                   ; lrVolume
                  jmp Wait4User                   ; WaitSomeTime
; ------------------------------------------------------------------------------------------------------------- ;
ChkDemo           cmp #LR_GameDemo                ; 
                  bne ShowStartGfx                ; 
                  
GoScores          jsr ShowHighScores              ; 

                  lda #LR_GameGame                ;
                  sta LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  
                  clc                             ;
                  jmp Wait4User                   ; 
; ------------------------------------------------------------------------------------------------------------- ;
ShowStartGfx      lda #$00                        ; 
                  sta LR_LevelNoDisk              ; 000-049
                  sta LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  jmp StartGraficOut              ; StartGrafic
; ------------------------------------------------------------------------------------------------------------- ;
GoClrHighScores   jsr ClearHighScores             ; 
                  jmp GoScores                    ; 
; ------------------------------------------------------------------------------------------------------------- ;
GameRestart       ldx #$00                        ; 
                  stx LR_LevelNoDisk              ; 000-049
                  
                  inx                             ;
                  stx LR_LevelNoGame              ; 001-050
                  stx LR_Cheated                  ; flag:
                  
                  lda #LR_GameGame                ;
                  sta LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  
_GetVolume        lda #LR_VolumeMax               ;
                  sta LR_Volume                   ; 
                  jmp GameStart                   ; 
; ------------------------------------------------------------------------------------------------------------- ;
TabOffEnmyCycles  .byte $00
                  .byte $03
                  .byte $06
                  .byte $09
                  .byte $0c
                  .byte $0f
                  .byte $12
                  .byte $15
                  .byte $18
                  .byte $1b
                  .byte $1e
; ------------------------------------------------------------------------------------------------------------- ;
TabEnmyHoleTime   .byte $26
                  .byte $26
                  .byte $2e
                  .byte $44
                  .byte $47
                  .byte $49
                  .byte $4a
                  .byte $4b
                  .byte $4c
                  .byte $4d
                  .byte $4e
                  .byte $4f
                  .byte $50
                  .byte $51
                  .byte $52
                  .byte $53
                  .byte $54
                  .byte $55
                  .byte $56
                  .byte $57
                  .byte $58
; ------------------------------------------------------------------------------------------------------------- ;
StartGraficOut    jsr ClearHiresDisp              ; ClearDisplay20      <StartGrafic>

                  lda #LR_BlackBlack              ;
                  jsr ColourLevel                 ; 
                  
                  lda SCROLY                      ; VIC 2 - $D011 = VIC Control Register 1
                  ora #$20                        ; set bitmap mode
                  sta SCROLY                      ; VIC 2 - $D011 = VIC Control Register 1
                  
                  lda VMCSB                       ; VIC 2 - $D018 = Chip Memory Control
                  and #$f0                        ; chr generator
                  ora #$08                        ;   to video base + 2000-3fff
                  sta VMCSB                       ; VIC 2 - $D018 = Chip Memory Control
                  
                  lda #$00                        ;
                  sta LR_Counter                  ;
_GetNextGfxColor  ldx LR_Counter                  ; <sgGetNextColor>
                  inc LR_Counter                  ;
                  lda TabColorOutLo,x             ; target lo
                  sta __ModColorOutL              ; 
                  lda TabColorOutHi,x             ; target high
                  sta __ModColorOutH              ; 
                  lda TabColorAmount,x            ; amount
                  tay                             ;
                  lda TabColorValue,x             ; color
                  beq StartGraphicPic             ; 
                  
_SetColor         sta LR_ScrnMultColor,y          ; color target      <sgCopyColors>
__ModColorOutH    = *-1
__ModColorOutL    = *-2
                  dey                             ;
                  cpy #$ff                        ;
                  bne _SetColor                   ; 
                  
                  jmp _GetNextGfxColor            ; 
; ------------------------------------------------------------------------------------------------------------- ;                  
TabColorOutLo     .byte $05                       ; color target addresse low
                  .byte $05
                  .byte $21
                  .byte $21
                  .byte $ba
                  .byte $27
                  .byte $7c
TabColorOutHi     .byte $04                       ; color target addresse high
                  .byte $05
                  .byte $05
                  .byte $06
                  .byte $06
                  .byte $07
                  .byte $07
TabColorAmount    .byte $ff                       ; color amount
                  .byte $09
                  .byte $ff
                  .byte $82
                  .byte $68
                  .byte $41
                  .byte $37
TabColorValue     .byte $30 ; Cyan                ; color
                  .byte $30 ; Cyan
                  .byte $10 ; White
                  .byte $10 ; White
                  .byte $70 ; Yellow
                  .byte $30 ; Cyan
                  .byte $f0 ; Light Grey
                  
                  .byte $00 ; EndOfTab
; ------------------------------------------------------------------------------------------------------------- ;
StartGraphicPic   lda SCROLX                      ; VIC 2 - $D016 = Control Register 2 (and Horizontal Fine Scrolling) <sgCopyPicture>
                  and #$ef                        ; reset multi color mode
_MultiColorOff    sta SCROLX                      ; VIC 2 - $D016 = Control Register 2 (and Horizontal Fine Scrolling)
                  
_CopyDataI        lda #<CR_StartGfx               ; from $13b0
                  sta $0f                         ;
                  lda #>CR_StartGfx               ;
                  sta $10                         ; ($0f/$10) -> graphic data start  address
                  
                  lda #<(LR_ScrnHiReDisp-1)       ; to   $2000
                  sta $0d                         ;
                  lda #>(LR_ScrnHiReDisp-1)       ; 
                  sta $0e                         ; ($0d/$0e) -> graphic data target address
                  
_GetData          ldy #$00                        ; 
                  lda ($0f),y                     ;
                  sta $1e                         ; first byte is counter
                  iny                             ;
                  lda ($0f),y                     ;
                  sta $1f                         ; second byte is data

_SetPtr           lda $0f                         ; 
                  clc                             ;
                  adc #$02                        ; set pointer to next pair of data
                  sta $0f                         ;
                  bcc _SetCounter                 ; 
                  inc $10                         ;
                  
_SetCounter       lda $1e                         ; first byte is counter
                  tay                             ;
                  lda $1f                         ; second byte is data
_CopyData         sta ($0d),y                     ; 
                  dey                             ;
                  bne _CopyData                   ; 
                  
_SetTarget        lda $0d                         ; set next target pos
                  clc                             ;
                  adc $1e                         ; first byte is counter
                  sta $0d                         ;
                  bcc _ChkEnd                     ; 
                  inc $0e                         ;
                  
_ChkEnd           lda $0e                         ; 
                  cmp #$3f                        ; max 3fff
                  bcc _GetData                    ; 
                  
                  lda #$0d                        ; 
                  jsr OutTheBest                  ; 
                  
StartGraficOutX   jmp Wait4User                   ; WaitSomeTime
; ------------------------------------------------------------------------------------------------------------- ;
IRQ_PlaySounds    ldx LR_PtrTuneToPlay
                  cpx LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  beq IRQ_SoundsReset             ; all tunes completed
                  
                  lda #$11                        ; triangle wave/start ADS
                  sta LR_WaveVoice2
                  sta LR_WaveVoice3
                  lda LR_TuneSuReVol,x            ; tune s/r/volume  (not used)
                  lda #$f0
                  and LR_Volume
                  sta SUREL2                      ; SID - $D40D = Oscillator 2 Sustain/Release
                  sta SUREL3                      ; SID - $D414 = Oscillator 3 Sustain/Release
                  lda LR_TuneDataPtrV2,x          ; tab tune data pointer voice 2
                  bne _Voice02
                  
                  sta LR_WaveVoice2
_Voice02          tay
                  lda TabVocsFreqDatLo,y
                  sta FRELO2                      ; SID - $D407 = Oscillator 2 Frequency Control (Low Byte)
                  lda TabVocsFreqDatHi,y
                  sta FREHI2                      ; SID - $D408 = Oscillator 2 Frequency Control (High Byte)
                  lda LR_TuneDataPtrV3,x          ; tab tune data pointer voice 3
                  bpl _ChkVoice03
                  
                  lda LR_TuneDataPtrV2,x          ; tab tune data pointer voice 2
                  tay
                  sec
                  lda TabVocsFreqDatLo,y
                  sbc #$80
                  sta FRELO3                      ; SID - $D40E = Oscillator 3 Frequency Control (Low Byte)
                  lda TabVocsFreqDatHi,y
                  sbc #$00
                  sta FREHI3                      ; SID - $D40F = Oscillator 3 Frequency Control (High Byte)
                  jmp _PlayTune
                  
_ChkVoice03       bne _Voice03
                  
                  sta LR_WaveVoice3
_Voice03          tay
                  lda TabVocsFreqDatLo,y
                  sta FRELO3                      ; SID - $D40E = Oscillator 3 Frequency Control (Low Byte)
                  lda TabVocsFreqDatHi,y
                  sta FREHI3                      ; SID - $D40F = Oscillator 3 Frequency Control (High Byte)
_PlayTune         lda LR_WaveVoice2
                  sta VCREG2                      ; SID - $D40B = Oscillator 2 Control
                  lda LR_WaveVoice3
                  sta VCREG3                      ; SID - $D412 = Oscillator 3 Control
_DecTime          dec LR_TunePlayTime,x           ; tab tune times
                  bne IRQ_PlaySoundsX             ; not completed yet
                  
                  inc LR_PtrTuneToPlay            ; next tune to play
                  
IRQ_PlaySoundsX   rts
; ------------------------------------------------------------------------------------------------------------- ;
IRQ_SoundsReset   lda #$00
                  sta VCREG2                      ; SID - $D40B = Oscillator 2 Control
                  sta VCREG3                      ; SID - $D412 = Oscillator 3 Control
                  
IRQ_SoundsResetX  rts
; ------------------------------------------------------------------------------------------------------------- ;
SetTune           pla                             ; played during IRQ
                  sta $7d
                  pla
                  sta $7e                         ; ($7d/$7e) ptr melody data
                  bne _SetNext
                  
_CpyTune          sei
                  
                  ldy #$00
                  lda ($7d),y
                  beq _PrepareXit
                  
                  ldx LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  sta LR_TunePlayTime,x           ; tab tune times
                  iny
                  lda ($7d),y
                  sta LR_TuneDataPtrV2,x          ; tab tune data pointer voice 2
                  iny
                  lda ($7d),y
                  sta LR_TuneDataPtrV3,x          ; tab tune data pointer voice 3
                  iny
                  lda ($7d),y
                  sta LR_TuneSuReVol,x            ; tune s/r/volume  (not used)
                  inc LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  lda $7d
                  clc
                  adc #$04                        ; tune entry length $04
                  sta $7d
                  lda $7e
                  adc #$00
                  sta $7e
                  bne _CpyTune
                  
_SetNext          inc $7d
                  bne _CpyTune
                  inc $7e
                  bne _CpyTune
                  
_PrepareXit       lda $7e                         ; point behind melody data
                  pha
                  lda $7d
                  pha
                  
                  cli
                  
SetTuneX          rts
; ------------------------------------------------------------------------------------------------------------- ;
Randomizer        sta LR_RandomAc                 ; save accumulator
_GetBeam          lda RASTER                      ; VIC 2 - $D012 = Read: Raster Scan Line/ Write: Line for Raster IRQ
                  sta LR_RasterBeamPos
                  cpx LR_RasterBeamPos
                  bcc _ChkBeam
                  beq _ChkBeam
                  jmp _GetBeam
                  
_ChkBeam          cpy LR_RasterBeamPos
                  bcc _GetBeam
                  
                  sec
                  sbc LR_Random
                  bcs _ChkAc
                  
                  eor #$ff
                  adc #$01
_ChkAc            cmp LR_RandomAc
                  bcc _GetBeam
                  
                  lda LR_RasterBeamPos
                  sta LR_Random
                  
RandomizerX       rts
; ------------------------------------------------------------------------------------------------------------- ;
MelodyInit        lda MelodyMaxNo
                  sta LR_MelodyNo
                  lda MelodyMinHight
                  sta LR_MelodyHeight
                  
MelodyInitX       rts
; ------------------------------------------------------------------------------------------------------------- ;
; SetNextMelody   Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
SetNextMelody     dec LR_MelodyNo                 ; $00-$09
                  bpl SetNextMelodyX              ; 
                  
                  inc LR_MelodyHeight             ; $02-$0b
                  lda LR_MelodyHeight             ; 
                  cmp MelodyMaxHight              ; 
                  bcc _GetMax                     ;
                  
                  lda MelodyMinHight              ; 
                  sta LR_MelodyHeight             ; 

_GetMax           lda MelodyMaxNo                 ; 
                  sta LR_MelodyNo                 ; $00-$09

SetNextMelodyX    rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
VictoryTuneCopy   lda LR_MelodyNo                 ; $00-$09
                  asl a                           ; *2
                  tax                             ;
                  lda TabMelodyPtr,x              ;
                  sta $7d                         ; lrzLoSoundFrom
                  lda TabMelodyPtr+1,x            ;
                  sta $7e                         ; ($7d/$7e) -> melody data
                  
_CpyTune          sei                             ; 

                  ldy #$00                        ;
                  lda ($7d),y                     ; lrzVecSoundFrom
                  beq _PrepXit                    ; 
                  
                  ldx LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  sta LR_TunePlayTime,x           ; SoundStack0 - score duration
                  iny                             ;
                  lda ($7d),y                     ; lrzVecSoundFrom
                  beq _Voice01                    ; 
                  
                  clc                             ;
                  adc LR_MelodyHeight             ; 
_Voice01          sta LR_TuneDataPtrV2,x          ; 
                  iny                             ;
                  lda ($7d),y                     ; lrzVecSoundFrom
                  beq _Voice02                    ;
                  bmi _Voice02                    ; 
                  
                  clc                             ;
                  adc LR_MelodyHeight             ; lrMelodyAdd (02-0b)
_Voice02          sta LR_TuneDataPtrV3,x          ;       <cvtStoreC2>
                  iny                             ;
                  lda ($7d),y                     ; lrzVecSoundFrom
                  sta LR_TuneSuReVol,x            ;       <cvtStoreC3>
                  inc LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  
_SetPointer       lda $7d                         ; get next 4 bytes
                  clc                             ;
                  adc #$04                        ;
                  sta $7d                         ; 
                  lda $7e                         ; 
                  adc #$00                        ;
                  sta $7e                         ; 
                  bne _CpyTune                    ; always
                  
_PrepXit          cli                             ; 

VictoryTuneCopyX  rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
IRQ               inc LR_CountIRQs                ; 

                  lda #$00                        ;
                  sta $7c                         ; tune value voice 1
                  lda LR_Volume                   ; 
                  and #$0f                        ;
                  sta SIGVOL                      ; SID - $D418 = Volume and Filter Select
                  lda LR_FallsDown                ; $00=fall $20=no fall $ff=init
                  bne _BeepInit                   ;
                  
                  ldx LR_FallBeep                 ; 
                  stx $7c                         ; tune value voice 1
                  jmp _ChkShoot                   ;
                  
_BeepInit         lda #LR_FallBeepIni             ; 
                  sta LR_FallBeep                 ; 
                  
_ChkShoot         lda LR_Shoots                   ; $00=no  $01=shoot right  $ff=shoot left
                  beq _ShootInit                  ;
                  
                  lda LR_ShootSound               ;
                  sec                             ;
                  sbc #LR_ShootSoundSub           ;
                  sta LR_ShootSound               ;
                  sta $7c                         ; tune value voice 1
                  beq _ShootInit                  ;
                  
                  jmp _ChkDeath                   ;
                  
_ShootInit        lda #LR_ShootSoundIni           ; 
                  sta LR_ShootSound               ;

_ChkDeath         lda LR_DeathTune                ; 
                  beq _SetTune                    ;
                  
                  sec                             ;
                  sbc #$04                        ;
                  sta $7c                         ; tune value voice 1
                  sta LR_DeathTune                ; 
                  
_SetTune          lda $7c                         ; tune value voice 1
                  sta FREHI1                      ; SID - $D401 = Oscillator 1 Frequency Control (High Byte)
                  jsr IRQ_PlaySounds              ; 
                  
                  lda $c5                         ; key value
                  bne _ChkKey                     ;
                  
                  lda #$07                        ;
_ChkKey           cmp #$40                        ; no key pressed
                  bne _ChkKeyFlag                 ;
                  
                  lda #$00                        ; 
                  sta LR_KeyOld                   ; set no key
                  jmp C64_IRQ                     ; continue sytem IRQ
                  
_ChkKeyFlag       pha                             ; 
                  lda C64_KeyFlag                 ;
                  and #$04                        ;
                  tax                             ;
                  pla                             ;
                  cpx #$04                        ;
                  bne _ChkKeyOld                  ;
                  
                  ora #$80                        ;
_ChkKeyOld        cmp LR_KeyOld                   ; 
                  beq IRQ_X                       ;
                  
                  sta LR_KeyOld                   ; 
                  sta LR_KeyNew                   ; 
IRQ_X             jmp C64_IRQ                     ; continue sytem IRQ
; ------------------------------------------------------------------------------------------------------------- ;
ColdStartInit     lda $01                         ; 
                  and #$fe                        ; basic off
                  sta $01                         ;
                  
                  lda #$00                        ;
                  sta $1e                         ;
                  lda #$00                        ;
                  sta $1f                         ;
                  
                  ldy #$00                        ;
                  lda #$19                        ; 25
                  sta CR_Work                     ;
_GetAmount        ldx #$08                        ;
_GetValue         lda $1f                         ;
                  sta LR_TabOffHiresHi,y          ; offset grafic output high
                  lda $1e                         ;
                  sta LR_TabOffHiresLo,y          ; offset grafic output low
                  inc $1e                         ;
                  iny                             ;
                  dex                             ;
                  bne _GetValue                   ;
                  
                  clc                             ;
                  adc #$39                        ;
                  sta $1e                         ;
                  lda $1f                         ;
                  adc #$01                        ;
                  sta $1f                         ;
                  
                  dec CR_Work                     ;
                  bne _GetAmount                  ;
                  
                  lda #<NMI                       ;
                  sta C64_PtrNMI                  ;
                  lda #>NMI                       ;
                  sta C64_PtrNMI+1                ; point NMI vector to rti
                  
                  jsr ClearHiresDisp              ; 
                  
                  lda #BLACK                      ; 
                  sta BGCOL0                      ; VIC 2 - $D021 = BackGround Color 0
                  sta EXTCOL                      ; VIC 2 - $D020 = Border Color

                  sei                             ;

                  lda #<IRQ                       ;
                  sta C64_PtrIRQ                  ;
                  lda #>IRQ                       ;
                  sta C64_PtrIRQ+1                ; irq vector

                  cli                             ;

                  lda #$b0                        ;
                  sta SUREL1                      ; SID - $D406 = Oscillator 1 Sustain/Release
                  lda #$11                        ;
                  sta VCREG1                      ; SID - $D404 = Oscillator 1 Control

                  ldx #$30                        ; $30*$40=$0c00
                  stx LR_SpritePtr00              ; sprite 0 data at $0c00
                  inx                             ;
                  stx LR_SpritePtr02              ; sprite 2 data at $0c40
                  inx                             ;
                  stx LR_SpritePtr03              ; sprite 3 data at $0c80
                  inx                             ;
                  stx LR_SpritePtr04              ; sprite 4 data at $0cc0
                  inx                             ;
                  stx LR_SpritePtr06              ; sprite 6 data at $0d00
                  inx                             ;
                  stx LR_SpritePtr07              ; sprite 7 data at $0d40
                  
                  lda #$00                        ;
                  sta SPBGPR                      ; VIC 2 - $D01B = Sprite to Foreground Priority
                  tay                             ;
_ClearZP          sta $0002,y                     ;
                  sta LR_SpriteStore01,y          ;
                  sta LR_SpriteStore02,y          ;
                  iny                             ;
                  bne _ClearZP                    ;
                  
                  lda #$ff                        ;
                  sta SPENA                       ; VIC 2 - $D015 = Sprite Enable
                  lda #CYAN                       ;
; ------------------------------------------------------------------------------------------------------------- ;
ColorSprites      ldy #$07                        ;       <csiSpriteColor>
_SetSpriteColor   sta SP0COL,y                    ; VIC 2 - $D027 - Color Sprite 0      <csiSpriteColors>
                  dey                             ;
                  bne _SetSpriteColor             ; 
                  
                  iny                             ; always a white lode runner
                  sty SP0COL                      ; VIC 2 - $D027 - Color Sprite 0
                  
ColorSpritesX     rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
ColourLevel       sta __ModColor                  ; ac contains colours ac=color1 and color 2 <SetMultiColours>

                  lda SCROLX                      ; VIC 2 - $D016 = Control Register 2 (and Horizontal Fine Scrolling)
                  ora #$10                        ; set multicolour bitmapping mode
                  sta SCROLX                      ; VIC 2 - $D016 = Control Register 2 (and Horizontal Fine Scrolling)
                  
                  ldy #$00                        ;
_GetColor         lda #LR_OrangeBlue              ; modified by ac value
__ModColor        = *-1
                  sta LR_ScrnMultColor,y          ; screen - colours 1 & 2
                  sta LR_ScrnMultColor+$0100,y    ;
                  sta LR_ScrnMultColor+$0200,y    ;
                  sta LR_ScrnMultColor+$02f8,y    ;
                  lda #WHITE                      ; 
                  sta COLORAM,y                   ; colour ram - colour 3
                  sta COLORAM+$0100,y             ;
                  sta COLORAM+$0200,y             ;
                  sta COLORAM+$0300,y             ;
                  dey                             ;
                  bne _GetColor                   ;
                  
ColourLevelX      rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
NMI               rti                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TabEnmyEnab       .byte $01 ; .......#
                  .byte $05 ; .....#.#
                  .byte $0d ; ....##.#
                  .byte $1d ; ...###.#
                  .byte $5d ; .#.###.#
                  .byte $dd ; ##.###.#
; ------------------------------------------------------------------------------------------------------------- ;
ShowSaveList      lda #>LR_ScrnHiReDisp           ; 
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  
                  lda #LR_LevelDiskSavL           ; 155 - (t=$0c s=$0b) containes the saved game entry list
                  sta LR_LevelNoDisk              ; 000-049
                  
                  lda #CR_SavListIdLen            ;
                  sta CR_InputBufMax              ;
                  
                  lda #$02                        ;
                  sta LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  
                  lda #LR_DiskRead                ;
                  jsr ControlDiskOper             ; ac: $01=load $02=store
                  jsr CheckSaveList               ; check "BJB" id - clear data otherwise
                  jsr ClearHiresDisp              ; 
                  
                  lda #LR_YellowCyan              ;
                  jsr ColourLevel                 ; 
                  
                  lda #$00                        ;
                  sta $4f                         ; screen col ($00 - $1b)
                  lda #$04                        ;
                  sta $50                         ; screen row ($00 - $0f)
                  jsr TextOut                     ; TextOut
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $ce ; N
                  .byte $c1 ; A
                  .byte $cd ; M
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $cc ; L
                  .byte $a0 ; <blank>
                  .byte $cd ; M
                  .byte $c5 ; E
                  .byte $ce ; N
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $d3 ; S
                  .byte $c3 ; C
                  .byte $cf ; O
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $8d ; <newline>
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $a0 ; <blank>
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $a0 ; <blank>
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $a0 ; <blank>
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $8d ; <newline>
                  .byte $00 ; EndOfText
                  
                  ldy #$00                        ;
                  sty $1c                         ; ptr save game data

_SaveNameOutI     lda #CR_SavListIdLen            ;
                  sta $1d                         ; name length
                  
_SaveNameOut      ldy $1c                         ; ptr save game data
                  lda CR_SavList,y                ;
                  jsr PrepareChrOut               ;
                  
                  inc $1c                         ; ptr save game data
                  dec $1d                         ; name length
                  bne _SaveNameOut                ;
                  
_PosLevel         inc $4f                         ; screen col ($00 - $1b)
                  inc $4f                         ; screen col ($00 - $1b)
                  ldy $1c                         ; get ptr save game data
                  inc $1c                         ; set ptr save game data
                  inc $1c                         ; 
                  
_GetLevel         lda CR_SavList,y                ;
                  cmp #$a0                        ; <blank>
                  bne _OutLevel                   ;
                  
                  jmp _SetNextEntry               ;
                  
_OutLevel         jsr ConvertHex2Dec              ; Hex2Dec  (1307=100 1308=10 1309=1)

                  lda LR_Digit100                 ; lrDec100
                  jsr PrepareDigitOut             ; Digits2Screen
                  lda LR_Digit10                  ; lrDec10
                  jsr PrepareDigitOut             ; Digits2Screen
                  lda LR_Digit1                   ; lrDec1
                  jsr PrepareDigitOut             ; Digits2Screen
                  
_PosMen           inc $4f                         ; screen col ($00 - $1b)
                  inc $4f                         ; screen col ($00 - $1b)
                  ldy $1c                         ; get ptr save game data
                  inc $1c                         ; set ptr save game data
                  
_GetMen           lda CR_SavList,y                ;
                  jsr ConvertHex2Dec              ; Hex2Dec  (1307=100 1308=10 1309=1)
                  
_OutMen           lda LR_Digit100                 ; lrDec100
                  jsr PrepareDigitOut             ; Digits2Screen
                  lda LR_Digit10                  ; lrDec10
                  jsr PrepareDigitOut             ; Digits2Screen
                  lda LR_Digit1                   ; lrDec1
                  jsr PrepareDigitOut             ; Digits2Screen
 
_PosScore         inc $4f                         ; screen col ($00 - $1b)
                  ldy $1c                         ; get ptr save game data
                  inc $1c                         ; set ptr save game data
 
_GetScore         lda CR_SavList,y                ;
                  jsr SplitScoreOut               ;
                  
                  ldy $1c                         ; get ptr save game data
                  inc $1c                         ; set ptr save game data
                  lda CR_SavList,y                ;
                  jsr SplitScoreOut               ;
                  
                  ldy $1c                         ; get ptr save game data
                  inc $1c                         ; set ptr save game data
                  lda CR_SavList,y                ;
                  jsr SplitScoreOut               ;
                  
                  ldy $1c                         ; get ptr save game data
                  lda CR_SavList,y                ;
                  jsr SplitScoreOut               ;
                  
_SetNewRow        lda #$8d                        ; <newline>
                  jsr PrepareChrOut               ;
                  
_SetNextEntry     lda $1c                         ; get ptr save game data
                  and #$f0                        ;
                  clc                             ;
                  adc #$10                        ;
                  sta $1c                         ; set ptr save game data to next entry

_ChkMax           cmp #$a0                        ; maxiumum reached - $09*10
                  beq ShowSaveListX               ;
                  
_GoNextRow        jmp _SaveNameOutI               ;
                  
ShowSaveListX     rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
SaveGame          jsr LoadScoreBlock              ; 
                  bcs ShowSaveListX               ; bad
                  
                  jsr ChkUniquePlayId             ; 
                  
                  lda LR_LevelNoDisk              ; 000-049
                  sta CR_SaveNoDisk               ;
                  
_GoShowSaveList   jsr ShowSaveList                ; 

                  lda #>LR_ScrnHiReDisp           ;
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  jsr BaseLines                   ; 
                  
_TitleLine        lda #$00                        ;
                  sta $50                         ; screen row ($00 - $0f)
                  sta $4f                         ; screen col ($00 - $1b)
                  jsr TextOut                     ; TextOut
                  .byte $a0 ; <blank>
                  .byte $d3 ; S
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $d4 ; T
                  .byte $cf ; O
                  .byte $a0 ; <blank>
                  .byte $d3 ; S
                  .byte $c1 ; A
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $c7 ; G
                  .byte $c1 ; A
                  .byte $cd ; M
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $c9 ; I
                  .byte $ce ; N
                  .byte $a0 ; <blank>
                  .byte $d0 ; P
                  .byte $d2 ; R
                  .byte $cf ; O
                  .byte $c7 ; G
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $d3 ; S
                  .byte $d3 ; S
                  .byte $8d ; <newline>
                  .byte $a0 ; <blank>
                  .byte $c4 ; D
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $d4 ; T
                  .byte $cf ; O
                  .byte $a0 ; <blank>
                  .byte $c4 ; D
                  .byte $c5 ; E
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $d4 ; T
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $ce ; N
                  .byte $a0 ; <blank>
                  .byte $c5 ; E
                  .byte $ce ; N
                  .byte $d4 ; T
                  .byte $d2 ; R
                  .byte $d9 ; Y
                  .byte $a0 ; <blank>
                  .byte $c2 ; B
                  .byte $c5 ; E
                  .byte $cc ; L
                  .byte $cf ; O
                  .byte $d7 ; W
                  .byte $8d ; <newline>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $bc ; <
                  .byte $d2 ; R
                  .byte $af ; /
                  .byte $d3 ; S
                  .byte $be ; >
                  .byte $a0 ; <blank>
                  .byte $d4 ; T
                  .byte $cf ; O
                  .byte $a0 ; <blank>
                  .byte $c3 ; C
                  .byte $cf ; O
                  .byte $ce ; N
                  .byte $d4 ; T
                  .byte $c9 ; I
                  .byte $ce ; N
                  .byte $d5 ; U
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $c7 ; G
                  .byte $c1 ; A
                  .byte $cd ; M
                  .byte $c5 ; E
                  .byte $00 ; EndOfText
                  
                  lda #$00                        ;
                  sta LR_KeyNew                   ; 
                  jsr WaitKeyBlink                ;
                  
                  ldx #$00                        ;
                  stx LR_KeyNew                   ; discard key pressed
                  
_Chk_s            cmp #$0d                        ; "s"
                  bne _Chk_D                      ;
                  
                  jmp _SaveNew                    ;
                  
_Chk_d            cmp #$12                        ; "d"
                  beq _DeleteOld                  ;
                  
                  cmp #$3f                        ; RUN/STOP
                  bne _BadKey                     ;
                  
_Abort            jmp _RestartLevelOne            ; 
                  
_BadKey           jsr Beep                        ; 
                  jmp _TitleLine                  ; start over
                  
_DeleteOld        lda #$00                        ; 
                  sta $50                         ; screen row ($00 - $0f)
                  sta $4f                         ; screen col ($00 - $1b)
                  jsr TextOut                     ; TextOut
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $c4 ; D
                  .byte $c5 ; E
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $d4 ; T
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $ce ; N
                  .byte $a0 ; <blank>
                  .byte $c5 ; E
                  .byte $ce ; N
                  .byte $d4 ; T
                  .byte $d2 ; R
                  .byte $d9 ; Y
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $8d ; <newline>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $ce ; N
                  .byte $c1 ; A
                  .byte $cd ; M
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $be ; >
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $bc ; <
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $8d ; <newline>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $bc ; <
                  .byte $d2 ; R
                  .byte $af ; /
                  .byte $d3 ; S
                  .byte $be ; >
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $d4 ; T
                  .byte $cf ; O
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $c2 ; B
                  .byte $cf ; O
                  .byte $d2 ; R
                  .byte $d4 ; T
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $00 ; EndOfText
                  
_SetNameSpace     dec $50                         ; screen row ($00 - $0f)
                  lda #CR_DelSavColName           ;
                  sta $4f                         ; screen col ($00 - $1b)
                  
                  jsr InputControl                ; get a name
                  jsr DelSaveListLine             ; 
                  cpx #$00                        ; 
                  beq _RestartList                ;
                  
_ShowList         jmp _GoShowSaveList             ;
                  
_RestartList      jmp _TitleLine                  ; 

_SaveNew          lda #$00                        ; 
                  sta $50                         ; screen row ($00 - $0f)
                  sta $4f                         ; screen col ($00 - $1b)
                  jsr TextOut                     ; TextOut
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $d3 ; S
                  .byte $c1 ; A
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $a0 ; <newline>
                  .byte $c7 ; G
                  .byte $c1 ; A
                  .byte $cd ; M
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $c9 ; I
                  .byte $ce ; N
                  .byte $a0 ; <blank>
                  .byte $d0 ; P
                  .byte $d2 ; R
                  .byte $cf ; O
                  .byte $c7 ; G
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $d3 ; S
                  .byte $d3 ; S
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $8d ; <newline>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $ce ; N
                  .byte $c1 ; A
                  .byte $cd ; M
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $be ; >
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $bc ; <
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $8d ; <newline>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $bc ; <
                  .byte $d2 ; R
                  .byte $af ; /
                  .byte $d3 ; S
                  .byte $be ; >
                  .byte $a0 ; <blank>
                  .byte $d4 ; T
                  .byte $cf ; O
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $c2 ; B
                  .byte $cf ; O
                  .byte $d2 ; R
                  .byte $d4 ; T
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $00 ; EndOfText
                  
                  dec $50                         ; screen row ($00 - $0f)
                  lda #$0b                        ;
                  sta $4f                         ; screen col ($00 - $1b)
                  
                  jsr InputControl                ;
                  beq _GoTitleLine                ; no name entered or run/stop
                  
                  jsr LookupSaveList              ; carry_clear=name not in list  carry_set=name in list
                  bcs _FillEntry                  ; name found in list - overwrite
                  
                  jsr FindFreeEntry               ;
                  bcs _FillEntry                  ; found
                  
                  jsr Beep                        ; save game list full
                  jsr Beep                        ; 
_GoTitleLine      jmp _TitleLine                  ;

_FillEntry        tay                             ; 
                  ldx #$00                        ;
_CpyName          lda CR_InputBuf,x               ;
                  sta CR_SavList,y                ;
                  iny                             ;
                  inx                             ;
                  cpx #$08                        ;
                  bcc _CpyName                    ;
                  
_CpyLevel         lda LR_LevelNoGame              ; 001-050
                  sta CR_SavList,y                ;
                  
_CpySavLevel      iny                             ;
                  lda CR_SaveNoDisk               ;
                  sta CR_SavList,y                ;
                  
_CpyLives         iny                             ;
                  lda LR_NumLives                 ; lrNumLives
                  sta CR_SavList,y                ;
                  
_CpyScore         iny                             ;
                  lda LR_ScoreHi                  ; lrScoreHigh
                  sta CR_SavList,y                ;
                  iny                             ;
                  lda LR_ScoreMidHi               ; lrScoreMidHigh
                  sta CR_SavList,y                ;
                  iny                             ;
                  lda LR_ScoreMidLo               ; lrScoreMidLow
                  sta CR_SavList,y                ;
                  iny                             ;
                  lda LR_ScoreLo                  ; lrScoreLow
                  sta CR_SavList,y                ;

                  jsr ChkUniquePlayId             ; 
                  
                  lda #LR_DiskWrite               ;
                  jsr ControlDiskOper             ; ac: $01=load $02=store
                  jsr ShowSaveList                ;
                  
                  lsr LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  
                  jmp Wait4User                   ; WaitSomeTime

_RestartLevelOne  jsr ClearHiresDisp              ; ClearDisplay20
                  lda CR_LevelColor               ; 
                  jsr ColourLevel                 ; 
                  jsr BaseLines                   ; 
                  
                  lda #$00                        ;
                  sta CR_NoFunction               ;
                  lda CR_SaveNoDisk               ;
                  sta LR_LevelNoDisk              ; 000-049
                  
                  lda #$ff                        ;
                  sta LR_LvlReload                ; 000-049 - force level reload from disk if <> LR_LevelNoDisk

SaveGameX         jmp LevelStart                  ; StartNewLevel
; ------------------------------------------------------------------------------------------------------------- ;
DelSaveListLine   jsr LookupSaveList              ; carry_clear=name not in list  carry_set=name in list
                  bcc _BeepBeep                   ; entry not found
                  
                  tay                             ; name position
_MoveUp           lda CR_SavList + CR_SavListRowLen,y  ;
                  sta CR_SavList,y                ; overwrite entry found - move the whole list ome pos up = delete
                  iny                             ;
                  cpy #$a0                        ;
                  bcc _MoveUp                     ;
                  
                  jsr ChkUniquePlayId             ; 
                  
                  lda #LR_DiskWrite               ;
_Write            jsr ControlDiskOper             ; ac: $01=load $02=store
                  
                  clc                             ;
                  rts                             ;

_BeepBeep         jsr Beep                        ;
                  jsr Beep                        ;
                  
                  clc                             ;
DelSaveListLineX  rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
InputControl      lda #$c0                        ;
InputControlSpec  sta CR_InputControl             ; highscores/register

                  ldx #CR_InputBufLen             ; length
                  lda #$a0                        ; <blank>
_ClrInputBuffer   sta CR_InputBuf,x               ;
                  dex                             ;
                  bpl _ClrInputBuffer             ;
                  
                  inx                             ; $00
                  stx CR_InputBufPtr              ;
                  stx LR_KeyNew                   ; 
                  
_OutWaitKey       ldx CR_InputBufPtr              ; 
                  lda CR_InputBuf,x               ;
                  jsr GetChrSubst                 ;
                  jsr WaitKeyBlink                ;
                  
                  ldx #$00                        ;
                  stx LR_KeyNew                   ; reset
                  
_Chk_RS           cmp #$3f                        ; RUN/STOP
                  beq _RetBad                     ;
                  
                  jsr GetKeySubst                 ;
                  
                  bit CR_InputControl             ;
                  bpl _Chk_Return                 ; no serial number
                  
                  cmp #$b0                        ; lower key "0"
                  bcc _Chk_Return                 ;
                                                  ; handle $b0 - $b9 = key 0-9
                  cmp #$ba                        ; lower key "9"
                  bcc _Store                      ;
                  
_Chk_Return       cmp #$8d                        ; <return> - end of edit
                  beq _Return                     ;
                  
_Chk_Up           cmp #$88                        ; <cursor up/down>
                  beq _CurUp                      ;
                  
_Chk_Right        cmp #$95                        ; <cursor left/right>
                  beq _CurRight                   ;
                  
_Chk_Blank        cmp #$a0                        ; <blank>
                  beq _Store                      ;
                  
                  bit CR_InputControl             ;
                  bvc _BeepBeep                   ;
                  
_Chk_Dot          cmp #$ae                        ; "."
                  beq _Store                      ;
                  
_Chk_A            cmp #$c1                        ; "A"
                  bcc _BeepBeep                   ;
                  
                  cmp #$db                        ; "Z" + 1
_Chk_Z            bcs _BeepBeep                   ;

_Store            ldx CR_InputBufPtr              ;
                  sta CR_InputBuf,x               ;
                  jsr PrepareChrOut               ;
                  
                  inc CR_InputBufPtr              ;
                  lda CR_InputBufPtr              ;
                  cmp CR_InputBufMax              ;
                  bcc _OutWaitKey                 ;
                  
                  dec CR_InputBufPtr              ;
                  dec $4f                         ; screen col ($00 - $1b)
                  jmp _OutWaitKey                 ;
                  
_Return           ldx CR_InputBufMax              ; 
_ChkBlanks        lda CR_InputBuf,x               ; 
                  cmp #$a0                        ;
                  bne _RetGood                    ;
                  
                  dex                             ;
                  bpl _ChkBlanks                  ; 
                  
_RetBad           sec                             ; <blank> name entry or RUN/STOP
                  ldx #$00                        ;
                  rts                             ;
                  
_RetGood          sec                             ;
                  ldx #$01                        ;
                  rts                             ;
                  
_CurUp            dec $4f                         ; screen col ($00 - $1b)
                  dec CR_InputBufPtr              ;
                  bpl _OutWaitKey                 ;
                  
                  inc $4f                         ; screen col ($00 - $1b)
                  inc CR_InputBufPtr              ;
                  jmp _BeepBeep                   ;
                  
_CurRight         ldx CR_InputBufPtr              ; 
                  inx                             ;
                  cpx CR_InputBufMax              ;
                  bcs _BeepBeep                   ;
                  
                  inc $4f                         ; screen col ($00 - $1b)
                  inc CR_InputBufPtr              ;
                  jmp _OutWaitKey                 ;
                  
_BeepBeep         jsr Beep                        ; 
                  jsr Beep                        ;
                  jmp _OutWaitKey                 ;
InputControlX     = *                             ;
; ------------------------------------------------------------------------------------------------------------- ;
LookupSaveList    ldy #$00                        ; carry_clear=name not in list  carry_set=name in list ac=position
_ChkEntryI        ldx #$00                        ;
_ChkEntry         lda CR_SavList,y                ;
                  cmp CR_InputBuf,x               ;
                  bne _Differs                    ;
                  
                  iny                             ;
                  inx                             ;
                  cpx #CR_SavListIdLen            ;
                  bne _ChkEntry                   ;
                  
_Same             tya                             ; save name already existing
                  and #$f0                        ;
                  sec                             ; save name found and can be replaced
                  rts                             ;

_Differs          tya                             ; actual save name differs from entered name so check next entry
                  and #$f0                        ;
                  clc                             ;
                  adc #CR_SavListRowLen           ;
                  
                  tay                             ;
                  cmp #CR_SavListMaxLen           ;
_ChkNext          bne _ChkEntryI                  ;
                  
                  clc                             ; new save name
LookupSaveListX   rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
FindFreeEntry     ldy #$00                        ; carry_clear=list full  carry_set=free entry found  ac=position
_ChkEntryI        ldx #CR_SavListIdLen            ; 
                  lda #$a0                        ; <blank>
_ChkEntry         cmp LR_LvlDataSavLod,y          ;
                  bne _SetNextEntry               ;
                  
                  iny                             ;
                  dex                             ;
                  bne _ChkEntry                   ;
                  
_FreeEntry        tya                             ;
                  and #$f0                        ;
                  sec                             ;
                  rts                             ;
                  
_SetNextEntry     tya                             ;
                  and #$f0                        ;
                  clc                             ;
                  adc #CR_SavListRowLen           ;
                  tay                             ;
                  cmp #CR_SavListMaxLen           ; 
                  bne _ChkEntryI                  ;
                  
_ListFull         clc                             ;
                  rts                             ;

PrepWait4User     lsr LR_GameCtrl                 ; $00=Init $01=demo $02=play

FindFreeEntryX    jmp Wait4User                   ; WaitSomeTime
; ------------------------------------------------------------------------------------------------------------- ;
LoadGame          jsr LoadScoreBlock              ; 
                  bcs PrepWait4User               ;
                  
                  lda #$02                        ;
                  sta LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  
                  jsr SetUniquePlayId             ; SetUniquePlayId
                  jsr ShowSaveList                ;
                  
                  lda #$00                        ;
                  sta $4f                         ; screen col ($00 - $1b)
                  sta $50                         ; screen row ($00 - $0f)
                  jsr TextOut                     ; TextOut
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $cc ; L
                  .byte $cf ; O
                  .byte $c1 ; A
                  .byte $c4 ; D
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $ce ; N
                  .byte $c4 ; D
                  .byte $a0 ; <blank>
                  .byte $d0 ; P
                  .byte $cc ; L
                  .byte $c1 ; A
                  .byte $d9 ; Y
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $a0 ; <blank>
                  .byte $c7 ; G
                  .byte $c1 ; A
                  .byte $cd ; M
                  .byte $c5 ; E
                  .byte $8d ; <newline>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $ce ; N
                  .byte $c1 ; A
                  .byte $cd ; M
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $be ; <
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $bc ; >
                  .byte $8d ; <newline>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $bc ; <
                  .byte $d2 ; R
                  .byte $af ; /
                  .byte $d3 ; S
                  .byte $be ; >
                  .byte $a0 ; <blank>
                  .byte $d4 ; T
                  .byte $cf ; O
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $c2 ; B
                  .byte $cf ; O
                  .byte $d2 ; R
                  .byte $d4 ; T
                  .byte $00 ; <newline>
                  
                  lda #CR_DelSavColName-1         ; 
                  dec $50                         ; screen row ($00 - $0f)
                  sta $4f                         ; screen col ($00 - $1b)
                  
                  jsr InputControl                ;
                  bcc LoadGame                    ; 
                  beq PrepWait4User               ; 

                  jsr LookupSaveList              ; carry_clear=name not in list  carry_set=name in list
                  bcs _SetEntry                   ; name found in list

                  jsr Beep                        ; 
                  jsr Beep                        ;
                  jmp LoadGame                    ; 
                  
_SetEntry         clc                             ; name length
                  adc #CR_SavListIdLen            ; point behind entry name

                  tay                             ;
_GetLevel         lda CR_SavListLevelG - CR_SavListIdLen,y ; game level
                  sta LR_LevelNoGame              ; 001-050
                  
                  lda CR_SavListLevelD - CR_SavListIdLen,y ; disk level
                  pha                             ; save CR_SavListLevelD because of a later list rewrite
                  
_GetLives         lda CR_SavListLives  - CR_SavListIdLen,y
                  sta LR_NumLives                 ; lrNumLives
                  
_DecLives         sec                             ; discount a live whith any load
                  sbc #$01                        ;
                  sta CR_SavListLives  - CR_SavListIdLen,y
                  
                  lda CR_SavListScHi   - CR_SavListIdLen,y
                  sta LR_ScoreHi                  ; lrScoreHigh
                  lda CR_SavListScMiHi - CR_SavListIdLen,y
                  sta LR_ScoreMidHi               ; lrScoreMidHigh
                  lda CR_SavListScMiLo - CR_SavListIdLen,y
                  sta LR_ScoreMidLo               ; lrScoreMidLow
                  lda CR_SavListScLo   - CR_SavListIdLen,y
                  sta LR_ScoreLo                  ; lrScoreLow
                  
                  lda LR_NumLives                 ; lrNumLives
                  cmp #$01                        ; last life
                  bne _ReinitGame                 ; no - keep entry
                  
                  jsr DelSaveListLine             ; yes - delete entry
                  
_ReinitGame       jsr ChkUniquePlayId             ; ChkUniquePlayId

                  lda #LR_DiskWrite               ;
                  jsr ControlDiskOper             ; ac: $01=load $02=store
                  
                  jsr ClearHiresDisp              ; ClearDisplay20
                  jsr ClearHiresPrep              ; ClearDisplay40
                  
                  pla                             ; restore CR_SavListLevelD
                  sta LR_LevelNoDisk              ; 000-049
                  jsr SetNewColors                ; SetNewColors (new colors any 10th level)
                  
                  lda CR_LevelColor               ; lrNewLevelColor
                  jsr ColourLevel                 ; 
                  
                  lda #$00                        ;
                  sta CR_StatusColor              ; lrNewStatusColor
                  
                  lda #>LR_ScrnHiReDisp           ;
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  jsr BaseLines                   ; 
                  
                  lda #>LR_ScrnHiRePrep           ;
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  jsr BaseLines                   ; 
                  
                  jsr MelodyInit                  ; InitVictoryTune
                  
                  lda #$00                        ;
                  sta LR_CntSpeedLaps             ; 
                  sta LR_EnmyBirthCol             ;
                  
                  lda #LR_VolumeMax               ;
                  sta LR_Volume                   ; 
                  sta LR_LvlReload                ; 000-049 - force level reload from disk if <> LR_LevelNoDisk
                  jsr SetUniquePlayId             ; 
                  
LoadGameX         jmp LevelStart                  ; 
; ------------------------------------------------------------------------------------------------------------- ;
ClearHighScores   jsr ClearHiresDisp              ; 

_WaitKey          lda $c5                         ; C64: key value
                  cmp #$40                        ; no key pressed
                  bne _WaitKey                    ;
                  
                  lda #$00                        ; reset
                  sta LR_KeyNew                   ; 
                  
                  lda #>LR_ScrnHiReDisp           ;
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  
                  lda #LR_YellowCyan              ;
                  jsr ColourLevel                 ; 
                  
                  lda #$00                        ;
                  sta $4f                         ; screen col ($00 - $1b)
                  sta $50                         ; screen row ($00 - $0f)
                  jsr TextOut                     ; TextOut
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $d4 ; T
                  .byte $c8 ; H
                  .byte $c9 ; I
                  .byte $d3 ; S
                  .byte $a0 ; <blank>
                  .byte $c3 ; C
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $c1 ; A
                  .byte $d2 ; R
                  .byte $d3 ; S
                  .byte $a0 ; <Sblank>
                  .byte $d4 ; T
                  .byte $c8 ; H
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $c8 ; H
                  .byte $c9 ; I
                  .byte $c7 ; G
                  .byte $c8 ; H
                  .byte $8d ; <newline>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $d3 ; S
                  .byte $c3 ; C
                  .byte $cf ; O
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $c6 ; F
                  .byte $c9 ; I
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $cf ; O
                  .byte $c6 ; F
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $cc ; L
                  .byte $cc ; L
                  .byte $8d ; <newline>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $c5 ; E
                  .byte $ce ; N
                  .byte $d4 ; T
                  .byte $d2 ; R
                  .byte $c9 ; I
                  .byte $c5 ; E
                  .byte $d3 ; S
                  .byte $ae ; .
                  .byte $8d ; <newline>
                  .byte $8d ; <newline>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $d9 ; Y
                  .byte $cf ; O
                  .byte $d5 ; U
                  .byte $a0 ; <blank>
                  .byte $d3 ; S
                  .byte $d5 ; U
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $a8 ; (
                  .byte $d9 ; Y
                  .byte $af ; /
                  .byte $ce ; N
                  .byte $a9 ; )
                  .byte $a0 ; <blank>
                  .byte $00 ; EndOfText
                  
                  lda #$00                        ; 
                  jsr WaitKeyBlink                ;
                  
                  ldx #$00                        ; reset
                  stx LR_KeyNew                   ; 
                  
                  cmp #$19                        ; "y"
                  bne ClearHighScoresX            ;
                  
                  lda #$81                        ;
                  jsr GetPutHiScores              ; ($1100-$11ff) ac: $01=load $02=store 81= 82=
                  
                  ldy #$83                        ;
                  lda #$00                        ;
_ClearData        sta LR_LvlDataSavLod+$ff,y      ;
                  dey                             ;
                  bne _ClearData                  ;
                  
                  lsr LR_LevelNoDisk              ; 000-049
                  
                  lda #$82                        ;
                  jsr GetPutHiScores              ; ($1100-$11ff) ac: $01=load $02=store 81= 82=
                  
ClearHighScoresX  rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
CheckSaveList     lda CR_SavListId                ;
                  cmp #$c4                        ; "D"
                  bne ClrSaveList                 ; wrong id - clear and write back
                  
                  lda CR_SavListId+$01            ;
                  cmp #$ca                        ; "J"
                  bne ClrSaveList                 ; wrong id - clear and write back
                  
                  lda CR_SavListId+$02            ;
                  cmp #$c2                        ; "B"
                  bne ClrSaveList                 ; wrong id - clear and write back

CheckSaveListX    rts                             ; good list
; ------------------------------------------------------------------------------------------------------------- ;
ClrSaveList       lda #$a0                        ; <blank> - wrong id - clear and write back
                  ldx #$00                        ;
_ClrLevelData     sta LR_LvlDataSavLod,x          ;
                  inx                             ;
                  bne _ClrLevelData               ;
                  
_SetID            lda #$c4                        ; "D"
                  sta CR_SavListId                ;
                  lda #$ca                        ; "J"
                  sta CR_SavListId+$01            ;
                  lda #$c2                        ; "B"
                  sta CR_SavListId+$02            ;
                  
_ClrLevelWrite    lda #LR_DiskWrite               ;
                  jsr ControlDiskOper             ; ac: $01=load $02=store
                  
ClrSaveListX      rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
LoadScoreBlock    lda #$02                        ;
                  sta LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  
                  lda #LR_DiskRead                ;
                  jsr GetPutHiScores              ; ($1100-$11ff) ac: $01=load $02=store 81= 82=
                  cmp #$00                        ;
                  bne LoadScoreBad                ;
                  
_LoadScoreGood    sec                             ;
                  rts                             ;
                  
LoadScoreBad      clc                             ; 
LoadScoreBlockX   rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
SplitScoreOut     jsr SplitScoreDigit             ;

                  lda LR_Digit10                  ; lrDec10
                  jsr PrepareDigitOut             ; Digits2Screen
                  
                  lda LR_Digit1                   ; lrDec1
                  jsr PrepareDigitOut             ; Digits2Screen
                  
SplitScoreOutX    rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
VictoryMsg        lda CR_DiskStatus               ; CR_DiskStatus
                  bmi LoadScoreBad                ; bad
                  
                  lda LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  lsr a                           ;
                  beq LoadScoreBad                ; 
                  
                  ldx #LR_LevelMsgLen             ; length victory msg
                  stx CR_Work                     ;
_GetMsgText       lda LR_LevelMsg,x               ; 
                  beq _SetNext                    ; don't move $00 - EndOfText leads to program abend
                  
_PutMsgText       sta TabMsgBuffer,x              ; 
_SetNext          dex                             ;
                  bpl _GetMsgText                 ; 
                  
                  lda #LR_BasLinRowStat           ; 
                  sta $50                         ; screen row ($00 - $0f)
                  lda #LR_BasLinColMsg            ;
                  sta $4f                         ; screen col ($00 - $1b)
                  jsr TextOut                     ; 
TabMsgBuffer      .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $00 ; EndOfText
                  
                  lda #LR_YellowYellow            ; 
                  sta CR_StatusColor              ; 
                  
                  ldx #LR_LevelMsgLenCo           ;
_SetMsgColor      sta LR_ScrnMultColor+$03aa,x    ; 
                  dex                             ;
                  bpl _SetMsgColor                ; 
                  
VictoryMsgX       rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
SetUniquePlayId   lda LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  lsr a                           ;
                  beq SetUniquePlayIdX            ; demo
                  
                  lda #LR_DiskRead                ;
                  jsr GetPutHiScores              ; ($1100-$11ff) ac: $01=load $02=store 81= 82=
                  
                  lda RASTER                      ; VIC 2 - $D012 = Read: Raster Scan Line/ Write: Line for Raster IRQ
                  sta CR_UniquePID                ; 
                  sta CR_HiScoreUPID              ; unique play id disk store
                  
                  lda #LR_DiskWrite               ; 
_Write            jsr GetPutHiScores              ; ($1100-$11ff) ac: $01=load $02=store 81= 82=
                  
SetUniquePlayIdX  rts                             ; supiX
; ------------------------------------------------------------------------------------------------------------- ;
ChkUniquePlayId   lda LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  lsr a                           ;
                  beq SetUniquePlayIdX            ; demo
                  
                  lda #LR_DiskRead                ;
                  jsr GetPutHiScores              ; ($1100-$11ff) ac: $01=load $02=store 81= 82=
                  
                  lda CR_HiScoreUPID              ; 
                  cmp CR_UniquePID                ; lrUniquePlayId
                  beq SetUniquePlayIdX            ; 
                  
                  jsr ClearHiresDisp              ; ClearDisplay20
                  
                  lda #>LR_ScrnHiReDisp           ;
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  
                  lda #LR_YellowCyan              ;
                  jsr ColourLevel                 ; 
                  
                  lda #$00                        ;
                  sta $50                         ; screen row ($00 - $0f)
                  sta $4f                         ; screen col ($00 - $1b)
                  jsr TextOut                     ; TextOut
                  .byte $c4 ; D
                  .byte $c9 ; I
                  .byte $d3 ; S
                  .byte $cb ; K
                  .byte $a0 ; <blank>
                  .byte $d3 ; S
                  .byte $d7 ; W
                  .byte $c1 ; A
                  .byte $d0 ; P
                  .byte $a0 ; <blank>
                  .byte $ce ; N
                  .byte $cf ; O
                  .byte $d4 ; T
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $cc ; L
                  .byte $cc ; L
                  .byte $cf ; O
                  .byte $d7 ; W
                  .byte $c5 ; E
                  .byte $c4 ; D
                  .byte $ae ; .
                  .byte $8d ; <newline>
                  .byte $8d ; <newline>
                  .byte $c8 ; H
                  .byte $c9 ; I
                  .byte $d4 ; T
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $ce ; N
                  .byte $d9 ; Y
                  .byte $a0 ; <blank>
                  .byte $cb ; K
                  .byte $c5 ; E
                  .byte $d9 ; Y
                  .byte $00 ; EndOfText
                  
                  lda #$00                        ;
                  jsr WaitKeyBlink                ;
                  
                  lda #$00                        ;
                  sta LR_KeyNew                   ; lrNewKey
                  
ChkUniquePlayIdX  jmp ColdStart                   ; ColdStart
; ------------------------------------------------------------------------------------------------------------- ;
SetNewColors      lda CR_DiskStatus               ; 
                  bmi _SetDefault                 ; bad
                  
                  lda LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  lsr a                           ;
                  beq _SetDefault                 ; 
                  
_GetColorPtrI     lda LR_LevelNoDisk              ; 000-049
                  ldx #$ff                        ;
_GetColorPtr      inx                             ; 
                  sec                             ;
                  sbc #$0a                        ;
                  bcs _GetColorPtr                ; 
                  
                  lda TabLevelColors,x            ; 
_SetLevelColor    sta CR_LevelColor               ; 

_SetEnemyColor    lsr a                           ; isolate enemy color
                  lsr a                           ;
                  lsr a                           ;
                  lsr a                           ;
                  jsr ColorSprites                ;
                  
_Exit             rts                             ; 

_SetDefault       lda #LR_CyanRed                 ; 
                  jmp _SetLevelColor              ; 
SetNewColorsX     =*                              ; 
; ------------------------------------------------------------------------------------------------------------- ;
TabLevelColors    .byte LR_CyanRed                ; right nybble contains enemy sprite color
                  .byte LR_GreenLtRed
                  .byte LR_CyanOrange
                  .byte LR_PurpleGreen
                  .byte LR_PurpleLtBlue
; ------------------------------------------------------------------------------------------------------------- ;
TabLrDiskId       .byte $44 ; d                   ; dane bigham
                  .byte $41 ; a
                  .byte $4e ; n
                  .byte $45 ; e
                  .byte $20 ; <blank>
                  .byte $42 ; b
                  .byte $49 ; i
                  .byte $47 ; g
                  .byte $48 ; h
                  .byte $41 ; a
                  .byte $4d ; m
; ------------------------------------------------------------------------------------------------------------- ;
InitLevel         stx LR_LevelCtrl                ; $00=prepared copy already at $4000-$5fff)

                  ldx #$ff                        ;
                  stx $03                         ; adr col lode runner
                  
                  inx                             ; 00
                  stx LR_NumXitLadders            ; # hidden ladders
                  stx LR_GoldToGet                ; # gold
                  stx LR_EnmyNo                   ; # enemies
                  stx LR_NoEnemy2Move             ; # enemies to move
                  stx $54                         ;
                  stx $53                         ; disk level data offset
                  stx $1e                         ; left right nybble 00=right
                  stx $50                         ; screen row ($00 - $0f)
                  
                  txa                             ; $00
                  ldx #LR_TabHoleMax              ; 30
_HoleTime         sta LR_TabHoleOpenT,x           ; hole open time tab
                  dex                             ;
                  bpl _HoleTime                   ; 
                  
                  ldx #LR_TabEnemyBMax            ; max 6
_ENReBirthStep    sta LR_TabEnemyBirtT,x          ; enemy rebirth step time
                  dex                             ;
                  bpl _ENReBirthStep              ; 
                  
                  lda #LR_Life                    ; 
                  sta LR_Alive                    ; 
                  
                  lda LR_LevelNoDisk              ; 000-049
                  cmp LR_LvlReload                ; 000-049 - force level reload from disk if <> LR_LevelNoDisk
                  beq _SetSameLevel               ; 
                  
_NewLevel         lda #LR_DiskRead                ; 
                  jsr ControlDiskOper             ; ac: $01=load $02=store
                  
                  jsr ChkUniquePlayId             ; 
                  
                  lda CR_DiskStatus               ; 
                  bmi _SetSameLevel               ; 
                  
                  lda LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  lsr a                           ;
                  beq _SetSameLevel               ; 
                  
                  lda LR_LevelNoDisk              ; 000-049
                  cmp #CR_LevelNoMax              ; 
                  bcs _SetSameLevel               ; 
                  
                  ldx #CR_LevelDataMax            ; length level data
_FlipLevelData    lda LR_LvlDataSavLod-1,x        ; 
                  eor #$ff                        ; flip all bits
                  sta LR_LvlDataSavLod-1,x        ; 
                  dex                             ;
                  bne _FlipLevelData              ; 
                  
_SetSameLevel     lda LR_LevelNoDisk              ; 000-049      <ilInitUnpack>
                  sta LR_LvlReload                ; 000-049 - force level reload from disk if <> LR_LevelNoDisk
                  
                  jsr SetNewColors                ; SetNewColors (new colors any 10th level)
                  
                  ldy $50                         ; screen row ($00 - $0f)
_ExpandDataI      lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09                         ; 
                  sta $0b                         ; lrzLoPlayLvlDat (0a00-0bc3)
                  lda TabExLvlDatRowH8,y          ; 
                  sta $0a                         ; ($09/$0a) point to expanded level data row pointer $0800-$09c3
                  lda TabExLvlDatRowHa,y          ; 
                  sta $0c                         ; ($09/$0a) point to expanded level data row pointer $0a00-$0bc3
                  
                  lda #$00                        ;
                  sta $4f                         ; screen col ($00 - $1b)
                  
_GetDataBytes     lda $1e                         ;  control left/right nybble to process  $00=right
                  lsr a                           ;
                  
                  ldy $53                         ; disk level data offset
                  lda LR_LvlDataSavLod,y          ; disk level data offset
                  bcs _LeftNybble                 ; carry possibly set by _Carry4RightLeft
                  
_RightNybble      and #$0f                        ; isolate right nybble
                  bpl _InitNybbleMark             ; always
                  
_LeftNybble       lsr a                           ; isolate left nybble
                  lsr a                           ;
                  lsr a                           ;
                  lsr a                           ;
                  
                  inc $53                         ; both nybbles processed so point to next byte
                  
_InitNybbleMark   inc $1e                         ; force carry set the next round by _Carry4RightLeft

                  ldy $4f                         ; screen col ($00 - $1b)
                  
                  cmp #LR_TileValid               ; valid byte range is $00-$09
                  bcc _PutDataBytes               ; lower
                  
_SetEmpty         lda #LR_TileEmpty               ; not valid so store a $00
                  
_PutDataBytes     sta ($09),y                     ; unpacked level data ($0800-$09c3)
_PutCtrlBytes     sta ($0b),y                     ; play level control data ($0a00-$0bc3)
                  
                  inc $4f                         ; screen col ($00 - $1b)
                  lda $4f                         ; screen col ($00 - $1b)
                  cmp #$1c                        ; $1b - max 27 cols
                  bcc _GetDataBytes               ; 
                  
                  inc $50                         ; screen row ($00 - $0f)
                  ldy $50                         ; screen row ($00 - $0f)
                  cpy #LR_ScrnMaxRows+1           ; $0f - max 15 rows
                  bcc _ExpandDataI                ; 
                  
_GoCheckLevel     jsr CheckLevel                  ; 
_NoError          bcc InitLevelX                  ; good

                  lda CR_DiskStatus               ; 
                  bpl GoColdStart                 ; 
                  
_LevelError       lda LR_LevelNoDisk              ; 000-049
                  beq GoColdStart                 ;
                  
                  ldx #$00                        ;
                  stx LR_LevelNoDisk              ; 000-049
                  
_ChkGameSpeed     lda LR_CntSpeedLaps             ; lrGameSpeed
                  cmp #LR_CntSpeedMax+1           ; max 9
                  bcs _SetFF                      ;
                  
                  inc LR_CntSpeedLaps             ; increase game speed
                  
_SetFF            dex                             ;
                  jmp InitLevel                   ; restart
                  
InitLevelX        rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
GoColdStart       jmp ColdStart
; ------------------------------------------------------------------------------------------------------------- ;
ControlDiskOper   pha                             ; ac: 1=load 2=store <GetPutCtrl>
                  bpl _ChkGameCtrl                ; 
                  
                  pla                             ; $81/$82
                  and #$7f                        ;
                  pha                             ;
                  
                  jmp DiskRW                      ; 
                  
_ChkGameCtrl      lda LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  lsr a                           ;
                  beq _IsDemo                     ; 
                  
                  jmp DiskRW                      ; 
                  
_IsDemo           pla                             ; 
                  
                  lda LR_LevelNoDisk              ; 000-049
                  cmp #CR_LevelNoMaxDmo           ; max built in demo levels
                  bcc _SetLvlDataPtr              ; 

_RestartDemo      lda #$00                        ;
                  sta LR_LevelNoDisk              ; 000-049

_SetLvlDataPtr    clc                             ; 
                  adc #>TabDemoLvlData            ; .hbu000.
                  sta __ModCpyDemoLvlH            ; modify load adress
                  
                  ldy #$00                        ;
_CpyDemoLvlData   lda TabDemoLvlData,y            ; 
__ModCpyDemoLvlH  = *-1
                  sta LR_LvlDataSavLod,y          ;
                  iny                             ;
                  bne _CpyDemoLvlData             ; 
                  
ControlDiskOperX  rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
GetPutHiScores    tax                             ; save action $01=load $02=store
                  
                  lda LR_LevelNoDisk              ; 000-049
                  pha                             ; save actual disk level no
                  
_SetScoreBuffer   inc Mod_GetDiskByte             ; set to LR_ScoreSavLod
                  inc Mod_PutDiskByte             ; 
                  
                  lda #LR_LevelDiskScor           ; disk level 151 contains the high scores
                  sta LR_LevelNoDisk              ; 000-049
                  
                  txa                             ; restore action $01=load $02=store
                  jsr ControlDiskOper             ; 
                  
                  pla                             ; restore disk level no
                  sta LR_LevelNoDisk              ; 000-049
                  
_SetLevelBuffer   dec Mod_GetDiskByte             ; reset to LR_LvlDataSavLod
                  dec Mod_PutDiskByte             ; 
                  
                  ldy #LR_HiScoreIdLen            ; length lr disk id
                  lda #$00                        ;
                  sta $25                         ; 
_ChkDiskID        lda LR_HiScoreDiskId,y          ; DANE BIGHAM
                  sta CR_DiskStatus               ; 
                  and #$7f                        ; to lower
                  eor TabLrDiskId,y               ; dane bigham
                  ora $25                         ;
                  sta $25                         ;
                  dey                             ;
                  bpl _ChkDiskID                  ; 
                  
                  lda $25                         ;
                  beq _ChkDikStatus               ; 
                  
                  lda #$00                        ; 
                  lda #>LR_ScrnHiReDisp           ;
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  
                  lda #$00                        ;
                  sta $50                         ; screen row ($00 - $0f)
                  sta $4f                         ; screen col ($00 - $1b)
                  jsr ClearHiresDisp              ; 
                  
                  lda #LR_YellowCyan              ;
                  jsr ColourLevel                 ; 
                  jsr TextOut                     ; TextOut
                  .byte $c4 ; D
                  .byte $c9 ; I
                  .byte $d3 ; S
                  .byte $cb ; K
                  .byte $c5 ; E
                  .byte $d4 ; T
                  .byte $d4 ; T
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $c9 ; I
                  .byte $ce ; N
                  .byte $a0 ; <blank>
                  .byte $c4 ; D
                  .byte $d2 ; R
                  .byte $c9 ; I
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $c9 ; I
                  .byte $d3 ; S
                  .byte $8d ; <newline>
                  .byte $ce ; N
                  .byte $cf ; O
                  .byte $d4 ; T
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $a0 ; <blank>
                  .byte $cc ; L
                  .byte $cf ; O
                  .byte $c4 ; D
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $d2 ; R
                  .byte $d5 ; U
                  .byte $ce ; N
                  .byte $ce ; N
                  .byte $c5 ; E
                  .byte $d2 ; R
                  .byte $a0 ; <blank>
                  .byte $c4 ; D
                  .byte $c9 ; I
                  .byte $d3 ; S
                  .byte $cb ; K
                  .byte $ae ; .
                  .byte $00 ; EndOfText
                  
_WaitIRQI         lda #$4b                        ; init IRQ wait
                  sta LR_CountIRQs                ; lrWaitCounter  (inc any IRQ)
                  
_WaitIRQ          lda LR_CountIRQs                ; 
                  bne _WaitIRQ                    ;
                  
                  jmp ColdStart                   ; ColdStart

_Exit             rts                             ; 
                  
_ChkDikStatus     ldx #$03                        ; 
                  lda CR_DiskStatus               ; 
                  bmi _SavDiskStatus              ; bad
                  
                  ldx #$08                        ; 
                  
_SavDiskStatus    stx CR_ScoreOffset              ;

                  lda #LR_DiskMaster              ;
                  ldx LR_HiScoreDiskUM            ;
                  bne GetPutHiScoresX             ; 
                  
                  lda #LR_DiskData                ;
GetPutHiScoresX   rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
DiskRW            lda #$00                        ; GetPutDisk
                  sta SPENA                       ; VIC 2 - $D015 = Sprite Enable
                  jsr CLALL                       ; KERNAL - $FFE7 = Close all Files
                  
                  ldx #"0"                        ; 
                  lda LR_LevelNoDisk              ; 000-049
                  and #$0f                        ; isolate right nybble
                  cmp #$0a                        ;
                  bcc _PutSectorHi                ; lower 10
                  
                  ldx #"1"                        ; 
                  sec                             ;
                  sbc #$0a                        ; convert hex 0a-0f  to  bin 00-05
_PutSectorHi      stx Mod__BlkRWSecHi             ; u1:02 0 03 00 - Disk Sector Hi
                  clc                             ;
                  adc #"0"                        ; generate digit 0-9
                  sta Mod__BlkRWSecLo             ; u1:02 0 03 00 - Disk Sector Lo
                  
                  lda LR_LevelNoDisk              ; 000-049
                  lsr a                           ; isolate left nybble
                  lsr a                           ;
                  lsr a                           ;
                  lsr a                           ;
                  clc                             ;
                  adc #$03                        ; disk level data starts at Track 03 Sector 00
                  jsr ConvertHex2Dec              ; Hex2Dec  (1307=100 1308=10 1309=1)
                  
                  lda LR_Digit10                  ; 
                  clc                             ;
                  adc #"0"                        ; convert to string
                  sta Mod__BlkRWTrkHi             ; u1:02 0 03 00 - Disk Track Hi
                  
                  lda LR_Digit1                   ; lrDec1
                  clc                             ;
                  adc #"0"                        ; convert to string
                  sta Mod__BlkRWTrkLo             ; u1:02 0 03 00 - Disk Track Lo
                  
_SetNoFileNam     lda #$00                        ;
                  jsr SETNAM                      ; KERNAL - $FFBD = Set Filename Parameters
                  
                  lda #$0f                        ; 15, 8 ,15 - command channel
                  ldx #$08                        ;
                  ldy #$0f                        ;
                  jsr SETLFS                      ; KERNAL - $FFBA = Set Logical File Parameters
                  jsr OPEN                        ; KERNAL - $FFC0 = Open a Logical File
                  bcs DiskError                   ; 
                  
                  lda #$01                        ; length file name
                  ldx #<FilNamHash                ; adr lo file name - #
                  ldy #>FilNamHash                ; adr hi file name - #
                  jsr SETNAM                      ; KERNAL - $FFBD = Set Filename Parameters
                  
                  lda #$02                        ; 2 , 8, 2
                  ldx #$08                        ;
                  ldy #$02                        ;
                  jsr SETLFS                      ; KERNAL - $FFBA = Set Logical File Parameters
                  jsr OPEN                        ; KERNAL - $FFC0 = Open a Logical File
                  bcs DiskError                   ; 
                  
                  pla                             ; restore mode: $01=load $02=store
                  lsr a                           ;
_ReadBlock        bcs ExecDiskCmdRead             ; 
                  
                  lsr a                           ;
                  bcc _ClearDataI                 ; bad mode
                  
_WriteBlock       jmp ExecDiskCmdWrit             ; 
                  
_ClearDataI       ldy #LR_TileEmpty               ; 
                  tya                             ;
_ClearData        sta LR_ScoreSavLod,y            ; clear high score storage
                  sta LR_LvlDataSavLod,y          ; clear level storage
                  iny                             ;
                  bne _ClearData                  ; 
                  
                  lda #LR_LevelDiskMax            ; 149 blocks to write
                  sta LR_LevelNoDisk              ; 000-049
                  jsr CLALL                       ; KERNAL - $FFE7 = Close all Files
                  
_PutClearedData   lda #LR_DiskWrite               ; 
                  jsr ControlDiskOper             ; ac: $01=load $02=store
                  
                  dec LR_LevelNoDisk              ; 000-049
                  lda LR_LevelNoDisk              ; 000-049
                  cmp #$ff                        ;
                  bne _PutClearedData             ; 
                  
                  ldy #LR_HiScoreIdLen            ; length lr id
_SetDiskID        lda TabLrDiskId,y               ; lr disk id=dane bigham
                  sta LR_HiScoreDiskId,y          ;
                  dey                             ;
                  bpl _SetDiskID                  ; 
                  
                  iny                             ; $00 - LR_DiskNoData
                  sty LR_HiScoreDiskUM            ; offset indicator store in high score block
                  
_PutClearedScore  lda #LR_DiskWrite               ; 
                  jsr GetPutHiScores              ; ($1100-$11ff) ac: $01=load $02=store 81= 82=
                  
DiskRWX           rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
DiskError         jsr ResetDisk                   ; DiskCloseAll <DiskError>
                  jmp StartGraficOut              ; StartGrafic
; ------------------------------------------------------------------------------------------------------------- ;
ExecDiskCmdRead   lda #"1"                        ; "1" - load command
                  sta Mod__BlkRWCmd               ; u1=read - u1:02 0 03 00
                  jsr CLRCHN                      ; KERNAL - $FFCC = Restore Default Devices
                  
                  ldx #$0f                        ; 15 = command channel
                  jsr CHKOUT                      ; KERNAL - $FFC9 = Define an Output Channel
                  bcs DiskError                   ; 
                  
                  ldy #$00                        ;
_CmdOut           lda BlkRWCmdString,y            ; command string - u1:02 0 03 00
                  beq _GoChkDiskCC                ; <end of string>
                  jsr CHROUT                      ; KERNAL - $FFD2 = Output a Character
                  iny                             ;
                  jmp _CmdOut                     ; 
                  
_GoChkDiskCC      jsr CheckDiskCC                 ; 
                  jsr CLRCHN                      ; KERNAL - $FFCC = Restore Default Devices
                  ldx #$02                        ; 2 = data channel
                  jsr CHKIN                       ; KERNAL - $FFC6 = Define an Input Channel
                  bcs DiskError                   ; 
                  
                  jsr CHRIN                       ; KERNAL - $FFCF = Input a Character
                  
                  ldy #$00                        ;
_ChrIn            jsr CHRIN                       ; KERNAL - $FFCF = Input a Character <gdGetData>
                  sta LR_LvlDataSavLod,y          ;
Mod_GetDiskByte     = *-1
                  iny                             ;
                  bne _ChrIn                      ; 
                  
ExecDiskCmdReadX  jmp ResetDisk                   ; DiskCloseAll
; ------------------------------------------------------------------------------------------------------------- ;
ExecDiskCmdWrit   lda #"2"                        ; "2" - store command
                  sta Mod__BlkRWCmd               ; u2=write - u1:02 0 03 00
                  jsr CLRCHN                      ; KERNAL - $FFCC = Restore Default Devices
                  
                  ldx #$02                        ; 2 = data channel
                  jsr CHKOUT                      ; KERNAL - $FFC9 = Define an Output Channel
                  bcs DiskError                   ; 
                  
                  ldy #$00                        ;
_ChrOut           lda LR_LvlDataSavLod,y          ; get a data byte
Mod_PutDiskByte     = *-1
                  jsr CHROUT                      ; KERNAL - $FFD2 = Output a Character
                  iny                             ;
                  bne _ChrOut                     ; 
                  
                  jsr CLRCHN                      ; KERNAL - $FFCC = Restore Default Devices
                  
                  ldx #$0f                        ; 15 = command channel
                  jsr CHKOUT                      ; KERNAL - $FFC9 = Define an Output Channel
                  
                  ldy #$00                        ;
_CmdOut           lda BlkRWCmdString,y            ; u2:02_0_tt_ss
                  beq _GoCheckDiskCC              ; <end of string>
                  
                  jsr CHROUT                      ; KERNAL - $FFD2 = Output a Character
                  iny                             ;
                  jmp _CmdOut                     ; 

_GoCheckDiskCC    jsr CheckDiskCC                 ; 

ExecDiskCmdWritX  jmp ResetDisk                   ; DiskCloseAll
; ------------------------------------------------------------------------------------------------------------- ;
                  .byte $00 ; 
FilNamHash        .byte $23 ; #

BlkRWCmdString    .byte $55 ; u
Mod__BlkRWCmd     .byte $31 ; 1
                  .byte $3a ; :
                  .byte $30 ; 0
                  .byte $32 ; 2
                  .byte $20 ; <blank>
                  .byte $30 ; 0
                  .byte $20 ; <blank>
Mod__BlkRWTrkHi   .byte $30 ; 0 - Track
Mod__BlkRWTrkLo   .byte $33 ; 3 - Track
                  .byte $20 ; <blank>
Mod__BlkRWSecHi   .byte $30 ; 0 - Sector
Mod__BlkRWSecLo   .byte $30 ; 0 - Sector
                  .byte $0d ; <enter>
                  .byte $00 ; EndOfCmd
; ------------------------------------------------------------------------------------------------------------- ;
CheckDiskCC       jsr CLRCHN                      ; KERNAL - $FFCC = Restore Default Devices

                  ldx #$0f                        ; 15 - command channel      <CLRCHN - Restore I/O Vector [f333]>
                  jsr CHKIN                       ; KERNAL - $FFC6 = Define an Input Channel
                  jsr CHRIN                       ; KERNAL - $FFCF = Input a Character
                  
                  sta $1e                         ;
                  jsr CHRIN                       ; KERNAL - $FFCF = Input a Character
                  
                  ora $1e                         ;
                  sta $1e                         ;
_ChrIn            jsr CHRIN                       ; KERNAL - $FFCF = Input a Character  <decmGetMsg>
                  cmp #$0d                        ; <return>
                  bne _ChrIn                      ; 
                  
                  lda $1e                         ; 
                  cmp #$30                        ; "0"
                  beq CheckDiskCCX                ; 
                  
                  jmp ColdStart                   ; error => ColdStart
                  
CheckDiskCCX      rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
ResetDisk         lda #$0f                        ; 15 - command channel <DiskCloseAll>
                  jsr CLOSE                       ; KERNAL - $FFC3 = Close a Logical File
                  lda #$02                        ; 2 - data channel
                  jsr CLOSE                       ; KERNAL - $FFC3 = Close a Logical File
                  jmp CLALL                       ; KERNAL - $FFE7 = Close all Files
; ------------------------------------------------------------------------------------------------------------- ;
CheckLevel        ldy #$0f                        ; max row
                  sty $50                         ; screen row ($00 - $0f)
                  
                  lda #$00                        ;
                  sta SPENA                       ; VIC 2 - $D015 = Sprite Enable
                  
_SetLevelPtr      lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09                         ; 
                  sta $0b                         ; 
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a                         ; 
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c                         ; 
                  
                  ldy #LR_ScrnMaxCols             ; 
                  sty $4f                         ; screen col ($00 - $1b)
                  
_GetLevelByte     lda ($09),y                     ; unpacked level data ($0800-$09c3)

                  ldx LR_LevelCtrl                ; level display control  $00=prepared copy already at $4000-$5fff
                  beq _ToGoGfxOutPrep             ; 
                  
_ChkXitLadder     cmp #LR_TileLadderXit           ; hidden ladder
                  bne _ChkGold                    ; 
                  
                  ldx LR_NumXitLadders            ; # hidden ladders
                  cpx #LR_NumXitLdrsMax           ; max 45
                  bcs _SetEmptyByte               ; 
                  
_IncXitLadder     inc LR_NumXitLadders            ; count  - inc no of hidden ladders

_PutXitLadderAdr  inx                             ;
                  lda $50                         ; screen row ($00 - $0f)
                  sta LR_TabXitLdrRow,x           ; adr row hidden ladders tab
                  tya                             ;
                  sta LR_TabXitLdrCol,x           ; adr col hidden ladder tab
_SetEmptyByte     lda #$00                        ; blank for hidden ladder/enemy
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  sta ($0b),y                     ; play level control data ($0a00-$0bc3)
_ToGoGfxOutPrep   beq _GoGfxOutPrep               ; always

_ChkGold          cmp #LR_TileGold                ; 
                  bne _ChkEnemy                   ; 
                  
                  inc LR_GoldToGet                ; count  - inc no of gold to get
                  bne _GoGfxOutPrep               ; always
                  
_ChkEnemy         cmp #LR_TileEnemy               ;
                  bne _ChkLodeRunner              ;
                  
                  ldx LR_EnmyNo                   ; number of enemies
                  cpx #LR_EnmyNoMax               ; max 5 enemies
                  bcs _SetEmptyByte               ; 
                  
_IncEnemy         inc LR_NoEnemy2Move             ; count - inc no of enemies to move
                  inc LR_EnmyNo                   ; count - inc no of enemies
                  
_PutEnemyData     inx                             ;
                  tya                             ;
_PutEnemyCol      sta LR_TabEnemyCol,x            ; adr col enemy
                  lda $50                         ; screen row ($00 - $0f)
_PutEnemyRow      sta LR_TabEnemyRow,x            ; adr row enemy

                  lda #$00                        ; 
_PutEnemyGold     sta LR_TabEnemyGold,x           ; enemy has gold tab
_PutEnemyNo       sta LR_TabEnemySprNo,x          ; actual enemy sprite number

                  lda #$02                        ; center to
                  sta LR_TabEnemyPosLR,x          ; enemy pos on image left/right tab
                  sta LR_TabEnemyPosUD,x          ; enemy pos on image up/down tab
                  
_ClrEnemyGfx      lda #$00                        ; 
                  sta ($0b),y                     ; play level control data ($0a00-$0bc3)
                  lda #$00                        ;
                  jsr ImageOut2Prep               ; output to preparation screen first ($4000)
                  
                  lda #LR_TileEnemy               ; 
_SetEnemyGfx      bne _GoGfxOutPrep               ; always
                  
_GoSetLevelPtr    bpl _SetLevelPtr                ; 
_GoGetLevelByte   bpl _GetLevelByte               ; 

_ChkLodeRunner    cmp #LR_TileLR                  ; 
                  bne _ChkTrap                    ; 
                  
                  ldx $03                         ; adr col lode runner
_ChkLodeRrExist   bpl _SetEmptyByte               ; one lr found already so blank out this one
                  
_SetLodeRrCol     sty $03                         ; adr col lode runner

                  ldx $50                         ; screen row ($00 - $0f)
_SetLodeRrRow     stx $04                         ; actual row lode runner
                  
_SetLodeRrCenter  ldx #$02                        ; center
                  stx $05                         ; lr pos on image left/right
                  stx $06                         ; lr pos on image up/down
                  
_SetLodeRrSprtNo  ldx #$08                        ;
                  stx $07                         ; lr sprite number
                  
                  lda #LR_TileEmpty               ;
                  sta ($0b),y                     ; clear lr in play level control data ($0a00-$0bc3)
                  lda #$00                        ;
                  jsr ImageOut2Prep               ; output to preparation screen first ($4000)
                  
                  lda #LR_TileLR                  ; 
_SetLodeRrGfx     bne _GoGfxOutPrep               ; always
                  
_ChkTrap          cmp #LR_TileWallTrap            ; 
                  bne _GoGfxOutPrep               ; 
                  
                  lda #LR_TileWallSoft            ; 
                  
_GoGfxOutPrep     jsr ImageOut2Prep               ; output to preparation screen first ($4000)

_SetPrevCol       dec $4f                         ; next screen col  (00-1b) bottom up
                  ldy $4f                         ; screen col ($00 - $1b)
                  bpl _GoGetLevelByte             ; 
                  
_SetPrevRow       dec $50                         ; next screen row  (00-0f) bottom up
                  ldy $50                         ; screen row ($00 - $0f)
                  bpl _GoSetLevelPtr              ; 
                  
                  lda LR_LevelCtrl                ; level display control  $00=prepared copy already at $4000-$5fff
                  beq ScreenPrep2Disp             ; copy prepared hires screen data to display screen
                  
                  lda $03                         ; adr col lode runner
                  bpl GoResetEnmyLodeR            ; lode runner tile found
                  
_SetError         sec                             ; error - no lode runner tile found
CheckLevelX       rts                             ; cldoErrX
; ------------------------------------------------------------------------------------------------------------- ;
ScreenPrep2Disp   lda CR_LevelColor               ; lrNewLevelColor <cldoCopy2Display>
                  jsr ColourLevel                 ; 
                  
_Init             lda #>LR_ScrnHiReDisp           ; to:   display hires screen
                  sta $12                         ;
                  lda #>LR_ScrnHiRePrep           ; from: prepare hires screen for direct output
                  sta $10                         ;
                  
                  lda #$00                        ;
                  sta $11                         ;
                  sta $0f                         ;
                  tay                             ;
_Copy             lda ($0f),y                     ; from 4000 - hidden screen      <cldoCopy>
                  sta ($11),y                     ; to 2000 - display screen
                  iny                             ;
                  bne _Copy                       ; 
                  
                  inc $12                         ;
                  inc $10                         ;
                  
                  ldx $10                         ;
                  cpx #>(LR_ScrnHiRePrep + $2000) ; end of screen data $5fff reached
                  bcc _Copy                       ; 
                  
_SetNoError       clc                             ; no errors
ScreenPrep2DispX  rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
ResetEnmyLodeR    lda #>LR_ScrnHiRePrep           ; 
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  jsr BaseLines                   ; 
                  jsr ScreenPrep2Disp             ; copy prepared hires screen data to display screen
                  
                  lda #>LR_ScrnHiReDisp           ;
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  
                  bne DoResetEnmyLodeR            ; always
                  
GoResetEnmyLodeR  jmp ResetEnmyLodeR              ;

                  beq ResetEnmyLodeR              ; 
                  
DoResetEnmyLodeR  ldy #LR_ScrnMaxRows             ; 
                  sty $50                         ; screen row ($00 - $0f)
                  
_SetLevelDataPtr  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09                         ; 
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a                         ; 
                  
_SetMaxCols       ldy #LR_ScrnMaxCols             ; $1b - max 27 cols
                  sty $4f                         ; screen col ($00 - $1b)
_GetData          lda ($09),y                     ; unpacked level data ($0800-$09c3)
_ChkLodeRunner    cmp #LR_TileLR                  ;
                  beq _SetBlank                   ; 
                  
_ChkEnemy         cmp #LR_TileEnemy               ;
                  bne _NextOutCol                 ; 
                  
_SetBlank         lda #LR_TileEmpty               ; blank substitution
                  jsr ImageOut2Prep               ; output to preparation screen first ($4000)
                  
_NextOutCol       dec $4f                         ; screen col ($00 - $1b)      <cldoClearNext>
                  ldy $4f                         ; screen col ($00 - $1b)
                  bpl _GetData                    ; 
                  
_NextOutRow       dec $50                         ; screen row ($00 - $0f)
                  ldy $50                         ; screen row ($00 - $0f)
                  bpl _SetLevelDataPtr            ; 
                  
                  clc                             ; no errors
ResetEnmyLodeRX   rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
ChkNewHighScore   jsr CheckNewChamp               ; 

                  lda LR_ScoreLo                  ; 
                  ora LR_ScoreMidLo               ; 
                  ora LR_ScoreMidHi               ; 
                  ora LR_ScoreHi                  ; 
                  beq ChkNewHighScoreX            ; no scores if zero
                  
                  lda #LR_DiskRead                ;
                  jsr GetPutHiScores              ; ($1100-$11ff) ac: $01=load $02=store 81= 82=
                  beq ChkNewHighScoreX            ; 
                  
                  ldy #$00                        ;
_CopyScoreBlock   lda LR_ScoreSavLod,y            ; 
                  sta LR_HiScoreOld,y             ;
                  iny                             ;
                  bne _CopyScoreBlock             ; 
                  
                  ldy #$01                        ; start with entry 1
_Checks           jsr GetRowOffset                ;

                  txa                             ;
                  clc                             ;
                  adc CR_ScoreOffset              ;
                  tax                             ;
                  
_ChkLevel         lda LR_LevelNoGame              ; level reached - 001-050
                  cmp CR_HiScoreLevel - CR_HiScoreNamLen,x
                  bcc _NextEntry                  ; 
                  bne SetNewHighScore             ;
                  
_ChkScoreHi       lda LR_ScoreHi                  ; score reached
                  cmp CR_HiScoreHi - CR_HiScoreNamLen,x
                  bcc _NextEntry                  ; 
                  bne SetNewHighScore             ;
                  
_ChkScoreMidHi    lda LR_ScoreMidHi               ; 
                  cmp CR_HiScoreMidHi - CR_HiScoreNamLen,x
                  bcc _NextEntry                  ; 
                  bne SetNewHighScore             ;
                  
_ChkScoreMidLo    lda LR_ScoreMidLo               ; 
                  cmp CR_HiScoreMidLo - CR_HiScoreNamLen,x
                  bcc _NextEntry                  ; 
                  bne SetNewHighScore             ;
                  
_ChkScoreLo       lda LR_ScoreLo                  ; 
                  cmp CR_HiScoreLo - CR_HiScoreNamLen,x
                  bcc _NextEntry                  ; 
                  bne SetNewHighScore             ;
                  
_NextEntry        iny                             ; 
                  cpy #$0b                        ; max 10 entries
                  bcc _Checks                     ; lower - so next
                  
ChkNewHighScoreX  rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
SetNewHighScore   cpy #LR_HiScoreMaxIDs           ; no insertion for last entry
                  beq _Insert                     ; simply overwrite
                  
                  sty $29                         ; row offset of new entry
                  
                  ldy #LR_HiScoreMaxIDs-1         ; $0a - max entries to move
_MoveDownI        jsr GetRowOffset                ;

                  lda CR_ScoreOffset              ;
                  clc                             ;
                  adc #$05                        ;
                  sta $22                         ;
                  
                  sta __ModMoveDownLo             ;
_MoveDown         lda LR_ScoreSavLod,x            ;
                  sta LR_ScoreSavLod,x            ;
__ModMoveDownLo   = *-2
                  inx                             ;
                  dec $22                         ;
                  bne _MoveDown                   ;
                  
                  cpy $29                         ; row offset of new entry
                  beq _Insert                     ;
                  
                  dey                             ; number of new entry not reached
                  bne _MoveDownI                  ; move next entry
                  
_Insert           jsr GetRowOffset                ;

                  lda CR_ScoreOffset              ;
                  sta CR_InputBufPtr              ;
                  
_ClrName          lda #$a0                        ; <blank>
                  sta CR_HiScoreNam,x             ;
                  inx                             ;
                  dec CR_InputBufPtr              ;
                  bne _ClrName                    ;
                  
_SetLevel         lda LR_LevelNoGame              ; 001-050
                  sta CR_HiScoreLevel-CR_HiScoreNamLen,x
                  
_SetScore         lda LR_ScoreHi                  ; 
                  sta CR_HiScoreHi-CR_HiScoreNamLen,x
                  lda LR_ScoreMidHi               ; 
                  sta CR_HiScoreMidHi-CR_HiScoreNamLen,x
                  lda LR_ScoreMidLo               ; 
                  sta CR_HiScoreMidLo-CR_HiScoreNamLen,x
                  lda LR_ScoreLo                  ; 
                  sta CR_HiScoreLo-CR_HiScoreNamLen,x
                  
                  sty $39                         ;
                  jsr ShowHighScores              ; ShowScores
                  
                  lda $39                         ;
                  clc                             ;
                  adc #$04                        ;
                  sta $50                         ; screen row ($00 - $0f)
                  
                  ldx #$40                        ;
                  lda #$07                        ; column
                  ldy CR_DiskStatus               ; 
                  bmi _SetColumn                  ; bad
                  
                  sec                             ;
                  sbc #$03                        ; column-3
                  ldx #$c0                        ;
                  
_SetColumn        sta $4f                         ; screen col ($00 - $1b)

                  lda CR_ScoreOffset              ;
                  sta CR_InputBufMax              ;
                  txa                             ;
                  jsr InputControlSpec            ; 
                  
                  ldy $39                         ;
                  jsr GetRowOffset                ;                  
                  stx __ModSetInputLo             ;
                  
                  ldx CR_ScoreOffset              ;
                  dex                             ;
_GetInput         lda CR_InputBuf,x               ;
                  sta LR_ScoreSavLod,x            ;
__ModSetInputLo   = *-2
                  dex                             ;
                  bpl _GetInput                   ;
                  
                  ldy #$00                        ;
_Score2New        lda LR_ScoreSavLod,y            ;
                  sta LR_HiScoreNew,y             ;
                  iny                             ;
                  bne _Score2New                  ;
                  
_GetDiskScore     lda #LR_DiskRead                ;
                  jsr GetPutHiScores              ; ($1100-$11ff) ac: $01=load $02=store 81= 82=
                  beq _BadWaitUser                ;
                  
                  ldy #$00                        ;
_Score2Old        lda LR_ScoreSavLod,y            ;
                  cmp LR_HiScoreOld,y             ;
                  bne _ScoreFromOldI              ;
                  
                  iny                             ;
                  bne _Score2Old                  ;
                  
_ScoreFromNew     lda LR_HiScoreNew,y             ;
                  sta LR_ScoreSavLod,y            ;
                  iny                             ;
                  bne _ScoreFromNew               ;

_PutDiskScore     lda #LR_DiskWrite               ;
                  jsr GetPutHiScores              ; ($1100-$11ff) ac: $01=load $02=store 81= 82=
                  
_BadWaitUser      jmp Wait4User                   ; 

_ScoreFromOldI    ldy #$00                        ; 
_ScoreFromOld     lda LR_HiScoreOld,y             ;
                  sta LR_ScoreSavLod,y            ;
                  iny                             ;
                  bne _ScoreFromOld               ;
                  
SetNewHighScoreX  jmp Wait4User                   ; 
; ------------------------------------------------------------------------------------------------------------- ;
ShowHighScores    jsr ClearHiresDisp              ; ClearDisplay20      <ShowScores>
                  lda #LR_YellowCyan              ;
                  jsr ColourLevel                 ; 
                  
                  lda #>LR_ScrnHiReDisp           ;
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  
                  lda #$00                        ;
                  sta $4f                         ; screen col ($00 - $1b)
                  sta $50                         ; screen row ($00 - $0f)
                  jsr TextOut                     ; TextOut
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $c3 ; C
                  .byte $c8 ; H
                  .byte $c1 ; A
                  .byte $cd ; M
                  .byte $d0 ; P
                  .byte $c9 ; I
                  .byte $cf ; O
                  .byte $ce ; N
                  .byte $d3 ; S
                  .byte $c8 ; H
                  .byte $c9 ; I
                  .byte $d0 ; P
                  .byte $a0 ; <blank>
                  .byte $cc ; L
                  .byte $cf ; O
                  .byte $c4 ; D
                  .byte $c5 ; E
                  .byte $d2 ; R
                  .byte $d5 ; U
                  .byte $ce ; N
                  .byte $ce ; N
                  .byte $c5 ; E
                  .byte $d2 ; R
                  .byte $a0 ; <blank>
                  .byte $8d ; <newline>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $c8 ; H
                  .byte $c9 ; I
                  .byte $c7 ; G
                  .byte $c8 ; H
                  .byte $a0 ; <blank>
                  .byte $d3 ; S
                  .byte $c3 ; C
                  .byte $cf ; O
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $d3 ; S
                  .byte $8d ; <newline>
                  .byte $8d ; <newline>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $ce ; N
                  .byte $c1 ; A
                  .byte $cd ; M
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $cc ; L
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $d3 ; S
                  .byte $c3 ; C
                  .byte $cf ; O
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $8d ; <newline>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $a0 ; <blank>
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $a0 ; <blank>
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $8d ; <newline>
                  .byte $00 ; EndOfText
                  
                  lda #$01                        ;
                  sta $28                         ; actual rank
                  
_ShowScores       cmp #$0a                        ; 10
                  bne _Not10                      ;
                  
                  lda #$01                        ; rank 10  - start with "1"
                  jsr PrepareDigitOut             ; 
                  
                  lda #$00                        ;
                  jsr PrepareDigitOut             ;
                  jmp _SepRankName                ; seperator dot
                  
_Not10            lda #$a0                        ; rank 1-9 - start with " "
                  jsr PrepareChrOut               ;
                  
                  lda $28                         ; actual rank
                  jsr PrepareDigitOut             ; 
                  
_SepRankName      lda #$ae                        ; "."
                  jsr PrepareChrOut               ;
                  
                  ldy #$01                        ;
                  lda CR_DiskStatus               ; 
                  bpl _SetBlankCount1             ; good
                  
                  ldy #$04                        ;
                  
_SetBlankCount1   sty CR_InputBufPtr              ;

_FourOrOneBlank1  lda #$a0                        ; <blank>
                  jsr PrepareChrOut               ;
                  
                  dec CR_InputBufPtr              ;
                  bne _FourOrOneBlank1            ;
                  
                  ldy $28                         ; actual rank
                  jsr GetRowOffset                ;
                  
                  stx $29                         ; score board offset
                  lda CR_ScoreOffset              ;
                  sta CR_InputBufPtr              ;
                  
                  clc                             ;
                  adc $29                         ; score board offset
                  tay                             ;
                  lda LR_ScoreSavLod,y            ;
                  bne _EntryOut                   ;
                  
                  jmp _NewLine                    ;
                  
_EntryOut         ldy $29                         ; score board offset
                  lda LR_ScoreSavLod,y            ;
                  jsr PrepareChrOut               ;
                  
                  inc $29                         ; score board offset
                  dec CR_InputBufPtr              ;
                  bne _EntryOut                   ;
                  
                  ldy #$02                        ;
                  lda CR_DiskStatus               ; 
                  bpl _SetBlankCount2             ; good
                  
                  ldy #$04                        ;
                  
_SetBlankCount2   sty CR_InputBufPtr              ;

_FourOrOneBlank2  lda #$a0                        ; <blank>
                  jsr PrepareChrOut               ;
                  
                  dec CR_InputBufPtr              ;
                  bne _FourOrOneBlank2            ;
                  
                  ldy $29                         ; score board offset
_GetLevel         lda CR_HiScoreLevel-CR_HiScoreNamLen,y
                  jsr ConvertHex2Dec              ; Hex2Dec  (1307=100 1308=10 1309=1)
                  
_PutLevel         lda LR_Digit100                 ; 
                  jsr PrepareDigitOut             ; 
                  lda LR_Digit10                  ; 
                  jsr PrepareDigitOut             ; 
                  lda LR_Digit1                   ; 
                  jsr PrepareDigitOut             ; 
                  
_TwoBlanks        jsr TextOut                     ; TextOut
                  .byte $a0                       ; <blank>
                  .byte $a0                       ; <blank>
                  .byte $00                       ; EndOfText
                  
_ScoreOut         ldy $29                         ; score board offset
                  lda CR_HiScoreHi-CR_HiScoreNamLen,y
                  jsr SplitScoreDigit             ;
                  
                  lda LR_Digit10                  ; 
                  jsr PrepareDigitOut             ; 
                  lda LR_Digit1                   ; 
                  jsr PrepareDigitOut             ; 
                  
                  ldy $29                         ; score board offset
                  lda CR_HiScoreMidHi-CR_HiScoreNamLen,y
                  jsr SplitScoreDigit             ;
                  
                  lda LR_Digit10                  ; 
                  jsr PrepareDigitOut             ; 
                  lda LR_Digit1                   ; 
                  jsr PrepareDigitOut             ;
                  
                  ldy $29                         ; score board offset
                  lda CR_HiScoreMidLo-CR_HiScoreNamLen,y
                  jsr SplitScoreDigit             ;
                  
                  lda LR_Digit10                  ; 
                  jsr PrepareDigitOut             ; 
                  lda LR_Digit1                   ; 
                  jsr PrepareDigitOut             ;
                  
                  ldy $29                         ; score board offset
                  lda CR_HiScoreLo-CR_HiScoreNamLen,y
                  jsr SplitScoreDigit             ;
                  
                  lda LR_Digit10                  ; 
                  jsr PrepareDigitOut             ; 
                  lda LR_Digit1                   ; 
                  jsr PrepareDigitOut             ;
                  
_NewLine          jsr SetNewLine                  ; 

                  inc $28                         ;
                  lda $28                         ;
                  cmp #LR_HiScoreMaxIDs+1         ;
                  bcs _GoOutTheBest               ;
                  
                  jmp _ShowScores                 ;
                  
_GoOutTheBest     lda #LR_BasLinRowStat           ; 
ShowHighScoresX   jmp OutTheBest                  ;
; ------------------------------------------------------------------------------------------------------------- ;
GetRowOffset      lda CR_DiskStatus               ; 
                  bpl _GetBad                     ; good
                  
_GetGood          ldx TabHiScRowPtrOk-1,y         ;                  
                  rts                             ;

_GetBad           ldx TabHiScRowPtrBad-1,y        ;
GetRowOffsetX     rts
; ------------------------------------------------------------------------------------------------------------- ;
TabHiScRowPtrOk   .byte $00
                  .byte $08
                  .byte $10
                  .byte $18
                  .byte $20
                  .byte $28
                  .byte $30
                  .byte $38
                  .byte $40
                  .byte $48
; ------------------------------------------------------------------------------------------------------------- ;
TabHiScRowPtrBad  .byte $00
                  .byte $0d
                  .byte $1a
                  .byte $27
                  .byte $34
                  .byte $41
                  .byte $4e
                  .byte $5b
                  .byte $68
                  .byte $75
; ------------------------------------------------------------------------------------------------------------- ;
OutTheBest        sta $50
                  lda CR_DiskStatus
                  bmi OutTheBestX                 ; bad
                  
                  lda CR_BestHi                   ; 
                  ora CR_BestMiHi                 ; 
                  ora CR_BestMiLo                 ;
                  ora CR_BestLo                   ;
                  beq OutTheBestX                 ; nobody passed the last level so far
                  
                  ldx #$00                        ;
                  stx CR_Work                     ;
                  stx $4f                         ; screen col ($00 - $1b)
                  stx $1e                         ;
                  
                  lda #>LR_ScrnHiReDisp           ;
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  
_HeroesMsgOut     lda CR_BestMsg,x                ; 
                  pha                             ;
                  
                  eor #$a0                        ; <blank>
                  ora $1e                         ;
                  sta $1e                         ;
                  
                  pla                             ;
                  jsr PrepareChrOut               ;
                  
                  inc CR_Work                     ;
                  ldx CR_Work                     ;
                  cpx #CR_BestMsgLen              ;
                  bcc _HeroesMsgOut               ; lower
                  
                  lda $1e                         ;
                  beq OutTheBestX                 ;
                  
                  inc $4f                         ; screen col ($00 - $1b)
                  
_HeroesScoreOut   lda CR_BestHi                   ;
                  jsr SplitScoreOut               ;
                  
                  lda CR_BestMiHi                 ;
                  jsr SplitScoreOut               ;
                  
                  lda CR_BestMiLo                 ;
                  jsr SplitScoreOut               ;
                  
                  lda CR_BestLo                   ;
                  jsr SplitScoreOut               ;
                  
OutTheBestX       rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TabHiScRowPtr_    .byte $00                       ; not used
                  .byte $00
                  .byte $08
                  .byte $10
                  .byte $18
                  .byte $20
                  .byte $28
                  .byte $30
                  .byte $38
                  .byte $40
                  .byte $48
; ------------------------------------------------------------------------------------------------------------- ;
; GetKeySubst     Function: Substitute a value for allowed keys
;                 Parms   : ac=key value
;                 Returns : ac=key substitution with bit7 set
; ------------------------------------------------------------------------------------------------------------- ;
GetKeySubst       cmp #$82                        ;
                  bne _GetSubst                   ;
                  
                  lda #$07                        ;
                  
_GetSubst         tay                             ;
                  lda TabKeySubst,y               ;
                  ora #$80                        ;
                  
GetKeySubstX      rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TabKeySubst       = *
KeyMatrixColBit0  .byte $00 ; $00 - DELETE 
                  .byte $0d ; $01 - RETURN
                  .byte $15 ; $02 - CRSR_R
                  .byte $ff ; $03 - F7
                  .byte $ff ; $04 - F1
                  .byte $ff ; $05 - F3
                  .byte $ff ; $06 - F5
                  .byte $08 ; $07 - CRSR_D
                  
KeyMatrixColBit1  .byte $33 ; $08 - 3
                  .byte $57 ; $09 - W
                  .byte $41 ; $0a - A
                  .byte $34 ; $0b - 4
                  .byte $5a ; $0c - Z
                  .byte $53 ; $0d - S
                  .byte $45 ; $0e - E
                  .byte $ff ; $0f - LSHIFT
                  
KeyMatrixColBit2  .byte $35 ; $10 - 5
                  .byte $52 ; $11 - R
                  .byte $44 ; $12 - D
                  .byte $36 ; $13 - 6
                  .byte $43 ; $14 - C
                  .byte $46 ; $15 - F
                  .byte $54 ; $16 - T
                  .byte $58 ; $17 - X
                  
KeyMatrixColBit3  .byte $37 ; $18 - 7
                  .byte $59 ; $19 - Y
                  .byte $47 ; $1a - G
                  .byte $38 ; $1b - 8
                  .byte $42 ; $1c - B
                  .byte $48 ; $1d - H
                  .byte $55 ; $1e - U
                  .byte $56 ; $1f - V
                  
KeyMatrixColBit4  .byte $39 ; $20 - 9
                  .byte $49 ; $21 - I
                  .byte $4a ; $22 - J
                  .byte $30 ; $23 - 0
                  .byte $4d ; $24 - M
                  .byte $4b ; $25 - K
                  .byte $4f ; $26 - O
                  .byte $4e ; $27 - N
                  
KeyMatrixColBit5  .byte $2b ; $28 - +
                  .byte $50 ; $29 - P
                  .byte $4c ; $2a - L
                  .byte $2d ; $2b - -
                  .byte $2e ; $2c - .
                  .byte $3a ; $2d - :
                  .byte $ff ; $2e - @
                  .byte $2c ; $2f - ,
                  
KeyMatrixColBit6  .byte $5c ; $30 - LIRA
                  .byte $2a ; $31 - *
                  .byte $3b ; $32 - ;
                  .byte $ff ; $33 - HOME
                  .byte $ff ; $34 - RSHIFT
                  .byte $3d ; $35 - =
                  .byte $ff ; $36 - ^
                  .byte $2f ; $37 - /
                  
KeyMatrixColBit7  .byte $31 ; $38 - 1
                  .byte $ff ; $39 - <-
                  .byte $ff ; $3a - CTRL
                  .byte $32 ; $3b - 2
                  .byte $20 ; $3c - SPACE
                  .byte $ff ; $3d - C=
                  .byte $51 ; $3e - Q
                  .byte $ff ; $3f - STOP
; ------------------------------------------------------------------------------------------------------------- ;
CheckNewChampXX   clc                             ; shortcut
                  rts                             ;

CheckNewChamp     jsr ChkUniquePlayId             ; 
                  
                  lda CR_DiskStatus               ; 
                  bmi CheckNewChampXX             ; bad
                  
                  lda LR_LevelNoGame              ; 001-050
                  cmp #CR_LevelNoMax              ; 051
                  bcc CheckNewChampXX             ; lower
                  
                  jsr ClearHiresDisp              ; 
                  
                  lda #>LR_ScrnHiReDisp           ;
                  sta $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  
                  lda #LR_YellowCyan              ;
                  jsr ColourLevel                 ; 
                  
                  lda #$00                        ;
                  sta $4f                         ; screen col ($00 - $1b)
                  sta $50                         ; screen row ($00 - $0f)
                  jsr TextOut                     ; TextOut
                  .byte $8d ; <newline>
                  .byte $8d ; <newline>
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $a0 ; <blank>
                  .byte $c3 ; C
                  .byte $cf ; O
                  .byte $ce ; N
                  .byte $c7 ; G
                  .byte $d2 ; R
                  .byte $c1 ; A
                  .byte $d4 ; T
                  .byte $d5 ; U
                  .byte $cc ; L
                  .byte $c1 ; A
                  .byte $d4 ; T
                  .byte $c9 ; I
                  .byte $cf ; O
                  .byte $ce ; N
                  .byte $d3 ; D
                  .byte $a0 ; <blank>
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $8d ; <newline>
                  .byte $8d ; <newline>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $d9 ; Y
                  .byte $cf ; O
                  .byte $d5 ; U
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $8d ; <newline>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $cc ; L
                  .byte $cf ; O
                  .byte $c4 ; D
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $d2 ; R
                  .byte $d5 ; U
                  .byte $ce ; N
                  .byte $ce ; N
                  .byte $c5 ; E
                  .byte $d2 ; R
                  .byte $a0 ; <blank>
                  .byte $c3 ; C
                  .byte $c8 ; H
                  .byte $c1 ; A
                  .byte $cd ; M
                  .byte $d0 ; P
                  .byte $c9 ; I
                  .byte $cf ; O
                  .byte $ce ; N
                  .byte $8d ; <newline>
                  .byte $8d ; <newline>
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $a0 ; <blank>
                  .byte $c3 ; C
                  .byte $cf ; O
                  .byte $ce ; N
                  .byte $c7 ; G
                  .byte $d2 ; R
                  .byte $c1 ; A
                  .byte $d4 ; T
                  .byte $d5 ; U
                  .byte $cc ; L
                  .byte $c1 ; A
                  .byte $d4 ; T
                  .byte $c9 ; I
                  .byte $cf ; O
                  .byte $ce ; N
                  .byte $d3 ; S
                  .byte $a0 ; <blank>
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $00 ; EndOfText
                  
_ChkOldSavHi      lda CR_BestHi                   ; saved old best score 
                  cmp LR_ScoreHi                  ; 
                  beq _ChkOldSavMidHi             ; 
                  bcs _GoSecPassword              ; 
                  
                  jmp _SuperMsgColorI             ; 
                  
_ChkOldSavMidHi   lda CR_BestMiHi                 ; 
                  cmp LR_ScoreMidHi               ; 
                  beq _ChkOldSavMidLo             ; 
                  bcs _GoSecPassword              ; 
                  
                  jmp _SuperMsgColorI             ; 
                  
_ChkOldSavMidLo   lda CR_BestMiLo                 ; 
                  cmp LR_ScoreMidLo               ; 
                  beq _ChkOldSavLo                ; 
                  bcs _GoSecPassword              ; 
                  
                  jmp _SuperMsgColorI             ; 
_ChkOldSavLo      lda CR_BestLo                   ; 
                  cmp LR_ScoreLo                  ; 
                  bcc _SuperMsgColorI             ; 
                  
_GoSecPassword    jmp _SecPassword                ; 

_SuperMsgColorI   lda #$20                        ; 
                  lda #CR_GreenGreen              ;
                  ldx #$a0                        ;
_SuperMsgColor    sta LR_ScrnMultColor+$00c8,x    ;
                  dex                             ;
                  bne _SuperMsgColor              ;
                  
                  lda #$00                        ;
                  sta $4f                         ; screen col ($00 - $1b)
                  lda #$09                        ;
                  sta $50                         ; screen row ($00 - $0f)
                  jsr TextOut                     ; TextOut
                  .byte $d9 ; Y
                  .byte $cf ; O
                  .byte $d5 ; U
                  .byte $d2 ; R
                  .byte $a0 ; <blank>
                  .byte $d3 ; S
                  .byte $c3 ; C
                  .byte $cf ; O
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $c9 ; I
                  .byte $d3 ; S
                  .byte $a0 ; <blank>
                  .byte $d4 ; T
                  .byte $c8 ; H
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $c2 ; B
                  .byte $c5 ; E
                  .byte $d3 ; S
                  .byte $d4 ; T
                  .byte $a0 ; <blank>
                  .byte $c5 ; E
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $d2 ; R
                  .byte $8d ; <newline>
                  .byte $8d ; <newline>
                  .byte $a0 ; <blank>
                  .byte $c5 ; E
                  .byte $ce ; N
                  .byte $d4 ; T
                  .byte $c5 ; E
                  .byte $d2 ; R
                  .byte $a0 ; <blank>
                  .byte $d9 ; Y
                  .byte $cf ; O
                  .byte $d5 ; U
                  .byte $d2 ; R
                  .byte $a0 ; <blank>
                  .byte $d6 ; V
                  .byte $c9 ; I
                  .byte $c3 ; C
                  .byte $d4 ; T
                  .byte $cf ; O
                  .byte $d2 ; R
                  .byte $d9 ; Y
                  .byte $a0 ; <blank>
                  .byte $cd ; M
                  .byte $c5 ; E
                  .byte $d3 ; S
                  .byte $d3 ; S
                  .byte $c1 ; A
                  .byte $c7 ; G
                  .byte $c5 ; E
                  .byte $8d ; <newline>
                  .byte $8d ; <newline>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $be ; >
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $bc ; <
                  .byte $00 ; EndOfText
                  
                  lda #$04                        ;
                  sta $4f                         ; screen col ($00 - $1b)
                  
                  lda #CR_BestMsgLen              ;
                  sta CR_InputBufMax              ;
                  jsr InputControl                ;
                  beq _SecPassword                ; 
                  
                  ldx #CR_BestMsgLen              ; 
_CpyMessage       lda CR_InputBuf,x               ; copy msg to high score data
                  sta CR_BestMsg,x                ; 
                  dex                             ;
                  bpl _CpyMessage                 ; 
                  
_CpyScore         lda LR_ScoreLo                  ; copy score to high score data
                  sta CR_BestLo                   ;
                  lda LR_ScoreMidLo               ; 
                  sta CR_BestMiLo                 ;
                  lda LR_ScoreMidHi               ; 
                  sta CR_BestMiHi                 ;
                  lda LR_ScoreHi                  ; 
                  sta CR_BestHi                   ;
                  
_SetScore         lda #LR_DiskWrite               ; write back high scoreblock
                  jsr GetPutHiScores              ; ac: $01=load $02=store 81= 82=
                  
_SecPassword      lda #$09                        ; "your score ..."
                  jsr ClearTheRow                 ;
                  
                  lda #$0b                        ; "Enter your ..."
                  jsr ClearTheRow                 ;
                  
                  lda #$0d                        ; <victory msg>
                  jsr ClearTheRow                 ;
                  
                  lda #$0a                        ;
                  sta $50                         ; screen row ($00 - $0f)
                  jsr TextOut                     ; TextOut
                  .byte $8d ; <newline>
                  .byte $c4 ; D
                  .byte $cf ; O
                  .byte $a0 ; <blank>
                  .byte $d9 ; Y
                  .byte $cf ; O
                  .byte $d5 ; U
                  .byte $a0 ; <blank>
                  .byte $d7 ; W
                  .byte $c1 ; A
                  .byte $ce ; N
                  .byte $d4 ; T
                  .byte $a0 ; <blank>
                  .byte $d4 ; T
                  .byte $cf ; O
                  .byte $a0 ; <blank>
                  .byte $cb ; K
                  .byte $ce ; N
                  .byte $cf ; O
                  .byte $d7 ; W
                  .byte $a0 ; <blank>
                  .byte $d9 ; Y
                  .byte $cf ; O
                  .byte $d5 ; U
                  .byte $d2 ; R
                  .byte $8d ; <newline>
                  .byte $a0 ; <blank>
                  .byte $d3 ; S
                  .byte $c5 ; E
                  .byte $c3 ; C
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $d4 ; T
                  .byte $a0 ; <blank>
                  .byte $d0 ; P
                  .byte $c1 ; A
                  .byte $d3 ; S
                  .byte $d3 ; S
                  .byte $d7 ; W
                  .byte $cf ; O
                  .byte $d2 ; R
                  .byte $c4 ; D
                  .byte $a0 ; <blank>
                  .byte $a8 ; (
                  .byte $d9 ; Y
                  .byte $af ; /
                  .byte $ce ; N
                  .byte $a9 ; )
                  .byte $00 ; EndOfText
                  
                  lda #$00                        ;
                  jsr WaitKeyBlink                ;
                  
                  ldx #$00                        ;
                  stx LR_KeyNew                   ; 
                  
                  cmp #$19                        ; "y"
                  beq _GetRegKey                  ;
                  
                  sec                             ; 
_Exit             rts                             ; 
                  
_GetRegKey        lda #$0a                        ; 
                  sta $50                         ; screen row ($00 - $0f)
                  jsr TextOut                     ; TextOut
                  .byte $8d ; <newline>
                  .byte $c3 ; C
                  .byte $c1 ; A
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $c6 ; F
                  .byte $d5 ; U
                  .byte $cc ; L
                  .byte $cc ; L
                  .byte $d9 ; Y
                  .byte $a0 ; <blank>
                  .byte $d4 ; T
                  .byte $d9 ; Y
                  .byte $d0 ; P
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $c9 ; I
                  .byte $ce ; N
                  .byte $a0 ; <blank>
                  .byte $d4 ; T
                  .byte $c8 ; H
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $d3 ; S
                  .byte $c5 ; E
                  .byte $d2 ; R
                  .byte $c9 ; I
                  .byte $c1 ; A
                  .byte $cc ; L
                  .byte $8d ; <newline>
                  .byte $ce ; N
                  .byte $d5 ; U
                  .byte $cd ; M
                  .byte $c2 ; B
                  .byte $c5 ; E
                  .byte $d2 ; R
                  .byte $a0 ; <blank>
                  .byte $cf ; O
                  .byte $ce ; N
                  .byte $a0 ; <blank>
                  .byte $d9 ; Y
                  .byte $cf ; O
                  .byte $d5 ; U
                  .byte $d2 ; R
                  .byte $a0 ; <blank>
                  .byte $c3 ; C
                  .byte $c8 ; H
                  .byte $c1 ; A
                  .byte $cd ; M
                  .byte $d0 ; P
                  .byte $c9 ; I
                  .byte $cf ; O
                  .byte $ce ; N
                  .byte $d3 ; S
                  .byte $c8 ; H
                  .byte $c9 ; I
                  .byte $d0 ; P
                  .byte $8d ; <newline>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $c7 ; G
                  .byte $c9 ; I
                  .byte $d3 ; S
                  .byte $d4 ; T
                  .byte $d2 ; R
                  .byte $c1 ; A
                  .byte $d4 ; T
                  .byte $c9 ; I
                  .byte $cf ; O
                  .byte $ce ; N
                  .byte $a0 ; <blank>
                  .byte $c3 ; C
                  .byte $c1 ; A
                  .byte $d2 ; R
                  .byte $c4 ; D
                  .byte $a0 ; <blank>
                  .byte $8d ; <newline>
                  .byte $8d ; <newline>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $be ; <
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $bc ; >
                  .byte $00 ; EndOfText
                  
                  lda #$0b                        ;
                  sta $4f                         ; screen col ($00 - $1b)
                  
                  lda #CR_SerialNoLen             ;
                  sta CR_InputBufMax              ;
                  
                  lda #$80                        ;
                  jsr InputControlSpec            ;
                  
                  jsr ChkUniquePlayId             ; 
                  
_ChkCounter       lda CR_HiScoreCount             ; 
                  cmp #$02                        ;
                  bcs _OutSecPswd                 ;
                  
_IncCounter       inc CR_HiScoreCount             ; 
                  
_SetCounter       lda #LR_DiskWrite               ;
                  jsr GetPutHiScores              ; ac: $01=load $02=store 81= 82=
                  
                  ldx #$03                        ; omit the first digit
_GetSerial        lda CR_SerialNoPos2,x           ;
                  sec                             ;
                  sbc #$b0                        ; reset key value to $00-$09
_SetSerial        sta CR_SerialNoPos2,x           ;
                  dex                             ;
                  bpl _GetSerial                  ;
                  
_GetSecPswd       lda CR_SerialNoPos2             ;
                  clc                             ;
                  adc CR_SerialNoPos3             ;
                  tax                             ;
                  lda TabAncientLegend,x          ; Apple Commodore Atari
                  sta __ModSecPswd02              ;
                  
                  lda CR_SerialNoPos3             ;
                  clc                             ;
                  adc CR_SerialNoPos4             ;
                  tax                             ;
                  lda TabAncientLegend,x          ; Apple Commodore Atari
                  sta __ModSecPswd03              ;
                  
                  lda CR_SerialNoPos4             ;
                  clc                             ;
                  adc CR_SerialNoPos5             ;
                  tax                             ;
                  lda TabAncientLegend,x          ; Apple Commodore Atari
                  sta __ModSecPswd04              ;
                  
                  lda CR_SerialNoPos5             ;
                  clc                             ;
                  adc CR_SerialNoPos2             ;
                  tax                             ;
                  lda TabAncientLegend,x          ; Apple Commodore Atari
                  sta __ModSecPswd05              ;
                  
_OutSecPswd       jsr ClearHiresDisp              ; ClearDisplay20
                  lda #$06                        ;
                  sta $50                         ; screen row ($00 - $0f)
                  jsr TextOut                     ; TextOut
                  .byte $8d ; <newline>
                  .byte $c2 ; B
                  .byte $c5 ; E
                  .byte $cc ; L
                  .byte $cf ; O
                  .byte $d7 ; W
                  .byte $a0 ; <blank>
                  .byte $c9 ; I
                  .byte $d3 ; S
                  .byte $a0 ; <blank>
                  .byte $d9 ; Y
                  .byte $cf ; O
                  .byte $d5 ; U
                  .byte $d2 ; R
                  .byte $a0 ; <blank>
                  .byte $d5 ; U
                  .byte $ce ; N
                  .byte $c9 ; I
                  .byte $d1 ; Q
                  .byte $d5 ; U
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $d3 ; S
                  .byte $c5 ; E
                  .byte $c3 ; C
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $d4 ; T
                  .byte $8d ; <newline>
                  .byte $d0 ; P
                  .byte $c1 ; A
                  .byte $d3 ; S
                  .byte $d3 ; S
                  .byte $d7 ; W
                  .byte $cf ; O
                  .byte $d2 ; R
                  .byte $c4 ; D
                  .byte $ae ; .
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $d7 ; W
                  .byte $d2 ; R
                  .byte $c9 ; I
                  .byte $d4 ; T
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $c9 ; I
                  .byte $d4 ; T
                  .byte $a0 ; <blank>
                  .byte $cf ; O
                  .byte $ce ; N
                  .byte $a0 ; <blank>
                  .byte $d9 ; Y
                  .byte $cf ; O
                  .byte $d5 ; U
                  .byte $d2 ; R
                  .byte $8d ; <newline>
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $c7 ; G
                  .byte $c9 ; I
                  .byte $d3 ; S
                  .byte $d4 ; T
                  .byte $d2 ; R
                  .byte $c1 ; A
                  .byte $d4 ; T
                  .byte $c9 ; I
                  .byte $cf ; O
                  .byte $ce ; N
                  .byte $a0 ; <blank>
                  .byte $c3 ; C
                  .byte $c1 ; A
                  .byte $d2 ; R
                  .byte $c4 ; D
                  .byte $a0 ; <blank>
                  .byte $d2 ; R
                  .byte $c9 ; I
                  .byte $c7 ; G
                  .byte $c8 ; H
                  .byte $d4 ; T
                  .byte $a0 ; <blank>
                  .byte $ce ; N
                  .byte $cf ; O
                  .byte $d7 ; W
                  .byte $8d ; <newline>
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $ce ; N
                  .byte $c4 ; D
                  .byte $a0 ; <blank>
                  .byte $cd ; M
                  .byte $c1 ; A
                  .byte $c9 ; I
                  .byte $cc ; L
                  .byte $a0 ; <blank>
                  .byte $c9 ; I
                  .byte $d4 ; T
                  .byte $a0 ; <blank>
                  .byte $d4 ; T
                  .byte $cf ; O
                  .byte $a0 ; <blank>
                  .byte $c2 ; B
                  .byte $d2 ; R
                  .byte $cf ; O
                  .byte $c4 ; D
                  .byte $c5 ; E
                  .byte $d2 ; R
                  .byte $c2 ; B
                  .byte $d5 ; U
                  .byte $ce ; N
                  .byte $c4 ; D
                  .byte $8d ; <newline>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $d3 ; S
                  .byte $a0 ; <blank>
                  .byte $d3 ; S
                  .byte $cf ; O
                  .byte $cf ; O
                  .byte $ce ; N
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $d3 ; S
                  .byte $a0 ; <blank>
                  .byte $d0 ; P
                  .byte $cf ; O
                  .byte $d3 ; S
                  .byte $d3 ; S
                  .byte $c9 ; I
                  .byte $c2 ; B
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $8d ; <newline>
                  .byte $8d ; <newline>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $be ; <
                  .byte $c3 ; C
__ModSecPswd02    .byte $d1 ; Q
__ModSecPswd03    .byte $c1 ; A
__ModSecPswd04    .byte $c4 ; D
__ModSecPswd05    .byte $c9 ; I
                  .byte $bc ; >
                  .byte $8d ; <newline>
                  .byte $8d ; <newline>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $c8 ; H
                  .byte $c9 ; I
                  .byte $d4 ; T
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $a0 ; <blank>
                  .byte $cb ; K
                  .byte $c5 ; E
                  .byte $d9 ; Y
                  .byte $a0 ; <blank>
                  .byte $00 ; EndOfText
                  
                  lda #$00                        ;
                  jsr WaitKeyBlink                ;
                  
                  lda #$00                        ;
                  sta LR_KeyNew                   ;
                   
                  sec                             ;
CheckNewChampX    rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
TabAncientLegend  .byte $c1 ; A
                  .byte $d0 ; P
                  .byte $d0 ; P
                  .byte $cc ; L
                  .byte $c5 ; E

                  .byte $c3 ; C
                  .byte $cf ; O
                  .byte $cd ; M
                  .byte $cd ; M
                  .byte $cf ; O
                  .byte $c4 ; D
                  .byte $cf ; O
                  .byte $d2 ; R
                  .byte $c5 ; E

                  .byte $c1 ; A
                  .byte $d4 ; T
                  .byte $c1 ; A
                  .byte $d2 ; R
                  .byte $c9 ; I
; ------------------------------------------------------------------------------------------------------------- ;
MoveLodeRunner    lda #LR_GetGoldGot
                  sta LR_GetGold                  ; get gold  $00=just gets it
                  lda LR_Shoots                   ; $00=no $01=right $ff=left
                  beq _MoveLR
                  bpl _GoFireRightLR
                  
_GoFireLeftLR     jmp LRFireLeft
_GoFireRightLR    jmp LRFireRight
                  
_MoveLR           ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $03
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)  = data under lr
                  cmp #NoTileLadder
                  beq _GoChkFallDown
                  
                  cmp #NoTilePole
                  bne _GetPosUD
                  
                  lda $06                         ; lr pos on image up/down
                  cmp #$02                        ; in middle of screen image
                  beq _GoChkFallDown
                  
_GetPosUD         lda $06                         ; lr pos on image up/down
                  cmp #$02                        ; in middle of screen image
                  bcc _SetFallDown
                  
                  ldy $04                         ; actual row lode runner
                  cpy #LR_ScrnMaxRows             ; $0f - max 15 rows
                  beq _GoChkFallDown              ; bottom reached
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8+1,y        ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  ldy $03                         ; adr column lode runner
                  lda ($09),y                     ; unpacked level data ($0800-$09c3) + 1
                  cmp #$00                        ; nothing
                  beq _SetFallDown
                  
                  cmp #NoTileEnemy
                  beq _GoChkFallDown
                  
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  beq _GoChkFallDown
                  
                  cmp #NoTileWallHard
                  beq _GoChkFallDown
                  
                  cmp #NoTileLadder
                  bne _SetFallDown
                  
_GoChkFallDown    jmp _EndFallDown
                  
_SetFallDown      lda #LR_Falls
                  sta LR_FallsDown                ; $00=fall $20=no fall $ff=init
                  dec LR_FallBeep
                  jsr GetLRGfxOff
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
                  lda #$07
                  ldx $08                         ; control shooter mode
                  bmi _SetSpriteNo
                  
                  lda #$0f
_SetSpriteNo      sta $07                         ; lr sprite number
                  jsr MovLRWaitPosX
                  
                  inc $06                         ; lr pos on image up/down
                  lda $06
                  cmp #$05                        ; max
                  bcs _InitPosUD
                  
                  jsr MovLRGold                   ; wait for center and handle the gold
                  jmp MovLRKill
                  
_InitPosUD        lda #$00
                  sta $06                         ; lr pos on image up/down
                  
                  ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  bne _Store
                  
                  lda #NoTileBlank                ; empty substitution
                  
_Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  inc $04                         ; actual row lode runner
                  ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $03                         ; adr column lode runner
                  lda #NoTileLodeRunner
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  jmp MovLRKill
                  
_EndFallDown      lda LR_FallsDown                ; $00=fall $20=no fall $ff=init
                  bne _Always
                  
_Always           lda #LR_FallsNo                 ; end
                  sta LR_FallsDown                ; $00=fall $20=no fall $ff=init
                  
                  jsr GetPlayCmd
                  
                  lda LR_JoyUpDo
_ChkMoveUp        cmp #LR_JoyMoveUp               ; move up
                  bne _ChkMoveDown
                  
_MoveUp           jsr MovLRUp
                  bcs _ChkMoveLeft
                  rts
                  
_ChkMoveDown      cmp #LR_JoyMoveDo               ; move down
                  bne _ChkFireLeft
_MoveDown         jsr LRMoveDown
                  bcs _ChkMoveLeft
                  rts
                  
_ChkFireLeft      cmp #LR_JoyFireLe               ; fire left
                  bne _ChkFireRight
_FireLeft         jsr MovLRFireLeft
                  bcs _ChkMoveLeft
                  rts
                  
_ChkFireRight     cmp #LR_JoyFireRi               ; fire right
                  bne _ChkMoveLeft
_FireRight        jsr MovLRFireRight
                  bcs _ChkMoveLeft
                  rts
                  
_ChkMoveLeft      lda LR_JoyLeRi
                  cmp #LR_JoyMoveLe               ; move left
                  bne _ChkMoveRight
                  
_MoveLeft         jmp MovLRLeft
                  
_ChkMoveRight     cmp #LR_JoyMoveRi               ; move right
                  bne MoveLodeRunnerX
_MoveRight        jmp LRMoveRight
                  
MoveLodeRunnerX   rts
; ------------------------------------------------------------------------------------------------------------- ;
MovLRLeft         ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  ldx $05
                  cpx #$03
                  bcs MovLRLeftABit               ; not yet in center so MovLRLeftABit
                  
                  ldy $03                         ; adr column lode runner
                  beq MovLRLeftX
                  
                  dey
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #NoTileWallHard
                  beq MovLRLeftX
                  
                  cmp #NoTileWallWeak
                  beq MovLRLeftX
                  
                  cmp #NoTileWallTrap
                  bne MovLRLeftABit
                  
MovLRLeftX        rts
; ------------------------------------------------------------------------------------------------------------- ;
MovLRLeftABit     jsr GetLRGfxOff
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
                  lda #$ff
                  sta $08                         ; control shooter mode
                  jsr MovLRWaitPosY
                  
                  dec $05                         ; lr pos on image left/right = one step left
                  bpl _Gold                       ; move from actual to next left field not yet complete
                  
_NewField         ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  bne _Store
                  
                  lda #NoTileBlank                ; empty substitution
                  
_Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  dec $03                         ; adr column lode runner
                  dey
                  lda #NoTileLodeRunner
_SetLR            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  lda #$04                        ; max right to
                  sta $05                         ;   lr pos on image left/right
                  bne _SetNextPos                 ; always
                  
_Gold             jsr MovLRGold                   ; wait for center and handle the gold
                  
_SetNextPos       ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTilePole
                  beq _PoleImage
                  
_RunImage         lda #NoLR_RunLeMin              ; low image no
                  ldx #NoLR_RunLeMax              ; high image no
                  bne _OutImage
                  
_PoleImage        lda #NoLR_PoleLeMin             ; low image no
                  ldx #NoLR_PoleLeMax             ; high image no
_OutImage         jsr MovLRSetImg
                  
MovLRLeftABitX    jmp MovLRKill
; ------------------------------------------------------------------------------------------------------------- ;
LRMoveRight       ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldx $05                         ; lr pos on image left/right
                  cpx #$02
                  bcc MovLRRightABit              ; not yet in center so MovLRRightABit
                  
                  ldy $03                         ; adr column lode runner
                  cpy #LR_ScrnMaxCols             ; $1b - max 27 cols
                  beq LRMoveRightX
                  
                  iny
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #NoTileWallHard
                  beq LRMoveRightX
                  
                  cmp #NoTileWallWeak
                  beq LRMoveRightX
                  
                  cmp #NoTileWallTrap
                  bne MovLRRightABit
                  
LRMoveRightX      rts
; ------------------------------------------------------------------------------------------------------------- ;
MovLRRightABit    jsr GetLRGfxOff
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
                  lda #$01
                  sta $08                         ; control shooter mode
                  jsr MovLRWaitPosY
                  
                  inc $05                         ; lr pos on image left/right
                  lda $05                         ; lr pos on image left/right
                  cmp #$05                        ; max
                  bcc _Gold
                  
                  ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  bne _Store
                  
                  lda #NoTileBlank                ; empty substitution
_Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  inc $03                         ; adr column lode runner
                  iny
                  lda #NoTileLodeRunner
_SetLR            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  lda #$00
                  sta $05                         ; lr pos on image left/right
                  beq _SetNextPos                 ; always
                  
_Gold             jsr MovLRGold                   ; wait for center and handle the gold
                  
_SetNextPos       ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTilePole
                  beq _PoleImage
                  
_RunImage         lda #NoLR_RunRiMin              ; low image no
                  ldx #NoLR_RunRiMax              ; high image no
                  bne _OutImage
                  
_PoleImage        lda #NoLR_PoleRiMin             ; low image no
                  ldx #NoLR_PoleRiMax             ; high image no
_OutImage         jsr MovLRSetImg
                  
MovLRRightABitX   jmp MovLRKill
; ------------------------------------------------------------------------------------------------------------- ;
MovLRUp           ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3) = data under lr
                  cmp #NoTileLadder
                  beq MovLRUpABit
                  
                  ldy $06                         ; lr pos on image up/down
                  cpy #$03                        ; in center
                  bcc MovUpXitSetCarry            ; no
                  
                  ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3) + 1 = data below lr
                  cmp #NoTileLadder
                  beq MovUpGetGfxOff
                  
MovUpXitSetCarry  sec
MovLRUpX          rts
; ------------------------------------------------------------------------------------------------------------- ;
MovLRUpABit       ldy $06                         ; lr pos on image up/down
                  cpy #$03                        ; in center
                  bcs MovUpGetGfxOff              ; equal/higher
                  
                  ldy $04                         ; actual row lode runner
                  beq MovUpXitSetCarry
                  
                  lda TabExLvlDatRowLo-1,y        ; expanded level data row pointer lo
                  sta $09
                  lda TabExLvlDatRowH8-1,y        ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $03                         ; adr column lode runner
                  lda ($09),y                     ; unpacked level data ($0800-$09c3) - 1 = data above lr
                  cmp #NoTileWallWeak
                  beq MovUpXitSetCarry
                  
                  cmp #NoTileWallHard
                  beq MovUpXitSetCarry
                  
                  cmp #NoTileWallTrap
                  beq MovUpXitSetCarry
; ------------------------------------------------------------------------------------------------------------- ;
MovUpGetGfxOff    jsr GetLRGfxOff
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
                  ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  jsr MovLRWaitPosX
                  
                  dec $06                         ; lr pos on image up/down
                  bpl MovUpDownGold
                  
                  ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  bne _Store
                  
                  lda #NoTileBlank                ; empty substitution
                  
_Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  dec $04                         ; actual row lode runner
                  ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $03                         ; adr column lode runner
                  lda #NoTileLodeRunner
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  lda #$04
                  sta $06                         ; lr pos on image up/down
                  bne MovUpDown                   ; always
                  
MovUpDownGold     jsr MovLRGold                   ; wait for center and handle the gold
                  
MovUpDown         lda #NoLR_LadderMin             ; low image no
                  ldx #NoLR_LadderMax             ; high image no
                  jsr MovLRSetImg
                  jsr MovLRKill
                  
                  clc
MovLRUpABitX      rts
; ------------------------------------------------------------------------------------------------------------- ;
LRMoveDown        ldy $06                         ; lr pos on image up/down
                  cpy #$02                        ; in center of screen image
                  bcc MovLRDownABit
                  
                  ldy $04                         ; actual row lode runner
                  cpy #LR_ScrnMaxRows             ; $0f - max 15 rows
                  bcs _XitSetCarry
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8+1,y        ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $03                         ; adr column lode runner
                  lda ($09),y                     ; unpacked level data ($0800-$09c3) + 1
                  cmp #NoTileWallHard
                  beq _XitSetCarry
                  
                  cmp #NoTileWallWeak
                  bne MovLRDownABit
                  
_XitSetCarry      sec
LRMoveDownX       rts
; ------------------------------------------------------------------------------------------------------------- ;
MovLRDownABit     jsr GetLRGfxOff
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
                  ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  jsr MovLRWaitPosX
                  
                  inc $06                         ; lr pos on image up/down
                  lda $06                         ; lr pos on image up/down
                  cmp #$05                        ; center screen image
                  bcc _GoMovUpDownGold
                  
                  ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  bne _Store
                  
                  lda #NoTileBlank                ; empty substitution
                  
_Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  inc $04                         ; actual row lode runner
                  ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $03                         ; adr column lode runner
                  lda #NoTileLodeRunner
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  lda #$00
                  sta $06                         ; lr pos on image up/down
                  jmp MovUpDown
                  
_GoMovUpDownGold  jmp MovUpDownGold
                  
FireLeftNone      jmp OutLRFireLeftNo
; ------------------------------------------------------------------------------------------------------------- ;
MovLRFireLeft     lda #LR_ShootsLe
                  sta LR_Shoots                   ; $00=no $01=right $ff=left
                  sta LR_JoyUpDo
                  sta LR_JoyLeRi
                  lda #$00
                  sta $54                         ; lr actual sprite number
                  
LRFireLeft        ldy $04                         ; actual row lode runner
                  cpy #LR_ScrnMaxRows             ; $0f - max 15 rows
                  bcs FireLeftNone                ; no walls left for shooting
                  
                  iny
                  jsr GetCtrlDataPtr
                  
                  ldy $03                         ; adr column lode runner
                  beq FireLeftNone                ; leftmost position
                  
                  dey
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #NoTileWallWeak
                  bne FireLeftNone
                  
                  ldy $04                         ; actual row lode runner
                  jsr GetCtrlDataPtr
                  
                  ldy $03                         ; adr column lode runner
                  dey
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #NoTileBlank                ; empty
                  bne OutLRFireLeft
                  
                  jsr GetLRGfxOff
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
                  jsr MovLRWaitPosX
                  jsr MovLRWaitPosY
                  
                  ldx $54                         ; lr actual sprite number
                  lda #$00
                  cpx #$06
                  bcs _StoreSpriteNo
                  
                  lda #$06
                  
_StoreSpriteNo    sta $07
                  jsr MovLRKill
                  
                  ldx $54                         ; lr actual sprite number
                  cpx #$0c
                  beq MovLRSetHoleLe
                  
                  cpx #$00
                  beq _GetShootImage2
                  
_GetShootImage1   lda TabShootNoSpark-1,x
                  pha
                  
                  ldx $03                         ; adr column lode runner
                  dex
                  ldy $04                         ; actual row lode runner
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row
                  
                  pla
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
                  ldx $54                         ; lr actual sprite number
_GetShootImage2   lda TabShootNoSpark,x
                  pha                             ; save image number
                  
                  ldx $03                         ; adr column lode runner
                  dex
                  stx $4f                         ; screen col  (00-1b)
                  
                  ldy $04                         ; actual row lode runner
                  sty $50                         ; screen row  (00-0f)
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row
                  
                  pla                             ; restore image number
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  
                  ldx $54                         ; lr actual sprite number
_GetMeltImage     lda TabShootMeltGrnd,x
                  inc $50                         ; screen row  (00-0f)
_PutMeltImage     jsr ImageOut2Disp               ; direct output to display screen
                  
                  inc $54                         ; lr actual sprite number
                  
                  clc
MovLRFireLeftX    rts
; ------------------------------------------------------------------------------------------------------------- ;
OutLRFireLeft     ldy $04                         ; actual row lode runner
                  iny                             ; +1
                  sty $50                         ; screen row  (00-0f)
                  ldy $03                         ; adr column lode runner
                  dey
                  sty $4f                         ; screen col  (00-1b)
                  
                  lda #NoTileWallWeak
                  jsr ImageOut2Disp               ; direct output to display screen
                  
                  ldx $54                         ; lr actual sprite number
                  beq OutLRFireLeftNo
                  
                  dex
_GetShootImage    lda TabShootNoSpark,x
                  pha
                  
                  ldy $04                         ; actual row lode runner
                  ldx $03                         ; adr column lode runner
                  dex
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row
                  
                  pla
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
OutLRFireLeftNo   lda #LR_ShootsNo
                  sta LR_Shoots                   ; $00=no $01=right $ff=left
                  
                  sec
OutLRFireLeftX    rts
; ------------------------------------------------------------------------------------------------------------- ;
MovLRSetHoleLe    ldx $03                         ; adr column lode runner
                  dex
                  jmp MovLRSetHole
; ------------------------------------------------------------------------------------------------------------- ;
GoSetNoShoot      jmp SetNoShoot
; ------------------------------------------------------------------------------------------------------------- ;
MovLRFireRight    lda #LR_ShootsRi
                  sta LR_Shoots                   ; $00=no $01=right $ff=left
                  sta LR_JoyUpDo
                  sta LR_JoyLeRi
                  lda #$0c
                  sta $54                         ; lr actual sprite number
                  
LRFireRight       ldy $04                         ; actual row lode runner
                  cpy #LR_ScrnMaxRows             ; $0f - max 15 rows
                  bcs GoSetNoShoot
                  
                  iny
                  jsr GetCtrlDataPtr
                  ldy $03                         ; adr column lode runner
                  cpy #LR_ScrnMaxCols             ; $1b - max 27 cols
                  bcs GoSetNoShoot
                  
                  iny
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #NoTileWallWeak
                  bne GoSetNoShoot
                  
                  ldy $04                         ; actual row lode runner
                  jsr GetCtrlDataPtr
                  
                  ldy $03                         ; adr column lode runner
                  iny
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #NoTileBlank                ; empty
                  bne MovLRFireNoHole
                  
                  jsr GetLRGfxOff
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  jsr MovLRWaitPosX
                  jsr MovLRWaitPosY
                  
                  ldx $54                         ; lr actual sprite number
                  lda #$08
                  cpx #$12
                  bcs _SetSprite
                  
                  lda #$0e
_SetSprite        sta $07                         ; lr sprite number
                  jsr MovLRKill
                  
                  ldx $54                         ; lr actual sprite number
                  cpx #$18
                  beq MovLRSetHoleRi
                  
                  cpx #$0c
                  beq _GetShootImage2
                  
_GetShootImage1   lda TabShootNoSpark-1,x
                  pha
                  
                  ldx $03                         ; adr column lode runner
                  inx
                  ldy $04                         ; actual row lode runner
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row
                  
                  pla
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
                  ldx $54                         ; lr actual sprite number
_GetShootImage2   lda TabShootNoSpark,x
                  pha
                  
                  ldx $03                         ; adr column lode runner
                  inx
                  stx $4f                         ; screen col  (00-1b)
                  ldy $04                         ; actual row lode runner
                  sty $50                         ; screen row  (00-0f)
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row
                  
                  pla
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  
                  inc $50                         ; screen row  (00-0f)
                  ldx $54
_GetMeltImage     lda TabShootMelt,x
_PutMeltImage     jsr ImageOut2Disp               ; direct output to display screen
                  
                  inc $54
                  clc
MovLRFireRightX   rts
; ------------------------------------------------------------------------------------------------------------- ;
MovLRFireNoHole   ldy $04                         ; actual row lode runner
                  iny
                  sty $50                         ; screen row  (00-0f)
                  ldy $03                         ; adr column lode runner
                  iny
                  sty $4f                         ; screen col  (00-1b)
                  lda #NoTileWallWeak
                  jsr ImageOut2Disp               ; direct output to display screen
                  
                  ldx $54                         ; lr actual sprite number
                  cpx #$0c
                  beq SetNoShoot
                  
                  dex
_GetShootImage    lda TabShootNoSpark,x
                  pha
                  
                  ldx $03                         ; adr column lode runner
                  inx
                  ldy $04                         ; actual row lode runner
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row
                  
                  pla
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
SetNoShoot        lda #LR_ShootsNo
                  sta LR_Shoots                   ; $00=no $01=right $ff=left
                  
                  sec
MovLRFireNoHoleX  rts
; ------------------------------------------------------------------------------------------------------------- ;
MovLRSetHoleRi    ldx $03
                  inx
                  jmp MovLRSetHole
; ------------------------------------------------------------------------------------------------------------- ;
TabSpriteNoLodeR  = *
TabLR_RunLeMin    .byte $0b ; $00 - run    left 01
                  .byte $0c ; $01 - run    left 02
TabLR_RunLeMax    .byte $0d ; $02 - run    left 03
TabLR_PoleLeMin   .byte $18 ; $03 - pole   left 01
                  .byte $19 ; $04 - pole   left 02
TabLR_PoleLeMax   .byte $1a ; $05 - pole   left 03
                  .byte $0f ; $06 - fire   left
                  .byte $13 ; $07 - fall   left
TabLR_RunRiMin    .byte $09 ; $08 - run    right 01
                  .byte $10 ; $09 - run    right 02
TabLR_RunRiMax    .byte $11 ; $0a - run    right 03
TabLR_PoleRiMin   .byte $15 ; $0b - pole   right 01
                  .byte $16 ; $0c - pole   right 02
TabLR_PoleRiMax   .byte $17 ; $0d - pole   right 03
                  .byte $25 ; $0e - fire   right
                  .byte $14 ; $0f - fall   right
TabLR_LadderMin   .byte $0e ; $10 - ladder up/down 01
TabLR_LadderMax   .byte $12 ; $11 - ladder up/down 02
; ------------------------------------------------------------------------------------------------------------- ;
NoLR_RunLeMin     := TabLR_RunLeMin  - TabSpriteNoLodeR
NoLR_RunLeMax     := TabLR_RunLeMax  - TabSpriteNoLodeR
NoLR_PoleLeMin    := TabLR_PoleLeMin - TabSpriteNoLodeR
NoLR_PoleLeMax    := TabLR_PoleLeMax - TabSpriteNoLodeR
NoLR_RunRiMin     := TabLR_RunRiMin  - TabSpriteNoLodeR
NoLR_RunRiMax     := TabLR_RunRiMax  - TabSpriteNoLodeR
NoLR_PoleRiMin    := TabLR_PoleRiMin - TabSpriteNoLodeR
NoLR_PoleRiMax    := TabLR_PoleRiMax - TabSpriteNoLodeR
NoLR_LadderMin    := TabLR_LadderMin - TabSpriteNoLodeR
NoLR_LadderMax    := TabLR_LadderMax - TabSpriteNoLodeR
; ------------------------------------------------------------------------------------------------------------- ;
TabShootNoSpark   .byte $1b ; $00 - shoot spark 00
                  .byte $1b ; $01 - shoot spark 00
                  .byte $1c ; $02 - shoot spark 01
                  .byte $1c ; $03 - shoot spark 01
                  .byte $1d ; $04 - shoot spark 02
                  .byte $1d ; $05 - shoot spark 02
                  .byte $1e ; $06 - shoot spark 03
                  .byte $1e ; $07 - shoot spark 03
                  .byte $00 ; $08 - tile empty
                  .byte $00 ; $09 - tile empty
                  .byte $00 ; $0a - tile empty
                  .byte $00 ; $0b - tile empty
; ------------------------------------------------------------------------------------------------------------- ;
TabShootMelt      .byte $26 ; $00 - init melt above ground 01
                  .byte $26 ; $01 - init melt above ground 02
                  .byte $27 ; $02 - init melt above ground 01
                  .byte $27 ; $03 - init melt above ground 02
                  .byte $1d ; $04 - shoot spark 02
                  .byte $1d ; $05 - shoot spark 02
                  .byte $1e ; $06 - shoot spark 03
                  .byte $1e ; $07 - shoot spark 03
                  .byte $00 ; $08 - tile empty
                  .byte $00 ; $09 - tile empty
                  .byte $00 ; $0a - tile empty
                  .byte $00 ; $0b - tile empty
; ------------------------------------------------------------------------------------------------------------- ;
TabShootMeltGrnd  .byte $1f  ; $00 - shoot melt ground 01
                  .byte $1f  ; $01 - shoot melt ground 01
                  .byte $20  ; $02 - shoot melt ground 02
                  .byte $20  ; $03 - shoot melt ground 02
                  .byte $21  ; $04 - shoot melt ground 03
                  .byte $21  ; $05 - shoot melt ground 03
                  .byte $22  ; $06 - shoot melt ground 04
                  .byte $22  ; $07 - shoot melt ground 04
                  .byte $23  ; $08 - shoot melt ground 05
                  .byte $23  ; $09 - shoot melt ground 05
                  .byte $24  ; $0a - shoot melt ground 06
                  .byte $24  ; $0b - shoot melt ground 06
; ------------------------------------------------------------------------------------------------------------- ;
ContinueDemo      lda LR_KeyNew                   ; lrNewKey
                  bne _Kill                       ;
                  
                  lda CIAPRA                      ; CIA 1 - $DC00 = Data Port A
                  and #$10                        ; isolate fire button
                  bne RunDemo                     ; no
                  
_Kill             lsr $59                         ; save LR_LevelNoGame
                  lsr LR_Alive                    ; kill LR immediately ends the level
                  
                  cmp #$aa                        ; 
                  beq _GoGetUserKey               ;
                  
                  cmp #$01                        ;
                  bne _SetLastLife                ;
                  
_GoGetUserKey     jmp GetUserKey                  ; 

_SetLastLife      lda #$01                        ; 
                  sta LR_NumLives                 ; last live used up ends the demo immediately
                  
ContinueDemoX     rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
RunDemo           lda $58                         ; duration demo move
                  bne _DoMove                     ; not ended yet
                  
                  ldy #$00                        ;
_GetMove          lda ($55),y                     ; demo data pointer
                  sta $57                         ; type of demo move  (l/r/u/d/fire)
                  
_GetTime          iny                             ;
                  lda ($55),y                     ; demo data pointer
                  sta $58                         ; duration demo move
                  
_IncMovePtr       lda $55                         ;
                  clc                             ;
                  adc #$02                        ;
                  sta $55                         ; demo data pointer low
                  lda $56                         ;
                  adc #$00                        ;
                  sta $56                         ; demo data pointer high
                  
_DoMove           lda $57                         ; type demo move  (l/r/u/d/fire)
                  and #$0f                        ; isolate right nybble for up/down moves
                  tax                             ;
                  lda TabDemoJoyActn,x            ; demo joystick action tab
_SetUpDo          sta LR_JoyUpDo                  ; 

                  lda $57                         ; type demo move  (l/r/u/d/fire)
                  lsr a                           ; isolate left nybble for left/right moves
                  lsr a                           ;
                  lsr a                           ;
                  lsr a                           ;
                  tax                             ;
                  lda TabDemoJoyActn,x            ;
_SetLeRi          sta LR_JoyLeRi                  ;

_DecTime          dec $58                         ; duration demo move

RunDemoX          rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TabDemoJoyActn    .byte LR_JoyMoveUp ; 0 - $21=up
                  .byte LR_JoyMoveLe ; 1 - $22=left
                  .byte LR_JoyMoveDo ; 2 - $25=down
                  .byte LR_JoyMoveRi ; 3 - $2a=right
                  .byte LR_JoyFireRi ; 4 - $26=fire-right
                  .byte LR_JoyFireLe ; 5 - $1e=fire-left
; ------------------------------------------------------------------------------------------------------------- ;
GetPlayCmd        lda LR_GameCtrl                 ; $00=Init $01=demo $02=play
                  cmp #LR_GameDemo                ;
                  beq ContinueDemo                ;
                  
                  ldx LR_KeyNew                   ;
                  bne _ChkKeyI                    ; pressed
                  
                  lda LR_ControllerTyp            ; lrControl (ca=joystick  cb=keyboard)
                  cmp #LR_Keyboard                ;
                  beq GetPlayCmdX                 ;
                  
_GoChkJoyPort     jmp ChkJoyPort                  ;

_ChkKeyI          lda #LR_KeyNewNone              ; 
                  sta LR_KeyNew                   ; reset actual key
                  
                  stx $23                         ; save actual key
                  ldy #$ff                        ;
_ChkKey           iny                             ;
                  lda TabPlayCmdChr,y             ; in game keys tab  (RUN/STOP R A J K + - D ? ?)
                  beq _ChkCtrlType                ; was no legal command key
                  
                  cmp $23                         ;
                  bne _ChkKey                     ;
                  
                  tya                             ;
                  asl a                           ;
                  tay                             ;
_PrepareCmd       lda TabPlayCmdSub+1,y           ;
                  pha                             ;
                  lda TabPlayCmdSub,y             ;
                  pha                             ;
_DispatchCmd      rts                             ;

_ChkCtrlType      lda LR_ControllerTyp            ; lrControl (ca=joystick  cb=keyboard)
                  cmp #$ca                        ;
                  beq _GoChkJoyPort               ;
                  
                  ldx $23                         ;
                  stx LR_JoyUpDo                  ; 
                  stx LR_JoyLeRi                  ; 
                  
GetPlayCmdX       rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
IGC_Never         inc LR_CntSpeedLaps             ; speed up
                  inc LR_NumLives                 ; 
                  lsr LR_Alive                    ; kill lr

IGC_NeverX        rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
IGC_Pause         jsr GetAKey                     ;
                  cmp #$03                        ;
                  bne _Chk_RunStop                ;
                  
                  sta CR_Cheat                    ;
_Chk_RunStop      cmp #$3f                        ; RUN/STOP
                  bne IGC_Pause                   ;
                  
IGC_PauseX        jmp GetPlayCmd                  ;
; ------------------------------------------------------------------------------------------------------------- ;
IGC_Quit          jmp GameOver                    ; mlGameOver
; ------------------------------------------------------------------------------------------------------------- ;
IGC_Suicide       lsr LR_Alive                    ; lrStillAlive  (0=killed)
IGC_SuicideX      rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
IGC_SetJoy        lda #$ca                        ;
                  sta LR_ControllerTyp            ; lrControl (ca=joystick  cb=keyboard)
IGC_SetJoyX       jmp GetPlayCmd                  ;
; ------------------------------------------------------------------------------------------------------------- ;
IGC_SetKeyBd      lda #$cb                        ; 
                  sta LR_ControllerTyp            ; lrControl (ca=joystick  cb=keyboard)
IGC_SetKeyBdX     jmp GetPlayCmd                  ;
; ------------------------------------------------------------------------------------------------------------- ;
IGC_DecSpeed      lda LR_GameSpeed                ; lrGameSpeed
                  cmp #LR_SpeedMin                ;
                  beq LR_SpeedMaxX                ;
                  
                  dec LR_GameSpeed                ; lrGameSpeed
                  
IGC_DecSpeedX     jmp GetPlayCmd                  ;
; ------------------------------------------------------------------------------------------------------------- ;
IGC_IncSpeed      lda LR_GameSpeed                ; lrGameSpeed
                  cmp #LR_SpeedMax                ;
                  beq LR_SpeedMaxX                ;
                  
                  inc LR_GameSpeed                ; lrGameSpeed
                  
LR_SpeedMaxX      jmp GetPlayCmd                  ;
; ------------------------------------------------------------------------------------------------------------- ;
IGC_ShootMode     lda LR_ShootMode                ; lrShootMode
                  eor #$ff                        ;
                  sta LR_ShootMode                ; lrShootMode
IGC_ShootModeX    jmp GetPlayCmd                  ;
; ------------------------------------------------------------------------------------------------------------- ;
ChkJoyPort        lda CIAPRA                      ; CIA 1 - $DC00 = Data Port A
                  and #$10                        ; Bit 4: Joystick 2 - Fire   0=pressed
                  bne _ChkMoves                   ;
                  
_CheckMode        lda $08                         ;
                  eor LR_ShootMode                ;
                  bpl _FireLeft                   ;
                  
_FireRight        lda #LR_JoyFireRi               ; 
                  sta LR_JoyUpDo                  ; 
                  sta LR_JoyLeRi                  ; 
_FireRightX       rts                             ;
                  
_FireLeft         lda #LR_JoyFireLe               ; 
                  sta LR_JoyUpDo                  ; 
                  sta LR_JoyLeRi                  ; 
_FireLeftX        rts                             ;
                  
_ChkMoves         lda CIAPRA                      ; CIA 1 - $DC00 = Data Port A
                  sta $1e                         ; SavCIA
                  
_ChkUpDown        and #$02                        ; Bit 1: Joystick 2 - Down   0=pressed
                  beq _SetDown                    ;
                  
                  lda $1e                         ; SavCIA
                  and #$01                        ; Bit 0: Joystick 2 - Up     0=pressed
                  beq _SetUp                      ;
                  
_NetNoneUpDown    ldx #LR_JoyMoveNone
                  stx LR_JoyUpDo
                  beq _ChkLeftRight               ; always
                  
_SetUp            ldx #$21                        ;
                  stx LR_JoyUpDo                  ; 
                  bne _ChkLeftRight               ; always
                  
_SetDown          ldx #$25                        ;
                  stx LR_JoyUpDo                  ; 
                  
_ChkLeftRight     lda $1e                         ; SavCIA
                  and #$08                        ; Bit 3: Joystick 2 - Right  0=pressed
                  beq _SetRight                   ;
                  
                  lda $1e                         ; SavCIA
                  and #$04                        ; Bit 2: Joystick 2 - Left   0=pressed
                  beq _SetLeft                    ;
                  
 _SetNoneRiLeft    ldx #LR_JoyMoveNone            ;
                  stx LR_JoyLeRi                  ;
_SetNoneRiLeftX   rts                             ;
                  
_SetRight         ldx #LR_JoyMoveRi               ;
                  stx LR_JoyLeRi                  ;
_SetRightX        rts                             ;
                  
_SetLeft          ldx #LR_JoyMoveLe               ;
                  stx LR_JoyLeRi                  ;
                  
ChkJoyPortX       rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TabPlayCmdChr     .byte $3f ; RUN/STOP
                  .byte $91 ; R
                  .byte $8a ; A
                  .byte $a2 ; J
                  .byte $a5 ; K
                  .byte $2b ; +
                  .byte $28 ; -
                  .byte $92 ; D
                  .byte $b9 ; arrow left
                  .byte $b6 ; arrow up

                  .byte $00 ; EndOfTab
; ------------------------------------------------------------------------------------------------------------- ;
TabPlayCmdSub     .word IGC_Pause       - 1 ; 
                  .word IGC_Quit        - 1 ; 
                  .word IGC_Suicide     - 1 ; 
                  .word IGC_SetJoy      - 1 ; 
                  .word IGC_SetKeyBd    - 1 ; 
                  .word IGC_IncSpeed    - 1 ; 
                  .word IGC_DecSpeed    - 1 ; 
                  .word IGC_ShootMode   - 1 ; - Toggle Shoot Mode
                  .word IGC_IncLives    - 1 ; 
                  .word IGC_IncLevel    - 1 ; 
; ------------------------------------------------------------------------------------------------------------- ;
GetLRGfxOff       ldx $03                         ; adr col lode runner
                  ldy $05                         ; lr pos on image left/right
                  jsr GetXOff                     ;
                  
                  stx $23                         ; image number
                  ldy $04                         ; actual row lode runner
                  ldx $06                         ; lr pos on image up/down
                  jsr GetYOff                     ;
                  
                  ldx $07                         ; lr sprite number
                  lda TabSpriteNoLodeR,x          ; lr images tab
                  ldx $23                         ;
                  
GetLRGfxOffX      rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
MovLRGold         lda $05                         ; lr pos on image left/right
                  cmp #$02                        ; centered
                  bne MovLRGoldX                  ; no
                  
                  lda $06                         ; lr pos on image up/down
                  cmp #$02                        ; centered
                  bne MovLRGoldX                  ; no
                  
                  ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b                         ; 
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c                         ; 
                  
                  ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileGold                 ; 
                  bne MovLRGoldX                  ; no
                  
                  lsr LR_GetGold                  ; get gold  $00=just gets it
                  ldx #$10                        ;
                  ldy #$20                        ;
                  lda #$04                        ;
                  jsr Randomizer                  ; GetRndNum (x=VicLow y=VicHigh a=RndLow)
                  sta _Rnd01                      ;
                  
                  lda #$04                        ;
                  jsr Randomizer                  ; GetRndNum (x=VicLow y=VicHigh a=RndLow)
                  sta _Rnd02                      ;
                  
                  lda #$04                        ;
                  jsr Randomizer                  ; GetRndNum (x=VicLow y=VicHigh a=RndLow)
                  sta _Rnd03                      ;
                  
                  lda #$04                        ;
                  jsr Randomizer                  ; GetRndNum (x=VicLow y=VicHigh a=RndLow)
                  sta _Rnd04                      ;
                  
                  jsr SetTune                     ; data must follow directly
                  .byte $04                       ; tune time
_Rnd01            .byte $00                       ; tune data pointer voice 2
                  .byte $ff                       ; tune data pointer voice 3
                  .byte $b0                       ; tune s/r/volume  (not used)
                  
                  .byte $04                       ; tune time
_Rnd02            .byte $00                       ; tune data pointer voice 2
                  .byte $ff                       ; tune data pointer voice 3
                  .byte $a0                       ; tune s/r/volume  (not used)
                  
                  .byte $04                       ; tune time
_Rnd03            .byte $00                       ; tune data pointer voice 2
                  .byte $ff                       ; tune data pointer voice 3
                  .byte $90                       ; tune s/r/volume  (not used)
                  
                  .byte $04                       ; tune time
_Rnd04            .byte $00                       ; tune data pointer voice 2
                  .byte $ff                       ; tune data pointer voice 3
                  .byte $a0                       ; tune s/r/volume  (not used)
                  
                  .byte $00                       ; <EndOfTuneData>

_DecGoldToGet     dec LR_GoldToGet                ;
                  ldy $04                         ; actual row lode runner
                  sty $50                         ; screen row ($00 - $0f)
                  ldy $03                         ; adr col lode runner
                  sty $4f                         ; screen col ($00 - $1b)
                  lda #$00                        ;
                  sta ($0b),y                     ; 
                  jsr ImageOut2Prep               ; output to preparation screen first ($4000)
                  
                  ldy $50                         ; screen row  (00-0f)
                  ldx $4f                         ; screen col  (00-1b)
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row
                  
                  lda #NoTileGold                 ;
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
                  ldy #$05                        ; gold gives 500 points
                  lda #$00                        ;
                  jsr Score2BaseLine              ;
                  
MovLRGoldX        rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
MovLRSetImg       inc $07                         ; lr sprite number
                  cmp $07                         ; lr sprite number
                  bcc _ChkMax                     ; lower - check max
                  
_Set              sta $07                         ; lr sprite number
                  rts                             ;

_ChkMax           cpx $07                         ; lr sprite number
                  bcc _Set                        ;
                  
MovLRSetImgX      rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
MovLRKill         jsr GetLRGfxOff                 ;
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  
                  lda $27                         ; sprite collision  $01=lr caught
                  beq MovLRKillX                  ;
                  
                  lda LR_GetGold                  ; get gold  $00=just gets it
                  beq MovLRKillX                  ;
                  
                  lsr LR_Alive                    ; $00=lr killed
                  
MovLRKillX        rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
MovLRWaitPosX     lda $05                         ; lr pos on image left/right
                  cmp #$02                        ; center
                  bcc _IncPos                     ; lower
                  beq MovLRWaitPosXX              ;
                  
                  dec $05                         ; greater so dec lr pos on image left/right
                  jmp MovLRGold                   ; wait for center and handle the gold
                  
_IncPos           inc $05                         ; lr pos on image left/right
                  jmp MovLRGold                   ; wait for center and handle the gold
                  
MovLRWaitPosXX    rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
MovLRWaitPosY     lda $06                         ; lr pos on image up/down
                  cmp #$02                        ; center
                  bcc _IncPos                     ; lower
                  beq MovLRWaitPosYX              ;
                  
                  dec $06                         ; greater so dec lr pos on image up/down
                  jmp MovLRGold                   ; wait for center and handle the gold
                  
_IncPos           inc $06                         ; lr pos on image up/down
                  jmp MovLRGold                   ; wait for center and handle the gold
                  
MovLRWaitPosYX    rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
MovLRSetHole      lda #$00                        ;
                  sta LR_Shoots                   ; $00=no  $01=shoot right  $ff=shoot left
                  
                  ldy $04                         ; actual row lode runner
                  iny                             ;
                  stx $4f                         ; screen col ($00 - $1b)
                  sty $50                         ; screen row ($00 - $0f)
                  
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09                         ; 
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a                         ; 
                  
                  lda #NoTileBlank                ; empty
                  ldy $4f                         ; screen col  (00-1b)
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  jsr ImageOut2Disp               ; output directly to display screen ($2000)
                  
                  lda #NoTileBlank                ; empty
                  jsr ImageOut2Prep               ; output to preparation screen first ($4000)
                  
                  dec $50                         ; screen row ($00 - $0f)
                  lda #NoTileBlank                ; empty
                  jsr ImageOut2Disp               ; output directly to display screen ($2000)
                  
                  inc $50                         ; screen row ($00 - $0f)
                  ldx #$ff                        ;
_GetFreeSlot      inx                             ;
                  cpx #LR_TabHoleMax              ; $1e - max 30 slots
                  beq MovLRSetHoleX               ;
                  
                  lda LR_TabHoleOpenT,x           ; hole open time tab
                  bne _GetFreeSlot                ; already used - check next slot
                  
                  lda $50                         ; screen row  (00-0f)
                  sta LR_TabHoleRow,x             ; hole row tab
                  lda $4f                         ; screen col  (00-1b)
                  sta LR_TabHoleCol,x             ; hole column tab
                  
                  lda #LR_TabHoleOpenI            ;
                  sta LR_TabHoleOpenT,x           ; hole open time tab
                  
                  sec                             ;
MovLRSetHoleX     rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
IGC_IncLevel      lda C64_KeyFlag                 ; $01=Shift $02=Ctrl $04=Commodore
                  and #$06                        ;
                  cmp #$06                        ; Ctrl+Commodore
                  bne IGC_IncLevelX               ;
                  
                  lda CR_Cheat                    ; cheat mode set after RUN/STOP and F7 and RUN/STOP
                  beq IGC_IncLevelX               ;
                  
                  inc LR_NumLives                 ; inc because of kill with lsr Lr_Alive
                  inc LR_LevelNoGame              ; 001-050
                  inc LR_LevelNoDisk              ; 000-049
                  
                  lsr LR_Alive                    ; $00=killed
                  
IGC_IncLevelX     rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
IGC_IncLives      lda C64_KeyFlag                 ; $01=Shift $02=Ctrl $04=Commodore
                  and #$06                        ;
                  cmp #$06                        ; Ctrl+Commodore
                  bne IGC_IncLivesX               ;
                  
                  lda CR_Cheat                    ; cheat mode set after RUN/STOP and F7 and RUN/STOP
                  beq IGC_IncLivesX               ;
                  
                  inc LR_NumLives                 ; 
                  bne _LivesOut                   ; max 255
                  dec LR_NumLives                 ; lrNumLives
                  
_LivesOut         jsr Lives2BaseLine              ; StatusOutLives

IGC_IncLivesX     jmp GetPlayCmd                  ;
; ------------------------------------------------------------------------------------------------------------- ;
MoveEnemies       ldx LR_EnmyNo                   ; number of enemies
                  beq MoveEnemiesX                ;
                  
                  inc $36                         ; pointer actual enemy cycles
                  ldy $36                         ;
                  cpy #$03                        ;
                  bcc _NextCycle                  ; lower $00-$02
                  
                  ldy #$00                        ;
                  sty $36                         ;
                  
_NextCycle        lda $0032,y                     ; load move cycles
                  sta $35                         ; enemy move control
_Cycle            lsr $35                         ; enemy move control
                  bcc _ChkCycle                   ;
                  
                  jsr MoveOneEnemy                ;
                  
                  lda LR_Alive                    ; $00=lr killed
                  beq MoveEnemiesX                ; exit if dead
                  
_ChkCycle         lda $35                         ; enemy move control
                  bne _Cycle                      ;
                  
MoveEnemiesX      rts
; ------------------------------------------------------------------------------------------------------------- ;
TabEnmyCycles1    .byte $00 ; ........            ; LR_CntSpeedLaps ($00-$09) + LR_EnmyNo
TabEnmyCycles2    .byte $00 ; ........
TabEnmyCycles3    .byte $00 ; ........
                  
                  .byte $00 ; ........
                  .byte $01 ; .......#
                  .byte $01 ; .......#
                  
                  .byte $01 ; .......#
                  .byte $01 ; .......#
                  .byte $01 ; .......#
                  
                  .byte $01 ; .......#
                  .byte $03 ; ......##
                  .byte $01 ; .......#
                  
                  .byte $01 ; .......#
                  .byte $03 ; ......##
                  .byte $03 ; ......##
                  
                  .byte $03 ; ......##
                  .byte $03 ; ......##
                  .byte $03 ; ......##
                  
                  .byte $03 ; ......##
                  .byte $03 ; ......##
                  .byte $07 ; .....###
                  
                  .byte $03 ; ......##
                  .byte $07 ; .....###
                  .byte $07 ; .....###
                  
                  .byte $07 ; .....###
                  .byte $07 ; .....###
                  .byte $07 ; .....###
                  
                  .byte $07 ; .....###
                  .byte $07 ; .....###
                  .byte $0f ; ....####
                  
                  .byte $07 ; .....###
                  .byte $0f ; ....####
                  .byte $0f ; ....####
                  
                  .byte $0f ; ....####
                  .byte $0f ; ....####
                  .byte $0f ; ....####
                  
                  .byte $0f ; ....####
                  .byte $0f ; ....####
                  .byte $1f ; ...#####
                  
                  .byte $0f ; ....####
                  .byte $1f ; ...#####
                  .byte $1f ; ...#####
                  
                  .byte $1f ; ...#####
                  .byte $1f ; ...#####
                  .byte $1f ; ...#####
                  
                  .byte $1f ; ...#####
                  .byte $1f ; ...#####
                  .byte $3f ; ..######
                  
                  .byte $1f ; ...#####
                  .byte $3f ; ..######
                  .byte $3f ; ..######
                  
                  .byte $3f ; ..######
                  .byte $3f ; ..######
                  .byte $3f ; ..######
                  
                  .byte $3f ; ..######
                  .byte $3f ; ..######
                  .byte $7f ; .#######
                  
                  .byte $3f ; ..######
                  .byte $7f ; .#######
                  .byte $7f ; .#######
                  
                  .byte $7f ; .#######
                  .byte $7f ; .#######
                  .byte $7f ; .#######
; ------------------------------------------------------------------------------------------------------------- ;
TabSpriteNoEnemy  = *
TabEN_RunLeMin    .byte $08 ; $00 - run    left 01
                  .byte $2b ; $01 - run    left 02
TabEN_RunLeMax    .byte $2c ; $02 - run    left 03
TabEN_PoleLeMin   .byte $30 ; $03 - pole   left 01
                  .byte $31 ; $04 - pole   left 02
TabEN_PoleLeMax   .byte $32 ; $05 - pole   left 03
                  .byte $36 ; $06 - fall   left
TabEN_RunRiMin    .byte $28 ; $07 - run    right 01
                  .byte $29 ; $08 - run    right 02
TabEN_RunRiMax    .byte $2a ; $09 - run    right 03
TabEN_PoleRiMin   .byte $2d ; $0a - pole   right 01
                  .byte $2e ; $0b - pole   right 02
TabEN_PoleRiMax   .byte $2f ; $0c - pole   right 03
                  .byte $35 ; $0d - fall   right
TabEN_LadderMin   .byte $33 ; $0e - ladder up/down 01
TabEN_LadderMax   .byte $34 ; $0f - ladder up/down 02
; ------------------------------------------------------------------------------------------------------------- ;
NoEN_RunLeMin     := TabEN_RunLeMin  - TabSpriteNoEnemy
NoEN_RunLeMax     := TabEN_RunLeMax  - TabSpriteNoEnemy
NoEN_PoleLeMin    := TabEN_PoleLeMin - TabSpriteNoEnemy
NoEN_PoleLeMax    := TabEN_PoleLeMax - TabSpriteNoEnemy
NoEN_RunRiMin     := TabEN_RunRiMin  - TabSpriteNoEnemy
NoEN_RunRiMax     := TabEN_RunRiMax  - TabSpriteNoEnemy
NoEN_PoleRiMin    := TabEN_PoleRiMin - TabSpriteNoEnemy
NoEN_PoleRiMax    := TabEN_PoleRiMax - TabSpriteNoEnemy
NoEN_LadderMin    := TabEN_LadderMin - TabSpriteNoEnemy
NoEN_LadderMax    := TabEN_LadderMax - TabSpriteNoEnemy
; ------------------------------------------------------------------------------------------------------------- ;
MoveOneEnemy      inc LR_NoEnemy2Move             ; select next enemy
                  ldx LR_EnmyNo                   ; number of enemies
                  cpx LR_NoEnemy2Move             ; # of enemy to move
                  bcs _GetStatus                  ; max not reached
                  
                  ldx #LR_NoEnemy2MvMin           ; reset to first enemy
                  stx LR_NoEnemy2Move             ; 
                  
_GetStatus        jsr GetEnemyStatus              ;

_ChkHoleTime      lda $19                         ; enemy time in hole
                  bmi EnemyHoleTimeUp             ; time is up
                  beq EnemyHoleTimeUp             ; time is up
                  
                  dec $19                         ; enemy time in hole
                  ldy $19                         ; enemy time in hole
                  
                  cpy #LR_EnmyShivStart           ;
                  bcs _GetEnemyNo                 ; greater/equal
                  
                  jmp ShiverEnemyOut              ; lower - do shiver
                  
_GetEnemyNo       ldx LR_NoEnemy2Move             ; # of enemy to move
                  lda LR_TabEnemyBirtT,x          ; enemy rebirth step time
                  beq GoGfxOutXit                 ;
                  
MoveOneEnemyX     jmp SavEnemyStatus              ;
; ------------------------------------------------------------------------------------------------------------- ;
GoGfxOutXit       jmp MoveEnemyGfxOutX            ; enemy sprite out and exit move
; ------------------------------------------------------------------------------------------------------------- ;
EnemyHoleTimeUp   ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b                         ; 
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c                         ; 
                  
                  ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  
                  cmp #NoTileLadder               ;
                  beq EnemyHoleTimeUpX            ; free again
                  
                  cmp #NoTilePole                 ;
                  bne _ChkCenterLow               ;
                  
_ChkCenter        lda $1b                         ; actual enemy pos on image up/down
                  cmp #$02                        ; centered
                  beq EnemyHoleTimeUpX            ; free again
                  
_ChkCenterLow     lda $1b                         ; actual enemy pos on image up/down
                  cmp #$02                        ; center
                  bcc MoveEnemyGfxOut             ; lower
                  
_ChkCenterHigh    ldy $16                         ; actual enemy row
                  cpy #LR_ScrnMaxRows             ; $0f - max 15 rows
                  beq EnemyHoleTimeUpX            ; free again
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $09                         ; 
                  sta $0b                         ; 
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c                         ; 
                  lda TabExLvlDatRowH8+1,y        ; expanded level data row pointer $0800-$09c3
                  sta $0a                         ; 
                  
                  ldy $15                         ; actual enemy col
                  lda ($09),y                     ; unpacked level data ($0800-$09c3) + 1
                  
                  cmp #NoTileBlank                ;
                  beq MoveEnemyGfxOut             ;
                  
                  cmp #NoTileLodeRunner           ;
                  beq MoveEnemyGfxOut             ;
                  
                  cmp #NoTileEnemy                ;
                  beq EnemyHoleTimeUpX            ;
                  
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3) + 1
                  cmp #NoTileWallWeak             ;
                  beq EnemyHoleTimeUpX            ;
                  
                  cmp #NoTileWallHard             ;
                  beq EnemyHoleTimeUpX            ; free again
                  
                  cmp #NoTileLadder               ;
                  bne MoveEnemyGfxOut             ;
                  
EnemyHoleTimeUpX  jmp MoveEnemy                   ;
; ------------------------------------------------------------------------------------------------------------- ;
MoveEnemyGfxOut   jsr MovEnmyGetXYNo              ;
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  jsr CenterEnemyLR               ;
                  
                  lda #$06                        ; .honz fall left
                  
                  ldy $18                         ; actual enemy dir right/left  $ff=left  $01=right
                  bmi _SetEnemySprtNo             ;
                  
                  lda #$0d                        ; .honz fall right
                  
_SetEnemySprtNo   sta $17                         ; actual enemy sprite number

                  inc $1b                         ; actual enemy pos on image up/down
                  lda $1b                         ; actual enemy pos on image up/down
                  cmp #$05                        ; max
                  bcs B_81ba                      ;
                  
                  lda $1b                         ; actual enemy pos on image up/down
                  cmp #$02                        ; center
                  bne MoveEnemyGfxOutX            ; enemy sprite out and exit move
                  
_GoTakeGold       jsr EnmyTakeGold                ;
                  
                  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b                         ; 
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c                         ;
                  
                  ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  
                  cmp #NoTileWallWeak             ;
                  bne MoveEnemyGfxOutX            ;
                  
                  lda $19                         ; enemy time in hole
                  bpl _StoreHoleTime              ;
                  
                  dec LR_GoldToGet                ; 
                  
_StoreHoleTime    lda LR_EnmyHoleTime             ; enemy time in hole
                  sta $19                         ; enemy time in hole
                  
_ScoreEnemyHole   ldy #$01                        ;
                  lda #$00                        ; score 100 points for a digged in enemy
                  jsr Score2BaseLine              ; 
                  
MoveEnemyGfxOutX  jsr MovEnmyGetXYNo              ;
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  jmp SavEnemyStatus              ;
; ------------------------------------------------------------------------------------------------------------- ;
B_81ba            lda #$00                        ;
                  sta $1b                         ; actual enemy pos on image up/down
                  
                  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  bne _Store
                  
                  lda #NoTileBlank
                  
_Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  inc $16                         ; actual enemy row
                  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $15                         ; actual enemy col
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
_ChkCatchLR       cmp #NoTileLodeRunner
                  bne _NoCatchLR
                  
_KillLR           lsr LR_Alive                    ; $00=lr killed
                  
_NoCatchLR        lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  bne _SetEnemyTile
                  
                  lda $19                         ; enemy time in hole
                  bpl _SetEnemyTile
                  
                  ldy $16                         ; actual enemy row
                  dey
                  sty $50                         ; screen row  (00-0f)
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $15                         ; actual enemy col
                  sty $4f                         ; screen col  (00-1b)
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
_ChkEmpty         cmp #NoTileBlank
                  beq _LeaveGold
                  
                  dec LR_GoldToGet
                  jmp _GetEnemyTilePtr            ; a piece of gold got lost
                  
_LeaveGold        lda #NoTileGold
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  sta ($0b),y                     ; play level control data ($0a00-$0bc3)
                  
_DisplayGold      jsr ImageOut2Prep               ; direct output to preparation screen
                  
                  ldy $50                         ; screen row  (00-0f)
                  ldx $4f                         ; screen col  (00-1b)
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row
                  
                  lda #NoTileGold
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  
_GetEnemyTilePtr  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  lda #LR_EnmyHoleTI              ; $00 - init
                  sta $19                         ; enemy time in hole
                  
                  ldy $15                         ; actual enemy col
_SetEnemyTile     lda #NoTileEnemy
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  jsr MovEnmyGetXYNo
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  
                  jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
ShiverEnemyOut    cpy #LR_EnmyShivStop            ; move out if lower
                  bcc MoveEnemy
                  
                  jsr MovEnmyGetXYNo              ; Gold/Enemy/LR
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
                  ldy $19                         ; enemy time in hole
                  lda TabEnemyShiver-7,y          ; shiver the last hole seconds
                  sta $1a                         ; actual enemy pos on image left/right
                  
_ShiverOut        jsr MovEnmyGetXYNo
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  
ShiverEnemyOutX   jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
TabEnemyShiver    .byte $02
                  .byte $01
                  .byte $02
                  .byte $03
                  .byte $02
                  .byte $01
; ------------------------------------------------------------------------------------------------------------- ;
MoveEnemy         ldx $15                         ; actual enemy col
                  ldy $16                         ; actual enemy row
                  jsr GetEnemyMoveDir             ;
                  
                  asl a                           ;
                  tay                             ;
                  lda TabEnemyMoveDir+1,y         ;
                  pha                             ;
                  lda TabEnemyMoveDir,y           ;
                  pha                             ;
                  
MoveEnemyX        rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TabEnemyMoveDir   .word SavEnemyStatus - 1
                  .word MoveEnemyLeft  - 1
                  .word MoveEnemyRight - 1
                  .word MoveEnemyUp    - 1
                  .word MoveEnemyDown  - 1
; ------------------------------------------------------------------------------------------------------------- ;
MoveEnemyUpHole   lda $19                         ; enemy time in hole
                  beq MoveEnemyUpHoleX
                  bmi MoveEnemyUpHoleX
                  
                  inc $19                         ; enemy time in hole
MoveEnemyUpHoleX  jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
MoveEnemyUp       ldy $1b                         ; actual enemy pos on image up/down
                  cpy #$03
                  bcs StepEnemyUp
                  
                  ldy $16                         ; actual enemy row
                  beq MoveEnemyUpHole             ; already already max up
                  
                  dey
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $15                         ; actual enemy col
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #NoTileWallWeak
                  beq MoveEnemyUpHole             ; blocked
                  
                  cmp #NoTileWallHard
                  beq MoveEnemyUpHole             ; blocked
                  
                  cmp #NoTileWallTrap
                  beq MoveEnemyUpHole             ; blocked
                  
                  cmp #NoTileEnemy
MoveEnemyUpX      beq MoveEnemyUpHole             ; blocked
; ------------------------------------------------------------------------------------------------------------- ;
StepEnemyUp       jsr MovEnmyGetXYNo
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  jsr CenterEnemyLR
                  
                  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  dec $1b                         ; actual enemy pos on image up/down
                  bpl GoEnemyTakeGold
                  
_GoEnemyDropGold  jsr EnmyDropGold
                  
                  ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  bne _Store
                  
                  lda #NoTileBlank
                  
_Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  dec $16                         ; actual enemy row
                  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $15                         ; actual enemy col
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
_ChkCatchLR       cmp #NoTileLodeRunner
                  bne _NoCatchLR
                  
_KillLR           lsr LR_Alive                    ; $00=lr killed
                  
_NoCatchLR        lda #NoTileEnemy
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  lda #$04
                  sta $1b                         ; actual enemy pos on image up/down
                  bne ChkEnemySprtRng
                  
GoEnemyTakeGold   jsr EnmyTakeGold
                  
ChkEnemySprtRng   lda #NoEN_LadderMin             ; .hbu008.
                  ldx #NoEN_LadderMax             ; .hbu008.
                  
                  jsr MovENSetImg                 ; increase sprite number and check range
                  jsr MovEnmyGetXYNo
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  
StepEnemyUpX      jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
MoveEnemyDown     ldy $1b                         ; actual enemy pos on image up/down
                  cpy #$02
                  bcc StepEnemyDown
                  
                  ldy $16                         ; actual enemy row
                  cpy #LR_ScrnMaxRows
                  bcs MoveEnemyDownX              ; already max down
                  
                  iny
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $15                         ; actual enemy col
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #NoTileWallHard
                  beq MoveEnemyDownX              ; blocked
                  
                  cmp #NoTileEnemy
                  beq MoveEnemyDownX              ; blocked
                  
                  cmp #NoTileWallWeak             ; blocked
                  bne StepEnemyDown
                  
MoveEnemyDownX    jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
StepEnemyDown     jsr MovEnmyGetXYNo
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  jsr CenterEnemyLR
                  
                  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  inc $1b                         ; actual enemy pos on image up/down
                  lda $1b                         ; actual enemy pos on image up/down
                  cmp #$05
                  bcc StepEnemyDownX
                  
                  jsr EnmyDropGold
                  
                  ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  bne _Store
                  
                  lda #$00
_Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  inc $16                         ; actual enemy row
                  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $15                         ; actual enemy col
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
_ChkCatchLR       cmp #NoTileLodeRunner
                  bne _NoCatchLR
                  
_KillLR           lsr LR_Alive                    ; $00=lr killed
                  
_NoCatchLR        lda #NoTileEnemy
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  lda #$00
                  sta $1b                         ; actual enemy pos on image up/down
                  jmp ChkEnemySprtRng
                  
StepEnemyDownX    jmp GoEnemyTakeGold
; ------------------------------------------------------------------------------------------------------------- ;
MoveEnemyLeft     ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldx $1a                         ; actual enemy pos on image left/right
                  cpx #$03
                  bcs StepEnemyLeft               ; equal or greater
                  
                  ldy $15                         ; actual enemy col
                  beq MoveEnemyLeftX              ; already max left
                  
_ChkLeft          dey
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #NoTileEnemy
                  beq MoveEnemyLeftX              ; blocked
                  
                  cmp #NoTileWallHard
                  beq MoveEnemyLeftX              ; blocked
                  
                  cmp #NoTileWallWeak
                  beq MoveEnemyLeftX              ; blocked
                  
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallTrap             ; blocked
                  bne StepEnemyLeft
                  
MoveEnemyLeftX    jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
StepEnemyLeft     jsr MovEnmyGetXYNo
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  jsr CenterEnemyUD
                  
                  lda #$ff
                  sta $18                         ; actual enemy dir right/left  $ff=left  $01=right
                  
                  dec $1a                         ; actual enemy pos on image left/right
                  bpl _GoTakeGold
                  
_GoDropGold       jsr EnmyDropGold
                  
                  ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  bne _Store
                  
                  lda #NoTileBlank
                  
_Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  dec $15                         ; actual enemy col
                  dey
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
_ChkCatchLR       cmp #NoTileLodeRunner
                  bne _NoCatchLR
                  
_KillLR           lsr LR_Alive                    ; $00=lr killed
                  
_NoCatchLR        lda #NoTileEnemy
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  lda #$04
                  sta $1a                         ; actual enemy pos on image left/right
                  bne _GetTile                    ; always
                  
_GoTakeGold       jsr EnmyTakeGold
                  
_GetTile          ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
_ChkPole          cmp #NoTilePole
                  beq _SetSpritePoleLe
                  
_SetSpriteRunLe   lda #NoEN_RunLeMin              ; .hbu008.
                  ldx #NoEN_RunLeMax              ; .hbu008
                  bne _DisplaySprite              ; always
                  
_SetSpritePoleLe  lda #NoEN_PoleLeMin             ; .hbu008.
                  ldx #NoEN_PoleLeMax             ; .hbu008.
                  
_DisplaySprite    jsr MovENSetImg                 ; increase sprite number and check range
                  jsr MovEnmyGetXYNo
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  
StepEnemyLeftX    jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
MoveEnemyRight    ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldx $1a                         ; actual enemy pos on image left/right
                  cpx #$02
                  bcc StepEnemyRight
                  
                  ldy $15                         ; actual enemy col
                  cpy #LR_ScrnMaxCols
                  beq MoveEnemyRightX             ; already max right
                  
_ChkRight         iny
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #NoTileEnemy
                  beq MoveEnemyRightX             ; blocked
                  
                  cmp #NoTileWallHard
                  beq MoveEnemyRightX             ; blocked
                  
                  cmp #NoTileWallWeak
                  beq MoveEnemyRightX             ; blocked
                  
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallTrap             ; blocked
                  bne StepEnemyRight              ; Ladder/Pole/XitLadder/Gold/LR
                  
MoveEnemyRightX   jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
StepEnemyRight    jsr MovEnmyGetXYNo
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  jsr CenterEnemyUD
                  
                  lda #$01
                  sta $18                         ; actual enemy dir right/left  $ff=left  $01=right
                  
                  inc $1a                         ; actual enemy pos on image left/right
                  lda $1a                         ; actual enemy pos on image left/right
                  cmp #$05
                  bcc _GoTakeGold
                  
_GoDropGold       jsr EnmyDropGold
                  
                  ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  bne _Store
                  
                  lda #NoTileBlank
                  
_Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  inc $15                         ; actual enemy col
                  iny
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
_ChkCatchLR       cmp #NoTileLodeRunner
                  bne _NoCatchLR
                  
_KillLR           lsr LR_Alive                    ; $00=lr killed
                  
_NoCatchLR        lda #NoTileEnemy
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  lda #$00
                  sta $1a                         ; actual enemy pos on image left/right
                  beq _GetTile
                  
_GoTakeGold       jsr EnmyTakeGold
                  
_GetTile          ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTilePole
                  beq _SetSpritePoleRi
                  
_SetSpriteRunRi   lda #NoEN_RunRiMin              ; .hbu008.
                  ldx #NoEN_RunRiMax              ; .hbu008.
                  bne _DisplaySprite
                  
_SetSpritePoleRi  lda #NoEN_PoleRiMin             ; .hbu008.
                  ldx #NoEN_PoleRiMax             ; .hbu008.
                  
_DisplaySprite    jsr MovENSetImg                 ; increase sprite number and check range
                  jsr MovEnmyGetXYNo
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  
StepEnemyRightX   jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
GetEnemyMoveDir   stx $28                         ; actual enemy work col
                  sty $29                         ; actual enemy work row
                  
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b                         ; 
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c                         ; 
                  
                  ldy $28                         ; actual enemy work col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  
                  cmp #NoTileWallWeak             ;
                  bne TstRowEnmyLR                ;
                  
                  lda $19                         ; enemy time in hole
                  beq TstRowEnmyLR                ;   is up
                  bmi TstRowEnmyLR                ;   is up
                  
                  lda #LR_EnemyMoveUp             ;
                  rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TstRowEnmyLR      ldy $29                         ; actual enemy work row
                  cpy $04                         ; actual row lode runner
                  beq BothOnSameRow               ;
                  
TstRowEnmyLRX     jmp BothOnDiffRow               ; lrzLRPosRow
; ------------------------------------------------------------------------------------------------------------- ;
BothOnSameRow     ldy $28                         ; actual enemy work col
                  sty $2a                         ; save actual enemy work col
                  
                  cpy $03                         ; actual col lode runner
BothOnSameRowX    bcs EnemyOnRiOfLR               ;
; ------------------------------------------------------------------------------------------------------------- ;
EnemyOnLeOfLR     inc $2a                         ; save actual enemy work col

                  ldy $29                         ; actual enemy work row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b                         ;
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c                         ; 
                  
                  ldy $2a                         ; save actual enemy work col
_GetTileRi        lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileLadder               ;
                  beq _ChkLRReached               ; 
                  
                  cmp #NoTilePole                 ;
                  beq _ChkLRReached               ;
                  
                  ldy $29                         ; actual enemy work row
                  cpy #LR_ScrnMaxRows             ;
                  beq _ChkLRReached               ; bottom reached
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b                         ;
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c                         ; 
                  
                  ldy $2a                         ; save actual enemy work col
_GetTileRiDo      lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileBlank                ;
                  beq BothOnDiffRow               ; 
                  
                  cmp #NoTileWallTrap             ;
                  beq BothOnDiffRow               ;
                  
_ChkLRReached     ldy $2a                         ; save actual enemy work col
                  cpy $03                         ; actual col lode runner
                  bne EnemyOnLeOfLR               ;
                  
                  lda #LR_EnemyMoveRi             ; 
                  
EnemyOnLeOfLRX    rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
EnemyOnRiOfLR     dec $2a                         ; save actual enemy work col

                  ldy $29                         ; actual enemy work row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b                         ;
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c                         ; 
                  
                  ldy $2a                         ; save actual enemy work col
_GetTileLe        lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #$03                        ;
                  beq _ChkLRReached               ; 
                  
                  cmp #NoTilePole                 ;
                  beq _ChkLRReached               ;
                  
                  ldy $29                         ; actual enemy work row
                  cpy #LR_ScrnMaxRows             ;
                  beq _ChkLRReached               ;
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b                         ;
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c                         ; 
                  
                  ldy $2a                         ; save actual enemy work col
_GetTileLeDo      lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileBlank                ;
                  beq BothOnDiffRow               ; 
                  
                  cmp #NoTileWallTrap             ;
                  beq BothOnDiffRow               ;
                  
_ChkLRReached     ldy $2a                         ; save actual enemy work col
                  cpy $03                         ; actual col lode runner
                  bne EnemyOnRiOfLR               ;
                  
                  lda #LR_EnemyMoveLe             ; 
                  
EnemyOnRiOfLRX    rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
BothOnDiffRow     lda #LR_EnemyMoveNo             ;
                  sta $2b                         ; actual enemy move direction
                  lda #$ff                        ; init
                  sta $2c                         ; move direction indicator
                  
                  ldx $28                         ; actual enemy work col
                  ldy $29                         ; actual enemy work row
                  
                  jsr GetEnmyPossLR               ;
                  jsr GetEnmyPossUD               ;
                  jsr TestColLeft                 ;
                  jsr TestColRight                ;
                  
                  lda $2b                         ; actual enemy move direction
BothOnDiffRowX    rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
BothOnDiffRowXX   rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TestColLeft       ldy $2d                         ; actual enemy possible col left
                  cpy $28                         ; actual enemy work col
                  beq BothOnDiffRowXX
                  
                  ldy $29                         ; actual enemy work row
                  cpy #$0f
                  beq _ChkWorkRow
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $2d                         ; actual enemy possible col left
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  beq _ChkWorkRow
                  
                  cmp #NoTileWallHard
                  beq _ChkWorkRow
                  
                  ldx $2d                         ; actual enemy possible col left
                  ldy $29                         ; actual enemy work row
                  jsr FindEnmyMoveUD1             ; ac=target row
                  
                  ldx $2d                         ; actual enemy possible col left
                  jsr GetDirIndicator
                  
                  cmp $2c                         ; move direction indicator
                  bcs _ChkWorkRow
                  
_SetNewInd01      sta $2c                         ; move direction indicator
                  
_SetDirLeft01     lda #LR_EnemyMoveLe
                  sta $2b                         ; actual enemy move direction
                  
_ChkWorkRow       ldy $29                         ; actual enemy work row
                  beq _IncColLeft
                  
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $2d                         ; actual enemy possible col left
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
_GetTileLe        cmp #NoTileLadder
                  bne _IncColLeft
                  
                  ldy $29                         ; actual enemy work row
                  ldx $2d                         ; actual enemy possible col left
                  jsr FindEnmyMoveUD0
                  
                  ldx $2d                         ; actual enemy possible col left
                  jsr GetDirIndicator
                  
                  cmp $2c                         ; move direction indicator
                  bcs _IncColLeft
                  
_SetNewInd02      sta $2c                         ; move direction indicator
                  
_SetDirLeft02     lda #LR_EnemyMoveLe
                  sta $2b                         ; actual enemy move direction
                  
_IncColLeft       inc $2d                         ; actual enemy possible col left
                  jmp TestColLeft
                  
TestColLeftX      rts
; ------------------------------------------------------------------------------------------------------------- ;
TestColRight      ldy $2e                         ; actual enemy possible col right
                  cpy $28                         ; actual enemy work col
                  beq TestColLeftX                ; max left
                  
                  ldy $29                         ; actual enemy work row
                  cpy #LR_ScrnMaxRows
                  beq _ChkMaxUp                   ; max down reached
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $2e                         ; actual enemy possible col right
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
_ChkTileRowDo     cmp #NoTileWallWeak
                  beq _ChkMaxUp
                  
                  cmp #NoTileWallHard
                  beq _ChkMaxUp
                  
                  ldx $2e                         ; actual enemy possible col right
                  ldy $29                         ; actual enemy work row
                  jsr FindEnmyMoveUD1             ; ac=target row
                  
                  ldx $2e                         ; actual enemy possible col right
                  jsr GetDirIndicator
                  
                  cmp $2c                         ; move direction indicator
                  bcs _ChkMaxUp
                  
_SetNewInd01      sta $2c                         ; move direction indicator
                  
_SetDirRight01    lda #LR_EnemyMoveRi
                  sta $2b                         ; actual enemy move direction
                  
_ChkMaxUp         ldy $29                         ; actual enemy work row
                  beq _DecColRight                ; max up reached - exit
                  
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $2e                         ; actual enemy possible col right
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileLadder
                  bne _DecColRight
                  
                  ldy $29                         ; actual enemy work row
                  ldx $2e                         ; actual enemy possible col right
                  jsr FindEnmyMoveUD0
                  
                  ldx $2e                         ; actual enemy possible col right
                  jsr GetDirIndicator
                  
                  cmp $2c                         ; move direction indicator
                  bcs _DecColRight
                  
_SetNewInd02      sta $2c                         ; move direction indicator
                  
_SetDirRight02    lda #LR_EnemyMoveRi
                  sta $2b                         ; actual enemy move direction
                  
_DecColRight      dec $2e                         ; actual enemy possible col right
TestColRightX     jmp TestColRight
; ------------------------------------------------------------------------------------------------------------- ;
GetEnmyPossUD     ldy $29                         ; actual enemy work row
                  cpy #LR_ScrnMaxRows
                  beq _ChkTopOfScreen             ; already on bottom of screen
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $28                         ; actual enemy work col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  beq _ChkTopOfScreen
                  
                  cmp #NoTileWallHard
                  beq _ChkTopOfScreen
                  
                  ldx $28                         ; actual enemy work col
                  ldy $29                         ; actual enemy work row
                  jsr FindEnmyMoveUD1             ; ac=target row
                  
                  ldx $28                         ; actual enemy work col
                  jsr GetDirIndicator
                  
                  cmp $2c                         ; move direction indicator
                  bcs _ChkTopOfScreen
                  
_SetNewIndDo      sta $2c                         ; move direction indicator
                  
_SetDirDown       lda #LR_EnemyMoveDo
                  sta $2b                         ; actual enemy move direction
                  
_ChkTopOfScreen   ldy $29                         ; actual enemy work row
                  beq GetEnmyPossUDX
                  
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $28                         ; actual enemy work col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileLadder
                  bne GetEnmyPossUDX
                  
                  ldx $28                         ; actual enemy work col
                  ldy $29                         ; actual enemy work row
                  jsr FindEnmyMoveUD0
                  
                  ldx $28                         ; actual enemy work col
                  jsr GetDirIndicator
                  
                  cmp $2c                         ; move direction indicator
                  bcs GetEnmyPossUDX
                  
_SetNewIndUp      sta $2c                         ; move direction indicator
                  
_SetDirUp         lda #LR_EnemyMoveUp
                  sta $2b                         ; actual enemy move direction
                  
GetEnmyPossUDX    rts
; ------------------------------------------------------------------------------------------------------------- ;
GetDirIndicator   sta $1e                         ; save target row
                  
_ChkRowLR         cmp $04                         ; actual row lode runner
                  bne _NotOnRowLR
                  
_SameLR           cpx $15                         ; actual enemy col
                  bcc _Lower                      ; lower
                  
                  txa
                  sec
                  sbc $15                         ; actual enemy col
                  rts
                  
_Lower            stx $1e                         ; actual enemy possible col left to save target row
                  lda $15                         ; actual enemy col
                  sec
                  sbc $1e                         ; save target row
                  rts
                  
_NotOnRowLR       bcc _AboveLR
                  
_BelowLR          sec
                  sbc $04                         ; actual row lode runner
                  clc
                  adc #$64 * 2                    ; $c8
                  rts
                  
_AboveLR          lda $04                         ; actual row lode runner
                  sec
                  sbc $1e                         ; save target row
                  clc
                  adc #$64
                  
GetDirIndicatorX  rts
; ------------------------------------------------------------------------------------------------------------- ;
RetTargetRow2     lda $31                         ; target row from work row
                  
RetTargetRow2X    rts
; ------------------------------------------------------------------------------------------------------------- ;
FindEnmyMoveUD0   sty $31                         ; target row from work row
                  stx $30                         ; target col from work col or possible col ri/le
                  
_ChkNextTileUp0   lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $30                         ; target col from work col or possible col ri/le
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileLadder
                  bne RetTargetRow2               ; exit
                  
_SetTargetRowUp   dec $31                         ; target row from work row
                  
                  ldy $30                         ; target col from work col or possible col ri/le
                  beq _ChkMaxColRi                ; already max left
                  
                  dey
                  
_GetTileLe        lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  beq _SetSavTargRowLe
                  
                  cmp #NoTileWallHard
                  beq _SetSavTargRowLe
                  
                  cmp #NoTileLadder
                  beq _SetSavTargRowLe
                  
                  ldy $31                         ; target row from work row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $30                         ; target col from work col or possible col ri/le
                  
                  dey
                  
_GetTileUpLe      lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTilePole
                  bne _ChkMaxColRi
                  
_SetSavTargRowLe  ldy $31                         ; target row from work row
                  sty $2f                         ; save target row from work row
                  cpy $04                         ; actual row lode runner
                  bcc RetSavTargetRow
                  beq RetSavTargetRow
                  
_ChkMaxColRi      ldy $30                         ; target col from work col or possible col ri/le
                  cpy #LR_ScrnMaxCols
                  beq _ChkTop
                  
                  ldy $31                         ; target row from work row
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $30                         ; target col from work col or possible col ri/le
                  iny
                  
_GetTileRi        lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  beq _SetSavTargRow
                  
                  cmp #NoTileWallHard
                  beq _SetSavTargRow
                  
                  cmp #NoTileLadder
                  beq _SetSavTargRow
                  
                  ldy $31                         ; target row from work row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $30                         ; target col from work col or possible col ri/le
                  iny
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTilePole
                  bne _ChkTop
                  
_SetSavTargRow    ldy $31                         ; target row from work row
                  sty $2f                         ; save target row from work row
                  cpy $04                         ; actual row lode runner
                  bcc RetSavTargetRow
                  beq RetSavTargetRow
                  
_ChkTop           ldy $31                         ; target row from work row
                  cpy #$01
                  bcc _RetTargetRow
                  
_GoCheckNext      jmp _ChkNextTileUp0
                  
_RetTargetRow     tya
                  
FindEnmyMoveUD0X  rts
; ------------------------------------------------------------------------------------------------------------- ;
RetSavTargetRow   lda $2f                         ; save target row from work row
                  
RetSavTargetRowX  rts
; ------------------------------------------------------------------------------------------------------------- ;
RetTargetRow      lda $31                         ; target row from work row
                  
RetTargetRowX     rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
FindEnmyMoveUD1   sty $31                         ; target row from work row
                  stx $30                         ; target col from work col or possible col ri/le
                  
_ChkNextTileUp1   lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $30                         ; target col from work col or possible col ri/le
_TileUnderFoot    lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  beq RetTargetRow
                  
                  cmp #NoTileWallHard
                  beq RetTargetRow
                  
                  ldy $31                         ; target row from work row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $30                         ; target col from work col or possible col ri/le
_TileLeRi         lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileBlank
                  beq _ChkRows
                  
                  cpy #$00                        ; max left
                  beq _ChkCols
                  
                  dey
                  
_TileNextLe       lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTilePole
                  beq _SetTargetRowLe
                  
                  ldy $31                         ; target row from work row
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $30                         ; target col from work col or possible col ri/le
                  dey
_TileUnderFootLe  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  beq _SetTargetRowLe
                  
                  cmp #NoTileWallHard
                  beq _SetTargetRowLe
                  
                  cmp #NoTileLadder
                  bne _ChkCols
                  
_SetTargetRowLe   ldy $31                         ; target row from work row
                  sty $2f                         ; save target row from work row
                  cpy $04                         ; actual row lode runner
                  bcs _RetTargetRow               ; still above of LR
                  
_ChkCols          ldy $30                         ; target col from work col or possible col ri/le
                  cpy #LR_ScrnMaxCols
                  bcs _ChkRows                    ; max right reached
                  
                  iny
                  
_TileNextRi       lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTilePole
                  beq _SetTargetRowRi
                  
                  ldy $31                         ; target row from work row
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $30                         ; target col from work col or possible col ri/le
                  iny
_TileUnderFootRi  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  beq _SetTargetRowRi
                  
                  cmp #NoTileLadder
                  beq _SetTargetRowRi
                  
                  cmp #NoTileWallHard
                  bne _ChkRows
                  
_SetTargetRowRi   ldy $31                         ; target row from work row
                  sty $2f                         ; save target row from work row
                  cpy $04                         ; actual row lode runner
                  bcs _RetTargetRow               ; still above of LR
                  
_ChkRows          inc $31                         ; target row from work row
                  ldy $31                         ; target row from work row
                  cpy #LR_ScrnMaxRows+1
                  bcs _RetMaxRow                  ; max reached
                  
_GoCheckNext      jmp _ChkNextTileUp1
                  
_RetMaxRow        lda #LR_ScrnMaxRows
_FindEnmyMoveUD1  rts
                  
_RetTargetRow     lda $2f                         ; save target row from work row
FindEnmyMoveUD1X  rts
; ------------------------------------------------------------------------------------------------------------- ;
GetEnmyPossLR     stx $2d                         ; actual enemy possible col left
                  stx $2e                         ; actual enemy possible col right
                  sty $20                         ; save actual enemy work row
                  
_GetNextColLeft   lda $2d                         ; actual enemy possible col left
                  beq _GetNextColRight            ; max left reached
                  
                  ldy $20                         ; save actual enemy work row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $2d                         ; actual enemy possible col left
                  dey                             ; get tile one left from
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
_ChkLeftTile      cmp #NoTileWallWeak
                  beq _GetNextColRight
                  
                  cmp #NoTileWallHard
                  beq _GetNextColRight
                  
                  cmp #NoTileLadder
                  beq _SetNextColLeft
                  
                  cmp #NoTilePole
                  beq _SetNextColLeft
                  
                  ldy $20                         ; save actual enemy work row
                  cpy #LR_ScrnMaxRows
                  beq _SetNextColLeft
                  
_ChkLeftDownTile  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $2d                         ; actual enemy possible col left
                  dey                             ; get tile one left/down from
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  beq _SetNextColLeft
                  
                  cmp #NoTileWallHard
                  beq _SetNextColLeft
                  
                  cmp #NoTileLadder
                  bne _SetOneLeft
                  
_SetNextColLeft   dec $2d                         ; actual enemy possible col left
                  bpl _GetNextColLeft
                  
_SetOneLeft       dec $2d                         ; actual enemy possible col left
                  
_GetNextColRight  lda $2e                         ; actual enemy possible col right
                  cmp #LR_ScrnMaxCols             ; $1b - max col right
                  beq GetEnmyPossLRX              ; exit
                  
                  ldy $20                         ; save actual enemy work row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $2e                         ; actual enemy possible col right
                  iny                             ; try one tile right from
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #NoTileWallWeak
                  beq GetEnmyPossLRX              ; exit
                  
                  cmp #NoTileWallHard
                  beq GetEnmyPossLRX              ; exit
                  
                  cmp #NoTileLadder
                  beq _SetNextColRight
                  
                  cmp #NoTilePole
                  beq _SetNextColRight
                  
                  ldy $20                         ; save actual enemy work row
                  cpy #LR_ScrnMaxRows
                  beq _SetNextColRight
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $2e                         ; actual enemy possible col right
                  iny                             ; try one tile right from
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileWallWeak
                  beq _SetNextColRight
                  
                  cmp #NoTileWallHard
                  beq _SetNextColRight
                  
                  cmp #NoTileLadder
                  bne _SetOneRight
                  
_SetNextColRight  inc $2e                         ; actual enemy possible col right
                  bpl _GetNextColRight
                  
_SetOneRight      inc $2e                         ; actual enemy possible col right
                  
GetEnmyPossLRX    rts
; ------------------------------------------------------------------------------------------------------------- ;
MovEnmyGetXYNo    ldx $15                         ; actual enemy col
                  ldy $1a                         ; actual enemy pos on image left/right
                  jsr GetXOff
                  
                  stx $23                         ; image number
                  
                  ldy $16                         ; actual enemy row
                  ldx $1b                         ; actual enemy pos on image up/down
                  jsr GetYOff
                  
                  ldx $17                         ; actual enemy sprite number
                  lda TabSpriteNoEnemy,x          ; enemy move images
                  
                  ldx $23                         ; image number
                  
MovEnmyGetXYNoX   rts
; ------------------------------------------------------------------------------------------------------------- ;
EnmyTakeGold      lda $1a                         ; actual enemy pos on image left/right
                  cmp #$02
                  bne EnmyTakeGoldX
                  
                  lda $1b                         ; actual enemy pos on image up/down
                  cmp #$02
                  bne EnmyTakeGoldX
                  
                  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileGold
                  bne EnmyTakeGoldX               ; no gold on level tile
                  
                  lda $19                         ; enemy time in hole
                  bmi EnmyTakeGoldX
                  
                  lda #$ff
                  sec
                  sbc LR_EnmyBirthCol             ; pointer: enemy rebirth column
                  sta $19                         ; enemy time in hole
                  
                  lda #NoTileBlank                ; clear gold in
                  sta ($0b),y                     ; play level control data ($0a00-$0bc3)
                  
                  ldy $16                         ; actual enemy row
                  sty $50                         ; screen row  (00-0f)
                  ldy $15                         ; actual enemy col
                  sty $4f                         ; screen col  (00-1b)
                  jsr ImageOut2Prep               ; direct output to preparation screen
                  
                  ldy $50                         ; screen row  (00-0f)
                  ldx $4f                         ; screen col  (00-1b)
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row
                  
                  lda #NoTileGold
                  jmp ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
EnmyTakeGoldX     rts
; ------------------------------------------------------------------------------------------------------------- ;
EnmyDropGold      lda $19                         ; enemy time in hole
                  bpl EnmyDropGoldX
                  
                  inc $19                         ; enemy time in hole
                  bne EnmyDropGoldX
                  
                  ldy $16                         ; actual enemy row
                  sty $50                         ; screen row  (00-0f)
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $15                         ; actual enemy col
                  sty $4f                         ; screen col  (00-1b)
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileBlank
                  bne _NotEmpty
                  
                  lda #NoTileGold
                  sta ($0b),y                     ; play level control data ($0a00-$0bc3)
                  jsr ImageOut2Prep               ; direct output to preparation screen
                  
                  ldy $50                         ; screen row  (00-0f)
                  ldx $4f                         ; screen col  (00-1b)
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row
                  
                  lda #NoTileGold
                  jmp ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  
_NotEmpty         dec $19                         ; enemy time in hole
EnmyDropGoldX     rts
; ------------------------------------------------------------------------------------------------------------- ;
MovENSetImg       inc $17                         ; actual enemy sprite number
_ChkMin           cmp $17                         ; actual enemy sprite number
                  bcc _ChkMax
                  
_SetSpriteNo      sta $17                         ; actual enemy sprite number
                  rts
                  
_ChkMax           cpx $17                         ; actual enemy sprite number
                  bcc _SetSpriteNo
                  
MovENSetImgX      rts
; ------------------------------------------------------------------------------------------------------------- ;
CenterEnemyLR     lda $1a                         ; actual enemy pos on image left/right
                  cmp #$02                        ; center
                  bcc _Inc1a                      ; lower
                  beq CenterEnemyLRX               ; in center
                  
_Dec1a            dec $1a                         ; back left a bit
                  jmp EnmyTakeGold
                  
_Inc1a            inc $1a                         ; back right a bit
                  jmp EnmyTakeGold
                  
CenterEnemyLRX    rts
; ------------------------------------------------------------------------------------------------------------- ;
CenterEnemyUD     lda $1b                         ; actual enemy pos on image up/down
                  cmp #$02                        ; center
                  bcc _Inc1b                      ; lower
                  beq CenterEnemyUDX              ; in center
                  
_Dec1b            dec $1b                         ; back up a bit
                  jmp EnmyTakeGold
                  
_Inc1b            inc $1b                         ; back down a bit
                  jmp EnmyTakeGold
                  
CenterEnemyUDX    rts
; ------------------------------------------------------------------------------------------------------------- ;
SavEnemyStatus    ldx LR_NoEnemy2Move             ; # of enemy to move
                  
                  lda $15                         ; actual enemy col
                  sta LR_TabEnemyCol,x            ; adr column enemies
                  lda $16                         ; actual enemy row
                  sta LR_TabEnemyRow,x            ; adr row enemies
                  lda $1a                         ; actual enemy pos on image left/right
                  sta LR_TabEnemyPosLR,x          ; enemy pos on image left/right tab
                  lda $1b                         ; actual enemy pos on image up/down
                  sta LR_TabEnemyPosUD,x          ; enemy pos on image up/down tab
                  lda $19                         ; enemy time in hole
                  sta LR_TabEnemyGold,x           ; enemy has gold tab
                  lda $18                         ; actual enemy dir right/left  $ff=left  $01=right
                  sta LR_TabEnemySpr__,x          ;
                  lda $17                         ; actual enemy sprite number
                  sta LR_TabEnemySprNo,x          ; actual enemy sprite number
                  
SavEnemyStatusX   rts
; ------------------------------------------------------------------------------------------------------------- ;
GetEnemyStatus    ldx LR_NoEnemy2Move             ; # of enemy to move
                  
                  lda LR_TabEnemyCol,x            ; adr column enemies
                  sta $15                         ; enemy col
                  lda LR_TabEnemyRow,x            ; adr row enemies
                  sta $16                         ; actual enemy row
                  lda LR_TabEnemyPosLR,x          ; enemy pos on image left/right tab
                  sta $1a                         ; actual enemy pos on image left/right
                  lda LR_TabEnemyPosUD,x          ; enemy pos on image up/down tab
                  sta $1b                         ; actual enemy pos on image up/down
                  lda LR_TabEnemySprNo,x          ; actual enemy sprite number
                  sta $17                         ; actual enemy sprite number
                  lda LR_TabEnemySpr__,x          ;
                  sta $18                         ; actual enemy dir right/left  $ff=left  $01=right
                  lda LR_TabEnemyGold,x           ; enemy has gold tab
                  sta $19                         ; enemy time in hole
                  
GetEnemyStatusX   rts
; ------------------------------------------------------------------------------------------------------------- ;
CloseHoles        jsr EnemyRebirth                ;
                  
                  inc LR_EnmyBirthCol             ; pointer: enemy rebirth column
_ChkBirthCol      lda LR_EnmyBirthCol             ; pointer: enemy rebirth column
                  cmp #LR_EnmyBColMax             ; $1c - max 28
                  bcc _ChkHoles
                  
                  lda #$00                        ; reset
                  sta LR_EnmyBirthCol             ; pointer: enemy rebirth column
                  
_ChkHoles         ldx #LR_TabHoleMax              ; max 30 open holes
_GetNextHoleTime  lda LR_TabHoleOpenT,x           ; hole open time tab
                  stx $52                         ; open holes time pointer
                  bne _DecHoleTime
                  
                  jmp _SetNextHoleTime            ; set next hole time
                  
_DecHoleTime      dec LR_TabHoleOpenT,x           ; open holes counter
                  beq _HoleOpenTimeOut            ; open time out - so close
                  
                  lda LR_TabHoleCol,x             ; hole column tab
                  sta $4f                         ; screen col  (00-1b)
                  lda LR_TabHoleRow,x             ; hole row tab
                  sta $50                         ; screen row  (00-0f)
                  
                  lda LR_TabHoleOpenT,x           ; hole open time tab
_ChkClose1stStep  cmp #LR_TabHoleOpenT1           ; first step close
                  bne _ChkClose2ndStep            ;  already passed
                  
                  lda #NoCloseHole00              ; close hole 1st step
_CloseStepOut     jsr ImageOut2Prep               ; direct output to preparation screen
                  
                  ldx $4f                         ; screen col  (00-1b)
                  ldy $50                         ; screen row  (00-0f)
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row
                  
                  lda #$00
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
_GoSetNextHT      jmp _SetNextHoleTime            ; set next hole time
                  
_ChkClose2ndStep  cmp #LR_TabHoleOpenT2           ; second step close
                  bne _GoSetNextHT                ;  already passed
                  
                  lda #NoCloseHole01              ; close hole 2nd step
                  bne _CloseStepOut               ; always
                  
_HoleOpenTimeOut  ldx $52                         ; open holes time pointer
                  ldy LR_TabHoleRow,x             ; hole row tab
                  sty $50                         ; screen row  (00-0f)
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy LR_TabHoleCol,x             ; hole column tab
                  sty $4f                         ; screen col  (00-1b)
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #$00
                  bne _ChkHoleLR                  ; closed hole was not emty
                  
                  jmp _CloseWithWall
                  
_ChkHoleLR        cmp #NoTileLodeRunner
                  bne _ChkHoleEnemy
                  
                  lsr LR_Alive                    ; $00=lr killed
                  
_ChkHoleEnemy     cmp #NoTileEnemy
                  beq _ReviveEnemy
                  
_ChkHoleGold      cmp #NoTileGold
                  bne _GoCloseWithWall
                  dec LR_GoldToGet
                  
_GoCloseWithWall  jmp _CloseWithWall
                  
_ReviveEnemy      lda #NoTileWallWeak
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  sta ($0b),y                     ; play level control data ($0a00-$0bc3)
                  jsr ImageOut2Disp               ; direct output to display screen
                  
                  lda #NoTileWallWeak
                  jsr ImageOut2Prep               ; direct output to preparation screen
                  
                  ldx LR_EnmyNo                   ; number of enemies
_ChkEnemyCol      lda LR_TabEnemyCol,x            ; adr column enemies
                  cmp $4f                         ; screen col  (00-1b)
                  beq _ChkEnemyRow
                  
                  jmp _SetNextEnemy
                  
_ChkEnemyRow      lda LR_TabEnemyRow,x            ; adr row enemies
                  cmp $50                         ; screen row  (00-0f)
                  bne _SetNextEnemy
                  
                  lda TabEnemyDisab,x             ; disable enemy sprite tab
                  and SPENA                       ; VIC 2 - $D015 = Sprite Enable
                  sta SPENA                       ; VIC 2 - $D015 = Sprite Enable
                  lda LR_TabEnemyGold,x           ; enemy has gold tab
                  bpl _ResetValues
                  
                  dec LR_GoldToGet                ; enemy still had gold
                  
_ResetValues      lda #$7f                        ; reset
                  sta LR_TabEnemyGold,x           ; enemy has gold tab entry
                  stx LR_NoEnemy2Move             ; # of enemy to move
                  jsr GetEnemyStatus
                  jsr MovEnmyGetXYNo
                  jsr ImageGameClear              ; clear on game screen (shootings/close holes/remove gold)
                  
                  ldx LR_NoEnemy2Move             ; # of enemy to move
                  ldy #$01                        ; start with top row
                  sty $50                         ; screen row  (00-0f)
_FindRebirthPosI  ldy $50                         ; screen row  (00-0f)
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy LR_EnmyBirthCol             ; pointer: enemy rebirth column
_FindRebirthPos   lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #NoTileBlank                ; empty
                  beq _SetRebirthPos              ; found
                  
                  inc LR_EnmyBirthCol             ; pointer: enemy rebirth column
                  ldy LR_EnmyBirthCol             ; pointer: enemy rebirth column
                  cpy #LR_ScrnMaxCols+1           ; $1b - max 27 cols
                  bcc _FindRebirthPos
                  
                  inc $50                         ; screen row  (00-0f)
                  lda #$00
                  sta LR_EnmyBirthCol             ; pointer: enemy rebirth column
                  beq _FindRebirthPosI            ; always
                  
_SetRebirthPos    tya
                  sta LR_TabEnemyCol,x            ; adr column enemies
                  lda $50                         ; screen row  (00-0f)
                  sta LR_TabEnemyRow,x            ; adr row enemies
                  lda #LR_TabEnemyBirt1+1
                  sta LR_TabEnemyBirtT,x          ; enemy rebirth step time
                  lda #$02
                  sta LR_TabEnemyPosUD,x          ; enemy pos on image up/down tab
                  sta LR_TabEnemyPosLR,x          ; enemy pos on image left/right tab
                  lda #$00
                  sta LR_TabEnemySprNo,x          ; actual enemy sprite number
                  ldy #$01
                  lda #$00                        ; score 100 points
                  jsr Score2BaseLine
                  jmp _SetNextHoleTime            ; set next hole time
                  
_SetNextEnemy     dex
                  beq _CloseWithWall
                  jmp _ChkEnemyCol
                  
_CloseWithWall    lda #NoTileWallWeak
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  jsr ImageOut2Disp               ; direct output to display screen
                  
                  lda #NoTileWallWeak
                  jsr ImageOut2Prep               ; direct output to preparation screen
                  
_SetNextHoleTime  ldx $52                         ; open holes time pointer
                  dex
                  bmi CloseHolesX                 ; all open holes processed
                  
                  jmp _GetNextHoleTime
                  
CloseHolesX       rts
; ------------------------------------------------------------------------------------------------------------- ;
EnemyRebirth      ldx LR_EnmyNo                   ; number of enemies
                  beq CloseHolesX                 ;
                  
_GetEnemyNumber   lda LR_NoEnemy2Move             ; # of enemy to move
                  pha                             ; save
                  
_GetNextStepTime  lda LR_TabEnemyBirtT,x          ; enemy rebirth step time
                  beq _SetNextStepTime            ; not dead
                  
                  stx LR_NoEnemy2Move             ; # of enemy to move
                  jsr GetEnemyStatus              ;
                  
                  lda #$7f                        ; no gold
                  sta LR_TabEnemyGold,x           ; enemy has gold tab
                  
                  lda LR_TabEnemyCol,x            ; adr column enemies
                  sta $4f                         ; screen col  (00-1b)
                  lda LR_TabEnemyRow,x            ; adr row enemies
                  sta $50                         ; screen row  (00-0f)
                  
_DecBirthTime     dec LR_TabEnemyBirtT,x          ; enemy rebirth step time
                  beq _RebirthReadyEN             ;
                  
_ChkBirth1stStep  lda LR_TabEnemyBirtT,x          ; enemy rebirth step time
                  cmp #LR_TabEnemyBirt1           ; first step rebirth
                  bne _ChkBirth2ndStep            ;   already passed
                  
                  lda #NoReviveEnemy00            ; rebirth 1st step
                  jsr ImageOut2Prep               ; output to preparation screen first ($4000)
                  jsr MovEnmyGetXYNo              ;
                  
                  lda #NoReviveEnemy00            ; rebirth 1st step
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  jmp _GetNextEnemy               ;
                  
_ChkBirth2ndStep  cmp #LR_TabEnemyBirt2           ; second step rebirth
                  bne _SetNextStepTime            ;
                  
                  lda #NoReviveEnemy01            ; rebirth 2nd step
                  jsr ImageOut2Prep               ; output to preparation screen first ($4000)
                  jsr MovEnmyGetXYNo              ;
                  
                  lda #NoReviveEnemy01            ; rebirth 2nd step
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  
_GetNextEnemy     ldx LR_NoEnemy2Move             ; # of enemy to move
_SetNextStepTime  dex                             ;
                  bne _GetNextStepTime            ;
                  
                  pla                             ; restore
                  sta LR_NoEnemy2Move             ; # of enemy to move
                  
_RebirthExit      rts                             ;

_RebirthReadyEN   ldy $50                         ; screen row  (00-0f)
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09                         ; 
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a                         ; 
                  
                  ldx LR_NoEnemy2Move             ; # of enemy to move
                  inc LR_TabEnemyBirtT,x          ; enemy rebirth step time
                  ldy $4f                         ; screen col  (00-1b)
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  bne _SetNextStepTime            ;
                  
                  lda #NoTileEnemy                ;
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  lda #NoTileBlank                ; empty
                  jsr ImageOut2Prep               ; output to preparation screen first ($4000)
                  
                  lda #NoTileBlank                ; empty
                  jsr ImageOut2Disp               ; output directly to display screen ($2000)
                  
                  lda #$00                        ;
                  ldx LR_NoEnemy2Move             ; # of enemy to move
                  sta LR_TabEnemyGold,x           ; enemy has gold tab
                  sta LR_TabEnemyBirtT,x          ; enemy rebirth step time
                  
                  lda #NoTileEnemy                ;
                  jsr ImageOut2Disp               ; output directly to display screen ($2000)
                  
                  ldx LR_NoEnemy2Move             ; # of enemy to move
                  lda TabEnemyEnab,x              ; enable enemy sprite tab
                  ora SPENA                       ; VIC 2 - $D015 = Sprite Enable
                  sta SPENA                       ; VIC 2 - $D015 = Sprite Enable
                  jmp _SetNextStepTime            ;
EnemyRebirthX     = *
; ------------------------------------------------------------------------------------------------------------- ;
TabEnemyEnab      .byte $00 ; ........
                  .byte $04 ; .....#..
                  .byte $08 ; ....#...
                  .byte $10 ; ...#....
                  .byte $40 ; .#......
                  .byte $80 ; #.......
; ------------------------------------------------------------------------------------------------------------- ;
TabEnemyDisab     .byte $00 ; ........
                  .byte $fb ; #####.##
                  .byte $f7 ; ####.###
                  .byte $ef ; ###.####
                  .byte $bf ; #.######
                  .byte $7f ; .#######
; ------------------------------------------------------------------------------------------------------------- ;
InitBothScreens   jsr ClearHiresDisp              ; ClearDisplay20      <InitBothScreens>
                  jsr ClearHiresPrep              ; ClearDisplay40
; ------------------------------------------------------------------------------------------------------------- ;
BaseLines         ldx #$22                        ; length of separator line

_SeparatorLine    lda $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)      <islSeparator>
                  cmp #>LR_ScrnHiRePrep           ; hires preparation screen
                  beq _HiResPrepare               ; 
                  
_HiResDisplay     lda #$0a                        ; grafic byte for
                  sta LR_StatsLinLeD01            ;   left end 0
                  sta LR_StatsLinLeD02            ;   left end 1
                  sta LR_StatsLinLeD03            ;   left end 2
                  sta LR_StatsLinLeD04            ;   left end 3
                  lda #$a0                        ; grafic byte for
_HiResDispReX     sta LR_StatsLinRiD01            ;   right end 0
                  sta LR_StatsLinRiD02            ;   right end 1
                  sta LR_StatsLinRiD03            ;   right end 2
                  sta LR_StatsLinRiD04            ;   right end 3
_HiResDispMid     ldy #$03                        ;       <islSep20MidInit>
                  lda #$aa                        ; grafic byte middle part seperation line
_HiResDispMidPut  sta LR_StatsLinMiD,y            ; middle part 0-3
__ModDispMidLo    = *-2
__ModDispMidHi    = *-1
                  dey                             ;
                  bpl _HiResDispMidPut            ; store next middle part 0-3
                  
_HiResDispNext    lda __ModDispMidLo              ; 
                  clc                             ;
                  adc #$08                        ; next position
                  sta __ModDispMidLo              ;
                  bcc _HiResDispDec               ; 
                  inc __ModDispMidHi              ;
                  
_HiResDispDec     dex                             ; 
                  bne _HiResDispMid               ; 
                  
                  lda #>LR_StatsLinMiD            ; restore old values
                  sta __ModDispMidHi              ;
                  lda #<LR_StatsLinMiD
                  sta __ModDispMidLo              ;
                  bne _InfoLine                   ; always
                  
_HiResPrepare     lda #$0a                        ; grafic byte left end seperation line      <islSep40>
                  sta LR_StatsLinLeP01            ;   left end 0
                  sta LR_StatsLinLeP02            ;   left end 1
                  sta LR_StatsLinLeP03            ;   left end 2
                  sta LR_StatsLinLeP04            ;   left end 3
                  lda #$a0                        ; grafic byte right end seperation line
_HiResPrepRiX     sta LR_StatsLinRiP01            ;   right end 0
                  sta LR_StatsLinRiP02            ;   right end 1
                  sta LR_StatsLinRiP03            ;   right end 2
                  sta LR_StatsLinRiP04            ;   right end 3
_HiResPrepMid     ldy #$03                        ;
                  lda #$aa                        ; grafic byte middle part seperation line
_HiResPrepMidPut  sta LR_StatsLinMiP,y            ; 
__ModPrepMidLo    = *-2
__ModPrepMidHi    = *-1
                  dey                             ;
                  bpl _HiResPrepMidPut            ;
                  
                  lda __ModPrepMidLo              ;
                  clc                             ;
                  adc #$08                        ; next position
                  sta __ModPrepMidLo              ;
                  bcc _HiResPrepDec               ;
                  inc __ModPrepMidHi              ;
                  
_HiResPrepDec     dex                             ;
                  bne _HiResPrepMid               ;
                  
                  lda #>LR_StatsLinMiP            ; restore old values
                  sta __ModPrepMidHi              ;
                  lda #<LR_StatsLinMiP            ;
                  sta __ModPrepMidLo              ;
                  
_InfoLine         lda #LR_BasLinRowStat           ; 
                  sta $50                         ; screen row ($00 - $0f)
                  lda #$00                        ; 
                  sta $4f                         ; screen col ($00 - $1b)
                  jsr TextOut                     ; TextOut
                  .byte $d3 ; S
                  .byte $c3 ; C
                  .byte $cf ; O
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $cd ; M
                  .byte $c5 ; E
                  .byte $ce ; N
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $cc ; L
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $00 ; EndOfText
                  
                  jsr Lives2BaseLine              ; 
                  jsr Level2BaseLine              ; 
                  
                  lda #$00                        ; no score to add
                  tay                             ; no score to add
                  
BaseLinesX        jmp Score2BaseLine              ; AddDisplayScore (ac=1s yr=100s) - display only - no score to add
; ------------------------------------------------------------------------------------------------------------- ;
Lives2BaseLine    lda CR_StatusColor              ; 
                  bne Level2BaseLineX             ; 
                  
                  lda LR_NumLives                 ; 
                  ldx #LR_BasLinColLve            ;
                  
ValueToBaseLine   stx $4f                         ; screen col ($00 - $1b)      <StatusOutValue>
                  jsr ConvertHex2Dec              ; Hex2Dec  (1307=100 1308=10 1309=1)
                  
                  lda #LR_BasLinRowStat           ;
                  sta $50                         ; screen row ($00 - $0f)
                  
                  lda LR_Digit100                 ; 
                  jsr PrepareDigitOut             ; 
                  
                  lda LR_Digit10                  ; 
                  jsr PrepareDigitOut             ; 
                  
                  lda LR_Digit1                   ; 
ValueToBaseLineX  jmp PrepareDigitOut             ; 
; ------------------------------------------------------------------------------------------------------------- ;
Level2BaseLine    lda LR_LevelNoGame              ; 001-050
                  ldx #LR_BasLinColLvl            ;
                  bne ValueToBaseLine             ;
                  
                  lda #$14                        ;
                  sta $4f                         ; screen col ($00 - $1b)
                  lda #$10                        ;
                  sta $50                         ; screen row ($00 - $0f)
                  jsr TextOut                     ; TextOut
                  .byte $cc                       ; LEVEL
                  .byte $c5
                  .byte $d6
                  .byte $c5
                  .byte $cc
                  .byte $00
                  
                  jmp Level2BaseLine              ;

Level2BaseLineX   rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
Score2BaseLine    clc                             ; AddDisplayScore (ac=1s yr=100s)

                  sed                             ;
                  
                  adc LR_ScoreLo                  ; lrScoreLow
                  sta LR_ScoreLo                  ; lrScoreLow
                  tya                             ;
                  adc LR_ScoreMidLo               ; lrScoreMidLow
                  sta LR_ScoreMidLo               ; lrScoreMidLow
                  lda #$00                        ;
                  adc LR_ScoreMidHi               ; lrScoreMidHigh
                  sta LR_ScoreMidHi               ; lrScoreMidHigh
                  lda #$00                        ;
                  adc LR_ScoreHi                  ; lrScoreHigh
                  sta LR_ScoreHi                  ; lrScoreHigh
                  
                  cld                             ;
                  
                  lda #LR_BasLinColScr            ; 
                  sta $4f                         ; screen col ($00 - $1b)
                  lda #LR_BasLinRowStat            ;
                  sta $50                         ; screen row ($00 - $0f)
                  
                  lda LR_ScoreHi                  ; lrScoreHigh
                  jsr SplitScoreDigit             ;
                  
                  lda LR_Digit1                   ; use only right nybble discard left nybble
                  jsr PrepareDigitOut             ; 
                  
                  lda LR_ScoreMidHi               ; 
                  jsr SplitScoreDigit             ;
                  
                  lda LR_Digit10                  ; 
                  jsr PrepareDigitOut             ; 
                  lda LR_Digit1                   ; 
                  jsr PrepareDigitOut             ; 
                  
                  lda LR_ScoreMidLo               ; 
                  jsr SplitScoreDigit             ;
                  
                  lda LR_Digit10                  ; 
                  jsr PrepareDigitOut             ; 
                  lda LR_Digit1                   ; 
                  jsr PrepareDigitOut             ;                   
                  lda LR_ScoreLo                  ; 
                  jsr SplitScoreDigit             ;
                  
                  lda LR_Digit10                  ; 
                  jsr PrepareDigitOut             ; 
                  lda LR_Digit1                   ; 
Score2BaseLineX   jmp PrepareDigitOut             ; 
; ------------------------------------------------------------------------------------------------------------- ;
SplitScoreDigit   sta LR_Digit10                  ; lrDec10

                  and #$0f                        ;
                  sta LR_Digit1                   ; lrDec1
                  lda LR_Digit10                  ; lrDec10
                  lsr a                           ;
                  lsr a                           ;
                  lsr a                           ;
                  lsr a                           ;
                  sta LR_Digit10                  ; lrDec10

SplitScoreDigitX  rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
ConvertHex2Dec    ldx #$00                        ; 
                  stx LR_Digit10                  ; digit 10 part
                  stx LR_Digit100                 ; digit 100 part
                  
_Chk100           cmp #$64                        ; 100
                  bcc _Chk10                      ; lower
                  
                  inc LR_Digit100                 ; count number of hundreds
                  sbc #$64                        ; 100
                  bne _Chk100                     ;
                   
_Chk10            cmp #$0a                        ; 10
                  bcc _Chk1                       ; 
                  
                  inc LR_Digit10                  ; count number of tens
                  sbc #$0a                        ;
                  bne _Chk10                      ; try for the next 10
                  
_Chk1             sta LR_Digit1                   ; count number of ones

ConvertHex2DecX   rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
PrepareDigitOut   clc                             ; 
                  adc #$3b                        ; map to digit image data numbers
                  
                  ldx $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  cpx #>LR_ScrnHiRePrep           ;
                  beq _Out2Prepare                ; 
                  
_Out2Display      jsr ImageOut2Disp               ; output directly to display screen ($2000)
                  inc $4f                         ; screen col ($00 - $1b)
                  rts                             ;

_Out2Prepare      jsr ImageOut2Prep               ; output to preparation screen first ($4000)
                  inc $4f                         ; screen col ($00 - $1b)
PrepareDigitOutX  rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
SetChrSubst_0_9   sec                             ;
                  sbc #$75                        ;

SetChrSubst_0_9X  rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
GetChrSubst       cmp #$b0                        ; key "0"
                  bcc _Chk_A_Z                    ;
                  
                  cmp #$ba                        ;
                  bcc SetChrSubst_0_9             ; key "9"
                  
_Chk_A_Z          cmp #$c1                        ; "A"
                  bcc _ChkSpecial                 ;
                  
                  cmp #$db                        ; "Z" + 1
                  bcc _SubstChr                   ;
                  
_ChkSpecial       ldx #$7c                        ; 
                  cmp #$a0                        ; <blank>
                  beq _SetSpecial                 ;
                  
                  ldx #$db                        ;
                  cmp #$be                        ; ">"
                  beq _SetSpecial                 ;
                  
                  inx                             ;
                  cmp #$ae                        ; "."
                  beq _SetSpecial                 ;
                  
                  inx                             ;
                  cmp #$a8                        ; "("
                  beq _SetSpecial                 ;
                  
                  inx                             ;
                  cmp #$a9                        ; ")"
                  beq _SetSpecial                 ;
                  
                  inx                             ;
                  cmp #$af                        ; "/"
                  beq _SetSpecial                 ;
                  
                  inx                             ;
                  cmp #$ad                        ; "-"
                  beq _SetSpecial                 ;
                  
                  inx                             ;
                  cmp #$bc                        ; "<"
                  beq _SetSpecial                 ;
                  
                  lda #$10                        ;
                  rts                             ;
                  
_SetSpecial       txa                             ;
_SubstChr         sec                             ;
                  sbc #$7c                        ;
                  
GetChrSubstX      rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
PrepareChrOut     cmp #$8d                        ; <newline>
                  beq SetNewLine                  ; 
                  
                  jsr GetChrSubst                 ;
                  
                  ldx $51                         ; control gfx screen output - display=$20(00) hidden=$40(00)
                  cpx #>LR_ScrnHiRePrep           ;
                  beq _OutToPrepare               ;
                  
_OutToDisplay     jsr ImageOut2Disp               ; output directly to display screen ($2000)
                  inc $4f                         ; screen col ($00 - $1b)
                  rts                             ;
                  
_OutToPrepare     jsr ImageOut2Prep               ; output to preparation screen first ($4000)
                  inc $4f                         ; screen col ($00 - $1b)
                  rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
SetNewLine        inc $50                         ; screen row ($00 - $0f) <NextScreenPos>
                  lda #$00                        ;
                  sta $4f                         ; screen col ($00 - $1b)

SetNewLineX       rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
ClearTheRow       sta $50                         ; screen row ($00 - $0f)
                  lda #$00                        ;
                  sta $4f                         ; screen col ($00 - $1b)
                  
                  lda #LR_ScrnMaxCols+1           ;
                  sta CR_Work                     ;
_WipeOut          lda #$a0                        ; <blank>
                  jsr PrepareChrOut               ;
                  
                  dec CR_Work                     ;
                  bne _WipeOut                    ;
                  
ClearTheRowX      rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TextOut           pla                             ; pull the text start address from the stack
                  sta $13                         ;
                  pla                             ;
                  sta $14                         ;
                  bne _SetNext                    ; always
                  
_GetNext          ldy #$00                        ;       <toGet>
                  lda ($13),y                     ;
                  beq _PrepXit                    ; zero as text end
                  
_ImageOut         jsr PrepareChrOut               ;

_SetNext          inc $13                         ;       <toNextPos>
                  bne _GetNext                    ;
                  
                  inc $14                         ;
                  bne _GetNext                    ;
                  
_PrepXit          lda $14                         ; push the text end address to the stack
                  pha                             ;
                  lda $13                         ; 
                  pha                             ;
                  
TextOutX          rts                             ; as return address
; ------------------------------------------------------------------------------------------------------------- ;
Beep              sei                             ;

                  lda #$60                        ; beep
                  sta FREHI1                      ; SID - $D401 = Oscillator 1 Frequency Control (High Byte)
                  ldy #$38                        ;
                  ldx #$00                        ; init wait
_Wait             dex                             ;
                  bne _Wait                       ;
                  dey                             ;
                  bne _Wait                       ;
                  sty FREHI1                      ; SID - $D401 = Oscillator 1 Frequency Control (High Byte)
                  
                  cli                             ;
                  
BeepX             rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
WaitKeyBlink      sta CR_WaitImageNo              ; save byte under cursor

_WaitBlank        lda #$00                        ; init wait for action timer
                  sta CR_WaitTimeLo               ;
                  lda #$0a                        ;
                  sta CR_WaitTimeHi               ;
                  
                  lda #$00                        ;
                  ldx CR_WaitImageNo              ;
                  bne _Out                        ;
                  
_GetBlankImg      lda #$0a                        ; image big reverse cursor

_Out              jsr ImageOut2Disp               ; output directly to display screen ($2000)

_WaitUser1        jsr ChkUserAction               ; check user input - carry_set=yes carry_clear=no
                  bcs _GotUserKey                 ;
                  
                  dec CR_WaitTimeLo               ;
                  bne _WaitUser1                  ;
                  dec CR_WaitTimeHi               ;
                  bne _WaitUser1                  ;
                  
_WaitImage        lda CR_WaitImageNo              ; get image number unter cursor
                  jsr ImageOut2Disp               ; output directly to display screen ($2000)

                  lda #$00                        ; init wait for action timer
                  sta CR_WaitTimeLo               ;
                  lda #$0a                        ;
                  sta CR_WaitTimeHi               ;
                  
_WaitUser2        jsr ChkUserAction               ; check user input - carry_set=yes carry_clear=no
                  bcs _GotUserKey                 ;
                  
                  dec CR_WaitTimeLo               ;
                  bne _WaitUser2                  ;
                  dec CR_WaitTimeHi               ;
                  bne _WaitUser2                  ;
                  
                  jmp _WaitBlank                  ;
                  
_GotUserKey       pha                             ; save key

_RestoreImage     lda CR_WaitImageNo              ; redisplay chr under cursor in case of got in blank blink phase
                  jsr ImageOut2Disp               ; output directly to display screen ($2000)
                  
                  pla                             ; restore key
WaitKeyBlinkX     rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
ChkUserAction     lda CIAPRA                      ; CIA 1 - $DC00 = Data Port A
                  and #$0f                        ; isolate - port a:  bit4=fire  bit3=right  bit2=left  bit1=down  bit0=up
                  eor #$0f                        ;
                  bne _SetUserAction              ; 
                  
                  lda CIAPRA                      ; CIA 1 - $DC00 = Data Port A
                  and #$10                        ;
                  beq _SetUserAction              ;
                  
                  lda LR_KeyNew                   ; lrNewKey
                  bne _SetUserAction              ;
                  
_SetNoUserAction  clc                             ; indicate no user action
                  rts                             ; 
                  
_SetUserAction    sec                             ; indicate user action
ChkUserActionX    rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
ImageOut2Disp     sta $23                         ; image number
                  lda #>LR_ScrnHiReDisp           ;
                  bne ImageOut                    ; always
                  
ImageOut2Prep     sta $23                         ; image number
                  lda #>LR_ScrnHiRePrep           ;
                  
ImageOut          sta $24                         ; target output  $20=$2000 $40=$4000

                  ldy $50                         ; screen row ($00 - $0f)
                  ldx $4f                         ; screen col ($00 - $1b)
                  jsr GetColRowGfxOff             ; 
                  sty $20                         ; row offset
                  
                  jsr SetSpritePos                ;
                  jsr GetOutGfxPosAdd             ; xr=VIC Sprite XPOS offset
                  stx $41                         ; image position number  (bits 0-1 of $4f substitution)
                  
                  lda TabInsImageLe,x             ; insert image left tab  (4 different image positions)
                  sta $25                         ; isolate right grafic part
                  lda TabInsImageRi,x             ; insert image right tab (4 different image positions)
                  sta $26                         ; isolate left grafic part

_GetImage         jsr GetImageBytes               ; stored from $5b-$7b

_SetHeight        lda #$0b                        ; 11 - hight of each image
                  sta $22                         ; image hight
                  
                  ldx #$00                        ;
                  lda $41                         ; image position number  (bits 0-1 of $4f substitution)
                  cmp #$05                        ; $05 impossible
                  bcs ImageOutBig                 ; never called
                  
_ImageOut         ldy $20                         ; grafic row substitution
                  jsr GetOutGfxPtr                ;
                  
                  ldy #$00
                  lda ($0f),y                     ; get grafic screen image byte
                  and $25                         ; clear the right grafic part
                  ora $5b,x                       ; insert new image byte
                  sta ($0f),y                     ; write grafic screen image byte
                  
                  inx                             ; point to next image byte
                  ldy #$08                        ; insert right part of image into right part of screen image
                  lda ($0f),y                     ; get grafic screen image byte
                  and $26                         ; clear the left grafic part
                  ora $5b,x                       ; insert new image byte
                  sta ($0f),y                     ; write grafic screen image byte
                  
                  inx                             ;
                  inx                             ;
                  
                  inc $20                         ; grafic row substitution
                  dec $22                         ; image hight
                  bne _ImageOut                   ;
                  
ImageOutX         rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
ImageOutBig       ldy $20                         ; grafic row substitution
                  jsr GetOutGfxPtr                ;
                  
                  ldy #$00
                  lda ($0f),y                     ; get grafic screen image byte
                  and $25                         ; clear the right grafic part
                  ora $5b,x                       ; insert new image byte
                  sta ($0f),y                     ; write grafic screen image byte
                  
                  inx                             ; point to next image byte
                  ldy #$08                        ; insert into right part of screen image
                  lda $5b,x                       ; get new image byte
                  sta ($0f),y                     ; write grafic screen image byte
                  
                  inx                             ; point to next image byte
                  ldy #$10                        ;
                  lda ($0f),y                     ; get grafic screen image byte
                  and $26                         ; clear the left grafic part
                  ora $5b,x                       ; overlay new image byte
                  sta ($0f),y                     ; write grafic screen image byte
                  
                  inx                             ;
                  inc $20                         ; grafic row substitution
                  dec $22                         ; image hight
                  bne ImageOutBig                 ;
                  
ImageOutBigX      rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TabInsImageLe     .byte $00 ; ........
                  .byte $c0 ; ##......
                  .byte $f0 ; ####....
                  .byte $fc ; ######..
; ------------------------------------------------------------------------------------------------------------- ;
TabInsImageRi     .byte $3f ; ..######
                  .byte $0f ; ....####
                  .byte $03 ; ......##
                  .byte $00 ; ........
; ------------------------------------------------------------------------------------------------------------- ;
ImageGameClear    sty $20                         ; grafic row substitution
                  sta $23                         ; image number
                  jsr GetOutGfxPosAdd             ;
                  
                  sta $21                         ; low byte grafic tab addition
                  stx $41                         ; image position number  (bits 0-1 of $4f substitution)
                  jsr GetImageBytes               ;
                  
                  ldx #$0b                        ;
                  stx $22                         ; image hight
                  
                  ldx #$00                        ;
                  
                  lda $41                         ; image position number  (bits 0-1 of $4f substitution)
                  cmp #$05                        ; $05 impossible
                  bcs ImageGameClrBig             ;
                  
_UpdateOut        ldy $20                         ; grafic row substitution
                  jsr GetMoveGfxPtr               ;
                  
                  ldy #$00                        ; image left part
                  
_Get1st           lda $5b,x                       ; image byte
                  eor #$ff                        ;
                  and ($0f),y                     ; screen grafic pointer byte
                  ora ($11),y                     ; hidden grafic pointer byte
_Put1st           sta ($0f),y                     ; screen grafic pointer byte

                  inx                             ;
                  
                  ldy #$08                        ; image right part
                  
_Get2nd           lda $5b,x                       ; image byte
                  eor #$ff                        ;
                  and ($0f),y                     ; screen grafic pointer byte
                  ora ($11),y                     ; hidden grafic pointer byte
_Put2nd           sta ($0f),y                     ; screen grafic pointer byte

_Ign3rd           inx                             ; 3rd imge byte always $00 - ignore
                  inx                             ;
                  
                  inc $20                         ; grafic row substitution
                  
                  dec $22                         ; image hight
                  bne _UpdateOut                  ;
                  
ImageGameClearX   rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
ImageGameClrBig   ldy $20                         ; grafic row substitution
                  jsr GetMoveGfxPtr               ;
                  
                  ldy #$00                        ; image left part
                  
_Get1st           lda $5b,x                       ; image byte
                  eor #$ff                        ;
                  and ($0f),y                     ; screen grafic pointer byte
                  ora ($11),y                     ; hidden grafic pointer byte
_Put1st           sta ($0f),y                     ; screen grafic pointer byte

                  inx                             ; point to next image byte
                  
                  ldy #$08                        ; image mid part
                  
_Get2nd           lda $5b,x                       ; image byte
                  eor #$ff                        ;
                  and ($0f),y                     ; screen grafic pointer byte
                  ora ($11),y                     ; hidden grafic pointer byte
_Put2nd           sta ($0f),y                     ; screen grafic pointer byte

                  inx                             ; point to next image byte
                  
                  ldy #$10                        ;
                  
                  lda $5b,x                       ; image right part
                  eor #$ff                        ;
                  and ($0f),y                     ; screen grafic pointer byte
                  ora ($11),y                     ; hidden grafic pointer byte
_Put3rd           sta ($0f),y                     ; screen grafic pointer byte

                  inx                             ; point to next image byte
                  
                  inc $20                         ; grafic row substitution
                  
                  dec $22                         ; image hight
                  bne ImageGameClrBig             ;
                  
ImageGameClrBigX  rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
ImageGameSet      sty $20                         ; grafic row substitution
                  sta $23                         ; image number
                  jsr SetSpritePos                ; xr=VIC Sprite XPOS offset
                  jsr GetOutGfxPosAdd             ;
                  
                  sta $21                         ; low byte grafic tab addition
                  stx $41                         ; image position number  (bits 0-1 of 4f substitution)
                  
_GetImage         jsr GetImageBytes               ; stored from $5b-$7b

                  lda #$0b                        ;
                  sta $22                         ; image hight
                  
                  ldx #$00                        ;
                  stx $27                         ; clear sprite collision  $01=lr caught
                  
                  lda $41                         ;
                  cmp #$05                        ;
                  bcs ImageGameSetBig             ;
                  
_SpriteOut        ldy $20                         ; grafic row substitution
                  jsr GetMoveGfxPtr               ;
                  
                  ldy #$00                        ; first image half
                  
_Get1st           lda $5b,x                       ; image byte
                  ora ($0f),y                     ; screen grafic pointer byte
_Set1st           sta ($0f),y                     ; screen grafic pointer byte

                  inx                             ; image byte pointer
                  
                  ldy #$08                        ; second image half
                  
_Get2nd           lda $5b,x                       ; image byte
                  ora ($0f),y                     ; screen grafic pointer byte
_Set2nd           sta ($0f),y                     ; screen grafic pointer byte

_Ign3rd           inx                             ; 3rd imge byte always $00 - ignore
                  inx                             ;
                  
                  inc $20                         ; grafic row substitution
                  
                  dec $22                         ; image hight
                  bne _SpriteOut                  ;
                  
ImageGameSetX     rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
ImageGameSetBig   ldy $20                         ; grafic row substitution
                  jsr GetMoveGfxPtr               ;
                  
                  ldy #$00                        ; first image half
                  
_Get1st           lda $5b,x                       ; image byte
                  ora ($0f),y                     ; screen grafic pointer byte
_Set1st           sta ($0f),y                     ; screen grafic pointer byte

                  inx                             ; image byte pointer
                  
                  ldy #$08                        ; second image half
                  
_Get2nd           lda $5b,x                       ; image byte
                  ora ($0f),y                     ; screen grafic pointer byte
_Set2nd           sta ($0f),y                     ; screen grafic pointer byte

                  inx                             ; image byte pointer
                  
                  ldy #$10                        ;
                  
_Get3rd           lda $5b,x                       ; image byte
                  ora ($0f),y                     ; screen grafic pointer byte
_Set3rd           sta ($0f),y                     ; screen grafic pointer byte

                  inx                             ; image byte pointer
                  
                  inc $20                         ; grafic row substitution
                  
                  dec $22                         ; image hight
                  bne ImageGameSetBig             ;
                  
ImageGameSetBigX  rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
GetImageBytes     lda #$0b                        ; 11 rows with 3 bytes
                  sta $22                         ; image hight
                  
                  lda #<TabTileDataPtr            ; get image data pointer
                  sta $0d                         ;                  
                  lda #>TabTileDataPtr            ; get image data pointer
                  sta $0e                         ;
                  
_SetImgByteBase   ldy TabImageData,x              ; four different image pos tab
                  sty __ModGetImgDatH1            ; $00=$a0 $01=$a2 $02=$a4 $03=$a6
                  sty __ModGetImgDatH3            ;
                  iny                             ;                  
                  sty __ModGetImgDatH2            ; $00=$a1 $01=$a3 $02=$a5 $03=$a7
                  sty __ModGetImgDatH4            ;
                  
_SetZeroPgPtr     ldx #$00                        ; zero page storage pointer
_ConstructImage   ldy $23                         ; image number

_Get1stImgDatOff  lda ($0d),y                     ; get the offset to the image data bytes
                  tay                             ;
                  
_Get1stImgByte    lda TabTileDataA0,y             ; get 1st image byte     from $a000/$a200/$a400/$a600
__ModGetImgDatH1  = *-1

_Set1stImgByte    sta $5b,x                       ; store it to 1st position

_Get2ndImgByteLo  lda TabTileDataA0,y             ; get 2nd image 1st part from $a100/$a300/$a500/$a700
__ModGetImgDatH2   = *-1

_Set2ndImgByte    sta $5c,x                       ; store it to 2nd position

_IncOffsetPtr01   lda $0d                         ; point to next grafix data bytes
                  clc                             ;
                  adc #$68                        ;
                  sta $0d                         ;
                  lda $0e                         ;
                  adc #$00                        ;
                  sta $0e                         ;
                  
                  ldy $23                         ; image number
                  
_Get2ndImgDatOff  lda ($0d),y                     ; get the offset to the image data bytes
                  tay                             ;
                  
_Get2ndImgByteHi  lda TabTileDataA0,y             ; get 2nd image 2nd part from $a000/$a200/$a400/$a600
__ModGetImgDatH3  = *-1

_Ovl2ndImgByteLo  ora $5c,x                       ; overlay it with 2nd position
_Set2ndImgByteOK  sta $5c,x                       ; store it to 2nd position

_Get3rdImgByte    lda TabTileDataA0,y             ; get 3rd image byte     from $a100/$a300/$a500/$a700
__ModGetImgDatH4  = *-1

_Sto3rdImgByteLo  sta $5d,x                       ; store it to 3rd position

_IncOffsetPtr02   lda $0d                         ; point to next grafix data bytes
                  clc                             ;
                  adc #$68                        ;
                  sta $0d                         ;
                  lda $0e                         ;
                  adc #$00                        ;
                  sta $0e                         ;
                  
_IncZeroPgPtr     inx                             ; point to next zero page triple
                  inx                             ;
                  inx                             ;
                  
_DecImgRowCount   dec $22                         ; image hight
                  bne _ConstructImage             ;
                  
GetImageBytesX    rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TabImageData      .byte >TabTileDataA0            ;
                  .byte >TabTileDataA2            ;
                  .byte >TabTileDataA4            ;
                  .byte >TabTileDataA6            ;
; ------------------------------------------------------------------------------------------------------------- ;
SetSpritePos      lda LR_SprtPosCtrl              ; control sprite pos init  $00=init
                  bne SetSpritePosX               ;
                  
                  lda $23                         ; image number
                  cmp #$39                        ; first half of images ($00-$39) only
                  bcs SetSpritePosX               ;
                  
                  tay                             ;
                  lda TabSpriteGame,y             ; image substitution tab
                  bmi SetSpritePosX               ; image not to be substituted
                  beq _SavOffset                  ;
                  
                  sta $23                         ; substitute numbered MC image with game image
                  
_SavOffset        stx $21                         ; grafic xr offset from GetColRowGfxOff
                  jsr CopySpriteData              ; xr=sprite number * 2
                  
_SetSpriteXPos    lda $21                         ; grafic xr offset from GetColRowGfxOff
                  clc                             ;
                  adc #$0c                        ; 12
                  asl a                           ; *2
                  and #$f8                        ; clear bits 0-2
                  sta SP0X,x                      ; VIC 2 - $D000 = Sprite 0 PosX
                  bcc _ClrSpriteXPosHi            ; no x pos msb so ClearSpritesXMSB
                  
_SetSpriteXPosHi  lda TabSetSprtMSB,x             ; sprite set x pos msb tab
                  ora MSIGX                       ; VIC 2 - $D010 = MSBs Sprites 0-7 PosX
                  sta MSIGX                       ; VIC 2 - $D010 = MSBs Sprites 0-7 PosX
                  jmp _SetSpriteYPos              ;
                  
_ClrSpriteXPosHi  lda TabClrSprtMSB,x             ; sprite clear x pos msb tab
                  and MSIGX                       ; VIC 2 - $D010 = MSBs Sprites 0-7 PosX
                  sta MSIGX                       ; VIC 2 - $D010 = MSBs Sprites 0-7 PosX
                  
_SetSpriteYPos    lda $20                         ; 
                  clc                             ;
                  adc #$32                        ;
                  sta SP0Y,x                      ; VIC 2 - $D001 = Sprite 0 PosY
                  
                  lda SPSPCL                      ; VIC 2 - $D01E = Sprite/Sprite Collision
                  and #$01                        ; isolate bit 0
                  sta $27                         ; sprite collision  1=lr caught
                  
                  pla                             ; discard return address
                  pla                             ;
                  
SetSpritePosX     rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TabSetSprtMSB     .byte $01 ; .......#  set   - sprite x pos msb tab
TabClrSprtMSB     .byte $fe ; #######.  clear - sprite x pos msb tab
                  
                  .byte $02 ; ......#.  set   - sprite x pos msb tab
                  .byte $fd ; ######.#  clear - sprite x pos msb tab
                  
                  .byte $04 ; .....#..  set   - sprite x pos msb tab
                  .byte $fb ; #####.##  clear - sprite x pos msb tab
                  
                  .byte $08 ; ....#...  set   - sprite x pos msb tab
                  .byte $f7 ; ####.###  clear - sprite x pos msb tab
                  
                  .byte $10 ; ...#....  set   - sprite x pos msb tab
                  .byte $ef ; ###.####  clear - sprite x pos msb tab
                  
                  .byte $20 ; ..#.....  set   - sprite x pos msb tab
                  .byte $df ; ##.#####  clear - sprite x pos msb tab
                  
                  .byte $40 ; .#......  set   - sprite x pos msb tab
                  .byte $bf ; #.######  clear - sprite x pos msb tab
                  
                  .byte $80 ; #.......  set   - sprite x pos msb tab
                  .byte $7f ; .#######  clear - sprite x pos msb tab
; ------------------------------------------------------------------------------------------------------------- ;
; TabSpriteGame   Function: Game sprite substitution table
;                         : All entries correspond to their positions in DatImages
;                         : Sprite $00 entries will be positionally corrected
;                         : Sprite $ff entries will be ignored
;                         : Sprite $nn entries will replace their corresponding position number
;                 Parms   : ac=Sprite ID
;                 Returns : 
; ------------------------------------------------------------------------------------------------------------- ;
TabSpriteGame     .byte $ff                       ; $00 (not_used)
                  .byte $ff                       ; $01 (not_used)
                  .byte $ff                       ; $02 (not_used)
                  .byte $ff                       ; $03 (not_used)
                  .byte $ff                       ; $04 (not_used)
                  .byte $ff                       ; $05 (not_used)
                  .byte $ff                       ; $06 (not_used)
                  .byte $ff                       ; $07 (not_used)
                  .byte $0b                       ; $08 - enemy      - replace MC tile in game mode
                  .byte $00                       ; $09 - LodeRunner - if set to NoSprite_RuRi00 - lr is mispaced in many levels - why??
                  .byte $ff                       ; $0a (not_used)
                  .byte $00                       ; $0b --> sprite run    left  01
                  .byte $00                       ; $0c --> sprite run    left  02
                  .byte $00                       ; $0d --> sprite run    left  03
                  .byte $00                       ; $0e --> sprite ladder u/d   01
                  .byte $00                       ; $0f --> sprite fire   left
                  .byte $00                       ; $11 --> sprite run    right 02
                  .byte $00                       ; $12 --> sprite run    right 03
                  .byte $00                       ; $13 --> sprite ladder u/d   02
                  .byte $00                       ; $14 --> sprite fall   left
                  .byte $00                       ; $15 --> sprite fall   right
                  .byte $00                       ; $16 --> sprite pole   right 01
                  .byte $00                       ; $17 --> sprite pole   right 02
                  .byte $00                       ; $18 --> sprite pole   right 03
                  .byte $00                       ; $19 --> sprite pole   left  01
                  .byte $00                       ; $1a --> sprite pole   left  02
                  .byte $00                       ; $1b --> sprite pole   left  03
                  .byte $ff                       ; $1c (not_used)
                  .byte $ff                       ; $1d (not_used)
                  .byte $ff                       ; $1e (not_used)
                  .byte $ff                       ; $1f (not_used)
                  .byte $ff                       ; $20 (not_used)
                  .byte $ff                       ; $21 (not_used)
                  .byte $ff                       ; $22 (not_used)
                  .byte $ff                       ; $23 (not_used)
                  .byte $ff                       ; $24 (not_used)
                  .byte $ff                       ; $25 (not_used)
                  .byte $00                       ; $26 --> sprite fire   right
                  .byte $ff                       ; $27 (not_used)
                  .byte $ff                       ; $28 (not_used)
                  .byte $09                       ; $29 -
                  .byte $10                       ; $2a -
                  .byte $11                       ; $2b -
                  .byte $0c                       ; $2c -
                  .byte $0d                       ; $2d -
                  .byte $15                       ; $2e -
                  .byte $16                       ; $2f -
                  .byte $17                       ; $30 -
                  .byte $18                       ; $31 -
                  .byte $19                       ; $32 -
                  .byte $1a                       ; $33 -
                  .byte $0e                       ; $34 -
                  .byte $12                       ; $35 -
                  .byte $14                       ; $36 -
                  .byte $13                       ; $37 -
                  .byte $ff                       ; $38 (not_used)
                  .byte $ff                       ; $39 (not_used)
; ------------------------------------------------------------------------------------------------------------- ;
CopySpriteData    pha                             ; save image id

                  lda $21                         ; grafic xr offset from GetColRowGfxOff
                  and #$03                        ; isolate bit 0-1
                  tax                             ;
                  jsr GetImageBytes               ; stored from $5b-$7b
                  
                  pla                             ; restore image id
                  beq _CopyDataI                  ; lode runner
                  
                  lda LR_NoEnemy2Move             ; # of enemy to move
                  
_CopyDataI        tax                             ;
                  lda TabSprtDatPtrLo,x           ; sprite data pos low tab
                  sta __ModMovSprtDatL            ; modify store address low
                  lda TabSprtDatPtrHi,x           ; sprite data pos high tab
                  sta __ModMovSprtDatH            ; modify store address high
                  
                  lda TabSpriteNum,x              ; sprite number tab
                  tax                             ;
                  
                  ldy #$20                        ; 32
_CopyData         lda $005b,y                     ; image has 33 bytes
_MoveSprtDat      sta _MoveSprtDat,y              ; store it to correct sprite data storage  ($0c00-$0dff)
__ModMovSprtDatL  = *-2
__ModMovSprtDatH  = *-1
                  dey                             ;
                  bpl _CopyData                   ;
                  
                  txa                             ;
                  asl a                           ; *2 - gives VIC sprite XPOS offset
                  tax                             ;
                  
CopySpriteDataX   rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TabSprtDatPtrLo   .byte <LR_SpriteData00          ; sprite data pos low tab
                  .byte <LR_SpriteData01
                  .byte <LR_SpriteData02
                  .byte <LR_SpriteData03
                  .byte <LR_SpriteData04
                  .byte <LR_SpriteData05
; ------------------------------------------------------------------------------------------------------------- ;
TabSprtDatPtrHi   .byte >LR_SpriteData00          ; sprite data pos high tab
                  .byte >LR_SpriteData01
                  .byte >LR_SpriteData02
                  .byte >LR_SpriteData03
                  .byte >LR_SpriteData04
                  .byte >LR_SpriteData05
; ------------------------------------------------------------------------------------------------------------- ;
TabSpriteNum      .byte $00                       ; filler  - LR_NoEnemy2Move counter from 1-5
                  .byte $02                       ; enemy 1 - color table pos
                  .byte $03                       ; enemy 2 - color table pos
                  .byte $04                       ; enemy 3 - color table pos
                  .byte $06                       ; enemy 4 - color table pos
                  .byte $07                       ; enemy 5 - color table pos
; ------------------------------------------------------------------------------------------------------------- ;
GetColRowGfxOff   lda TabSubstRow,y               ; tab: Row2Screen
                  pha                             ;
                  lda TabSubstCol,x               ; tab: Col2Screen
                  tax                             ;
                  pla                             ;
                  tay                             ;
                  
GetColRowGfxOffX  rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
TabSubstRow       .byte $00 ; 00                  ; game row positions
                  .byte $0b ; 01
                  .byte $16 ; 02
                  .byte $21 ; 03
                  .byte $2c ; 04
                  .byte $37 ; 05
                  .byte $42 ; 06
                  .byte $4d ; 07
                  .byte $58 ; 08
                  .byte $63 ; 09
                  .byte $6e ; 0a
                  .byte $79 ; 0b
                  .byte $84 ; 0c
                  .byte $8f ; 0d
                  .byte $9a ; 0e
                  .byte $a5 ; 0f
                  .byte $b5 ; 10
; ------------------------------------------------------------------------------------------------------------- ;
TabSubstCol       .byte $0a ; 01: ....#.   #.   - rightmost two bits isolated for GetImageBytes - position type 0-3
                  .byte $0f ; 02: ....##   ##
                  .byte $14 ; 03: ...#.#   ..
                  .byte $19 ; 04: ...##.   .#
                  .byte $1e ; 05: ...###   #.
                  .byte $23 ; 06: ..#...   ##
                  .byte $28 ; 07: ..#.#.   ..
                  .byte $2d ; 08: ..#.##   .#
                  .byte $32 ; 09: ..##..   #.
                  .byte $37 ; 0a: ..##.#   ##
                  .byte $3c ; 0b: ..####   ..
                  .byte $41 ; 0c: .#....   .#
                  .byte $46 ; 0d: .#...#   #.
                  .byte $4b ; 0e: .#..#.   ##
                  .byte $50 ; 0f: .#.#..   ..
                  .byte $55 ; 10: .#.#.#   .#
                  .byte $5a ; 11: .#.##.   #.
                  .byte $5f ; 12: .#.###   ##
                  .byte $64 ; 13: .##..#   ..
                  .byte $69 ; 14: .##.#.   .#
                  .byte $6e ; 15: .##.##   #.
                  .byte $73 ; 16: .###..   ##
                  .byte $78 ; 17: .####.   ..
                  .byte $7d ; 18: .#####   .#
                  .byte $82 ; 19: #.....   #.
                  .byte $87 ; 1a: #....#   ##
                  .byte $8c ; 1b: #...##   ..
                  .byte $91 ; 1c: #..#..   .#
; ------------------------------------------------------------------------------------------------------------- ;
GetXOff           tya                             ;
                  pha                             ; 
                  jsr GetColRowGfxOff             ;
                  
                  pla                             ;
                  tay                             ;
                  txa                             ;
                  clc                             ;
                  adc TabOffsetsX,y               ;
                  tax                             ;
                  
GetXOffX          rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TabOffsetsX       .byte $fe ; -2
                  .byte $ff ; -1
                  .byte $00 ;  0
                  .byte $01 ; +1
                  .byte $02 ; +2
; ------------------------------------------------------------------------------------------------------------- ;
GetYOff           txa                             ;
                  pha                             ;
                  jsr GetColRowGfxOff             ;
                  
                  pla                             ;
                  tax                             ;
                  tya                             ;
                  clc                             ;
                  adc TabOffsetsY,x               ;
                  tay                             ;
                  rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
TabOffsetsY       .byte $fb ; -4
                  .byte $fd ; -2
                  .byte $00 ;  0
                  .byte $02 ; +2
                  .byte $04 ; +4
; ------------------------------------------------------------------------------------------------------------- ;
GetOutGfxPosAdd   lda #$00
                  sta CR_GfxAddHi                 ; init high grafic add
                                                                                    
                  txa                                                               
                  pha                             ; save xr
                  and #$03                        ; isolate bit 0-1
                  tax                                                               
                  pla                             ; restore xr
                                                                                    
                  asl a                           ; *2
                  rol CR_GfxAddHi                 ; save carry in high grafic add
                  and #$f8                        ; kill bits 0-2
                  sta CR_GfxAddLo                 ;   of low grafic add

GetOutGfxPosAddX  rts
; ------------------------------------------------------------------------------------------------------------- ;
GetCtrlDataPtr    lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09                         ; 
                  sta $0b                         ; 
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a                         ; 
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c                         ; 

GetCtrlDataPtrX   rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
GetOutGfxPtrClr   lda #$00                        ;
                  sta CR_GfxAddLo                 ;
                  sta CR_GfxAddHi                 ;

GetOutGfxPtr      lda LR_TabOffHiresLo,y          ; offset grafic output low
                  clc                             ;
                  adc CR_GfxAddLo                 ; low grafic add
                  sta $0f                         ; screen grafic low pointer
                  lda LR_TabOffHiresHi,y          ; offset grafic output high
                  adc CR_GfxAddHi                 ; high grafic add
                  ora $24                         ; graphic output  (20=2000-2fff  40=4000-4fff)
                  sta $10                         ; screen grafic high pointer
                  
GetOutGfxPtrX     rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
GetMoveGfxPtr     lda LR_TabOffHiresLo,y          ; offset grafic output low
                  clc
                  adc CR_GfxAddLo                 ; low grafic add
                  sta $0f                         ; screen grafic low pointer
                  sta $11                         ; hidden grafic low pointer
                  
                  lda LR_TabOffHiresHi,y          ; offset grafic output high
                  adc CR_GfxAddHi                 ; high grafic add
                  ora #>LR_ScrnHiReDisp            ; $20 - point to $2000-$3fff  (display screen)
                  sta $10                         ; screen grafic high pointer
                  eor #>LR_ScrnHiReDisp + >LR_ScrnHiRePrep ; $60 - point to $4000-$5fff  (hidden screen)
                  sta $12                         ; hidden grafic high pointer
                  
GetMoveGfxPtrX    rts
; ------------------------------------------------------------------------------------------------------------- ;
ClearHiresDisp    lda #>LR_ScrnHiReDisp           ; $2000-$3fff - hires display screen
                  
                  ldx #$00                        ; disable all sprites
                  stx SPENA                       ; VIC 2 - $D015 = Sprite Enable
                  
                  ldx #>(LR_ScrnHiReDisp + $2000) ; $40 - upper border
                  bne ClearScrn                   ; always
                  
ClearHiresPrep    lda #>LR_ScrnHiRePrep           ; $40=$4000-$5fff  copy of screen  (hidden setup/copy to $2000)
                  ldx #>(LR_ScrnHiRePrep + $2000) ; $60 - upper border
                  
ClearScrn         sta $10                         ; screen grafic high pointer
                  ldy #$00
                  sty $0f                         ; screen grafic low pointer
                  tya
                  
_Clear            sta ($0f),y                     ; screen grafic pointer byte
                  iny                             ; next byte
                  bne _Clear
                  
                  inc $10                         ; next block
                  cpx $10                         ; upper border
                  bne _Clear                      ; not reached
                  
ClearScrnX        rts
; ------------------------------------------------------------------------------------------------------------- ;
TabExLvlDatRowLo  .byte $00                       ; expanded level data row pointer lo
                  .byte $1c
                  .byte $38
                  .byte $54
                  .byte $70
                  .byte $8c
                  .byte $a8
                  .byte $c4
                  .byte $e0
                  
                  .byte $00
                  .byte $1c
                  .byte $38
                  .byte $54
                  .byte $70
                  .byte $8c
                  .byte $a8
; ------------------------------------------------------------------------------------------------------------- ;
TabExLvlDatRowH8  .byte $08                       ; expanded level data row pointer $0800-$09c3
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
; ------------------------------------------------------------------------------------------------------------- ;
TabExLvlDatRowHa  .byte $0a                       ; expanded level data row pointer $0a00-$0bc3
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
; ------------------------------------------------------------------------------------------------------------- ;
; ShowExitLadders Function: Show secret ladders if all gold is collected
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
ShowExitLadders   lda #$00
                  sta LR_TabXitLdrCol             ; init not empty mark
                  
                  ldx LR_NumXitLadders            ; # hidden ladders
                  stx WrkXitLadders               ; # hidden ladders to display
_Ladders          ldx WrkXitLadders               ; # hidden ladders to display
                  beq _ExitCheckGold              ; finished
                  
                  lda LR_TabXitLdrCol,x           ; adr column hidden ladder tab
                  bmi _DecLadderCount             ; already cleared
                  
                  sta $4f                         ; screen col  (00-1b)
                  lda LR_TabXitLdrRow,x           ; adr row hidden ladders tab
                  sta $50                         ; screen row  (00-0f)
                  tay
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $4f                         ; screen col  (00-1b)
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  bne _SetNotEmpty                ; position not empty
                  
_LadderOutCtrl    lda #LR_TileLadder
                  sta ($0b),y                     ; play level control data ($0a00-$0bc3)
                  
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  bne _LadderOutDisp              ; not empty
                  
_LadderOutData    lda #LR_TileLadder
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
_LadderOutDisp    lda #LR_TileLadder
                  jsr ImageOut2Prep               ; output to preparation screen first ($4000)
                  
                  ldx $4f                         ; screen col  (00-1b)
                  ldy $50                         ; screen row  (00-0f)
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row
                  
                  lda #LR_TileLadder
                  jsr ImageGameSet                ; set images on game screen (sprites/shootss/hidden ladders)
                  
_ClrTabXitLadder  ldx WrkXitLadders               ; # hidden ladders to display
                  lda #$ff
                  sta LR_TabXitLdrCol,x           ; clear adr column hidden ladder tab
                  bmi _DecLadderCount             ; always
                  
_SetNotEmpty      lda #$01
                  sta LR_TabXitLdrCol             ; set not empty mark
                  
_DecLadderCount   dec WrkXitLadders               ; # hidden ladders to display
                  jmp _Ladders
                  
_ExitCheckGold    lda LR_TabXitLdrCol             ; not empty mark
                  bne ShowExitLaddersX            ; not set
                  
                  dec LR_GoldToGet
                  
ShowExitLaddersX  rts
; ------------------------------------------------------------------------------------------------------------- ;
WrkXitLadders     .byte $00
; ------------------------------------------------------------------------------------------------------------- ;
GetAKey           lda LR_KeyNew                   ; 
                  beq GetAKey                     ;
                  
                  ldx #$00                        ;
                  stx LR_KeyNew                   ; 
                  
GetAKeyX          rts                             ;
; ------------------------------------------------------------------------------------------------------------- ;
FlipGmeOverSign   lda #$01                        ; fastest
                  sta WrkSignSpinSpeed            ; 
                  lda #$20                        ;
                  sta $24                         ;
_FlipSign         jsr FlipSignPhase05             ; 
                  jsr FlipSignPhase04             ;
                  jsr FlipSignPhase03             ;
                  jsr FlipSignPhase02             ;
                  jsr FlipSignPhase01             ;
                  jsr FlipSignPhase00             ;
                  jsr FlipSignPhase01             ;
                  jsr FlipSignPhase02             ;
                  jsr FlipSignPhase03             ;
                  jsr FlipSignPhase04             ;
                  jsr FlipSignPhase05             ;
                  jsr FlipSignPhase0a             ;
                  jsr FlipSignPhase09             ;
                  jsr FlipSignPhase08             ;
                  jsr FlipSignPhase07             ;
                  jsr FlipSignPhase06             ;
                  jsr FlipSignPhase07             ;
                  jsr FlipSignPhase08             ;
                  jsr FlipSignPhase09             ;
                  jsr FlipSignPhase0a             ;

                  lda WrkSignSpinSpeed            ; 
                  cmp #$64                        ; slowest
                  bcc _FlipSign                   ; 

                  jsr FlipSignPhase05             ;
                  jsr FlipSignPhase04             ;
                  jsr FlipSignPhase03             ;
                  jsr FlipSignPhase02             ;
                  jsr FlipSignPhase01             ;
                  jsr FlipSignPhase00             ;
                  clc                             ;
                  rts                             ; 
; ------------------------------------------------------------------------------------------------------------- ;
FlipSignPhase00   jsr FlipSignOut
                  .byte NoSignLine00
                  .byte NoSignLine01
                  .byte NoSignLine02
                  .byte NoSignLine03
                  .byte NoSignLine04
                  .byte NoSignLine05
                  .byte NoSignLine06
                  .byte NoSignLine07
                  .byte NoSignLine08
                  .byte NoSignLine09
                  .byte NoSignLine0a
                  .byte NoSignLine02
                  .byte NoSignLine01
                  .byte NoSignLine00
FlipSignPhase01   jsr FlipSignOut
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine01
                  .byte NoSignLine02
                  .byte NoSignLine03
                  .byte NoSignLine04
                  .byte NoSignLine05
                  .byte NoSignLine07
                  .byte NoSignLine09
                  .byte NoSignLine0a
                  .byte NoSignLine02
                  .byte NoSignLine01
                  .byte NoSignLine00
                  .byte NoSignLine00
FlipSignPhase02   jsr FlipSignOut
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine01
                  .byte NoSignLine02
                  .byte NoSignLine03
                  .byte NoSignLine04
                  .byte NoSignLine09
                  .byte NoSignLine0a
                  .byte NoSignLine02
                  .byte NoSignLine01
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
FlipSignPhase03   jsr FlipSignOut
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine01
                  .byte NoSignLine02
                  .byte NoSignLine03
                  .byte NoSignLine0a
                  .byte NoSignLine02
                  .byte NoSignLine01
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
FlipSignPhase04   jsr FlipSignOut
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine01
                  .byte NoSignLine03
                  .byte NoSignLine0a
                  .byte NoSignLine01
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
FlipSignPhase05   jsr FlipSignOut
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine01
                  .byte NoSignLine01
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
FlipSignPhase06   jsr FlipSignOut
                  .byte NoSignLine00
                  .byte NoSignLine01
                  .byte NoSignLine02
                  .byte NoSignLine0a
                  .byte NoSignLine09
                  .byte NoSignLine08
                  .byte NoSignLine07
                  .byte NoSignLine06
                  .byte NoSignLine05
                  .byte NoSignLine04
                  .byte NoSignLine03
                  .byte NoSignLine02
                  .byte NoSignLine01
                  .byte NoSignLine00
FlipSignPhase07   jsr FlipSignOut
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine01
                  .byte NoSignLine02
                  .byte NoSignLine0a
                  .byte NoSignLine09
                  .byte NoSignLine07
                  .byte NoSignLine05
                  .byte NoSignLine04
                  .byte NoSignLine03
                  .byte NoSignLine02
                  .byte NoSignLine01
                  .byte NoSignLine00
                  .byte NoSignLine00
FlipSignPhase08   jsr FlipSignOut
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine01
                  .byte NoSignLine02
                  .byte NoSignLine0a
                  .byte NoSignLine09
                  .byte NoSignLine04
                  .byte NoSignLine03
                  .byte NoSignLine02
                  .byte NoSignLine01
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
FlipSignPhase09   jsr FlipSignOut
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine01
                  .byte NoSignLine02
                  .byte NoSignLine0a
                  .byte NoSignLine03
                  .byte NoSignLine02
                  .byte NoSignLine01
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
FlipSignPhase0a   jsr FlipSignOut
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine01
                  .byte NoSignLine0a
                  .byte NoSignLine03
                  .byte NoSignLine01
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
; ------------------------------------------------------------------------------------------------------------- ;
;   Line00: ................................................................................................
;   Line01: ....#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.......
;   Line02: ..#.......................................................................................#.....
;   Line03: ..#...#.#.#.#...#.#.#...#.#.#.#.#...#.#.#.#.......#.#.#.#...#.#...#...#.#.#.#...#.#.#.#...#.....
;   Line04: ..#...#.....#...#...#...#.#.#...#...#.#...........#...#.#...#.#...#...#.#.#.#...#.....#...#.....
;   Line05: ..#...#.........#...#...#...#...#...#.#...........#...#.#...#.#...#...#.#.......#.....#...#.....
;   Line06: ..#...#.........#...#...#...#...#...#.#.#.#.......#...#.#...#.#...#...#.#.#.....#.#.#.#...#.....
;   Line07: ..#...#...#.#...#.#.#...#...#...#...#.#.#.#.......#.....#...#.#...#...#.........#.#.#.....#.....
;   Line08: ..#...#.....#...#...#...#...#...#...#.............#.....#...#.#.#.#...#.........#.#.#.....#.....
;   Line09: ..#...#.....#...#...#...#...#...#...#.............#.....#.....#.#.....#.........#.#...#...#.....
;   Line0a: ..#...#.#.#.#...#...#...#...#...#...#.#.#.#.......#.#.#.#.....#.......#.#.#.#...#.....#...#.....
; ------------------------------------------------------------------------------------------------------------- ;
DataSignLine00    .byte $00 ; ................................................................................................
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  
DataSignLine01    .byte $0a ; ....#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.......
                  .byte $aa ;
                  .byte $aa ;
                  .byte $aa ;
                  .byte $aa ;
                  .byte $aa ;
                  .byte $aa ;
                  .byte $aa ;
                  .byte $aa ;
                  .byte $aa ;
                  .byte $aa ;
                  .byte $80 ;
                  
DataSignLine02    .byte $20 ; ..#.......................................................................................#.....
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $20 ;
                  
DataSignLine03    .byte $22 ; ..#...#.#.#.#...#.#.#...#.#.#.#.#...#.#.#.#.......#.#.#.#...#.#...#...#.#.#.#...#.#.#.#...#.....
                  .byte $a8 ;
                  .byte $a8 ;
                  .byte $aa ;
                  .byte $8a ;
                  .byte $a0 ;
                  .byte $2a ;
                  .byte $8a ;
                  .byte $22 ;
                  .byte $a8 ;
                  .byte $aa ;
                  .byte $20 ;
                  
DataSignLine04    .byte $22 ; ..#...#.....#...#...#...#.#.#...#...#.#...........#...#.#...#.#...#...#.#.#.#...#.....#...#.....
                  .byte $08 ;
                  .byte $88 ;
                  .byte $a8 ;
                  .byte $8a ;
                  .byte $00 ;
                  .byte $22 ;
                  .byte $8a ;
                  .byte $22 ;
                  .byte $a8 ;
                  .byte $82 ;
                  .byte $20 ;
                  
DataSignLine05    .byte $22 ; ..#...#.........#...#...#...#...#...#.#...........#...#.#...#.#...#...#.#.......#.....#...#.....
                  .byte $00 ;
                  .byte $88 ;
                  .byte $88 ;
                  .byte $8a ;
                  .byte $00 ;
                  .byte $22 ;
                  .byte $8a ;
                  .byte $22 ;
                  .byte $80 ;
                  .byte $82 ;
                  .byte $20 ;
                  
DataSignLine06    .byte $22 ; ..#...#.........#...#...#...#...#...#.#.#.#.......#...#.#...#.#...#...#.#.#.....#.#.#.#...#.....
                  .byte $00 ;
                  .byte $88 ;
                  .byte $88 ;
                  .byte $8a ;
                  .byte $a0 ;
                  .byte $22 ;
                  .byte $8a ;
                  .byte $22 ;
                  .byte $a0 ;
                  .byte $aa ;
                  .byte $20 ;
                  

DataSignLine07    .byte $22 ; ..#...#...#.#...#.#.#...#...#...#...#.#.#.#.......#.....#...#.#...#...#.........#.#.#.....#.....
                  .byte $28 ;
                  .byte $a8 ;
                  .byte $88 ;
                  .byte $8a ;
                  .byte $a0 ;
                  .byte $20 ;
                  .byte $8a ;
                  .byte $22 ;
                  .byte $00 ;
                  .byte $a8 ;
                  .byte $20 ;
                  
DataSignLine08    .byte $22 ; ..#...#.....#...#...#...#...#...#...#.............#.....#...#.#.#.#...#.........#.#.#.....#.....
                  .byte $08 ;
                  .byte $88 ;
                  .byte $88 ;
                  .byte $88 ;
                  .byte $00 ;
                  .byte $20 ;
                  .byte $8a ;
                  .byte $a2 ;
                  .byte $00 ;
                  .byte $a8 ;
                  .byte $20 ;
                  
DataSignLine09    .byte $22 ; ..#...#.....#...#...#...#...#...#...#.............#.....#.....#.#.....#.........#.#...#...#.....
                  .byte $08 ;
                  .byte $88 ;
                  .byte $88 ;
                  .byte $88 ;
                  .byte $00 ;
                  .byte $20 ;
                  .byte $82 ;
                  .byte $82 ;
                  .byte $00 ;
                  .byte $a2 ;
                  .byte $20 ;
                  
DataSignLine0a    .byte $22 ; ..#...#.#.#.#...#...#...#...#...#...#.#.#.#.......#.#.#.#.....#.......#.#.#.#...#.....#...#.....
                  .byte $a8 ;
                  .byte $88 ;
                  .byte $88 ;
                  .byte $8a ;
                  .byte $a0 ;
                  .byte $2a ;
                  .byte $82 ;
                  .byte $02 ;
                  .byte $a8 ;
                  .byte $a2 ;
                  .byte $20 ;
; ------------------------------------------------------------------------------------------------------------- ;
TabSignDataAdr    =*                              ; flip data address tab
TabSignDataLen    = DataSignLine01-DataSignLine00 ; line data length
                  
ObjLine00         .word DataSignLine00 - TabSignDataLen - $02
ObjLine01         .word DataSignLine01 - TabSignDataLen - $02
ObjLine02         .word DataSignLine02 - TabSignDataLen - $02
ObjLine03         .word DataSignLine03 - TabSignDataLen - $02
ObjLine04         .word DataSignLine04 - TabSignDataLen - $02
ObjLine05         .word DataSignLine05 - TabSignDataLen - $02
ObjLine06         .word DataSignLine06 - TabSignDataLen - $02
ObjLine07         .word DataSignLine07 - TabSignDataLen - $02
ObjLine08         .word DataSignLine08 - TabSignDataLen - $02
ObjLine09         .word DataSignLine09 - TabSignDataLen - $02
ObjLine0a         .word DataSignLine0a - TabSignDataLen - $02
                  
NoSignLine00      := (DataSignLine00 - DataSignLine00) / TabSignDataLen
NoSignLine01      := (DataSignLine01 - DataSignLine00) / TabSignDataLen
NoSignLine02      := (DataSignLine02 - DataSignLine00) / TabSignDataLen
NoSignLine03      := (DataSignLine03 - DataSignLine00) / TabSignDataLen
NoSignLine04      := (DataSignLine04 - DataSignLine00) / TabSignDataLen
NoSignLine05      := (DataSignLine05 - DataSignLine00) / TabSignDataLen
NoSignLine06      := (DataSignLine06 - DataSignLine00) / TabSignDataLen
NoSignLine07      := (DataSignLine07 - DataSignLine00) / TabSignDataLen
NoSignLine08      := (DataSignLine08 - DataSignLine00) / TabSignDataLen
NoSignLine09      := (DataSignLine09 - DataSignLine00) / TabSignDataLen
NoSignLine0a      := (DataSignLine0a - DataSignLine00) / TabSignDataLen
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
FlipSignOut       pla                             ; start adr of data array is the return adr
                  sta $0d
                  pla
                  sta $0e
                  
                  ldy #$50
                  sty $50                         ; screen row  (00-0f)
                  bne _SetSignPtr                 ; always
                  
_SetGfxPtr        jsr GetOutGfxPtrClr             ; ($0f/$10) pointer
                  
                  ldy #$00
                  lda ($0d),y                     ; get sign control byte
                  asl a                           ; *2
                  tax
                  lda TabSignDataAdr,x            ; flip data address tab
                  sta __ModGetDataLo              ; modify load cmd low
                  lda TabSignDataAdr+1,x          ; flip data address tab + 1
                  sta __ModGetDataHi              ; modify load cmd high
                  
                  ldy #$70
                  sty $20                         ; grafic row substitution
                  
                  ldy #TabSignDataLen+2           ; $0e - sign data lenght
                  sty $1e
                  
_FlipSign         ldy $1e
                  inc $1e
_GetSignData      lda _GetSignData,y              ; get sign data byte
__ModGetDataLo    = *-2
__ModGetDataHi    = *-1
                  lsr a                           ; *2
                  ldy $20                         ; grafic row substitution
                  sta ($0f),y                     ; screen grafic pointer byte
                  tya
                  clc
                  adc #$08                        ; point to next position
                  sta $20                         ; grafic row substitution
                  
                  ldy $1e
                  cpy #$1a                        ; max
                  bcc _FlipSign
                  
_SetSignPtr       jsr FlipSignIncPtr
                  
                  inc $50                         ; screen row  (00-0f)
                  ldy $50                         ; screen row  (00-0f)
                  cpy #$5f                        ; max
                  bcc _SetGfxPtr
                  
                  ldx WrkSignSpinSpeed            ; flip sign spin speed
                  ldy #$ff
_Wait             dey
                  bne _Wait
                  dex
                  bne _Wait
                  
                  inc WrkSignSpinSpeed            ; flip sign spin speed so wait longer the next time
                  lda CIAPRA                      ; CIA 1 - $DC00 = Data Port A
                  and #$10                        ; isolate fire
                  beq FlipSignFinish              ; pressed
                  
                  lda LR_KeyNew                   ; actual key
                  bne FlipSignFinish              ; pressed some
                  
FlipSignOutX      rts
; ------------------------------------------------------------------------------------------------------------- ;
FlipSignFinish    pla                             ; pull return address from stack
                  pla
                  
                  sec
FlipSignFinishX   rts
; ------------------------------------------------------------------------------------------------------------- ;
WrkSignSpinSpeed  .byte $00
; ------------------------------------------------------------------------------------------------------------- ;
FlipSignIncPtr    inc $0d
                  bne FlipSignIncPtrX
                  inc $0e
                  
FlipSignIncPtrX   rts
; ------------------------------------------------------------------------------------------------------------- ;
TabTileDataA0     .byte $00
                  .byte $01
                  .byte $02
                  .byte $03
                  .byte $04
                  .byte $05
                  .byte $06
                  .byte $07
                  .byte $08
                  .byte $09
                  .byte $0a
                  .byte $0b
                  .byte $0c
                  .byte $0d
                  .byte $0e
                  .byte $0f
                  .byte $10
                  .byte $11
                  .byte $12
                  .byte $13
                  .byte $14
                  .byte $15
                  .byte $16
                  .byte $17
                  .byte $18
                  .byte $19
                  .byte $1a
                  .byte $1b
                  .byte $1c
                  .byte $1d
                  .byte $1e
                  .byte $1f
                  .byte $20
                  .byte $21
                  .byte $22
                  .byte $23
                  .byte $24
                  .byte $25
                  .byte $26
                  .byte $27
                  .byte $28
                  .byte $29
                  .byte $2a
                  .byte $2b
                  .byte $2c
                  .byte $2d
                  .byte $2e
                  .byte $2f
                  .byte $30
                  .byte $31
                  .byte $32
                  .byte $33
                  .byte $34
                  .byte $35
                  .byte $36
                  .byte $37
                  .byte $38
                  .byte $39
                  .byte $3a
                  .byte $3b
                  .byte $3c
                  .byte $3d
                  .byte $3e
                  .byte $3f
                  .byte $40
                  .byte $41
                  .byte $42
                  .byte $43
                  .byte $44
                  .byte $45
                  .byte $46
                  .byte $47
                  .byte $48
                  .byte $49
                  .byte $4a
                  .byte $4b
                  .byte $4c
                  .byte $4d
                  .byte $4e
                  .byte $4f
                  .byte $50
                  .byte $51
                  .byte $52
                  .byte $53
                  .byte $54
                  .byte $55
                  .byte $56
                  .byte $57
                  .byte $58
                  .byte $59
                  .byte $5a
                  .byte $5b
                  .byte $5c
                  .byte $5d
                  .byte $5e
                  .byte $5f
                  .byte $60
                  .byte $61
                  .byte $62
                  .byte $63
                  .byte $64
                  .byte $65
                  .byte $66
                  .byte $67
                  .byte $68
                  .byte $69
                  .byte $6a
                  .byte $6b
                  .byte $6c
                  .byte $6d
                  .byte $6e
                  .byte $6f
                  .byte $70
                  .byte $71
                  .byte $72
                  .byte $73
                  .byte $74
                  .byte $75
                  .byte $76
                  .byte $77
                  .byte $78
                  .byte $79
                  .byte $7a
                  .byte $7b
                  .byte $7c
                  .byte $7d
                  .byte $7e
                  .byte $7f
                  .byte $80
                  .byte $81
                  .byte $82
                  .byte $83
                  .byte $84
                  .byte $85
                  .byte $86
                  .byte $87
                  .byte $88
                  .byte $89
                  .byte $8a
                  .byte $8b
                  .byte $8c
                  .byte $8d
                  .byte $8e
                  .byte $8f
                  .byte $90
                  .byte $91
                  .byte $92
                  .byte $93
                  .byte $94
                  .byte $95
                  .byte $96
                  .byte $97
                  .byte $98
                  .byte $99
                  .byte $9a
                  .byte $9b
                  .byte $9c
                  .byte $9d
                  .byte $9e
                  .byte $9f
                  .byte $a0
                  .byte $a1
                  .byte $a2
                  .byte $a3
                  .byte $a4
                  .byte $a5
                  .byte $a6
                  .byte $a7
                  .byte $a8
                  .byte $a9
                  .byte $aa
                  .byte $ab
                  .byte $ac
                  .byte $ad
                  .byte $ae
                  .byte $af
                  .byte $b0
                  .byte $b1
                  .byte $b2
                  .byte $b3
                  .byte $b4
                  .byte $b5
                  .byte $b6
                  .byte $b7
                  .byte $b8
                  .byte $b9
                  .byte $ba
                  .byte $bb
                  .byte $bc
                  .byte $bd
                  .byte $be
                  .byte $bf
                  .byte $c0
                  .byte $c1
                  .byte $c2
                  .byte $c3
                  .byte $c4
                  .byte $c5
                  .byte $c6
                  .byte $c7
                  .byte $c8
                  .byte $c9
                  .byte $ca
                  .byte $cb
                  .byte $cc
                  .byte $cd
                  .byte $ce
                  .byte $cf
                  .byte $d0
                  .byte $d1
                  .byte $d2
                  .byte $d3
                  .byte $d4
                  .byte $d5
                  .byte $d6
                  .byte $d7
                  .byte $d8
                  .byte $d9
                  .byte $da
                  .byte $db
                  .byte $dc
                  .byte $dd
                  .byte $de
                  .byte $df
                  .byte $e0
                  .byte $e1
                  .byte $e2
                  .byte $e3
                  .byte $e4
                  .byte $e5
                  .byte $e6
                  .byte $e7
                  .byte $e8
                  .byte $e9
                  .byte $ea
                  .byte $eb
                  .byte $ec
                  .byte $ed
                  .byte $ee
                  .byte $ef
                  .byte $f0
                  .byte $f1
                  .byte $f2
                  .byte $f3
                  .byte $f4
                  .byte $f5
                  .byte $f6
                  .byte $f7
                  .byte $f8
                  .byte $f9
                  .byte $fa
                  .byte $fb
                  .byte $fc
                  .byte $fd
                  .byte $fe
                  .byte $ff
                  
TabTileDataA1     .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  
TabTileDataA2     .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  
                  .byte $10
                  .byte $10
                  .byte $10
                  .byte $10
                  
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  
                  .byte $12
                  .byte $12
                  .byte $12
                  .byte $12
                  
                  .byte $13
                  .byte $13
                  .byte $13
                  .byte $13
                  
                  .byte $14
                  .byte $14
                  .byte $14
                  .byte $14
                  
                  .byte $15
                  .byte $15
                  .byte $15
                  .byte $15
                  
                  .byte $16
                  .byte $16
                  .byte $16
                  .byte $16
                  
                  .byte $17
                  .byte $17
                  .byte $17
                  .byte $17
                  
                  .byte $18
                  .byte $18
                  .byte $18
                  .byte $18
                  
                  .byte $19
                  .byte $19
                  .byte $19
                  .byte $19
                  
                  .byte $1a
                  .byte $1a
                  .byte $1a
                  .byte $1a
                  
                  .byte $1b
                  .byte $1b
                  .byte $1b
                  .byte $1b
                  
                  .byte $1c
                  .byte $1c
                  .byte $1c
                  .byte $1c
                  
                  .byte $1d
                  .byte $1d
                  .byte $1d
                  .byte $1d
                  
                  .byte $1e
                  .byte $1e
                  .byte $1e
                  .byte $1e
                  
                  .byte $1f
                  .byte $1f
                  .byte $1f
                  .byte $1f
                  
                  .byte $20
                  .byte $20
                  .byte $20
                  .byte $20
                  
                  .byte $21
                  .byte $21
                  .byte $21
                  .byte $21
                  
                  .byte $22
                  .byte $22
                  .byte $22
                  .byte $22
                  
                  .byte $23
                  .byte $23
                  .byte $23
                  .byte $23
                  
                  .byte $24
                  .byte $24
                  .byte $24
                  .byte $24
                  
                  .byte $25
                  .byte $25
                  .byte $25
                  .byte $25
                  
                  .byte $26
                  .byte $26
                  .byte $26
                  .byte $26
                  
                  .byte $27
                  .byte $27
                  .byte $27
                  .byte $27
                  
                  .byte $28
                  .byte $28
                  .byte $28
                  .byte $28
                  
                  .byte $29
                  .byte $29
                  .byte $29
                  .byte $29
                  
                  .byte $2a
                  .byte $2a
                  .byte $2a
                  .byte $2a
                  
                  .byte $2b
                  .byte $2b
                  .byte $2b
                  .byte $2b
                  
                  .byte $2c
                  .byte $2c
                  .byte $2c
                  .byte $2c
                  
                  .byte $2d
                  .byte $2d
                  .byte $2d
                  .byte $2d
                  
                  .byte $2e
                  .byte $2e
                  .byte $2e
                  .byte $2e
                  
                  .byte $2f
                  .byte $2f
                  .byte $2f
                  .byte $2f
                  
                  .byte $30
                  .byte $30
                  .byte $30
                  .byte $30
                  
                  .byte $31
                  .byte $31
                  .byte $31
                  .byte $31
                  
                  .byte $32
                  .byte $32
                  .byte $32
                  .byte $32
                  
                  .byte $33
                  .byte $33
                  .byte $33
                  .byte $33
                  
                  .byte $34
                  .byte $34
                  .byte $34
                  .byte $34
                  
                  .byte $35
                  .byte $35
                  .byte $35
                  .byte $35
                  
                  .byte $36
                  .byte $36
                  .byte $36
                  .byte $36
                  
                  .byte $37
                  .byte $37
                  .byte $37
                  .byte $37
                  
                  .byte $38
                  .byte $38
                  .byte $38
                  .byte $38
                  
                  .byte $39
                  .byte $39
                  .byte $39
                  .byte $39
                  
                  .byte $3a
                  .byte $3a
                  .byte $3a
                  .byte $3a
                  
                  .byte $3b
                  .byte $3b
                  .byte $3b
                  .byte $3b
                  
                  .byte $3c
                  .byte $3c
                  .byte $3c
                  .byte $3c
                  
                  .byte $3d
                  .byte $3d
                  .byte $3d
                  .byte $3d
                  
                  .byte $3e
                  .byte $3e
                  .byte $3e
                  .byte $3e
                  
                  .byte $3f
                  .byte $3f
                  .byte $3f
                  .byte $3f
                  
TabTileDataA3     .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0
                  
TabTileDataA4     .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  
TabTileDataA5     .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0
                  
                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0
                  
                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0
                  
                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0
                  
                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0
                  
                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0
                  
                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0
                  
                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0
                  
                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0
                  
                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0
                  
                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0
                  
                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0
                  
                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0
                  
                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0
                  
                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0
                  
                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0
                  
TabTileDataA6     .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  
TabTileDataA7     .byte $00
                  .byte $04
                  .byte $08
                  .byte $0c
                  .byte $10
                  .byte $14
                  .byte $18
                  .byte $1c
                  .byte $20
                  .byte $24
                  .byte $28
                  .byte $2c
                  .byte $30
                  .byte $34
                  .byte $38
                  .byte $3c
                  .byte $40
                  .byte $44
                  .byte $48
                  .byte $4c
                  .byte $50
                  .byte $54
                  .byte $58
                  .byte $5c
                  .byte $60
                  .byte $64
                  .byte $68
                  .byte $6c
                  .byte $70
                  .byte $74
                  .byte $78
                  .byte $7c
                  .byte $80
                  .byte $84
                  .byte $88
                  .byte $8c
                  .byte $90
                  .byte $94
                  .byte $98
                  .byte $9c
                  .byte $a0
                  .byte $a4
                  .byte $a8
                  .byte $ac
                  .byte $b0
                  .byte $b4
                  .byte $b8
                  .byte $bc
                  .byte $c0
                  .byte $c4
                  .byte $c8
                  .byte $cc
                  .byte $d0
                  .byte $d4
                  .byte $d8
                  .byte $dc
                  .byte $e0
                  .byte $e4
                  .byte $e8
                  .byte $ec
                  .byte $f0
                  .byte $f4
                  .byte $f8
                  .byte $fc
                  
                  .byte $00
                  .byte $04
                  .byte $08
                  .byte $0c
                  .byte $10
                  .byte $14
                  .byte $18
                  .byte $1c
                  .byte $20
                  .byte $24
                  .byte $28
                  .byte $2c
                  .byte $30
                  .byte $34
                  .byte $38
                  .byte $3c
                  .byte $40
                  .byte $44
                  .byte $48
                  .byte $4c
                  .byte $50
                  .byte $54
                  .byte $58
                  .byte $5c
                  .byte $60
                  .byte $64
                  .byte $68
                  .byte $6c
                  .byte $70
                  .byte $74
                  .byte $78
                  .byte $7c
                  .byte $80
                  .byte $84
                  .byte $88
                  .byte $8c
                  .byte $90
                  .byte $94
                  .byte $98
                  .byte $9c
                  .byte $a0
                  .byte $a4
                  .byte $a8
                  .byte $ac
                  .byte $b0
                  .byte $b4
                  .byte $b8
                  .byte $bc
                  .byte $c0
                  .byte $c4
                  .byte $c8
                  .byte $cc
                  .byte $d0
                  .byte $d4
                  .byte $d8
                  .byte $dc
                  .byte $e0
                  .byte $e4
                  .byte $e8
                  .byte $ec
                  .byte $f0
                  .byte $f4
                  .byte $f8
                  .byte $fc
                  
                  .byte $00
                  .byte $04
                  .byte $08
                  .byte $0c
                  .byte $10
                  .byte $14
                  .byte $18
                  .byte $1c
                  .byte $20
                  .byte $24
                  .byte $28
                  .byte $2c
                  .byte $30
                  .byte $34
                  .byte $38
                  .byte $3c
                  .byte $40
                  .byte $44
                  .byte $48
                  .byte $4c
                  .byte $50
                  .byte $54
                  .byte $58
                  .byte $5c
                  .byte $60
                  .byte $64
                  .byte $68
                  .byte $6c
                  .byte $70
                  .byte $74
                  .byte $78
                  .byte $7c
                  .byte $80
                  .byte $84
                  .byte $88
                  .byte $8c
                  .byte $90
                  .byte $94
                  .byte $98
                  .byte $9c
                  .byte $a0
                  .byte $a4
                  .byte $a8
                  .byte $ac
                  .byte $b0
                  .byte $b4
                  .byte $b8
                  .byte $bc
                  .byte $c0
                  .byte $c4
                  .byte $c8
                  .byte $cc
                  .byte $d0
                  .byte $d4
                  .byte $d8
                  .byte $dc
                  .byte $e0
                  .byte $e4
                  .byte $e8
                  .byte $ec
                  .byte $f0
                  .byte $f4
                  .byte $f8
                  .byte $fc
                  
                  .byte $00
                  .byte $04
                  .byte $08
                  .byte $0c
                  .byte $10
                  .byte $14
                  .byte $18
                  .byte $1c
                  .byte $20
                  .byte $24
                  .byte $28
                  .byte $2c
                  .byte $30
                  .byte $34
                  .byte $38
                  .byte $3c
                  .byte $40
                  .byte $44
                  .byte $48
                  .byte $4c
                  .byte $50
                  .byte $54
                  .byte $58
                  .byte $5c
                  .byte $60
                  .byte $64
                  .byte $68
                  .byte $6c
                  .byte $70
                  .byte $74
                  .byte $78
                  .byte $7c
                  .byte $80
                  .byte $84
                  .byte $88
                  .byte $8c
                  .byte $90
                  .byte $94
                  .byte $98
                  .byte $9c
                  .byte $a0
                  .byte $a4
                  .byte $a8
                  .byte $ac
                  .byte $b0
                  .byte $b4
                  .byte $b8
                  .byte $bc
                  .byte $c0
                  .byte $c4
                  .byte $c8
                  .byte $cc
                  .byte $d0
                  .byte $d4
                  .byte $d8
                  .byte $dc
                  .byte $e0
                  .byte $e4
                  .byte $e8
                  .byte $ec
                  .byte $f0
                  .byte $f4
                  .byte $f8
                  .byte $fc
                  
TabTileDataPtr    .byte $00
                  .byte $a8
                  .byte $aa
                  .byte $c3
                  .byte $00
                  .byte $aa
                  .byte $c0
                  .byte $00
                  .byte $08
                  .byte $02
                  .byte $ff
                  .byte $10
                  .byte $10
                  .byte $10
                  .byte $0c
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $0c
                  .byte $64
                  .byte $c9
                  .byte $61
                  .byte $06
                  .byte $18
                  .byte $61
                  .byte $18
                  .byte $06
                  .byte $00
                  .byte $00
                  .byte $08
                  .byte $00
                  .byte $a4
                  .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $08
                  .byte $00
                  .byte $00
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $08
                  .byte $08
                  .byte $41
                  .byte $04
                  .byte $10
                  .byte $41
                  .byte $10
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $44
                  .byte $44
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $c0
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $c0
                  .byte $80
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $40
                  .byte $40
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $a8
                  .byte $aa
                  .byte $c3
                  .byte $ff
                  .byte $aa
                  .byte $c0
                  .byte $00
                  .byte $14
                  .byte $07
                  .byte $ff
                  .byte $38
                  .byte $38
                  .byte $38
                  .byte $0c
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $8c
                  .byte $6e
                  .byte $dd
                  .byte $61
                  .byte $06
                  .byte $18
                  .byte $61
                  .byte $18
                  .byte $06
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $a8
                  .byte $14
                  .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $1c
                  .byte $00
                  .byte $00
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $14
                  .byte $14
                  .byte $41
                  .byte $04
                  .byte $10
                  .byte $41
                  .byte $10
                  .byte $04
                  .byte $04
                  .byte $84
                  .byte $44
                  .byte $44
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $80
                  .byte $00
                  .byte $c0
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $c0
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $40
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $c0
                  .byte $80
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $40
                  .byte $00
                  .byte $40
                  .byte $40
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $a8
                  .byte $aa
                  .byte $ff
                  .byte $00
                  .byte $00
                  .byte $ff
                  .byte $00
                  .byte $14
                  .byte $07
                  .byte $ff
                  .byte $38
                  .byte $38
                  .byte $38
                  .byte $0f
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $fc
                  .byte $6e
                  .byte $dd
                  .byte $6d
                  .byte $1e
                  .byte $1e
                  .byte $6d
                  .byte $1e
                  .byte $1e
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $a8
                  .byte $80
                  .byte $14
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $1c
                  .byte $00
                  .byte $00
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $14
                  .byte $14
                  .byte $45
                  .byte $14
                  .byte $14
                  .byte $51
                  .byte $14
                  .byte $14
                  .byte $05
                  .byte $d4
                  .byte $44
                  .byte $44
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $c0
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $c0
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $c0
                  .byte $80
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $40
                  .byte $00
                  .byte $40
                  .byte $40
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $a8
                  .byte $aa
                  .byte $c3
                  .byte $00
                  .byte $3f
                  .byte $c3
                  .byte $00
                  .byte $04
                  .byte $0e
                  .byte $ff
                  .byte $1c
                  .byte $18
                  .byte $18
                  .byte $4e
                  .byte $03
                  .byte $06
                  .byte $06
                  .byte $1c
                  .byte $3f
                  .byte $7f
                  .byte $6f
                  .byte $1c
                  .byte $0e
                  .byte $3d
                  .byte $0e
                  .byte $dc
                  .byte $00
                  .byte $08
                  .byte $00
                  .byte $08
                  .byte $a8
                  .byte $a8
                  .byte $94
                  .byte $04
                  .byte $00
                  .byte $00
                  .byte $18
                  .byte $00
                  .byte $08
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $45
                  .byte $14
                  .byte $04
                  .byte $51
                  .byte $14
                  .byte $10
                  .byte $44
                  .byte $14
                  .byte $15
                  .byte $15
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $55
                  .byte $14
                  .byte $55
                  .byte $55
                  .byte $51
                  .byte $55
                  .byte $55
                  .byte $55
                  .byte $15
                  .byte $55
                  .byte $2a
                  .byte $a8
                  .byte $aa
                  .byte $a8
                  .byte $aa
                  .byte $aa
                  .byte $aa
                  .byte $82
                  .byte $20
                  .byte $08
                  .byte $82
                  .byte $80
                  .byte $82
                  .byte $82
                  .byte $aa
                  .byte $aa
                  .byte $aa
                  .byte $aa
                  .byte $aa
                  .byte $aa
                  .byte $82
                  .byte $a2
                  .byte $82
                  .byte $82
                  .byte $8a
                  .byte $aa
                  .byte $80
                  .byte $00
                  .byte $28
                  .byte $28
                  .byte $02
                  .byte $00
                  .byte $02
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $c0
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $c0
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $80
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $40
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $aa
                  .byte $c3
                  .byte $00
                  .byte $0c
                  .byte $03
                  .byte $00
                  .byte $15
                  .byte $37
                  .byte $ff
                  .byte $3b
                  .byte $1c
                  .byte $5e
                  .byte $7e
                  .byte $0f
                  .byte $0e
                  .byte $1e
                  .byte $1f
                  .byte $06
                  .byte $18
                  .byte $3c
                  .byte $78
                  .byte $07
                  .byte $0f
                  .byte $07
                  .byte $78
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $14
                  .byte $00
                  .byte $00
                  .byte $7e
                  .byte $00
                  .byte $00
                  .byte $15
                  .byte $14
                  .byte $15
                  .byte $05
                  .byte $15
                  .byte $14
                  .byte $50
                  .byte $05
                  .byte $14
                  .byte $05
                  .byte $50
                  .byte $54
                  .byte $15
                  .byte $04
                  .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $41
                  .byte $14
                  .byte $41
                  .byte $41
                  .byte $51
                  .byte $40
                  .byte $41
                  .byte $05
                  .byte $11
                  .byte $41
                  .byte $22
                  .byte $88
                  .byte $82
                  .byte $82
                  .byte $a0
                  .byte $a0
                  .byte $82
                  .byte $82
                  .byte $20
                  .byte $08
                  .byte $8a
                  .byte $80
                  .byte $a2
                  .byte $82
                  .byte $8a
                  .byte $82
                  .byte $8a
                  .byte $82
                  .byte $82
                  .byte $20
                  .byte $82
                  .byte $a2
                  .byte $82
                  .byte $82
                  .byte $8a
                  .byte $82
                  .byte $a0
                  .byte $00
                  .byte $28
                  .byte $28
                  .byte $02
                  .byte $00
                  .byte $0a
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $c0
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $c0
                  .byte $00
                  .byte $80
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $8a
                  .byte $aa
                  .byte $c3
                  .byte $00
                  .byte $0c
                  .byte $03
                  .byte $ff
                  .byte $44
                  .byte $6c
                  .byte $ff
                  .byte $cd
                  .byte $3e
                  .byte $7b
                  .byte $0e
                  .byte $5b
                  .byte $1f
                  .byte $37
                  .byte $1c
                  .byte $06
                  .byte $18
                  .byte $18
                  .byte $d8
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $18
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $8a
                  .byte $8a
                  .byte $8a
                  .byte $15
                  .byte $04
                  .byte $00
                  .byte $5b
                  .byte $00
                  .byte $00
                  .byte $44
                  .byte $15
                  .byte $45
                  .byte $15
                  .byte $14
                  .byte $10
                  .byte $50
                  .byte $04
                  .byte $04
                  .byte $05
                  .byte $10
                  .byte $04
                  .byte $14
                  .byte $04
                  .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $41
                  .byte $04
                  .byte $01
                  .byte $01
                  .byte $51
                  .byte $40
                  .byte $40
                  .byte $05
                  .byte $11
                  .byte $41
                  .byte $22
                  .byte $88
                  .byte $80
                  .byte $82
                  .byte $a0
                  .byte $a0
                  .byte $80
                  .byte $82
                  .byte $20
                  .byte $08
                  .byte $88
                  .byte $80
                  .byte $aa
                  .byte $a2
                  .byte $8a
                  .byte $82
                  .byte $8a
                  .byte $82
                  .byte $80
                  .byte $20
                  .byte $82
                  .byte $a2
                  .byte $82
                  .byte $82
                  .byte $8a
                  .byte $82
                  .byte $28
                  .byte $00
                  .byte $a0
                  .byte $0a
                  .byte $08
                  .byte $aa
                  .byte $28
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $40
                  .byte $c0
                  .byte $c0
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $40
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $c0
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $80
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $40
                  .byte $00
                  .byte $80
                  .byte $40
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $40
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $8a
                  .byte $aa
                  .byte $c3
                  .byte $00
                  .byte $0c
                  .byte $03
                  .byte $eb
                  .byte $06
                  .byte $0c
                  .byte $ff
                  .byte $0c
                  .byte $de
                  .byte $18
                  .byte $0e
                  .byte $43
                  .byte $1e
                  .byte $06
                  .byte $1c
                  .byte $1e
                  .byte $1e
                  .byte $18
                  .byte $18
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $18
                  .byte $08
                  .byte $80
                  .byte $88
                  .byte $00
                  .byte $8a
                  .byte $8a
                  .byte $8a
                  .byte $00
                  .byte $05
                  .byte $00
                  .byte $18
                  .byte $08
                  .byte $a0
                  .byte $0c
                  .byte $06
                  .byte $06
                  .byte $4c
                  .byte $0c
                  .byte $10
                  .byte $10
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $10
                  .byte $0e
                  .byte $1c
                  .byte $0f
                  .byte $1e
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $41
                  .byte $04
                  .byte $55
                  .byte $15
                  .byte $55
                  .byte $55
                  .byte $40
                  .byte $05
                  .byte $55
                  .byte $55
                  .byte $aa
                  .byte $aa
                  .byte $80
                  .byte $82
                  .byte $a8
                  .byte $a8
                  .byte $80
                  .byte $aa
                  .byte $28
                  .byte $0a
                  .byte $a8
                  .byte $80
                  .byte $aa
                  .byte $aa
                  .byte $82
                  .byte $aa
                  .byte $82
                  .byte $aa
                  .byte $aa
                  .byte $20
                  .byte $82
                  .byte $a2
                  .byte $82
                  .byte $28
                  .byte $aa
                  .byte $08
                  .byte $0a
                  .byte $00
                  .byte $a0
                  .byte $0a
                  .byte $08
                  .byte $aa
                  .byte $a0
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $c0
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $c0
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $80
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $40
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $40
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $8a
                  .byte $aa
                  .byte $ff
                  .byte $00
                  .byte $0c
                  .byte $c3
                  .byte $eb
                  .byte $15
                  .byte $0e
                  .byte $ff
                  .byte $1c
                  .byte $38
                  .byte $3c
                  .byte $1b
                  .byte $07
                  .byte $07
                  .byte $0f
                  .byte $36
                  .byte $36
                  .byte $1b
                  .byte $78
                  .byte $38
                  .byte $0e
                  .byte $07
                  .byte $07
                  .byte $1c
                  .byte $02
                  .byte $20
                  .byte $00
                  .byte $00
                  .byte $8a
                  .byte $8a
                  .byte $8a
                  .byte $8a
                  .byte $95
                  .byte $04
                  .byte $1c
                  .byte $22
                  .byte $40
                  .byte $0e
                  .byte $07
                  .byte $0f
                  .byte $1c
                  .byte $1e
                  .byte $78
                  .byte $38
                  .byte $0e
                  .byte $0f
                  .byte $0e
                  .byte $38
                  .byte $1b
                  .byte $36
                  .byte $0d
                  .byte $36
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $14
                  .byte $45
                  .byte $04
                  .byte $40
                  .byte $01
                  .byte $01
                  .byte $05
                  .byte $55
                  .byte $14
                  .byte $41
                  .byte $05
                  .byte $82
                  .byte $82
                  .byte $a0
                  .byte $a2
                  .byte $80
                  .byte $80
                  .byte $8a
                  .byte $a2
                  .byte $28
                  .byte $0a
                  .byte $aa
                  .byte $a0
                  .byte $82
                  .byte $aa
                  .byte $82
                  .byte $a0
                  .byte $82
                  .byte $a8
                  .byte $0a
                  .byte $28
                  .byte $a2
                  .byte $a2
                  .byte $aa
                  .byte $28
                  .byte $28
                  .byte $28
                  .byte $0a
                  .byte $00
                  .byte $a0
                  .byte $0a
                  .byte $20
                  .byte $aa
                  .byte $a0
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $c0
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $40
                  .byte $00
                  .byte $80
                  .byte $80
                  .byte $80
                  .byte $80
                  .byte $80
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $8a
                  .byte $aa
                  .byte $c3
                  .byte $00
                  .byte $aa
                  .byte $ff
                  .byte $eb
                  .byte $15
                  .byte $7b
                  .byte $ff
                  .byte $37
                  .byte $3c
                  .byte $66
                  .byte $1b
                  .byte $0d
                  .byte $0f
                  .byte $19
                  .byte $76
                  .byte $36
                  .byte $1b
                  .byte $d8
                  .byte $6c
                  .byte $1b
                  .byte $06
                  .byte $0d
                  .byte $36
                  .byte $20
                  .byte $0a
                  .byte $80
                  .byte $00
                  .byte $8a
                  .byte $8a
                  .byte $8a
                  .byte $8a
                  .byte $80
                  .byte $14
                  .byte $36
                  .byte $48
                  .byte $4a
                  .byte $7b
                  .byte $0f
                  .byte $19
                  .byte $1e
                  .byte $33
                  .byte $d8
                  .byte $6c
                  .byte $1b
                  .byte $0d
                  .byte $1b
                  .byte $6c
                  .byte $1b
                  .byte $76
                  .byte $0d
                  .byte $36
                  .byte $80
                  .byte $80
                  .byte $14
                  .byte $55
                  .byte $45
                  .byte $04
                  .byte $40
                  .byte $01
                  .byte $01
                  .byte $05
                  .byte $45
                  .byte $10
                  .byte $41
                  .byte $05
                  .byte $82
                  .byte $82
                  .byte $a0
                  .byte $a2
                  .byte $80
                  .byte $80
                  .byte $8a
                  .byte $a2
                  .byte $28
                  .byte $0a
                  .byte $a2
                  .byte $a0
                  .byte $82
                  .byte $8a
                  .byte $82
                  .byte $a0
                  .byte $82
                  .byte $a8
                  .byte $0a
                  .byte $28
                  .byte $a2
                  .byte $aa
                  .byte $aa
                  .byte $82
                  .byte $28
                  .byte $80
                  .byte $28
                  .byte $28
                  .byte $a0
                  .byte $0a
                  .byte $20
                  .byte $aa
                  .byte $28
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $40
                  .byte $00
                  .byte $c0
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $80
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $c0
                  .byte $80
                  .byte $00
                  .byte $40
                  .byte $40
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $80
                  .byte $80
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $80
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $8a
                  .byte $aa
                  .byte $c3
                  .byte $00
                  .byte $aa
                  .byte $c0
                  .byte $ff
                  .byte $10
                  .byte $03
                  .byte $ff
                  .byte $30
                  .byte $0e
                  .byte $63
                  .byte $18
                  .byte $0d
                  .byte $1c
                  .byte $31
                  .byte $06
                  .byte $36
                  .byte $1b
                  .byte $d8
                  .byte $6c
                  .byte $1b
                  .byte $06
                  .byte $0d
                  .byte $36
                  .byte $09
                  .byte $21
                  .byte $20
                  .byte $00
                  .byte $8a
                  .byte $8a
                  .byte $8a
                  .byte $8a
                  .byte $8a
                  .byte $15
                  .byte $36
                  .byte $50
                  .byte $11
                  .byte $03
                  .byte $1c
                  .byte $31
                  .byte $07
                  .byte $31
                  .byte $d8
                  .byte $6c
                  .byte $1b
                  .byte $0d
                  .byte $1b
                  .byte $6c
                  .byte $18
                  .byte $06
                  .byte $0d
                  .byte $36
                  .byte $80
                  .byte $80
                  .byte $55
                  .byte $55
                  .byte $45
                  .byte $15
                  .byte $45
                  .byte $41
                  .byte $01
                  .byte $05
                  .byte $45
                  .byte $10
                  .byte $41
                  .byte $05
                  .byte $8a
                  .byte $82
                  .byte $a2
                  .byte $a2
                  .byte $80
                  .byte $80
                  .byte $82
                  .byte $a2
                  .byte $28
                  .byte $8a
                  .byte $a2
                  .byte $a0
                  .byte $82
                  .byte $82
                  .byte $82
                  .byte $a0
                  .byte $88
                  .byte $a2
                  .byte $8a
                  .byte $28
                  .byte $a2
                  .byte $28
                  .byte $a2
                  .byte $82
                  .byte $28
                  .byte $8a
                  .byte $a0
                  .byte $28
                  .byte $28
                  .byte $28
                  .byte $80
                  .byte $00
                  .byte $0a
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $c0
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $c0
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $40
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $80
                  .byte $80
                  .byte $80
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $80
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $c3
                  .byte $00
                  .byte $00
                  .byte $c0
                  .byte $00
                  .byte $10
                  .byte $03
                  .byte $ff
                  .byte $30
                  .byte $0c
                  .byte $03
                  .byte $38
                  .byte $0d
                  .byte $0c
                  .byte $30
                  .byte $07
                  .byte $06
                  .byte $18
                  .byte $b0
                  .byte $6c
                  .byte $1b
                  .byte $03
                  .byte $0d
                  .byte $36
                  .byte $01
                  .byte $09
                  .byte $02
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $36
                  .byte $10
                  .byte $11
                  .byte $03
                  .byte $0c
                  .byte $30
                  .byte $06
                  .byte $01
                  .byte $b0
                  .byte $0c
                  .byte $1b
                  .byte $06
                  .byte $1b
                  .byte $6c
                  .byte $38
                  .byte $07
                  .byte $0c
                  .byte $06
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $55
                  .byte $15
                  .byte $55
                  .byte $55
                  .byte $01
                  .byte $55
                  .byte $55
                  .byte $10
                  .byte $55
                  .byte $05
                  .byte $8a
                  .byte $aa
                  .byte $aa
                  .byte $a8
                  .byte $aa
                  .byte $80
                  .byte $aa
                  .byte $a2
                  .byte $28
                  .byte $aa
                  .byte $a2
                  .byte $aa
                  .byte $82
                  .byte $82
                  .byte $aa
                  .byte $a0
                  .byte $a2
                  .byte $a2
                  .byte $aa
                  .byte $28
                  .byte $aa
                  .byte $20
                  .byte $82
                  .byte $82
                  .byte $28
                  .byte $aa
                  .byte $80
                  .byte $28
                  .byte $28
                  .byte $28
                  .byte $80
                  .byte $00
                  .byte $02
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $c0
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00

TabDemoLvlMoves   .byte $44
                  .byte $01
                  .byte $33
                  .byte $03
                  .byte $11
                  .byte $06
                  .byte $33
                  .byte $27
                  .byte $00
                  .byte $1d
                  .byte $33
                  .byte $2d
                  .byte $11
                  .byte $1f
                  .byte $55
                  .byte $01
                  .byte $11
                  .byte $03
                  .byte $44
                  .byte $01
                  .byte $22
                  .byte $04
                  .byte $44
                  .byte $01
                  .byte $22
                  .byte $13
                  .byte $11
                  .byte $0b
                  .byte $55
                  .byte $01
                  .byte $33
                  .byte $0a
                  .byte $22
                  .byte $1f
                  .byte $00
                  .byte $13
                  .byte $44
                  .byte $01
                  .byte $00
                  .byte $33
                  .byte $33
                  .byte $05
                  .byte $44
                  .byte $01
                  .byte $33
                  .byte $03
                  .byte $11
                  .byte $09
                  .byte $00
                  .byte $9d
                  .byte $33
                  .byte $31
                  .byte $44
                  .byte $01
                  .byte $11
                  .byte $04
                  .byte $44
                  .byte $01
                  .byte $11
                  .byte $09
                  .byte $33
                  .byte $10
                  .byte $44
                  .byte $01
                  .byte $11
                  .byte $04
                  .byte $44
                  .byte $01
                  .byte $11
                  .byte $10
                  .byte $33
                  .byte $0b
                  .byte $44
                  .byte $01
                  .byte $11
                  .byte $05
                  .byte $44
                  .byte $01
                  .byte $11
                  .byte $0e
                  .byte $33
                  .byte $0b
                  .byte $44
                  .byte $01
                  .byte $11
                  .byte $05
                  .byte $44
                  .byte $01
                  .byte $11
                  .byte $14
                  .byte $33
                  .byte $0b
                  .byte $44
                  .byte $01
                  .byte $11
                  .byte $04
                  .byte $44
                  .byte $01
                  .byte $11
                  .byte $13
                  .byte $33
                  .byte $0b
                  .byte $44
                  .byte $01
                  .byte $11
                  .byte $05
                  .byte $44
                  .byte $01
                  .byte $11
                  .byte $10
                  .byte $33
                  .byte $08
                  .byte $44
                  .byte $01
                  .byte $11
                  .byte $21
                  .byte $33
                  .byte $03
                  .byte $22
                  .byte $46
                  .byte $33
                  .byte $03
                  .byte $11
                  .byte $0b
                  .byte $55
                  .byte $01
                  .byte $33
                  .byte $07
                  .byte $55
                  .byte $01
                  .byte $66
                  .byte $05
                  .byte $33
                  .byte $01
                  .byte $55
                  .byte $01
                  .byte $33
                  .byte $04
                  .byte $55
                  .byte $01
                  .byte $66
                  .byte $bd
                  .byte $11
                  .byte $0e
                  .byte $44
                  .byte $01
                  .byte $22
                  .byte $04
                  .byte $44
                  .byte $01
                  .byte $66
                  .byte $04
                  .byte $33
                  .byte $08
                  .byte $00
                  .byte $04
                  .byte $33
                  .byte $05
                  .byte $00
                  .byte $7e
                  .byte $11
                  .byte $22
                  .byte $00
                  .byte $0e
                  .byte $11
                  .byte $19
                  .byte $55
                  .byte $01
                  .byte $33
                  .byte $05
                  .byte $55
                  .byte $01
                  .byte $33
                  .byte $04
                  .byte $55
                  .byte $01
                  .byte $11
                  .byte $07
                  .byte $44
                  .byte $01
                  .byte $22
                  .byte $04
                  .byte $44
                  .byte $01
                  .byte $66
                  .byte $03
                  .byte $00
                  .byte $0e
                  .byte $11
                  .byte $03
                  .byte $33
                  .byte $1e
                  .byte $00
                  .byte $47
                  .byte $11
                  .byte $2a
                  .byte $00
                  .byte $07
                  .byte $55
                  .byte $01
                  .byte $11
                  .byte $36
                  .byte $33
                  .byte $04
                  .byte $55
                  .byte $01
                  .byte $11
                  .byte $03
                  .byte $33
                  .byte $2c
                  .byte $00
                  .byte $0d
                  .byte $33
                  .byte $11
                  .byte $11
                  .byte $04
                  .byte $00
                  .byte $0b
                  .byte $55
                  .byte $01
                  .byte $22
                  .byte $04
                  .byte $44
                  .byte $01
                  .byte $33
                  .byte $0d
                  .byte $00
                  .byte $03
                  .byte $33
                  .byte $17
                  .byte $11
                  .byte $0f
                  .byte $00
                  .byte $03
                  .byte $11
                  .byte $21
                  .byte $00
                  .byte $0f
                  .byte $33
                  .byte $12
                  .byte $00
                  .byte $0f
                  .byte $33
                  .byte $0a
                  .byte $00
                  .byte $5a
                  .byte $33
                  .byte $19
                  .byte $00
                  .byte $0a
                  .byte $44
                  .byte $01
                  .byte $66
                  .byte $02
                  .byte $33
                  .byte $03
                  .byte $11
                  .byte $06
                  .byte $33
                  .byte $22
                  .byte $55
                  .byte $01
                  .byte $33
                  .byte $03
                  .byte $55
                  .byte $01
                  .byte $33
                  .byte $04
                  .byte $55
                  .byte $01
                  .byte $66
                  .byte $1f
                  .byte $00
                  .byte $1a
                  .byte $33
                  .byte $22
                  .byte $55
                  .byte $01
                  .byte $33
                  .byte $04
                  .byte $55
                  .byte $01
                  .byte $11
                  .byte $15
                  .byte $44
                  .byte $01
                  .byte $66
                  .byte $7b
                  .byte $10
                  .byte $1f
                  .byte $60
                  .byte $07
                  .byte $30
                  .byte $09
                  .byte $36
                  .byte $33
                  .byte $66
                  .byte $04
                  .byte $10
                  .byte $09
                  .byte $16
                  .byte $08
                  .byte $12
                  .byte $01
                  .byte $62
                  .byte $0c
                  .byte $32
                  .byte $01
                  .byte $36
                  .byte $32
                  .byte $44
                  .byte $01
                  .byte $16
                  .byte $0b
                  .byte $44
                  .byte $01
                  .byte $16
                  .byte $09
                  .byte $44
                  .byte $01
                  .byte $10
                  .byte $2c
                  .byte $60
                  .byte $04
                  .byte $30
                  .byte $03
                  .byte $36
                  .byte $0a
                  .byte $44
                  .byte $01
                  .byte $16
                  .byte $05
                  .byte $44
                  .byte $01
                  .byte $36
                  .byte $03
                  .byte $44
                  .byte $01
                  .byte $36
                  .byte $03
                  .byte $44
                  .byte $01
                  .byte $66
                  .byte $03
                  .byte $36
                  .byte $03
                  .byte $55
                  .byte $01
                  .byte $36
                  .byte $08
                  .byte $55
                  .byte $01
                  .byte $66
                  .byte $4c
                  .byte $16
                  .byte $09
                  .byte $10
                  .byte $15
                  .byte $44
                  .byte $01
                  .byte $10
                  .byte $2f
                  .byte $16
                  .byte $09
                  .byte $12
                  .byte $03
                  .byte $16
                  .byte $12
                  .byte $66
                  .byte $02
                  .byte $36
                  .byte $06
                  .byte $66
                  .byte $2d
                  .byte $55
                  .byte $01
                  .byte $16
                  .byte $03
                  .byte $10
                  .byte $1c
                  .byte $55
                  .byte $01
                  .byte $16
                  .byte $03
                  .byte $44
                  .byte $01
                  .byte $36
                  .byte $03
                  .byte $32
                  .byte $15
                  .byte $36
                  .byte $0b
                  .byte $30
                  .byte $0b
                  .byte $60
                  .byte $0c
                  .byte $44
                  .byte $01
                  .byte $62
                  .byte $0d
                  .byte $12
                  .byte $02
                  .byte $16
                  .byte $0d
                  .byte $44
                  .byte $01
                  .byte $66
                  .byte $20
                  .byte $36
                  .byte $04
                  .byte $30
                  .byte $17
                  .byte $36
                  .byte $1e
                  .byte $44
                  .byte $01
                  .byte $36
                  .byte $2f
                  .byte $30
                  .byte $08
                  .byte $60
                  .byte $03
                  .byte $10
                  .byte $22
                  .byte $16
                  .byte $1b
                  .byte $66
                  .byte $26
                  .byte $55
                  .byte $07
                  .byte $16
                  .byte $03
                  .byte $55
                  .byte $01
                  .byte $66
                  .byte $1d
                  .byte $16
                  .byte $02
                  .byte $10
                  .byte $85
                  .byte $60
                  .byte $02
                  .byte $30
                  .byte $03
                  .byte $36
                  .byte $03
                  .byte $32
                  .byte $0f
                  .byte $36
                  .byte $03
                  .byte $30
                  .byte $0c
                  .byte $36
                  .byte $20
                  .byte $66
                  .byte $01
                  .byte $16
                  .byte $0a
                  .byte $60
                  .byte $06
                  .byte $66
                  .byte $02
                  .byte $36
                  .byte $08
                  .byte $30
                  .byte $05
                  .byte $60
                  .byte $02
                  .byte $66
                  .byte $02
                  .byte $16
                  .byte $08
                  .byte $10
                  .byte $01
                  .byte $60
                  .byte $06
                  .byte $66
                  .byte $01
                  .byte $36
                  .byte $08
                  .byte $30
                  .byte $04
                  .byte $60
                  .byte $03
                  .byte $66
                  .byte $01
                  .byte $16
                  .byte $08
                  .byte $10
                  .byte $02
                  .byte $60
                  .byte $03
                  .byte $30
                  .byte $01
                  .byte $36
                  .byte $08
                  .byte $30
                  .byte $03
                  .byte $60
                  .byte $03
                  .byte $16
                  .byte $09
                  .byte $10
                  .byte $02
                  .byte $60
                  .byte $03
                  .byte $30
                  .byte $03
                  .byte $36
                  .byte $07
                  .byte $30
                  .byte $03
                  .byte $60
                  .byte $02
                  .byte $10
                  .byte $02
                  .byte $16
                  .byte $08
                  .byte $10
                  .byte $01
                  .byte $60
                  .byte $02
                  .byte $30
                  .byte $02
                  .byte $36
                  .byte $0a
                  .byte $30
                  .byte $02
                  .byte $60
                  .byte $02
                  .byte $10
                  .byte $03
                  .byte $16
                  .byte $04
                  .byte $10
                  .byte $03
                  .byte $60
                  .byte $05
                  .byte $30
                  .byte $02
                  .byte $36
                  .byte $07
                  .byte $66
                  .byte $16
                  .byte $36
                  .byte $02
                  .byte $66
                  .byte $33
                  .byte $55
                  .byte $01
                  .byte $36
                  .byte $05
                  .byte $55
                  .byte $01
                  .byte $36
                  .byte $04
                  .byte $55
                  .byte $01
                  .byte $36
                  .byte $03
                  .byte $55
                  .byte $01
                  .byte $36
                  .byte $03
                  .byte $55
                  .byte $01
                  .byte $66
                  .byte $a9
                  .byte $62
                  .byte $0c
                  .byte $66
                  .byte $07
                  .byte $60
                  .byte $0f
                  .byte $55
                  .byte $01
                  .byte $66
                  .byte $18
                  .byte $16
                  .byte $2a
                  .byte $55
                  .byte $01
                  .byte $16
                  .byte $03
                  .byte $66
                  .byte $01
                  .byte $60
                  .byte $07
                  .byte $66
                  .byte $03
                  .byte $36
                  .byte $03
                  .byte $30
                  .byte $1b
                  .byte $36
                  .byte $08
                  .byte $44
                  .byte $01
                  .byte $66
                  .byte $18
                  .byte $36
                  .byte $0f
                  .byte $66
                  .byte $08
                  .byte $44
                  .byte $01
                  .byte $66
                  .byte $38
                  .byte $30
                  .byte $0e
                  .byte $66
                  .byte $11
                  .byte $60
                  .byte $04
                  .byte $66
                  .byte $49
                  .byte $37

                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $33
                  .byte $07
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $37
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $33
                  .byte $07
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $37
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $33
                  .byte $07
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $37
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $09
                  .byte $00
                  .byte $33
                  .byte $07
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $30
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $03
                  .byte $00
                  .byte $30
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $b1
                  .byte $c3
                  .byte $b3
                  .byte $b5
                  .byte $8d
                  .byte $f9
                  .byte $f4
                  .byte $e1
                  .byte $e2
                  .byte $ec
                  .byte $e5
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $b1
                  .byte $c3
                  .byte $b5
                  .byte $b1
                  .byte $8d
                  .byte $e2
                  .byte $f9
                  .byte $f4
                  .byte $e1
                  .byte $e2
                  .byte $ec
                  .byte $e5
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $b1
                  .byte $c3
                  .byte $b6
                  .byte $b2
                  .byte $8d
                  .byte $e2
                  .byte $e9
                  .byte $f4
                  .byte $e1
                  .byte $e2
                  .byte $ec
                  .byte $e5
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $b1
                  .byte $c3
                  .byte $b7
                  .byte $c5
                  .byte $8d
                  .byte $f8
                  .byte $e2
                  .byte $f9
                  .byte $f4
                  .byte $e1
                  .byte $e2
                  .byte $ec
                  .byte $e5
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $b1
                  .byte $c3
                  .byte $b9
                  .byte $c1
                  .byte $8d
                  .byte $f8
                  .byte $e2
                  .byte $e9
                  .byte $f4
                  .byte $e1
                  .byte $e2
                  .byte $ec
                  .byte $e5
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $b1
                  .byte $c4
                  .byte $b2
                  .byte $b6
                  .byte $8d
                  .byte $e2
                  .byte $ef
                  .byte $ef
                  .byte $f4
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $b1
                  .byte $c4
                  .byte $c2
                  .byte $b2
                  .byte $8d
                  .byte $f3
                  .byte $e3
                  .byte $ef
                  .byte $f2
                  .byte $e5
                  .byte $e2
                  .byte $f5
                  .byte $e6
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $b1
                  .byte $c6
                  .byte $b0
                  .byte $b0
                  .byte $8d
                  .byte $e3
                  .byte $e8
                  .byte $e1
                  .byte $f2
                  .byte $e4
                  .byte $e1
                  .byte $f4
                  .byte $e1
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $c1
                  .byte $c4
                  .byte $b0
                  .byte $b0
                  .byte $8d
                  .byte $8d
                  .byte $f2
                  .byte $f7
                  .byte $f4
                  .byte $f3
                  .byte $f0
                  .byte $e1
                  .byte $f2
                  .byte $ed
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $c2
                  .byte $b7
                  .byte $c5
                  .byte $b8
                  .byte $8d
                  .byte $f2
                  .byte $f7
                  .byte $f4
                  .byte $f3
                  .byte $f6
                  .byte $ef
                  .byte $ec
                  .byte $ed
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $c2
                  .byte $b7
                  .byte $c5
                  .byte $c2
                  .byte $8d
                  .byte $f2
                  .byte $f7
                  .byte $f4
                  .byte $f3
                  .byte $f4
                  .byte $f2
                  .byte $e3
                  .byte $eb
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $c2
                  .byte $b7
                  .byte $c5
                  .byte $c3
                  .byte $8d
                  .byte $f2
                  .byte $f7
                  .byte $f4
                  .byte $f3
                  .byte $f3
                  .byte $e5
                  .byte $e3
                  .byte $f4
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $c2
                  .byte $b7
                  .byte $c5
                  .byte $c4
                  .byte $8d
                  .byte $f2
                  .byte $f7
                  .byte $f4
                  .byte $f3
                  .byte $e2
                  .byte $f5
                  .byte $e6
                  .byte $e6
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $c2
                  .byte $b7
                  .byte $c6
                  .byte $b0
                  .byte $8d
                  .byte $f2
                  .byte $f7
                  .byte $f4
                  .byte $f3
                  .byte $e3
                  .byte $ed
                  .byte $ee
; ------------------------------------------------------------------------------------------------------------- ;
TabDemoLvlData    = *
TabDemoLvl01      .byte $09                       ; data demo level 01
                  .byte $81
                  .byte $88
                  .byte $18
                  .byte $00
                  .byte $00
                  .byte $07
                  .byte $00
                  .byte $70
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $11
                  .byte $41
                  .byte $44
                  .byte $14
                  .byte $13
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $61
                  .byte $11
                  .byte $11
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $01
                  .byte $00
                  .byte $10
                  .byte $13
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $00
                  .byte $60
                  .byte $00
                  .byte $04
                  .byte $40
                  .byte $00
                  .byte $00
                  .byte $07
                  .byte $00
                  .byte $10
                  .byte $13
                  .byte $13
                  .byte $11
                  .byte $16
                  .byte $11
                  .byte $71
                  .byte $11
                  .byte $10
                  .byte $01
                  .byte $11
                  .byte $11
                  .byte $01
                  .byte $00
                  .byte $10
                  .byte $13
                  .byte $13
                  .byte $17
                  .byte $16
                  .byte $11
                  .byte $11
                  .byte $17
                  .byte $01
                  .byte $11
                  .byte $10
                  .byte $33
                  .byte $00
                  .byte $00
                  .byte $10
                  .byte $13
                  .byte $13
                  .byte $10
                  .byte $06
                  .byte $00
                  .byte $10
                  .byte $71
                  .byte $11
                  .byte $10
                  .byte $01
                  .byte $33
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $13
                  .byte $13
                  .byte $11
                  .byte $06
                  .byte $00
                  .byte $00
                  .byte $11
                  .byte $17
                  .byte $01
                  .byte $11
                  .byte $33
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $13
                  .byte $00
                  .byte $06
                  .byte $00
                  .byte $00
                  .byte $10
                  .byte $71
                  .byte $11
                  .byte $10
                  .byte $11
                  .byte $01
                  .byte $00
                  .byte $10
                  .byte $11
                  .byte $13
                  .byte $00
                  .byte $06
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $11
                  .byte $17
                  .byte $01
                  .byte $22
                  .byte $22
                  .byte $22
                  .byte $22
                  .byte $22
                  .byte $11
                  .byte $16
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $03
                  .byte $10
                  .byte $71
                  .byte $11
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $16
                  .byte $37
                  .byte $01
                  .byte $00
                  .byte $03
                  .byte $00
                  .byte $11
                  .byte $10
                  .byte $07
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $31
                  .byte $16
                  .byte $00
                  .byte $01
                  .byte $00
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $31
                  .byte $11
                  .byte $11
                  .byte $22
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $13
                  .byte $31
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $01
                  .byte $00
                  .byte $10
                  .byte $30
                  .byte $07
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $00
                  .byte $00
                  .byte $53
                  .byte $03
                  .byte $70
                  .byte $11
                  .byte $11
                  .byte $71
                  .byte $30
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $51
                  .byte $13
                  .byte $00
                  .byte $00
                  .byte $c4 ; D
                  .byte $c9 ; I
                  .byte $c4 ; D
                  .byte $a0 ; <blank>
                  .byte $d9 ; Y
                  .byte $cf ; O
                  .byte $d5 ; U
                  .byte $a0 ; <blank>
                  .byte $c7 ; G
                  .byte $c5 ; E
                  .byte $d4 ; T
                  .byte $a0 ; <blank>
                  .byte $d4 ; T
                  .byte $c8 ; H
                  .byte $c1 ; A
                  .byte $d4 ; T
                  .byte $00 ; 
                  .byte $00 ; 
                  .byte $cc ; L
                  .byte $cf ; O
                  .byte $c4 ; D
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $d2 ; T
                  .byte $d5 ; U
                  .byte $ce ; N
                  .byte $ce ; N
                  .byte $c5 ; E
                  .byte $52 ; r
                  .byte $00 ; 
; ------------------------------------------------------------------------------------------------------------- ;
TabDemoLvl02      .byte $09
                  .byte $81
                  .byte $88
                  .byte $18
                  .byte $00
                  .byte $00
                  .byte $07
                  .byte $00
                  .byte $70
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $11
                  .byte $41
                  .byte $44
                  .byte $14
                  .byte $13
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $61
                  .byte $11
                  .byte $11
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $01
                  .byte $00
                  .byte $10
                  .byte $13
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $00
                  .byte $60
                  .byte $00
                  .byte $04
                  .byte $40
                  .byte $00
                  .byte $00
                  .byte $07
                  .byte $00
                  .byte $10
                  .byte $13
                  .byte $13
                  .byte $11
                  .byte $16
                  .byte $11
                  .byte $71
                  .byte $11
                  .byte $10
                  .byte $01
                  .byte $11
                  .byte $11
                  .byte $01
                  .byte $00
                  .byte $10
                  .byte $13
                  .byte $13
                  .byte $17
                  .byte $16
                  .byte $11
                  .byte $11
                  .byte $17
                  .byte $01
                  .byte $11
                  .byte $10
                  .byte $33
                  .byte $00
                  .byte $00
                  .byte $10
                  .byte $13
                  .byte $13
                  .byte $10
                  .byte $06
                  .byte $00
                  .byte $10
                  .byte $71
                  .byte $11
                  .byte $10
                  .byte $01
                  .byte $33
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $13
                  .byte $13
                  .byte $11
                  .byte $06
                  .byte $00
                  .byte $00
                  .byte $11
                  .byte $17
                  .byte $01
                  .byte $11
                  .byte $33
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $13
                  .byte $00
                  .byte $06
                  .byte $00
                  .byte $00
                  .byte $10
                  .byte $71
                  .byte $11
                  .byte $10
                  .byte $11
                  .byte $01
                  .byte $00
                  .byte $10
                  .byte $11
                  .byte $13
                  .byte $00
                  .byte $06
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $11
                  .byte $17
                  .byte $01
                  .byte $22
                  .byte $22
                  .byte $22
                  .byte $22
                  .byte $22
                  .byte $11
                  .byte $16
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $03
                  .byte $10
                  .byte $71
                  .byte $11
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $16
                  .byte $37
                  .byte $01
                  .byte $00
                  .byte $03
                  .byte $00
                  .byte $11
                  .byte $10
                  .byte $07
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $31
                  .byte $16
                  .byte $00
                  .byte $01
                  .byte $00
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $31
                  .byte $11
                  .byte $11
                  .byte $22
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $13
                  .byte $31
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $01
                  .byte $00
                  .byte $10
                  .byte $30
                  .byte $07
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $00
                  .byte $00
                  .byte $53
                  .byte $03
                  .byte $70
                  .byte $11
                  .byte $11
                  .byte $71
                  .byte $30
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $51
                  .byte $13
                  .byte $00
                  .byte $00
                  .byte $c4 ; D
                  .byte $c9 ; I
                  .byte $c4 ; D
                  .byte $a0 ; <blank>
                  .byte $d9 ; Y
                  .byte $cf ; O
                  .byte $d5 ; U
                  .byte $a0 ; <blank>
                  .byte $c7 ; G
                  .byte $c5 ; E
                  .byte $d4 ; T
                  .byte $a0 ; <blank>
                  .byte $d4 ; T
                  .byte $c8 ; H
                  .byte $c1 ; A
                  .byte $d4 ; T
                  .byte $00 ; 
                  .byte $00 ; 
                  .byte $cc ; L
                  .byte $cf ; O
                  .byte $c4 ; D
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $d2 ; T
                  .byte $d5 ; U
                  .byte $ce ; N
                  .byte $ce ; N
                  .byte $c5 ; E
                  .byte $52 ; r
                  .byte $00 ; 
; ------------------------------------------------------------------------------------------------------------- ;
MelodyMaxNo       .byte $09
MelodyMinHight    .byte $02
MelodyMaxHight    .byte $0c
TabMelodyPtr      .word TabMelody00
                  .word TabMelody01
                  .word TabMelody02
                  .word TabMelody03
                  .word TabMelody04
                  .word TabMelody05
                  .word TabMelody06
                  .word TabMelody07
                  .word TabMelody08
                  .word TabMelody09
                  .word TabMelody0a               ; $00 - not used
                  .word TabMelody0a
                  .word TabMelody0a
                  .word TabMelody0a
                  .word TabMelody0a
; ------------------------------------------------------------------------------------------------------------- ;
TabVocsFreqDatLo  .byte $00
                  .byte $e1
                  .byte $68
                  .byte $f7
                  .byte $8f
                  .byte $30
                  .byte $da
                  .byte $8f
                  .byte $4e
                  .byte $18
                  .byte $ef
                  .byte $d2
                  .byte $c3
                  .byte $c3
                  .byte $d1
                  .byte $ef
                  .byte $1f
                  .byte $60
                  .byte $b5
                  .byte $1e
                  .byte $9c
                  .byte $31
                  .byte $df
                  .byte $a5
                  .byte $87
                  .byte $86
                  .byte $a2
                  .byte $df
                  .byte $3e
                  .byte $c1
                  .byte $6b
                  .byte $3c
                  .byte $39
                  .byte $63
                  .byte $be
                  .byte $4b
                  .byte $0f
                  
TabVocsFreqDatHi  .byte $00
                  .byte $08
                  .byte $09
                  .byte $09
                  .byte $0a
                  .byte $0b
                  .byte $0b
                  .byte $0c
                  .byte $0d
                  .byte $0e
                  .byte $0e
                  .byte $0f
                  .byte $10
                  .byte $11
                  .byte $12
                  .byte $13
                  .byte $15
                  .byte $16
                  .byte $17
                  .byte $19
                  .byte $1a
                  .byte $1c
                  .byte $1d
                  .byte $1f
                  .byte $21
                  .byte $23
                  .byte $25
                  .byte $27
                  .byte $2a
                  .byte $2c
                  .byte $2f
                  .byte $32
                  .byte $35
                  .byte $38
                  .byte $3b
                  .byte $3f
                  .byte $43

TabMelody09       .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $08
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $08
                  .byte $0c
                  .byte $ff
                  .byte $a0
                  .byte $08
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $d0
                  .byte $0c
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $08
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $06
                  .byte $13
                  .byte $ff
                  .byte $d0
                  .byte $06
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $06
                  .byte $13
                  .byte $ff
                  .byte $70
                  .byte $10
                  .byte $13
                  .byte $ff
                  .byte $40
                  .byte $10
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00

TabMelody05       .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $c0
                  .byte $04
                  .byte $12
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $11
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $0f
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $14
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $12
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $d0
                  .byte $04
                  .byte $12
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $11
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $0f
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $11
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $12
                  .byte $ff
                  .byte $a0
                  .byte $03
                  .byte $13
                  .byte $ff
                  .byte $d0
                  .byte $03
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $03
                  .byte $13
                  .byte $ff
                  .byte $70
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $40
                  .byte $10
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  
TabMelody02       .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $05
                  .byte $02
                  .byte $1c
                  .byte $a0
                  .byte $05
                  .byte $04
                  .byte $17
                  .byte $a0
                  .byte $05
                  .byte $05
                  .byte $15
                  .byte $a0
                  .byte $05
                  .byte $07
                  .byte $13
                  .byte $a0
                  .byte $05
                  .byte $09
                  .byte $11
                  .byte $a0
                  .byte $05
                  .byte $0b
                  .byte $10
                  .byte $a0
                  .byte $05
                  .byte $0c
                  .byte $0c
                  .byte $a0
                  .byte $05
                  .byte $10
                  .byte $0b
                  .byte $a0
                  .byte $05
                  .byte $11
                  .byte $09
                  .byte $a0
                  .byte $05
                  .byte $13
                  .byte $07
                  .byte $a0
                  .byte $05
                  .byte $15
                  .byte $05
                  .byte $a0
                  .byte $05
                  .byte $17
                  .byte $04
                  .byte $a0
                  .byte $05
                  .byte $1c
                  .byte $02
                  .byte $a0
                  .byte $10
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  
TabMelody06       .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $0c
                  .byte $ff
                  .byte $c0
                  .byte $08
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $06
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $08
                  .byte $ff
                  .byte $a0
                  .byte $08
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $08
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $0c
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $17
                  .byte $11
                  .byte $a0
                  .byte $08
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $18
                  .byte $10
                  .byte $a0
                  .byte $10
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  
TabMelody08       .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $05
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $05
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $0c
                  .byte $ff
                  .byte $b0
                  .byte $05
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $0e
                  .byte $ff
                  .byte $b0
                  .byte $05
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $10
                  .byte $ff
                  .byte $b0
                  .byte $05
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $05
                  .byte $00
                  .byte $00
                  .byte $a0
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $05
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $0c
                  .byte $ff
                  .byte $a0
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $0e
                  .byte $ff
                  .byte $b0
                  .byte $05
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $0b
                  .byte $ff
                  .byte $b0
                  .byte $05
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $b0
                  .byte $10
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  
TabMelody03       .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $0c
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $d0
                  .byte $08
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $02
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $02
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $10
                  .byte $ff
                  .byte $d0
                  .byte $08
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $02
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $02
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $0c
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $0c
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $06
                  .byte $07
                  .byte $ff
                  .byte $d0
                  .byte $06
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $06
                  .byte $07
                  .byte $ff
                  .byte $70
                  .byte $06
                  .byte $07
                  .byte $ff
                  .byte $50
                  .byte $10
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  
TabMelody00       .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $02
                  .byte $13
                  .byte $10
                  .byte $d0
                  .byte $06
                  .byte $13
                  .byte $10
                  .byte $a0
                  .byte $08
                  .byte $11
                  .byte $0e
                  .byte $a0
                  .byte $06
                  .byte $10
                  .byte $0c
                  .byte $a0
                  .byte $02
                  .byte $10
                  .byte $0c
                  .byte $40
                  .byte $08
                  .byte $10
                  .byte $0c
                  .byte $a0
                  .byte $08
                  .byte $11
                  .byte $0e
                  .byte $a0
                  .byte $06
                  .byte $10
                  .byte $0c
                  .byte $a0
                  .byte $02
                  .byte $10
                  .byte $0c
                  .byte $40
                  .byte $08
                  .byte $0e
                  .byte $07
                  .byte $a0
                  .byte $08
                  .byte $10
                  .byte $0c
                  .byte $a0
                  .byte $06
                  .byte $0e
                  .byte $07
                  .byte $a0
                  .byte $02
                  .byte $0e
                  .byte $07
                  .byte $40
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $d0
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $b0
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $a0
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $90
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $80
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $70
                  .byte $08
                  .byte $0e
                  .byte $07
                  .byte $a0
                  .byte $08
                  .byte $10
                  .byte $0c
                  .byte $a0
                  .byte $06
                  .byte $0e
                  .byte $07
                  .byte $a0
                  .byte $02
                  .byte $0e
                  .byte $07
                  .byte $40
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $d0
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $b0
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $a0
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $90
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $80
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $70
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $60
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $50
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $40
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $30
                  .byte $08
                  .byte $0e
                  .byte $07
                  .byte $20
                  .byte $10
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  
TabMelody04       .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $18
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $15
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $11
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $0e
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $11
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $0e
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $0c
                  .byte $ff
                  .byte $a0
                  .byte $0c
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $02
                  .byte $18
                  .byte $ff
                  .byte $a0
                  .byte $02
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $02
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $0c
                  .byte $ff
                  .byte $a0
                  .byte $10
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  
TabMelody07       .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $18
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $17
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $16
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $15
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $14
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $12
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $11
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $0f
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $0e
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $0d
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $0c
                  .byte $ff
                  .byte $a0
                  .byte $0c
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $02
                  .byte $0c
                  .byte $ff
                  .byte $a0
                  .byte $02
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $02
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $18
                  .byte $ff
                  .byte $a0
                  .byte $10
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  
TabMelody01       .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $18
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $18
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $15
                  .byte $ff
                  .byte $d0
                  .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $02
                  .byte $11
                  .byte $ff
                  .byte $a0
                  .byte $02
                  .byte $11
                  .byte $ff
                  .byte $80
                  .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $02
                  .byte $11
                  .byte $ff
                  .byte $a0
                  .byte $02
                  .byte $11
                  .byte $ff
                  .byte $80
                  .byte $0c
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $12
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $15
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $1f
                  .byte $0f
                  .byte $a0
                  .byte $04
                  .byte $15
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $12
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $15
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $1f
                  .byte $0f
                  .byte $a0
                  .byte $04
                  .byte $15
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $17
                  .byte $ff
                  .byte $d0
                  .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $02
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $02
                  .byte $13
                  .byte $ff
                  .byte $80
                  .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $02
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $02
                  .byte $13
                  .byte $ff
                  .byte $80
                  .byte $10
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  
TabMelody0a       .byte $00
; ------------------------------------------------------------------------------------------------------------- ;
