; ------------------------------------------------------------------------------------------------------------- ;
; Lode Runner - IT.PRG from $6000 to $B801
; ------------------------------------------------------------------------------------------------------------- ;
; Memory Map
; ------------------------------------------------------------------------------------------------------------- ;
; $0000 - $00ff:  Zero Page Values
; $0200 - $02ff:  <not used>
; $0300 - $03ff:  <not used>
; $0400 - $04f7:  Multi Color Screen
; $04f8 - $04ff:  Sprite Pointers
; $0800 - $09c3:  expanded level data row pointer
; $0a00 - $0bc3:  expanded level data row pointer - play level control
; $0c00 - $0cff:  Sprite Store 01
; $0d00 - $0dff:  Sprite Store 02
; $0e00 - $0ec7:  Tab Offsets HiRes Lo
; $0f00 - $0fc7:  Tab Offsets HiRes Hi
; $1000 - $10ff:  Level Data Save/Load
; $1100 - $11ff:  High Score Save/Load
; $1200 - $12ff:  Tables for Dynamic Value
; $1300 - $133b:  In Game Variables
; $1400 - $1fff:  Data Start Graphic
; $2000 - $3fff:  HighRes Display Screen
; $4000 - $5fff:  HighRes Prepare Screen
; $c000 - $c0ff:  Tunes Play Time
; $c100 - $c1ff:  Tunes Data Ptr Voice 2
; $c200 - $c2ff:  Tunes Data Ptr Voice 3
; $c300 - $c3ff:  Tunes Sustain/Release/Volume (not used)
; $c800 - $c8ff:  High Score Work Old
; $c900 - $c9ff:  High Score Work New
; $b100 - $b1c8:  Demo Move Data  Level 01
; $b1d0 - $b2c3:  Demo Move Data  Level 02
; $b2c4 - $b367:  Demo Move Data  Level 03
; $b300 - $b3ff:
; $b400 - $b4ff:
; $b500 - $b5ff:  Data Demo Level 01
; $b600 - $b6ff:  Data Demo Level 02
; $b700 - $b7ff:  Data Demo Level 03
; ------------------------------------------------------------------------------------------------------------- ;
                  * = $6000                       ; Start address
; ------------------------------------------------------------------------------------------------------------- ;
; compiler settings                                                                                             ;
; ------------------------------------------------------------------------------------------------------------- ;
                  incdir   ..\..\inc      

C64CIA1           include  cia1.asm               ; Complex Interface Adapter (CIA) #1 Registers  $DC00-$DC0F
C64CIA2           include  cia2.asm               ; Complex Interface Adapter (CIA) #2 Registers  $DD00-$DD0F
C64SID            include  sid.asm                ; Sound Interface Device (SID) Registers        $D400-$D41C
C64VicII          include  vic.asm                ; Video Interface Chip (VIC-II) Registers       $D000-$D02E
C64Kernel         include  kernel.asm             ; Kernel Vectors
C64Colors         include  color.asm              ; Colour RAM Address / Colours
;
InGameVars        include  inc\LR_Vars.asm        ; Game Variables
InZeroPageVars    include  inc\LR_Zpg.asm         ; Zero Page Variables
; ------------------------------------------------------------------------------------------------------------- ;
Start             lda #$00
                  sta LR_Volume
                  jsr GameInitOnce

                  nop                             ; jsr S_8e11 - CopyProt  ==> obsolete
                  nop
                  nop

                  lda #LR_DiskRead
                  jsr GetPutHiScores              ; Target: $1100-$11ff

ColdStart         lda #$ff
                  sta LR_Volume
                  sta LR_FallsDown                ; $00=fall $20=no fall $ff=init
                  sta LR_DeathTune
                  sta LR_ShootMode
                  sta LR_StartCycle               ; ==> $ff=on $00=off

                  lda #$00
                  sta LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  sta LR_PtrTuneToPlay
                  sta LR_Shoots                   ; $00=no $01=right $ff=left
                  sta LR_DeathTune
                  sta LR_KeyNew
                  sta LR_KeyOld
                  sta LR_SprtPosCtrl

                  lda #>LR_LvlDataSavLod          ; $10 - Target: $1000-$10ff
                  sta Mod__GetDiskByte            ; adapt ReadDiskData  command
                  sta Mod__PutDiskByte            ; adapt WriteDiskData command
                  sta LR_Random                   ; last valid RND beam pos

                  lda $c5                         ; key value
                  sta LR_KeyOld
                  lda #$40                        ; reset: $40=no key pressed
                  sta $c5                         ; key value

                  lda #LR_SpeedNormal             ; wait 5 interupts before next move  (normal speed)
                  sta LR_GameSpeed
                  lda #LR_Joystick
                  sta LR_ControllerTyp

                  lda #LR_GameStart
                  sta LR_GameCtrl                 ; $00=start $01=demo $02=game $03=play_level $05=edit
                  jmp StartGraficOut
; ------------------------------------------------------------------------------------------------------------- ;
GameStart         lda #$00
                  sta LR_ScoreLo
                  sta LR_ScoreMidLo
                  sta LR_ScoreMidHi
                  sta LR_ScoreHi
                  sta LR_CntSpeedLaps
                  sta LR_CtrlCircle
                  sta LR_EnmyBirthCol             ; pointer: enemy rebirth column
                  sta $58

                  sta $55                         ; ==> needs update for low value - not moveable
                  lda #>TabMoveDemoLvl01
                  sta $56                         ; ($55/$56) -> DemoMoveData L1=$b100-$b1c8 L2=$b1d0-$b2c3 L3=$b2c4-

                  sta LR_LvlReload

                  lda #LR_NumLivesInit
                  sta LR_NumLives
                  lda #>LR_ScrnHiReDisp           ; $20
                  sta $51                         ; target output  $20=$2000 $40=$4000
                  jsr MelodyInit
                  jsr ClearAllScreens

                  lda #LR_CyanRed
                  jsr SetMultiColors
; ------------------------------------------------------------------------------------------------------------- ;
LevelStart        ldx #$01                        ; force new copy
                  jsr InitLevel

                  sta LR_PtrTuneToPlay
                  sta LR_PtrNxtTunePos            ; pointer: next free tune buffer byte

                  lda #LR_CircleOn
                  sta LR_CtrlCircle
                  ldy LR_EnmyNo                   ; number of enemies
                  lda TabEnmyEnab,y
                  sta SPENA                       ; VIC 2 - $D015 = Sprite Enable

                  lda #$00
                  sta LR_JoyUpDo
                  sta LR_JoyLeRi

                  lda LR_GameCtrl                 ; $00=start $01=demo $02=game $03=play_level $05=edit
                  lsr a
                  beq MainLoopInit

WaitUser          lda SPENA                       ; VIC 2 - $D015 = Sprite Enable
                  and #$fe                        ;   switch off sprite 1
                  sta SPENA                       ; VIC 2 - $D015 = Sprite Enable

                  ldy #$90                        ; waittime
                  ldx #$00
WaitUserLrBlack   dex                             ; black lode runner
                  jsr ChkUserAction
                  bcs MainLrWhite                 ; user pressed something

                  bne WaitUserLrBlack
                  dey
                  bne WaitUserLrBlack

                  lda SPENA                       ; VIC 2 - $D015 = Sprite Enable
                  ora #$01                        ;   switch on sprite 1
                  sta SPENA                       ; VIC 2 - $D015 = Sprite Enable

                  ldy #$90                        ; waittime
                  ldx #$00
WaitUserLrWhite   dex                             ; white lode runner
                  jsr ChkUserAction
                  bcs MainLrWhite                 ; user pressed something

                  bne WaitUserLrWhite
                  dey
                  bne WaitUserLrWhite

                  jmp WaitUser                    ; flicker player sprite 00 meanwhile

MainLrWhite       lda SPENA                       ; VIC 2 - $D015 = Sprite Enable
                  ora #$01                        ;   switch on sprite 1
                  sta SPENA                       ; VIC 2 - $D015 = Sprite Enable
; ------------------------------------------------------------------------------------------------------------- ;
MainLoopInit      ldx #LR_ShootsNo
                  stx LR_Shoots                   ; $00=no $01=right $ff=left
                  
                  lda LR_CntSpeedLaps             ; lap counter for speed up
                  clc
                  adc LR_EnmyNo                   ; number of enemies
                  tay
                  
                  ldx TabOffEnmyCycles,y          ; offsets enemy move cycles tab
                  lda TabEnmyCycles1,x            ; enemy move cycles tab
                  sta $32
                  lda TabEnmyCycles2,x            ; enemy move cycles tab + 1
                  sta $33
                  lda TabEnmyCycles3,x            ; enemy move cycles tab + 2
                  sta $34

                  ldy LR_CntSpeedLaps             ; lap counter for speed up
                  lda TabEnmyHoleTime,y           ; time in hole tab
                  sta LR_EnmyHoleTime             ; enemy time in hole
; ------------------------------------------------------------------------------------------------------------- ;
; The Main Loop
; ------------------------------------------------------------------------------------------------------------- ;
MainLoop          jsr MoveLodeRunner
                  lda LR_Alive
_ChkLRAccident    beq LrDeath                     ; lr accident

_ChkGold4Tune     lda LR_GoldToGet
                  bne _ChkLrPos                   ; some gold left

_Victory          jsr VictoryTuneCopy             ; prepare melody
                  jsr ShowExitLadders             ; display exit ladders

_ChkLrPos         lda $04                         ; actual row lode runner
                  bne _GoCloseHoles               ; not on top of the screen

                  lda $06                         ; lr pos on image up/down
                  cmp #$02                        ; $02=center of screen image
                  bne _GoCloseHoles

_ChkGold4Finish   lda LR_GoldToGet                ; fully on top of the screen and
                  beq LevelComplete               ; got all gold
                  cmp #$ff
                  beq LevelComplete               ; got all gold plus one

_GoCloseHoles     jsr CloseHoles
                  lda LR_Alive
_ChkLRTrapped     beq LrDeath                     ; lr trapped

_MveEnemies       jsr MoveEnemies
                  lda LR_Alive
_ChkLRCaught      beq LrDeath                     ; lr caught

_Delay            lda LR_CountIRQs                ; slow down game speed
                  cmp LR_GameSpeed
                  bcc _Delay

_SetWait          lda #LR_IRQsDflt                ; reinit wait cycle time
                  sta LR_CountIRQs
                  
MainLoopX         jmp MainLoop                    ; next round
; ------------------------------------------------------------------------------------------------------------- ;
LevelComplete     inc LR_LevelNoGame              ; 001-150
                  inc LR_LevelNoDisk              ; 000-149
_FinishTunes      lda LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  cmp LR_PtrTuneToPlay
                  bne _FinishTunes

                  jsr SetNextMelody

                  inc LR_NumLives
                  bne _ScoreTuneI
                  dec LR_NumLives                 ; max $ff

_ScoreTuneI       lda #LR_SoreValSub              ; init score tune subtraction value
                  sta $2f
                  sei                             ; not to be interrupted
                  
_ScoreTuneNext    lda #LR_SoreValStart
                  sec
                  sbc $2f
                  sta FREHI1                      ; SID - $D401 = Oscillator 1 Frequency Control (High Byte)
                  ldy #$2c
_ScoreTuneSetX    ldx #$00
_ScoreTuneWaitX   dex
                  bne _ScoreTuneWaitX
                  
                  dey
                  bne _ScoreTuneSetX
                  
                  sty FREHI1                      ; SID - $D401 = Oscillator 1 Frequency Control (High Byte)
                  tya
                  iny
                  jsr ScoreToBaseLine             ; score increases whilst the
                  
                  dec $2f                         ; tune gets higher and higher
                  bpl _ScoreTuneNext
                  
                  cli                             ; let interrupts happen again
GoLevelStart      jmp LevelStart
; ------------------------------------------------------------------------------------------------------------- ;
LrDeath           dec LR_NumLives
                  lda LR_GameCtrl                 ; $00=start $01=demo $02=game $03=play_level $05=edit
                  lsr a
                  bne LrDeathTuneI

                  jmp GameVolume
; ------------------------------------------------------------------------------------------------------------- ;
LrDeathTuneI      lda #LR_DeathTuneVal
                  sta LR_DeathTune
_WaitGameTuneX    lda LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  cmp LR_PtrTuneToPlay
                  bne _WaitGameTuneX              ; wait for all in game tunes to be finished

                  lda #LR_ShootsNo
                  sta LR_Shoots                   ; $00=no $01=right $ff=left
                  lda #LR_FallsNo
                  sta LR_FallsDown                ; $00=fall $20=no fall $ff=init
                  jsr LivesToBaseLine

_WaitDeathTuneX   lda LR_DeathTune
                  bne _WaitDeathTuneX

                  lda LR_NumLives
                  bne GoLevelStart
; ------------------------------------------------------------------------------------------------------------- ;
GameOver          jsr ChkNewHighScore
                  jsr FlipGmeOverSign

WaitForDemoI      ldx #$ff                        ; set wait counter 1/2 values
                  ldy #$ff
                  bcs WaitForDemo

                  lda #$00
                  sta LR_KeyNew
WaitForDemo       lda #$03
                  sta $50                         ; set wait counter 3 value

WaitForDemoUser   lda CIAPRA                      ; CIA 1 - $DC00 = Data Port A
                  and #$10                        ; bit4=fire  bit3=right  bit2=left  bit1=down  bit0=up
                  beq GameStartInit               ; fire button pressed

                  lda LR_KeyNew
                  cmp #$8e                        ; "E"
                  bne WaitForDemoKey

                  jmp LrBoardEditor

WaitForDemoKey    cmp #$01                        ; ENTER
                  beq GoHighScores

                  lda LR_KeyNew
                  bne GameStartInit

                  dex                             ; count down first  wait time part
                  bne WaitForDemoUser
                  dey                             ; count down second wait time part
                  bne WaitForDemoUser
                  dec $50                         ; count down third  wait time part
                  bne WaitForDemoUser

                  lda LR_GameCtrl                 ; $00=start $01=demo $02=game $03=play_level $05=edit
                  bne DemoHighScores

                  ldx #LR_GameDemo
                  stx LR_GameCtrl                 ; $00=start $01=demo $02=game $03=play_level $05=edit
                  stx LR_LevelNoGame              ; 001-150
                  stx $59
                  stx LR_Cheated                  ; $01=no

                  ldx LR_Volume
                  stx M_SetVolume
                  lda #$00
                  sta LR_Volume
                  sta LR_LevelNoDisk              ; 000-149
                  jmp GameStart
; ------------------------------------------------------------------------------------------------------------- ;
GameVolume        lda #$00                        ; *modified
M_SetVolume       = *-1
                  sta LR_Volume
                  jmp WaitForDemoI
; ------------------------------------------------------------------------------------------------------------- ;
DemoHighScores    cmp #LR_GameDemo                ; demo
                  bne DemoStartGraphic

GoHighScores      jsr ShowHighScores

                  lda #LR_GameGame
                  sta LR_GameCtrl                 ; $00=start $01=demo $02=game $03=play_level $05=edit
                  clc
                  jmp WaitForDemoI
; ------------------------------------------------------------------------------------------------------------- ;
DemoStartGraphic  lda #LR_GameStart
                  sta LR_LevelNoDisk              ; 000-149
                  sta LR_GameCtrl                 ; $00=start $01=demo $02=game $03=play_level $05=edit
                  jmp StartGraficOut
; ------------------------------------------------------------------------------------------------------------- ;
GameStartInit     ldx #LR_LevelDiskMin
                  stx LR_LevelNoDisk              ; 000-149
                  inx
                  stx LR_LevelNoGame              ; 001-150
                  stx LR_Cheated                  ; $01=no
                  lda #LR_GameGame
                  sta LR_GameCtrl                 ; $00=start $01=demo $02=game $03=play_level $05=edit
                  lda #LR_VolumeMax
                  sta LR_Volume
                  jmp GameStart
; ------------------------------------------------------------------------------------------------------------- ;
TabOffEnmyCycles  .byte $00
                  .byte $03
                  .byte $06
                  .byte $09
                  .byte $0c
                  .byte $0f
                  .byte $12
                  .byte $15
                  .byte $18
                  .byte $1b
                  .byte $1e
; ------------------------------------------------------------------------------------------------------------- ;
TabEnmyHoleTime   .byte $26
                  .byte $26
                  .byte $2e
                  .byte $44
                  .byte $47
                  .byte $49
                  .byte $4a
                  .byte $4b
                  .byte $4c
                  .byte $4d
                  .byte $4e
                  .byte $4f
                  .byte $50
                  .byte $51
                  .byte $52
                  .byte $53
                  .byte $54
                  .byte $55
                  .byte $56
                  .byte $57
                  .byte $58
; ------------------------------------------------------------------------------------------------------------- ;
StartGraficOut    jsr ClearHiresDisp

                  lda #LR_BlackBlack
                  jsr SetMultiColors

                  lda SCROLY                      ; VIC 2 - $D011 = VIC Control Register 1
                  ora #$20
                  sta SCROLY                      ; VIC 2 - $D011 = VIC Control Register 1
                  lda VMCSB                       ; VIC 2 - $D018 = Chip Memory Control
                  and #$f0                        ; chr generator to video base + 2000-3fff
                  ora #$08
                  sta VMCSB                       ; VIC 2 - $D018 = Chip Memory Control
                  ldy #$00
_ColourReg01      lda #$60                        ; BLUE
                  sta LR_ScrnMultColor+$0000,y
                  sta LR_ScrnMultColor+$0018,y
                  lda #$10                        ; WHITE
                  sta LR_ScrnMultColor+$0168,y
                  dey
                  bne _ColourReg01

                  ldy #$50                        ; amount
_ColourReg02      lda #LR_RedBlack
                  sta LR_ScrnMultColor+$0118,y
                  sta LR_ScrnMultColor+$0258,y
                  lda #LR_WhiteBlack
                  sta LR_ScrnMultColor+$02d0,y
                  lda #LR_BlueBlack
                  sta LR_ScrnMultColor+$0348,y
                  dey
                  bpl _ColourReg02

                  lda SCROLX                      ; VIC 2 - $D016 = Control Register 2 (and Horizontal Fine Scrolling)
                  and #$ef
                  sta SCROLX                      ; VIC 2 - $D016 = Control Register 2 (and Horizontal Fine Scrolling)
_CopyDataI        lda #<LR_StartGfx
                  sta $0f
                  lda #>LR_StartGfx
                  sta $10                         ; ($0f/$10) -> graphic data start  address
                  lda #<(LR_ScrnHiReDisp-1)
                  sta $0d
                  lda #>(LR_ScrnHiReDisp-1)
                  sta $0e                         ; ($0d/$0e) -> graphic data target address
_GetData          ldy #$00
                  lda ($0f),y
                  sta $1e                         ; first  byte is counter
                  iny
                  lda ($0f),y
                  sta $1f                         ; second byte is data
                  lda $0f
                  clc
                  adc #$02                        ; set pointer to next pair of data
                  sta $0f
                  bcc _SetCounter

                  inc $10
_SetCounter       lda $1e
                  tay
                  lda $1f
_CopyData         sta ($0d),y
                  dey
                  bne _CopyData

                  lda $0d                         ; set next target pos
                  clc
                  adc $1e
                  sta $0d
                  bcc _ChkEnd

                  inc $0e
_ChkEnd           lda $0e
                  cmp #$3f
                  bcc _GetData

StartGraficOutX   jmp WaitForDemoI
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
IRQ_PlaySounds    ldx LR_PtrTuneToPlay
                  cpx LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  beq IRQ_SoundsReset             ; all tunes completed

                  lda #$11                        ; triangle wave/start ADS
                  sta LR_WaveVoice2
                  sta LR_WaveVoice3
                  lda LR_TuneSuReVol,x            ; tune s/r/volume  (not used)
                  lda #$f0
                  and LR_Volume
                  sta SUREL2                      ; SID - $D40D = Oscillator 2 Sustain/Release
                  sta SUREL3                      ; SID - $D414 = Oscillator 3 Sustain/Release
                  lda LR_TuneDataPtrV2,x          ; tab tune data pointer voice 2
                  bne _Voice02

                  sta LR_WaveVoice2
_Voice02          tay
                  lda TabVocsFreqDatLo,y
                  sta FRELO2                      ; SID - $D407 = Oscillator 2 Frequency Control (Low Byte)
                  lda TabVocsFreqDatHi,y
                  sta FREHI2                      ; SID - $D408 = Oscillator 2 Frequency Control (High Byte)
                  lda LR_TuneDataPtrV3,x          ; tab tune data pointer voice 3
                  bpl _ChkVoice03

                  lda LR_TuneDataPtrV2,x          ; tab tune data pointer voice 2
                  tay
                  sec
                  lda TabVocsFreqDatLo,y
                  sbc #$80
                  sta FRELO3                      ; SID - $D40E = Oscillator 3 Frequency Control (Low Byte)
                  lda TabVocsFreqDatHi,y
                  sbc #$00
                  sta FREHI3                      ; SID - $D40F = Oscillator 3 Frequency Control (High Byte)
                  jmp _PlayTune

_ChkVoice03       bne _Voice03

                  sta LR_WaveVoice3
_Voice03          tay
                  lda TabVocsFreqDatLo,y
                  sta FRELO3                      ; SID - $D40E = Oscillator 3 Frequency Control (Low Byte)
                  lda TabVocsFreqDatHi,y
                  sta FREHI3                      ; SID - $D40F = Oscillator 3 Frequency Control (High Byte)
_PlayTune         lda LR_WaveVoice2
                  sta VCREG2                      ; SID - $D40B = Oscillator 2 Control
                  lda LR_WaveVoice3
                  sta VCREG3                      ; SID - $D412 = Oscillator 3 Control
_DecTime          dec LR_TunePlayTime,x           ; tab tune times
                  bne IRQ_PlaySoundsX             ; not completed yet

                  inc LR_PtrTuneToPlay            ; next tune to play

IRQ_PlaySoundsX   rts
; ------------------------------------------------------------------------------------------------------------- ;
IRQ_SoundsReset   lda #$00
                  sta VCREG2                      ; SID - $D40B = Oscillator 2 Control
                  sta VCREG3                      ; SID - $D412 = Oscillator 3 Control
                  
IRQ_SoundsResetX  rts
; ------------------------------------------------------------------------------------------------------------- ;
; SetTune         Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
SetTune           pla                             ; played during IRQ
                  sta $7d
                  pla
                  sta $7e                         ; ($7d/$7e) ptr melody data
                  bne _SetNext

_CpyTune          sei
                  ldy #$00
                  lda ($7d),y
                  beq _PrepareXit

                  ldx LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  sta LR_TunePlayTime,x           ; tab tune times
                  iny
                  lda ($7d),y
                  sta LR_TuneDataPtrV2,x          ; tab tune data pointer voice 2
                  iny
                  lda ($7d),y
                  sta LR_TuneDataPtrV3,x          ; tab tune data pointer voice 3
                  iny
                  lda ($7d),y
                  sta LR_TuneSuReVol,x            ; tune s/r/volume  (not used)
                  inc LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  lda $7d
                  clc
                  adc #$04                        ; tune entry length $04
                  sta $7d
                  lda $7e
                  adc #$00
                  sta $7e
                  bne _CpyTune

_SetNext          inc $7d
                  bne _CpyTune
                  inc $7e
                  bne _CpyTune

_PrepareXit       lda $7e                         ; point behind melody data
                  pha
                  lda $7d
                  pha
                  cli
SetTuneX          rts
; ------------------------------------------------------------------------------------------------------------- ;
; Randomizer      Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
Randomizer        sta LR_RandomAc                 ; save accumulator
_GetBeam          lda RASTER                      ; VIC 2 - $D012 = Read: Raster Scan Line/ Write: Line for Raster IRQ
                  sta LR_RasterBeamPos
                  cpx LR_RasterBeamPos
                  bcc _ChkBeam
                  beq _ChkBeam
                  jmp _GetBeam

_ChkBeam          cpy LR_RasterBeamPos
                  bcc _GetBeam

                  sec
                  sbc LR_Random
                  bcs _ChkAc

                  eor #$ff
                  adc #$01
_ChkAc            cmp LR_RandomAc
                  bcc _GetBeam

                  lda LR_RasterBeamPos
                  sta LR_Random
RandomizerX       rts
; ------------------------------------------------------------------------------------------------------------- ;
; MelodyInit      Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
MelodyInit        lda MelodyMaxNo
                  sta LR_MelodyNo
                  lda MelodyMinHight
                  sta LR_MelodyHeight
MelodyInitX       rts
; ------------------------------------------------------------------------------------------------------------- ;
; SetNextMelody   Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
SetNextMelody     dec LR_MelodyNo
                  bpl SetNextMelodyX

                  inc LR_MelodyHeight
                  lda LR_MelodyHeight
                  cmp MelodyMaxHight
                  bcc _GetMax

                  lda MelodyMinHight
                  sta LR_MelodyHeight
_GetMax           lda MelodyMaxNo
                  sta LR_MelodyNo
SetNextMelodyX    rts
; ------------------------------------------------------------------------------------------------------------- ;
; VictoryTuneCopy Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
VictoryTuneCopy   lda LR_MelodyNo
                  asl a
                  tax
                  lda TabMelodyPtr,x
                  sta $7d
                  lda TabMelodyPtr+1,x
                  sta $7e                         ; ($7d/$7e) -> melody data
_CpyTune          sei
                  ldy #$00
                  lda ($7d),y
                  beq _PrepXit

                  ldx LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  sta LR_TunePlayTime,x           ; tab tune times
                  iny
                  lda ($7d),y
                  beq _Voice01

                  clc
                  adc LR_MelodyHeight
_Voice01          sta LR_TuneDataPtrV2,x          ; tab tune data pointer voice 2
                  iny
                  lda ($7d),y
                  beq _Voice02
                  bmi _Voice02

                  clc
                  adc LR_MelodyHeight
_Voice02          sta LR_TuneDataPtrV3,x          ; tab tune data pointer voice 3
                  iny
                  lda ($7d),y
                  sta LR_TuneSuReVol,x            ; tune s/r/volume  (not used)
                  inc LR_PtrNxtTunePos            ; pointer: next free tune buffer byte
                  lda $7d
                  clc
                  adc #$04
                  sta $7d
                  lda $7e
                  adc #$00
                  sta $7e
                  bne _CpyTune

_PrepXit          cli
VictoryTuneCopyX  rts
; ------------------------------------------------------------------------------------------------------------- ;
IRQ               inc LR_CountIRQs
                  lda #$00
                  sta $7c                         ; tune value voice 1
                  lda LR_Volume
                  and #$0f
                  sta SIGVOL                      ; SID - $D418 = Volume and Filter Select
                  lda LR_FallsDown                ; $00=fall $20=no fall $ff=init
                  bne _BeepInit

                  ldx LR_FallBeep
                  stx $7c                         ; tune value voice 1
                  jmp _ChkShoot

_BeepInit         lda #LR_FallBeepIni             ; fall beep start value
                  sta LR_FallBeep
_ChkShoot         lda LR_Shoots                   ; $00=no $01=right $ff=left
                  beq _ShootInit

                  lda LR_ShootSound
                  sec
                  sbc #LR_ShootSoundSub
                  sta LR_ShootSound
                  sta $7c                         ; tune value voice 1
                  beq _ShootInit

                  jmp _ChkDeath

_ShootInit        lda #LR_ShootSoundIni
                  sta LR_ShootSound
_ChkDeath         lda LR_DeathTune
                  beq _SetTune

                  sec
                  sbc #LR_DeathTuneSub
                  sta $7c                         ; tune value voice 1
                  sta LR_DeathTune
                  
_SetTune          lda $7c                         ; tune value voice 1
                  sta FREHI1                      ; SID - $D401 = Oscillator 1 Frequency Control (High Byte)
                  jsr IRQ_PlaySounds

                  lda $c5                         ; key value
                  bne _ChkKey

                  lda #$07
_ChkKey           cmp #$40
                  bne _ChkKeyFlag

                  lda #$00
                  sta LR_KeyOld
                  jmp C64_IRQ

_ChkKeyFlag       ldx C64_KeyFlag                 ; $01=shift $02=commodore $04=ctrl
                  beq _ChkKeyOld

                  ora #$80
_ChkKeyOld        cmp LR_KeyOld
                  beq IRQ_X

                  sta LR_KeyOld
                  sta LR_KeyNew
IRQ_X             jmp C64_IRQ                     ; system
; ------------------------------------------------------------------------------------------------------------- ;
; GameInitOnce    Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
GameInitOnce      lda $01
                  and #$fe                        ; basic off
                  sta $01

                  lda #$00
                  sta $1e
                  lda #$00                        ; ==> obsolete
                  sta $1f

                  ldy #$00
                  lda #$19                        ; 25
                  sta LR_Counter
_GetAmount        ldx #$08
_GetValue         lda $1f
                  sta LR_TabOffHiresHi,y          ; offset grafic output high
                  lda $1e
                  sta LR_TabOffHiresLo,y          ; offset grafic output low
                  inc $1e
                  iny
                  dex
                  bne _GetValue

                  clc
                  adc #$39
                  sta $1e
                  lda $1f
                  adc #$01
                  sta $1f
                  
                  dec LR_Counter
                  bne _GetAmount

                  lda #<NMI
                  sta C64_PtrNMI
                  lda #>NMI
                  sta C64_PtrNMI+1                ; point NMI vector to rti
                  jsr ClearHiresDisp

                  lda #BLACK
                  sta BGCOL0                      ; VIC 2 - $D021 = BackGround Color 0
                  sta EXTCOL                      ; VIC 2 - $D020 = Border Color
                  sei
                  lda #<IRQ
                  sta C64_PtrIRQ
                  lda #>IRQ
                  sta C64_PtrIRQ+1                ; IRQ vector
                  cli
                  lda #$b0
                  sta SUREL1                      ; SID - $D406 = Oscillator 1 Sustain/Release
                  lda #$11
                  sta VCREG1                      ; SID - $D404 = Oscillator 1 Control

                  ldx #$30                        ; $30*$40=$0c00
                  stx LR_SpritePtr00              ; sprite 0 data at $0c00
                  inx
                  stx LR_SpritePtr02              ; sprite 2 data at $0c40
                  inx
                  stx LR_SpritePtr03              ; sprite 3 data at $0c80
                  inx
                  stx LR_SpritePtr04              ; sprite 4 data at $0cc0
                  inx
                  stx LR_SpritePtr06              ; sprite 6 data at $0d00
                  inx
                  stx LR_SpritePtr07              ; sprite 7 data at $0d40

                  lda #CYAN
                  ldy #$07
_EnemyColor       sta SP0COL,y                    ; VIC 2 - $D027 = Color Sprite 0
                  dey
                  bne _EnemyColor

                  iny                             ; WHITE
                  sty SP0COL                      ; VIC 2 - $D027 = Color Sprite 0
                  lda #$00
                  sta SPBGPR                      ; VIC 2 - $D01B = Sprite to Foreground Priority
                  tay
_Clear            sta $0002,y                     ; ==> zero page
                  sta LR_SpriteStore01,y          ; sprite data store $0c00
                  sta LR_SpriteStore02,y          ; sprite data store
                  iny
                  bne _Clear

                  lda #$ff
                  sta SPENA                       ; VIC 2 - $D015 = Sprite Enable
GameInitOnceX     rts
; ------------------------------------------------------------------------------------------------------------- ;
; SetMultiColors  Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
SetMultiColors    sta M_MultiColors
                  lda SCROLX                      ; VIC 2 - $D016 = Control Register 2 (and Horizontal Fine Scrolling)
                  ora #$10
                  sta SCROLX                      ; VIC 2 - $D016 = Control Register 2 (and Horizontal Fine Scrolling)
                  ldy #$00

GetMultiColors    lda #LR_OrangeBlue              ; modified colors
M_MultiColors     = *-1
                  sta LR_ScrnMultColor+$0000,y
                  sta LR_ScrnMultColor+$0100,y
                  sta LR_ScrnMultColor+$0200,y
                  sta LR_ScrnMultColor+$02f8,y
                  lda #WHITE
                  sta COLORAM+$0000,y
                  sta COLORAM+$0100,y
                  sta COLORAM+$0200,y
                  sta COLORAM+$0300,y
                  dey
                  bne GetMultiColors

SetMultiColorsX   rts
; ------------------------------------------------------------------------------------------------------------- ;
NMI               rti
; ------------------------------------------------------------------------------------------------------------- ;
TabEnmyEnab       .byte $01                       ; .......#
                  .byte $05                       ; .....#.#
                  .byte $0d                       ; ....##.#
                  .byte $1d                       ; ...###.#
                  .byte $5d                       ; .#.###.#
                  .byte $dd                       ; ##.###.#
; ------------------------------------------------------------------------------------------------------------- ;
LrBoardEditor     lda #$00
                  sta LR_ScoreLo
                  sta LR_ScoreMidLo
                  sta LR_ScoreMidHi
                  sta LR_ScoreHi
                  lda #$ff                        ; force level reload
                  sta LR_LvlReload
                  lda #LR_NumLivesInit
                  sta LR_NumLives
                  sta LR_GameCtrl                 ; $00=start $01=demo $02=game $03=play_level $05=edit
                  sta LR_SprtPosCtrl
                  lda LR_ControllerTyp
                  sta M_ControllerTyp
                  lda #LR_Keyboard
                  sta LR_ControllerTyp
                  lda LR_LevelNoDisk              ; 000-149
                  cmp #LR_LevelDiskMax+1          ; 150
                  bcc GoClearScrnDisp             ; lower - clear hires display screen

                  lda #LR_LevelDiskMin
                  sta LR_LevelNoDisk              ; 000-149
GoClearScrnDisp   jsr ClearHiresDisp

                  lda #LR_YellowCyan              ; YELLOW/CYAN
                  jsr SetMultiColors

                  lda #>LR_ScrnHiReDisp           ; $20
                  sta $51                         ; target output  $20=$2000 $40=$4000
                  lda #$00
                  sta LR_KeyNew
                  sta $4f                         ; screen col  (00-1b)
                  sta $50                         ; screen row  (00-0f)
                  jsr TextOut
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $cc ; L
                  .byte $cf ; O
                  .byte $c4 ; D
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $d2 ; R
                  .byte $d5 ; U
                  .byte $ce ; N
                  .byte $ce ; N
                  .byte $c5 ; E
                  .byte $d2 ; R
                  .byte $a0 ; <blank>
                  .byte $c2 ; B
                  .byte $cf ; O
                  .byte $c1 ; A
                  .byte $d2 ; R
                  .byte $c4 ; D
                  .byte $a0 ; <blank>
                  .byte $c5 ; E
                  .byte $c4 ; D
                  .byte $c9 ; I
                  .byte $d4 ; T
                  .byte $cf ; O
                  .byte $d2 ; R
                  .byte $8d ; <nl>
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $8d ; <nl>
                  .byte $a0 ; <blank>
                  .byte $d2 ; R
                  .byte $af ; /
                  .byte $d3 ; S
                  .byte $a0 ; <blank>
                  .byte $cb ; K
                  .byte $c5 ; E
                  .byte $d9 ; Y
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $c2 ; B
                  .byte $cf ; O
                  .byte $d2 ; R
                  .byte $d4 ; T
                  .byte $d3 ; S
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $ce ; N
                  .byte $d9 ; Y
                  .byte $a0 ; <blank>
                  .byte $c3 ; C
                  .byte $cf ; O
                  .byte $cd ; M
                  .byte $cd ; M
                  .byte $c1 ; A
                  .byte $ce ; N
                  .byte $c4 ; D
                  .byte $8d ; <nl>
                  .byte $00 ; EndOfText

BoEdWaitCmd       lda $50                         ; screen row  (00-0f)
                  cmp #LR_BEDCmdLinMax
                  bcs GoClearScrnDisp             ; clear hires display screen

                  jsr TextOut
                  .byte $8d ; <nl>
                  .byte $c3 ; C
                  .byte $cf ; O
                  .byte $cd ; M
                  .byte $cd ; M
                  .byte $c1 ; A
                  .byte $ce ; N
                  .byte $c4 ; D
                  .byte $be ; >
                  .byte $00 ; EndOfText

_BoEdWaitCmd      jsr GetCheckKey                 ; ac=value
_FindEditCmd      ldy TabEditCmds,x
                  beq GoBeepWaitCmd

                  cmp TabEditCmds,x
                  beq FoundEditCmd

                  inx
                  bne _FindEditCmd

GoBeepWaitCmd     jsr Beep
                  jmp BoEdWaitCmd

FoundEditCmd      txa
                  asl a
                  tax
                  lda TabEditSubs+1,x
                  pha
                  lda TabEditSubs,x
                  pha
FoundEditCmdX     rts                             ; call edit command routine
; ------------------------------------------------------------------------------------------------------------- ;
TabEditCmds       .byte $29 ; P(lay)
                  .byte $14 ; C(lear level)
                  .byte $0e ; E(dit)
                  .byte $24 ; M(ove)
                  .byte $21 ; I(nitialize)
                  .byte $0d ; S(core clear)
                  .byte $00 ; EndOfCmds

TabEditSubs       .word BED_PlayLevel  - 1
                  .word BED_ClearLevel - 1
                  .word BED_Level      - 1
                  .word BED_MoveLevel  - 1
                  .word BED_InitDisk   - 1
                  .word BED_ClearScore - 1
; ------------------------------------------------------------------------------------------------------------- ;
BED_PlayLevel      jsr TextOut
                  .byte $8d ; <nl>
                  .byte $be ; >
                  .byte $be ; >
                  .byte $d0 ; P
                  .byte $cc ; L
                  .byte $c1 ; A
                  .byte $d9 ; Y
                  .byte $a0 ; <blank>
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $cc ; L
                  .byte $00 ; EndOfText

_EdPlayLevel      jsr DisplayGetLvlNo
                  bcs BED_PlayLevelX
                  
                  lda #$00
M_ControllerTyp   = *-1
                  sta LR_ControllerTyp
                  lda #LR_GamePlay
                  sta LR_GameCtrl                 ; $00=start $01=demo $02=game $03=play_level $05=edit
                  lda #LR_CheatedNo
                  sta LR_Cheated                  ; $01=not cheated
                  lda #$00
                  sta LR_SprtPosCtrl
                  lda LR_LevelNoDisk              ; 000-149
                  beq _GoGameStart                ; no cheating if level=$00
                  
                  lsr LR_Cheated                  ; $00=cheated
_GoGameStart      jmp GameStart                   ; play selected level

BED_PlayLevelX    jmp GoBeepWaitCmd
; ------------------------------------------------------------------------------------------------------------- ;
BED_ClearLevel     jsr TextOut
                  .byte $8d ; <nl>
                  .byte $be ; >
                  .byte $be ; >
                  .byte $c3 ; C
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $c1 ; A
                  .byte $d2 ; R
                  .byte $a0 ; <blank>
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $cc ; L
                  .byte $00 ; EndOfText

_EdClearLevel     jsr DisplayGetLvlNo
                  bcs BED_ClearLevelX
                  jsr CheckLRDisk
                  ldy #$00
                  tya
_Clear            sta LR_LvlDataSavLod,y          ; clear level store
                  iny
                  bne _Clear
                  
                  lda #LR_DiskWrite
                  jsr ControlDiskOper

                  jmp BoEdWaitCmd
BED_ClearLevelX   jmp GoBeepWaitCmd
; ------------------------------------------------------------------------------------------------------------- ;
BED_Level         jsr TextOut
                  .byte $8d ; <nl>
                  .byte $be ; >
                  .byte $be ; >
                  .byte $c5 ; E
                  .byte $c4 ; D
                  .byte $c9 ; I
                  .byte $d4 ; T
                  .byte $a0 ; <blank>
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $cc ; L
                  .byte $00 ; EndOfText

_EdLevel          jsr DisplayGetLvlNo
                  bcs BED_LevelX
                  jmp LevelEditor
BED_LevelX        jmp GoBeepWaitCmd
; ------------------------------------------------------------------------------------------------------------- ;
BED_MoveLevel     jsr TextOut
                  .byte $8d ; <nl>
                  .byte $be ; >
                  .byte $be ; >
                  .byte $cd ; M
                  .byte $cf ; O
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $cc ; L
                  .byte $00 ; EndOfText

_EdMoveLevelFrom  jsr DisplayGetLvlNo
                  bcs BED_MoveLevelX              ; greater 150

                  sty SavMoveLvlNoFrom
                  jsr TextOut
                  .byte $a0 ; <blank>
                  .byte $d4 ; T
                  .byte $cf ; O
                  .byte $a0 ; <blank>
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $cc ; L
                  .byte $00 ; EndOfText

_EdMoveLevelTo    jsr DisplayGetLvlNo
                  bcs BED_MoveLevelX              ; greater 150

                  sty SavMoveLvlNoTo
                  jsr TextOut
                  .byte $8d ; <nl>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $d3 ; S
                  .byte $cf ; O
                  .byte $d5 ; U
                  .byte $d2 ; R
                  .byte $c3 ; C
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $c4 ; D
                  .byte $c9 ; I
                  .byte $d3 ; S
                  .byte $cb ; K
                  .byte $c5 ; E
                  .byte $d4 ; T
                  .byte $d4 ; T
                  .byte $c5 ; E
                  .byte $00 ; EndOfText

_EdMoveLevelR     jsr GetCheckKey                 ; read level
                  jsr CheckLRDisk

                  lda SavMoveLvlNoFrom
                  sta LR_LevelNoDisk              ; 000-149
                  lda #LR_DiskRead
                  jsr ControlDiskOper

                  jsr TextOut
                  .byte $8d ; <nl>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $c4 ; D
                  .byte $c5 ; E
                  .byte $d3 ; S
                  .byte $d4 ; T
                  .byte $c9 ; I
                  .byte $ce ; N
                  .byte $c1 ; A
                  .byte $d4 ; T
                  .byte $c9 ; I
                  .byte $cf ; O
                  .byte $ce ; N
                  .byte $a0 ; <blank>
                  .byte $c4 ; D
                  .byte $c9 ; I
                  .byte $d3 ; S
                  .byte $cb ; K
                  .byte $c5 ; E
                  .byte $d4 ; T
                  .byte $d4 ; T
                  .byte $c5 ; E
                  .byte $00 ; EndOfText

_EdMoveLevelW     jsr GetCheckKey                 ; write level
                  jsr CheckLRDisk
                  lda SavMoveLvlNoTo
                  sta LR_LevelNoDisk              ; 000-149
                  lda #LR_DiskWrite
                  jsr ControlDiskOper

                  jmp BoEdWaitCmd
BED_MoveLevelX    jmp GoBeepWaitCmd
; ------------------------------------------------------------------------------------------------------------- ;
BED_InitDisk      jsr TextOut
                  .byte $8d ; <nl>
                  .byte $be ; >
                  .byte $be ; >
                  .byte $c9 ; I
                  .byte $ce ; N
                  .byte $c9 ; I
                  .byte $d4 ; T
                  .byte $c9 ; I
                  .byte $c1 ; A
                  .byte $cc ; L
                  .byte $c9 ; I
                  .byte $da ; Z
                  .byte $c5 ; E
                  .byte $8d ; <nl>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $d4 ; T
                  .byte $c8 ; H
                  .byte $c9 ; I
                  .byte $d3 ; D
                  .byte $a0 ; <blank>
                  .byte $d0 ; P
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $d0 ; P
                  .byte $c1 ; A
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $d3 ; S
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $ce ; N
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $cc ; L
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $c1 ; A
                  .byte $c4 ; D
                  .byte $d9 ; Y
                  .byte $8d ; <nl>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $c6 ; F
                  .byte $cf ; O
                  .byte $d2 ; R
                  .byte $cd ; M
                  .byte $c1 ; A
                  .byte $d4 ; T
                  .byte $d4 ; T
                  .byte $c5 ; E
                  .byte $c4 ; D
                  .byte $a0 ; <blank>
                  .byte $c4 ; D
                  .byte $c9 ; I
                  .byte $d3 ; S
                  .byte $cb ; K
                  .byte $a0 ; <blank>
                  .byte $c6 ; F
                  .byte $cf ; O
                  .byte $d2 ; R
                  .byte $a0 ; <blank>
                  .byte $d5 ; U
                  .byte $d3 ; S
                  .byte $c5 ; E
                  .byte $d2 ; R
                  .byte $8d ; <nl>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $c3 ; C
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $c1 ; A
                  .byte $d4 ; T
                  .byte $c5 ; E
                  .byte $c4 ; D
                  .byte $a0 ; <blank>
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $cc ; L
                  .byte $d3 ; S
                  .byte $ae ; .
                  .byte $8d ; <nl>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a8 ; (
                  .byte $d7 ; W
                  .byte $c9 ; I
                  .byte $cc ; L
                  .byte $cc ; L
                  .byte $a0 ; <blank>
                  .byte $c4 ; D
                  .byte $c5 ; E
                  .byte $d3 ; S
                  .byte $d4 ; T
                  .byte $d2 ; R
                  .byte $cf ; O
                  .byte $d9 ; Y
                  .byte $a0 ; <blank>
                  .byte $cf ; O
                  .byte $cc ; L
                  .byte $c4 ; D
                  .byte $a0 ; <blank>
                  .byte $c4 ; D
                  .byte $c1 ; A
                  .byte $d4 ; T
                  .byte $c1 ; A
                  .byte $a9 ; )
                  .byte $ae ; .
                  .byte $8d ; <nl>
                  .byte $8d ; <nl>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $d9 ; Y
                  .byte $cf ; O
                  .byte $d5 ; U
                  .byte $a0 ; <blank>
                  .byte $d3 ; S
                  .byte $d5 ; U
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $a8 ; (
                  .byte $d9 ; Y
                  .byte $af ; /
                  .byte $ce ; N
                  .byte $a9 ; )
                  .byte $a0 ; <blank>
                  .byte $00 ; EndOfText

_EdInitDisk       jsr GetCheckKey
                  cmp #$19                        ; y(es)
                  bne BED_InitDiskX

                  lda #LR_DiskRead
                  jsr GetPutHiScores              ; Target: $1100-$11ff

                  cmp #LR_DiskMaster              ; lr master disk
                  bne _GetDiskLvlNo               ; no

                  jsr MsgMasterDisk
                  jmp GoClearScrnDisp             ; clear hires display screen

_GetDiskLvlNo     lda LR_LevelNoDisk              ; 000-149
                  pha
                  lda #LR_DiskInit
                  jsr ControlDiskOper

                  pla
                  sta LR_LevelNoDisk              ; 000-149
BED_InitDiskX     jmp BoEdWaitCmd
; ------------------------------------------------------------------------------------------------------------- ;
BED_ClearScore     jsr TextOut
                  .byte $8d ; <nl>
                  .byte $be ; >
                  .byte $be ; >
                  .byte $c3 ; C
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $c1 ; A
                  .byte $d2 ; R
                  .byte $a0 ; <blank>
                  .byte $d3 ; S
                  .byte $c3 ; C
                  .byte $cf ; O
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $c6 ; F
                  .byte $c9 ; I
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $8d ; <nl>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $d4 ; T
                  .byte $c8 ; H
                  .byte $c9 ; I
                  .byte $d3 ; S
                  .byte $a0 ; <blank>
                  .byte $c3 ; C
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $c1 ; A
                  .byte $d2 ; R
                  .byte $d3 ; S
                  .byte $a0 ; <blank>
                  .byte $d4 ; T
                  .byte $c8 ; H
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $c8 ; H
                  .byte $c9 ; I
                  .byte $c7 ; G
                  .byte $c8 ; H
                  .byte $8d ; <nl>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $d3 ; S
                  .byte $c3 ; C
                  .byte $cf ; O
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $c6 ; F
                  .byte $c9 ; I
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $cf ; O
                  .byte $c6 ; F
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $cc ; L
                  .byte $cc ; L
                  .byte $8d ; <nl>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $c5 ; E
                  .byte $ce ; N
                  .byte $d4 ; T
                  .byte $d2 ; R
                  .byte $c9 ; I
                  .byte $c5 ; E
                  .byte $d3 ; S
                  .byte $ae ; .
                  .byte $8d ; <nl>
                  .byte $8d ; <nl>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $d9 ; Y
                  .byte $cf ; O
                  .byte $d5 ; U
                  .byte $a0 ; <blank>
                  .byte $d3 ; S
                  .byte $d5 ; U
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $a8 ; (
                  .byte $d9 ; Y
                  .byte $af ; /
                  .byte $ce ; N
                  .byte $a9 ; )
                  .byte $a0 ; <blank>
                  .byte $00 ; EndOfText

_EdClearScore     jsr GetCheckKey
                  cmp #$19                        ; y(es)
                  bne BED_ClearScoreX

                  lda #LR_DiskRead
                  jsr GetPutHiScores              ; Target: $1100-$11ff

                  cmp #LR_DiskNoData              ; no lode runner data disk
                  beq _GoMsgNoLRDisk

                  lda #$00
                  ldy #LR_HiScoreLen              ; $7f=length high scores
_ClearScores      sta LR_HiScore,y
                  dey
                  bpl _ClearScores

                  lda #LR_DiskWrite
                  jsr GetPutHiScores              ; Target: $1100-$11ff
_EdClearScoreX    jmp BoEdWaitCmd

_GoMsgNoLRDisk    jsr MsgNoLRDisk
BED_ClearScoreX   jmp BoEdWaitCmd
; ------------------------------------------------------------------------------------------------------------- ;
LevelEditor       jsr ClearHiresDisp
                  jsr CheckLRDisk

                  lda #LR_CyanRed
                  jsr SetMultiColors

                  lda #>LR_ScrnHiRePrep           ; $40
                  sta $51                         ; target output  $20=$2000 $40=$4000
                  jsr StatusLines

                  ldx #LR_BEDLvlModNo             ; level data not modified
                  stx $5a                         ; edit status  $00=modified
                  dex
                  jsr InitLevel
                  bcc _EditorStart                ; successful
                  
                  jmp GoBeepWaitCmd

_EditorStart      lda #$00
                  sta $4f                         ; screen col  (00-1b)
                  sta $50                         ; screen row  (00-0f)
LevelEdGetKey     jsr SetPtr08GetKey              ; set ptr ($09/$0a) to expanded level data $0800-$09c3
                  jsr CheckDigitInput
                  bcs _ChkCommandI                ; no digit

                  sta $23                         ; level input tile $00-$09

                  ldy $50                         ; screen row  (00-0f)
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  ldy $4f                         ; screen col  (00-1b)

                  lda $23                         ; level input tile $00-$09
                  eor ($09),y                     ; unpacked level data ($0800-$09c3)
                  beq _GetTile                    ; same as input data so do not set modify flag

                  lsr $5a                         ; edit status  $00=modified
_GetTile          lda $23                         ; level input tile $00-$09
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  jsr ImageOutToDisp              ; direct output to display screen
                  jmp LevelEdGetKey

_ChkCommandI      sta $23                         ; level input tile $00-$09
                  ldy #$ff
_ChkCommand       iny
                  lda TabEditorCmds,y
                  beq BeepBadInput

                  cmp $23                         ; level input tile $00-$09
                  bne _ChkCommand

                  tya
                  asl a                           ; *2
                  tay
                  lda TabEditorSubs+1,y           ; high byte command routine
                  pha
                  lda TabEditorSubs,y             ; low byte command routine
                  pha
LevelEditorX      rts                             ; dispatch command routine
; ------------------------------------------------------------------------------------------------------------- ;
BeepBadInput      jsr Beep
BeepBadInputX     jmp LevelEdGetKey
; ------------------------------------------------------------------------------------------------------------- ;
LED_CurUp         lda $50                         ; screen row  (00-0f) - i=cursor up
                  beq BeepBadInput                ; 0=max up reached
                  dec $50                         ; screen row  (00-0f)
                  bpl LevelEdGetKey

LED_CurLe         lda $4f                         ; screen col  (00-1b) - j=cursor left
                  beq BeepBadInput                ; 0=max left reached
                  dec $4f                         ; screen col  (00-1b)
                  bpl LevelEdGetKey

LED_CurRi         lda $4f                         ; screen col  (00-1b) - k=cursor right
                  cmp #LR_ScrnMaxCols             ; $1b - max 27 cols
                  bcs BeepBadInput
                  inc $4f                         ; screen col  (00-1b)
                  bne LevelEdGetKey

LED_CurDo         lda $50                         ; screen row  (00-0f) - m=cursor down
                  cmp #LR_ScrnMaxRows             ; $0f - max 15 rows
                  bcs BeepBadInput
                  inc $50                         ; screen row  (00-0f)
                  bne LevelEdGetKey
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
LvlEdChkSave      lda $50                         ; screen row  (00-0f)
                  pha
                  lda $4f                         ; screen col  (00-1b)
                  pha

                  lda #LR_DiskRead
                  jsr GetPutHiScores              ; Target: $1100-$11ff

_ChkData          cmp #LR_DiskNoData              ; no lode runner data disk
                  bne _ChkMaster
                  jsr MsgNoLRDisk
                  jmp LvlEdResCur

_ChkMaster        cmp #LR_DiskMaster              ; master disk
                  bne _GoPackSaveLevel
                  
                  jsr MsgMasterDisk
                  jmp LvlEdResCur

_GoPackSaveLevel  jsr PackSaveLevel

                  pla
                  sta $4f                         ; screen col  (00-1b)
                  pla
                  sta $50                         ; screen row  (00-0f)

                  lda #LR_BEDLvlModNo             ; level data not modified
                  sta $5a                         ; edit status
LvlEdChkSaveX     rts
; ------------------------------------------------------------------------------------------------------------- ;
LvlEdResCur       lda #$00                        ; top left corner
                  sta $4f                         ; screen col  (00-1b)
                  sta $50                         ; screen row  (00-0f)
LvlEdResCurX      jmp LevelEdGetKey
; ------------------------------------------------------------------------------------------------------------- ;
LED_Save          jsr LvlEdChkSave                ; S=save level
LED_SaveX         jmp LevelEdGetKey
; ------------------------------------------------------------------------------------------------------------- ;
LED_NextLvl       lda LR_LevelNoDisk              ; 000-149 - F=get next level
                  cmp #LR_LevelDiskMax
LvlEdGoBeepBad    beq BeepBadInput
                  jsr LvlEdChkChFlag

                  inc LR_LevelNoDisk              ; 000-149
                  inc LR_LevelNoGame              ; 001-150
LED_NextLvlX      jmp LevelEditor
; ------------------------------------------------------------------------------------------------------------- ;
LED_PrevLvl       lda LR_LevelNoDisk              ; 000-149 - B=get previous level
                  beq LvlEdGoBeepBad
                  jsr LvlEdChkChFlag

                  dec LR_LevelNoGame              ; 001-150
                  dec LR_LevelNoDisk              ; 000-149
LED_PrevLvlX      jmp LevelEditor
; ------------------------------------------------------------------------------------------------------------- ;
LED_Quit          jsr LvlEdChkChFlag
LED_QuitX         jmp GoClearScrnDisp             ; clear hires display screen
; ------------------------------------------------------------------------------------------------------------- ;
LvlEdChkChFlag    lda $5a                         ; edit status  $00=modified
                  beq LvlEdChAsk
LvlEdChkChFlagX   rts
; ------------------------------------------------------------------------------------------------------------- ;
LvlEdChAsk        jsr ClearHiresDisp
                  lda M_MultiColors               ; save old colors
                  pha
                  lda #LR_YellowCyan
                  jsr SetMultiColors

                  lda #>LR_ScrnHiReDisp           ; $20
                  sta $51                         ; target output  $20=$2000 $40=$4000
                  lda #$00                        ; top left corner
                  sta $4f                         ; screen col  (00-1b)
                  sta $50                         ; screen row  (00-0f)
                  jsr TextOut
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $cc ; L
                  .byte $a0 ; <blank>
                  .byte $c8 ; H
                  .byte $c1 ; A
                  .byte $d3 ; S
                  .byte $a0 ; <blank>
                  .byte $c2 ; B
                  .byte $c5 ; E
                  .byte $c5 ; E
                  .byte $ce ; N
                  .byte $a0 ; <blank>
                  .byte $c3 ; C
                  .byte $c8 ; H
                  .byte $c1 ; A
                  .byte $ce ; N
                  .byte $c7 ; G
                  .byte $c5 ; E
                  .byte $c4 ; D
                  .byte $a0 ; <blank>
                  .byte $c2 ; B
                  .byte $d5 ; U
                  .byte $d4 ; T
                  .byte $8d ; <nl>
                  .byte $ce ; N
                  .byte $cf ; O
                  .byte $d4 ; T
                  .byte $a0 ; <blank>
                  .byte $d3 ; S
                  .byte $c1 ; A
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $c4 ; D
                  .byte $ae ; .
                  .byte $a0 ; <blank>
                  .byte $c4 ; D
                  .byte $cf ; O
                  .byte $a0 ; <blank>
                  .byte $d9 ; Y
                  .byte $cf ; O
                  .byte $d5 ; U
                  .byte $a0 ; <blank>
                  .byte $d7 ; W
                  .byte $c9 ; I
                  .byte $d3 ; S
                  .byte $c8 ; H
                  .byte $a0 ; <blank>
                  .byte $d4 ; T
                  .byte $cf ; O
                  .byte $8d ; <nl>
                  .byte $d3 ; S
                  .byte $c1 ; A
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $cd ; M
                  .byte $cf ; O
                  .byte $c4 ; D
                  .byte $c9 ; I
                  .byte $c6 ; F
                  .byte $c9 ; I
                  .byte $c5 ; E
                  .byte $c4 ; D
                  .byte $a0 ; <blank>
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $cc ; L
                  .byte $a0 ; <blank>
                  .byte $a8 ; (
                  .byte $d9 ; Y
                  .byte $af ; /
                  .byte $ce ; N
                  .byte $a9 ; )
                  .byte $a0 ; <blank>
                  .byte $00 ; EndOfText

                  jsr Beep

_WaitBlink        lda #$00
                  jsr WaitKeyBlink                ; wait for input key and blink cursor

                  ldx #$00
                  stx LR_KeyNew                   ; reset actual key value
                  cmp #$27                        ; "n"
                  beq _Return
                  cmp #$19                        ; "y"
                  bne _WaitBlink

                  jsr LvlEdChkSave

_Return           pla
LvlEdChAskX       jmp SetMultiColors
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
CheckLRDisk       lda #LR_DiskRead
                  jsr GetPutHiScores              ; Target: $1100-$11ff

_ChkData          cmp #LR_DiskNoData
                  bne _ChkMaster

                  jsr MsgNoLRDisk                 ; no lode runner data disk
                  jmp GoClearScrnDisp             ; clear hires display screen

_ChkMaster        cmp #LR_DiskMaster
                  bne CheckLRDiskX

                  jsr MsgMasterDisk               ; master disk
                  jmp GoClearScrnDisp             ; clear hires display screen

CheckLRDiskX      rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
MsgMasterDisk     jsr ClearHiresDisp

                  lda M_MultiColors               ; save old colors
                  pha

                  lda #>LR_ScrnHiReDisp           ; $20
                  sta $51                         ; target output  $20=$2000 $40=$4000
                  lda #LR_YellowCyan
                  jsr SetMultiColors

                  lda #$00                        ; top left corner
                  sta $4f                         ; screen col  (00-1b)
                  sta $50                         ; screen row  (00-0f)
                  jsr TextOut
                  .byte $d5 ; U
                  .byte $d3 ; S
                  .byte $c5 ; E
                  .byte $d2 ; R
                  .byte $a0 ; <blank>
                  .byte $ce ; N
                  .byte $cf ; O
                  .byte $d4 ; T
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $cc ; L
                  .byte $cc ; L
                  .byte $cf ; O
                  .byte $d7 ; W
                  .byte $c5 ; E
                  .byte $c4 ; D
                  .byte $a0 ; <blank>
                  .byte $d4 ; T
                  .byte $cf ; O
                  .byte $8d ; <nl>
                  .byte $cd ; M
                  .byte $c1 ; A
                  .byte $ce ; N
                  .byte $c9 ; I
                  .byte $d0 ; P
                  .byte $d5 ; U
                  .byte $cc ; L
                  .byte $c1 ; A
                  .byte $d4 ; T
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $cd ; M
                  .byte $c1 ; A
                  .byte $d3 ; S
                  .byte $d4 ; T
                  .byte $c5 ; E
                  .byte $d2 ; R
                  .byte $a0 ; <blank>
                  .byte $c4 ; D
                  .byte $c9 ; I
                  .byte $d3 ; S
                  .byte $cb ; K
                  .byte $c5 ; E
                  .byte $d4 ; T
                  .byte $d4 ; T
                  .byte $c5 ; E
                  .byte $ae ; .
MsgMasterDiskX    .byte $00 ; EndOfText

MsgKey2Cont       jsr TextOut
                  .byte $8d ; <nl>
                  .byte $8d ; <nl>
                  .byte $c8 ; H
                  .byte $c9 ; I
                  .byte $d4 ; T
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $a0 ; <blank>
                  .byte $cb ; K
                  .byte $c5 ; E
                  .byte $d9 ; Y
                  .byte $a0 ; <blank>
                  .byte $d4 ; T
                  .byte $cf ; O
                  .byte $a0 ; <blank>
                  .byte $c3 ; C
                  .byte $cf ; O
                  .byte $ce ; N
                  .byte $d4 ; T
                  .byte $c9 ; I
                  .byte $ce ; N
                  .byte $d5 ; U
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $00 ; EndOfText

                  jsr Beep

                  lda #$00                        ; blank chr under cursor
                  jsr WaitKeyBlink                ; wait for input key and blink cursor

                  lda #$00                        ; reset actual key
                  sta LR_KeyNew
                  lda #>LR_ScrnHiRePrep           ; $40
                  sta $51                         ; target output  $20=$2000 $40=$4000
                  jsr StatusLines

                  lda #LR_LevelPrep
                  sta LR_LevelCtrl                ; level display control  $00=prepared copy already at $4000-$5fff
                  jsr CheckLevel

                  pla                             ; restore old colors
MsgKey2ContX      jmp SetMultiColors
; ------------------------------------------------------------------------------------------------------------- ;
; MsgNoLRDisk     Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
MsgNoLRDisk       jsr ClearHiresDisp
                  lda M_MultiColors               ; save old colors
                  pha
                  lda #LR_YellowCyan
                  jsr SetMultiColors

                  lda #>LR_ScrnHiReDisp           ; $20
                  sta $51                         ; target output  $20=$2000 $40=$4000
                  lda #$00                        ; top left corner
                  sta $4f                         ; screen col  (00-1b)
                  sta $50                         ; screen row  (00-0f)
                  jsr TextOut
                  .byte $c4 ; D
                  .byte $c9 ; I
                  .byte $d3 ; S
                  .byte $cb ; K
                  .byte $c5 ; E
                  .byte $d4 ; T
                  .byte $d4 ; T
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $c9 ; I
                  .byte $ce ; N
                  .byte $a0 ; <blank>
                  .byte $c4 ; D
                  .byte $d2 ; R
                  .byte $c9 ; I
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $c9 ; I
                  .byte $d3 ; S
                  .byte $a0 ; <blank>
                  .byte $ce ; N
                  .byte $cf ; O
                  .byte $d4 ; T
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $8d ; <nl>
                  .byte $cc ; L
                  .byte $cf ; O
                  .byte $c4 ; D
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $d2 ; R
                  .byte $d5 ; U
                  .byte $ce ; N
                  .byte $ce ; N
                  .byte $c5 ; E
                  .byte $d2 ; R
                  .byte $a0 ; <blank>
                  .byte $c4 ; D
                  .byte $c1 ; A
                  .byte $d4 ; T
                  .byte $c1 ; A
                  .byte $a0 ; <blank>
                  .byte $c4 ; D
                  .byte $c9 ; I
                  .byte $d3 ; S
                  .byte $cb ; K
                  .byte $ae ; .
                  .byte $00 ; EndOfText

MsgNoLRDiskX      jmp MsgKey2Cont
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
SetPtr08GetKey    ldy $50                         ; screen row  (00-0f)
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  ldy $4f                         ; screen col  (00-1b)
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  jsr WaitKeyBlink                ; wait for input key and blink cursor

SetPtr08GetKeyX   rts
; ------------------------------------------------------------------------------------------------------------- ;
TabEditorCmds     .byte $22 ; j(left)
                  .byte $21 ; i(up)
                  .byte $25 ; k(right)
                  .byte $24 ; m(down)
                  .byte $8d ; S(ave)
                  .byte $95 ; F(orward level)
                  .byte $9c ; B(ackward level)
                  .byte $be ; Q(uit)
                  .byte $00 ; EndOfCmdTab

TabEditorSubs     .word LED_CurLe   - 1
                  .word LED_CurUp   - 1
                  .word LED_CurRi   - 1
                  .word LED_CurDo   - 1
                  .word LED_Save    - 1
                  .word LED_NextLvl - 1
                  .word LED_PrevLvl - 1
                  .word LED_Quit    - 1
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
DisplayGetLvlNo   ldy LR_LevelNoDisk              ; 000-149
                  iny
                  tya
                  jsr ConvertHex2Dec              ; 1307=100 1308=10 1309=1

                  lda $4f                         ; screen col  (00-1b)
                  sta SavScreenCol
                  ldy #$00
_GetGigits        lda LR_Digit100,y               ; digit 100/10/1 parts
                  sty SavCurrentPos
                  jsr PrepareDigitOut

                  ldy SavCurrentPos
                  iny
                  cpy #LR_BEDLvlLenMax+1          ; max 3
                  bcc _GetGigits                  ; not reached

                  lda SavScreenCol
                  sta $4f                         ; screen col  (00-1b)

                  ldy #$00
                  sty SavCurrentPos
_GetCurrentPos    ldx SavCurrentPos
                  lda LR_Digit100,x
                  clc
                  adc #$3b                        ; prepare for grafic output
                  jsr WaitKeyBlink                ; wait for input key and blink cursor
                  jsr CheckDigitInput
                  bcc _LvlNumDigits

_LvlNumNoDigits   cmp #$01                        ; RETURN
                  beq _GetScreenCol

                  cmp #$07                        ; CURSOR DOWN
                  beq _ChkCurDown

                  cmp #$82                        ; SHIFT CURSOR RIGHT
                  bne _ChkCurRight

_ChkCurDown       ldx SavCurrentPos               ; CURSOR DOWN
                  beq _GoBeep

                  dec SavCurrentPos
                  dec $4f                         ; screen col  (00-1b)
                  jmp _GetCurrentPos

_ChkCurRight      cmp #$02                        ; CURSOR RIGHT
                  bne _ChkKeyRS

                  ldx SavCurrentPos
                  cpx #LR_BEDLvlLenMax
                  beq _GoBeep

                  inc $4f                         ; screen col  (00-1b)
                  inc SavCurrentPos
                  jmp _GetCurrentPos

_ChkKeyRS         cmp #$3f                        ; RUN/STOP
                  bne _RSAbort
                  jmp BoEdWaitCmd

_RSAbort          jsr CheckDigitInput
                  bcs _GoBeep

_LvlNumDigits     ldy SavCurrentPos               ; input screen pos
                  sta LR_Digit100,y               ; update digit under screen pos
                  jsr PrepareDigitOut

                  inc SavCurrentPos
                  lda SavCurrentPos
                  cmp #LR_BEDLvlLenMax+1          ; max right
                  bcc _GetCurrentPos

                  dec SavCurrentPos
                  dec $4f                         ; screen col  (00-1b)
                  jmp _GetCurrentPos

_GoBeep           jsr Beep
                  jmp _GetCurrentPos

_GetScreenCol     lda SavScreenCol
                  clc
                  adc #LR_BEDLvlLenMax+1          ; rightmost digit
                  sta $4f                         ; screen col  (00-1b)

                  lda #$00                        ; init result
                  ldx LR_Digit100                 ; digit 100 part
                  beq _Chk10

                  clc
_Add100           adc #$64                        ; 100
                  bcs DisplayGetLvlNoX
                  dex
                  bne _Add100

_Chk10            ldx LR_Digit10                  ; digit 10 part
                  beq _Add1

                  clc
_Add10            adc #$0a                        ; 10
                  bcs DisplayGetLvlNoX
                  dex
                  bne _Add10

_Add1             clc
                  adc LR_Digit1                   ; digit 1 part
                  bcs DisplayGetLvlNoX

                  sta LR_LevelNoGame              ; 001-150
                  tay
                  dey
                  sty LR_LevelNoDisk              ; 000-149
                  cpy #LR_LevelNoMax              ; 150

DisplayGetLvlNoX  rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
GetCheckKey       lda #$00                        ; blank chr under cursor
                  jsr WaitKeyBlink                ; wait for input key and blink cursor

                  ldx #$00
                  stx LR_KeyNew                   ; reset actual key
                  cmp #$3f                        ; RUN/STOP
                  bne GetCheckKeyX

                  jmp BoEdWaitCmd
GetCheckKeyX      rts
; ------------------------------------------------------------------------------------------------------------- ;
SavCurrentPos     .byte $00
SavScreenCol      .byte $00
SavMoveLvlNoFrom  .byte $00
SavMoveLvlNoTo    .byte $00
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
CheckDigitInput   lda LR_KeyNew                   ; get actual key
                  ldy #$00
                  sty LR_KeyNew                   ; reset actual key
                  ldy #$09                        ; length digit key tab
_Check            cmp TabDigitKeys,y
                  beq _SetDigit
                  dey
                  bpl _Check

_SetNoDigit       sec                             ; flag: no digit
                  rts
                  
_SetDigit         tya
                  clc                             ; flag: was digit
CheckDigitInputX  rts
; ------------------------------------------------------------------------------------------------------------- ;
TabDigitKeys      .byte $23 ; 0
                  .byte $38 ; 1
                  .byte $3b ; 2
                  .byte $08 ; 3
                  .byte $0b ; 4
                  .byte $10 ; 5
                  .byte $13 ; 6
                  .byte $18 ; 7
                  .byte $1b ; 8
                  .byte $20 ; 9
; ------------------------------------------------------------------------------------------------------------- ;
TabLrDiskId       .byte $c4 ; D
                  .byte $c1 ; A
                  .byte $ce ; N
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $c2 ; B
                  .byte $c9 ; I
                  .byte $c7 ; G
                  .byte $c8 ; H
                  .byte $c1 ; A
                  .byte $cd ; M
; ------------------------------------------------------------------------------------------------------------- ;
; ChkNewHighScore Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
ChkNewHighScore   lda LR_Cheated                  ; $01=no
                  beq ChkNewHighScoreX

                  lda LR_ScoreLo
                  ora LR_ScoreMidLo
                  ora LR_ScoreMidHi
                  ora LR_ScoreHi
                  beq ChkNewHighScoreX            ; all zero

                  lda #LR_DiskRead
                  jsr GetPutHiScores              ; Target: $1100-$11ff
                  beq ChkNewHighScoreX            ; no lr data disk

                  ldy #$00
_CopyScores       lda LR_HiScore,y
                  sta LR_HiScoreOld,y
                  iny
                  bne _CopyScores

                  ldy #$01                        ; start with entry one
_CheckScores      ldx TabHiScOffRows,y            ; high score rows offsets
                  lda LR_LevelNoGame              ; 001-150
                  cmp LR_HiScoreLevel,x           ; score board entry - level
                  bcc _NextEntry
                  bne InsNewHighScore

                  lda LR_ScoreHi
                  cmp LR_HiScoreHi,x              ; score board entry - score
                  bcc _NextEntry
                  bne InsNewHighScore

                  lda LR_ScoreMidHi
                  cmp LR_HiScoreMidHi,x           ; score board entry - score
                  bcc _NextEntry
                  bne InsNewHighScore

                  lda LR_ScoreMidLo
                  cmp LR_HiScoreMidLo,x           ; score board entry - score
                  bcc _NextEntry
                  bne InsNewHighScore

                  lda LR_ScoreLo
                  cmp LR_HiScoreLo,x              ; score board entry - score
                  bcc _NextEntry
                  bne InsNewHighScore

_NextEntry        iny
                  cpy #LR_HiScoreMaxIDs+1         ; max 10 high score entries
                  bcc _CheckScores

ChkNewHighScoreX  rts
; ------------------------------------------------------------------------------------------------------------- ;
InsNewHighScore   cpy #LR_HiScoreMaxIDs           ; no insertion for enry 10
                  beq _Insert                     ; simply overwrite

                  sty $29                         ; number of new entry
                  ldy #LR_HiScoreMaxIDs-1         ; max entries to move
_MoveUpI          ldx TabHiScOffRows,y            ; high score rows offsets
                  lda #LR_HiScoreLEntry
                  sta $22                         ; entry length
_MoveUp           lda LR_HiScore,x
                  sta LR_HiScoreMovUp,x           ; move data on position up
                  inx
                  dec $22
                  bne _MoveUp

                  cpy $29                         ; number of new entry
                  beq _Insert

                  dey                             ; not reached
                  bne _MoveUpI                    ; move next entry

_Insert           ldx TabHiScOffRows,y            ; high score rows offsets
                  lda #$a0                        ; shift blank
                  sta LR_HiScoreAka1,x            ; initial 1
                  sta LR_HiScoreAka2,x            ; initial 2
                  sta LR_HiScoreAka3,x            ; initial 3

                  lda LR_LevelNoGame              ; 001-150
                  sta LR_HiScoreLevel,x           ; level
                  lda LR_ScoreHi
                  sta LR_HiScoreHi,x              ; score
                  lda LR_ScoreMidHi
                  sta LR_HiScoreMidHi,x           ; score
                  lda LR_ScoreMidLo
                  sta LR_HiScoreMidLo,x           ; score
                  lda LR_ScoreLo
                  sta LR_HiScoreLo,x              ; score

                  sty $39                         ; number of new entry
                  lda TabHiScOffRows,y            ; high score rows offsets
                  sta __ModGetInitials            ; modify screen get initials
                  sta __ModPutInitials            ;   in-/output commands
                  jsr ShowHighScores

                  lda $39                         ; number of new entry
                  clc
                  adc #LR_HiScRowOff1St           ; no of header rows
                  sta $50                         ; screen row  (00-0f)
                  lda #LR_HiScColOffID            ; start col initials
                  sta $4f                         ; screen col  (00-1b)
                  ldx #$00
                  stx SavCurrentPos               ; input screen pos
_GetNewInitials   ldx SavCurrentPos
__ModGetInitials  = *+1
                  lda LR_HiScoreAka,x             ; get initial
                  jsr GetChrSubst
                  jsr WaitKeyBlink                ; wait for input key and blink cursor

                  ldx #$00
                  stx LR_KeyNew                   ; reset key entered
                  jsr GetChrSubst2

                  cmp #$8d                        ; ENTER
                  beq _CopyNewScoresI             ; finished

                  cmp #$88                        ; CURSOR UP/DOWN
                  bne _GetCurLR

                  ldx SavCurrentPos
                  beq _BeepGetBad

                  dec SavCurrentPos
                  dec $4f                         ; screen col  (00-1b)
                  jmp _GetNewInitials

_GetCurLR         cmp #$95                        ; CURSOR LEFT/RIGHT
                  bne _GetChkDot

                  ldx SavCurrentPos
                  cpx #LR_HiScIDMaxLen-1          ; max right
                  beq _BeepGetBad

                  inc $4f                         ; screen col  (00-1b)
                  inc SavCurrentPos
                  jmp _GetNewInitials

_GetChkDot        cmp #$ae                        ; "."
                  beq _PutNewInitials

                  cmp #$a0                        ; SHIFT BLANK
                  beq _PutNewInitials

                  cmp #$c1                        ; "A"
                  bcc _BeepGetBad

                  cmp #$db                        ; "Z" + 1
                  bcs _BeepGetBad

_PutNewInitials   ldy SavCurrentPos
__ModPutInitials  = *+1
                  sta LR_HiScoreAka,y             ; store typed chr into score initials area
                  jsr DisplayChr

                  inc SavCurrentPos               ; input screen pos
                  lda SavCurrentPos
                  cmp #LR_HiScIDMaxLen            ; max right
                  bcc _GetNewInitials

                  dec SavCurrentPos
                  dec $4f                         ; screen col  (00-1b)
                  jmp _GetNewInitials

_BeepGetBad       jsr Beep
                  jmp _GetNewInitials

_CopyNewScoresI   ldy #$00
_CopyNewScores    lda LR_ScoreSavLod,y            ; new score
                  sta LR_HiScoreNew,y
                  iny
                  bne _CopyNewScores

                  lda #LR_DiskRead
                  jsr GetPutHiScores              ; Target: $1100-$11ff

                  ldy #$00
_ChkNewScores     lda LR_ScoreSavLod,y
                  cmp LR_HiScoreOld,y
                  bne InsNewHighScoreX

                  lda LR_HiScoreNew,y
                  sta LR_ScoreSavLod,y
                  iny
                  bne _ChkNewScores

                  lda #LR_DiskWrite
                  jsr GetPutHiScores              ; Target: $1100-$11ff
InsNewHighScoreX  jmp WaitForDemoI
; ------------------------------------------------------------------------------------------------------------- ;
; ShowHighScores  Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
ShowHighScores    jsr ClearHiresDisp
                  lda #LR_YellowCyan
                  jsr SetMultiColors

                  lda #$00                        ; set cursor to top left corner
                  sta $4f                         ; screen col  (00-1b)
                  sta $50                         ; screen row  (00-0f)
                  jsr TextOut
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $cc ; L
                  .byte $cf ; O
                  .byte $c4 ; D
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $d2 ; R
                  .byte $d5 ; U
                  .byte $ce ; N
                  .byte $ce ; N
                  .byte $c5 ; E
                  .byte $d2 ; R
                  .byte $a0 ; <blank>
                  .byte $c8 ; H
                  .byte $c9 ; I
                  .byte $c7 ; G
                  .byte $c8 ; H
                  .byte $a0 ; <blank>
                  .byte $d3 ; S
                  .byte $c3 ; C
                  .byte $cf ; O
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $d3 ; S
                  .byte $8d ; <nl>
                  .byte $8d ; <nl>
                  .byte $8d ; <nl>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $c9 ; I
                  .byte $ce ; N
                  .byte $c9 ; I
                  .byte $d4 ; T
                  .byte $c9 ; I
                  .byte $c1 ; A
                  .byte $cc ; L
                  .byte $d3 ; S
                  .byte $a0 ; <blank>
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $cc ; L
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $d3 ; S
                  .byte $c3 ; C
                  .byte $cf ; O
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $8d ; <nl>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $a0 ; <blank>
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $a0 ; <blank>
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $8d ; <nl>
                  .byte $00 ; EndOfText

                  lda #$01
                  sta $28                         ; actual rank
_ShowScores       cmp #$0a                        ; 10
                  bne _Not10

                  lda #$01                        ; 10  - start with "1"
                  jsr PrepareDigitOut
                  
                  lda #$00
                  jsr PrepareDigitOut
                  jmp _FourBlanks1

_Not10            lda #$a0                        ; <10 - start with " "
                  jsr DisplayChr
                  
                  lda $28                         ; actual rank
                  jsr PrepareDigitOut

_FourBlanks1      jsr TextOut
                  .byte $ae ;
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $00 ; EndOfText

                  ldx $28                         ; actual rank
                  ldy TabHiScOffRows,x            ; high score rows offsets
                  sty $29                         ; score board offset
                  lda LR_HiScoreLevel,y           ; get level no
                  bne _ScoreInitials
                  jmp _NextLine

_ScoreInitials    ldy $29                         ; score board offset
                  lda LR_HiScoreAka1,y            ; initial 1
                  jsr DisplayChr

                  ldy $29                         ; score board offset
                  lda LR_HiScoreAka2,y            ; initial 2
                  jsr DisplayChr

                  ldy $29                         ; score board offset
                  lda LR_HiScoreAka3,y            ; initial 3
                  jsr DisplayChr
                  jsr TextOut
_FourBlanks2      .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $00 ; EndOfText

                  ldy $29                         ; score board offset
                  lda LR_HiScoreLevel,y           ; level reached
                  jsr ConvertHex2Dec              ; 1307=100 1308=10 1309=1

                  lda LR_Digit100                 ; digit 100 part
                  jsr PrepareDigitOut

                  lda LR_Digit10                  ; digit 10 part
                  jsr PrepareDigitOut

                  lda LR_Digit1                   ; digit 1 part
                  jsr PrepareDigitOut

                  jsr TextOut
_TwoBlanks        .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $00 ; EndOfText

                  ldy $29                         ; score board offset
                  lda LR_HiScoreHi,y              ; score hi byte
                  jsr SplitScoreDigit

                  lda LR_Digit10                  ; left nybble
                  jsr PrepareDigitOut

                  lda LR_Digit1                   ; right nybble
                  jsr PrepareDigitOut

                  ldy $29                         ; score board offset
                  lda LR_HiScoreMidHi,y
                  jsr SplitScoreDigit

                  lda LR_Digit10                  ; left nybble
                  jsr PrepareDigitOut

                  lda LR_Digit1                   ; right nybble
                  jsr PrepareDigitOut

                  ldy $29                         ; score board offset
                  lda LR_HiScoreMidLo,y
                  jsr SplitScoreDigit

                  lda LR_Digit10                  ; left nybble
                  jsr PrepareDigitOut

                  lda LR_Digit1                   ; right nybble
                  jsr PrepareDigitOut

                  ldy $29                         ; score board offset
                  lda LR_HiScoreLo,y
                  jsr SplitScoreDigit

                  lda LR_Digit10                  ; left nybble
                  jsr PrepareDigitOut

                  lda LR_Digit1                   ; right nybble
                  jsr PrepareDigitOut

_NextLine         jsr NewLine
                  inc $28                         ; actual rank
                  lda $28                         ; actual rank
                  cmp #LR_HiScoreMaxIDs+1         ; max 10
                  bcs ShowHighScoresX

                  jmp _ShowScores

ShowHighScoresX   rts
; ------------------------------------------------------------------------------------------------------------- ;
TabHiScOffRows    .byte $00
                  .byte $00
                  .byte $08
                  .byte $10
                  .byte $18
                  .byte $20
                  .byte $28
                  .byte $30
                  .byte $38
                  .byte $40
                  .byte $48
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
GetChrSubst2      cmp #$82                        ; replaced by $07
                  bne _GetSubst
                  lda #$07
_GetSubst         tay
                  lda TabKeySubst,y
                  ora #$80
GetChrSubst2X     rts
; ------------------------------------------------------------------------------------------------------------- ;
TabKeySubst       .byte $00
                  .byte $0d
                  .byte $15
                  .byte $ff
                  .byte $ff
                  .byte $ff
                  .byte $ff
                  .byte $08
                  .byte $33
                  .byte $57
                  .byte $41
                  .byte $34
                  .byte $5a
                  .byte $53
                  .byte $45
                  .byte $ff
                  .byte $35
                  .byte $52
                  .byte $44
                  .byte $36
                  .byte $43
                  .byte $46
                  .byte $54
                  .byte $58
                  .byte $37
                  .byte $59
                  .byte $47
                  .byte $38
                  .byte $42
                  .byte $48
                  .byte $55
                  .byte $56
                  .byte $39
                  .byte $49
                  .byte $4a
                  .byte $30
                  .byte $4d
                  .byte $4b
                  .byte $4f
                  .byte $4e
                  .byte $2b
                  .byte $50
                  .byte $4c
                  .byte $2d
                  .byte $2e
                  .byte $3a
                  .byte $ff
                  .byte $2c
                  .byte $5c
                  .byte $2a
                  .byte $3b
                  .byte $ff
                  .byte $ff
                  .byte $3d
                  .byte $ff
                  .byte $2f
                  .byte $31
                  .byte $ff
                  .byte $ff
                  .byte $32
                  .byte $20
                  .byte $ff
                  .byte $51
                  .byte $ff
; ------------------------------------------------------------------------------------------------------------- ;
; InitLevel       Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
InitLevel         stx LR_LevelCtrl                ; level display control  $00=prepared copy already at 4000-5fff

                  ldx #$ff                        ; init to no lr found
                  stx $03                         ; adr column lode runner

                  inx                             ; $00
                  stx LR_NumXitLadders            ; # hidden ladders
                  stx LR_GoldToGet                ; # gold
                  stx LR_EnmyNo                   ; # enemies
                  stx LR_NoEnemy2Move             ; # enemies to move
                  stx $54
                  stx $53                         ; disk level data offset
                  stx $1e                         ; left right nybble 00=right
                  stx $50                         ; screen row  (00-0f)

                  txa                             ; $00
                  ldx #LR_TabHoleMax              ; max 30
_HoleTime         sta LR_TabHoleOpenT,x           ; hole open time tab
                  dex
                  bpl _HoleTime

                  ldx #LR_TabEnemyBMax            ; max 6
_EnemyBirthStep   sta LR_TabEnemyBirtT,x          ; enemy rebirth step time
                  dex
                  bpl _EnemyBirthStep

                  lda #LR_Life
                  sta LR_Alive                    ; $00=lr killed
                  lda LR_LevelNoDisk              ; 000-149
                  cmp LR_LvlReload
                  beq _SameLevel

_NewLevel         lda #LR_DiskRead
                  jsr ControlDiskOper

_SameLevel        lda LR_LevelNoDisk              ; 000-149
                  sta LR_LvlReload

                  ldy $50                         ; screen row  (00-0f)
_ExpandDataI      lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  lda #$00
                  sta $4f                         ; screen col  (00-1b)

_GetDataBytes     lda $1e                         ; control left/right nybble to process  00=right
                  lsr a
                  ldy $53                         ; disk level data offset
_GetOneDataByte   lda LR_LvlDataSavLod,y          ; get a packed level data byte
                  bcs _LeftNybble                 ; carry possibly set by prev lsr

_RightNybble      and #$0f                        ; isolate right nybble
                  bpl _InitNybbleMark             ; always

_LeftNybble       lsr a                           ; isolate left nybble
                  lsr a
                  lsr a
                  lsr a
                  inc $53                         ; both nybbles processed so point to next byte

_InitNybbleMark   inc $1e                         ; force carry set the next round
                  ldy $4f                         ; screen col  (00-1b)

_ChkValid         cmp #LR_TileValid               ; valid byte range is $00-$09
                  bcc _PutDataBytes               ; lower
_SetEmpty         lda #LR_TileEmpty               ; not valid so store a $00
_PutDataBytes     sta ($09),y                     ; unpacked level data ($0800-$09c3)
_PutCtrlBytes     sta ($0b),y                     ; play level control data ($0a00-$0bc3)

                  inc $4f                         ; screen col  (00-1b)
                  lda $4f                         ; screen col  (00-1b)
                  cmp #LR_ScrnMaxCols+1           ; $1b - max 27 cols
                  bcc _GetDataBytes

                  inc $50                         ; screen row  (00-0f)
                  ldy $50                         ; screen row  (00-0f)
                  cpy #LR_ScrnMaxRows+1           ; $0f - max 15 rows
                  bcc _ExpandDataI

_CheckLevel       jsr CheckLevel
_NoError          bcc InitLevelX                  ; 150 levels not completed

_LevelError       lda LR_LevelNoDisk              ; 000-149
                  beq GoColdStart

                  ldx #$00                        ; force ColdStart the next time
                  stx LR_LevelNoDisk              ; 000-149

_IncGameSpeed     lda LR_CntSpeedLaps             ; increase game speed
                  cmp #LR_CntSpeedMax+1           ; max 9
                  bcs _SetFF
                  inc LR_CntSpeedLaps

_SetFF            dex
                  jmp InitLevel                   ; restart

InitLevelX        rts
; ------------------------------------------------------------------------------------------------------------- ;
GoColdStart       jmp ColdStart
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
PackSaveLevel     lda #$00
                  sta $53                         ; disk level data offset
                  sta $1e                         ; left/right nybble 00=right
                  sta $50                         ; screen row  (00-0f)
_PackLevelI       ldy $50                         ; screen row  (00-0f)
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a

                  ldy #$00
                  sty $4f                         ; screen col  (00-1b)
_GetDataBytes     lda $1e                         ; control left/right nybble to process  00=right
                  lsr a
_GetOneDataByte   lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  bcs _LeftNybble                 ; set from lsr prev

_RightNybble      sta $23                         ; level input tile $00-$09 - store as right nybble
                  bpl _InitNybbleMark             ; always

_LeftNybble       asl a                           ; isolate left nybble
                  asl a
                  asl a
                  asl a
                  ora $23                         ; level input tile $00-$09 - merge with right nybble

                  ldy $53                         ; disk level data offset
_PutOneDataByte   sta LR_LvlDataSavLod,y

                  inc $53                         ; disk level data offset

_InitNybbleMark   inc $1e                         ; will set carry the next round
                  inc $4f                         ; screen col  (00-1b)
                  ldy $4f                         ; screen col  (00-1b)
                  cpy #LR_ScrnMaxCols+1           ; $1b - max 27 cols
                  bcc _GetDataBytes

                  inc $50                         ; screen row  (00-0f)
                  lda $50                         ; screen row  (00-0f)
                  cmp #LR_ScrnMaxRows+1           ; $0f - max 15 rows
                  bcc _PackLevelI

                  lda #LR_DiskWrite
PackSaveLevelX    jmp ControlDiskOper             ; write and exit
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function: Decide whether a level is to be loaded from disk or not (demo)
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
ControlDiskOper   pha                             ; $01=read $02=write $04=init
                  bpl _ChkGameCtrl

                  pla
                  and #$7f                        ; bit 7=0
                  pha
                  jmp SetNoFileName

_ChkGameCtrl      lda LR_GameCtrl                 ; $00=start $01=demo $02=game $03=play_level $05=edit
                  lsr a
                  beq _IsDemo

_GoDiskRW         jmp DiskRW                      ; only game levels have to be loaded

_IsDemo           pla                             ; 3 demo levels are built in
                  lda LR_LevelNoDisk              ; 000-149
                  cmp #LR_LevelNoMaxDmo           ; max 3 demo levels
                  bcc _SetDemoData

_RestartDemo      lda #$00                        ; restart at level 1
                  sta LR_LevelNoDisk              ; 000-149
_IncDemoSpeed     inc LR_CntSpeedLaps             ; increase game speed
                  ldx LR_CntSpeedLaps
                  cpx #LR_CntSpeedMax+1
                  bcc _SetDemoData                ; max 9
                  
                  dec LR_CntSpeedLaps

_SetDemoData      clc
                  adc #>TabDemoLvlData            ; modify demo level data to get
                  sta __ModCpyDemoData            ;   to next level data
                  ldy #$00
_CpyDemoData      lda TabDemoLvlData,y            ; get demo level data - $b500/$b600/$b700
__ModCpyDemoData  = *-1
                  sta LR_LvlDataSavLod,y
                  iny
                  bne _CpyDemoData

ControlDiskOperX  rts
; ------------------------------------------------------------------------------------------------------------- ;
; GetPutHiScores  Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
GetPutHiScores    tax                             ; ac $01=load $02=store
                  lda LR_LevelNoDisk              ; 000-149
                  pha                             ; save disk level no

                  inc Mod__GetDiskByte
                  inc Mod__PutDiskByte

                  lda #LR_LevelNoScore            ; disk level 151 is the high score store
                  sta LR_LevelNoDisk              ; 000-149
                  txa                             ; ac 01=load 02=store
                  jsr ControlDiskOper

                  pla                             ; restore disk level no
                  sta LR_LevelNoDisk              ; 000-149

                  dec Mod__GetDiskByte
                  dec Mod__PutDiskByte

                  ldy #LR_HiScoreIdLen            ; length lr disk id
                  lda #$00
                  sta $25                         ; check result
_ChkDiskID        lda LR_HiScoreDiskId,y          ; lr disk id
                  eor TabLrDiskId,y
                  ora $25
                  sta $25
                  dey
                  bpl _ChkDiskID

                  lda $25
                  beq _SetMasterDisk

_SetBadDisk       lda #LR_DiskNoData              ; $00 - no load runner data disk
                  rts
                  
_SetMasterDisk    lda #LR_DiskMaster              ; $01 - disk in drive is a load runner master disk
                  ldx LR_HiScoreDiskUM            ; offset indicator store in high score block
                  bne GetPutHiScoresX             ; always
                  
_SetUserDisk      lda #LR_DiskData                ; $ff - disk in drive is a load runner user disk

GetPutHiScoresX   rts
; ------------------------------------------------------------------------------------------------------------- ;
; GetPutHiScores  Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
DiskRW            lda #$00
                  sta SPENA                       ; VIC 2 - $D015 = Sprite Enable
                  jsr CLALL                       ; KERNAL - $FFE7 = Close all Files

                  ldx #"0"
                  lda LR_LevelNoDisk              ; 000-149
                  and #$0f                        ; isolate right nybble for sector calculation
                  cmp #$0a
                  bcc _PutSectorHi                ; lower 10

                  ldx #"1"
                  sec
                  sbc #$0a                        ; subtract 10 gives values from 0-5
_PutSectorHi      stx BlkRWSecHi                  ; comand sector
                  clc
                  adc #$30                        ; generate digit 0-9
                  sta BlkRWSecLo

                  lda LR_LevelNoDisk              ; 000-149
                  lsr a                           ; isolate left nybbley
                  lsr a
                  lsr a
                  lsr a
                  clc
                  adc #$03                        ; add start track 3
                  ldx #"0"
                  cmp #$0a
                  bcc _PutTrackHi

                  ldx #"1"
                  sec
                  sbc #$0a                        ; 0-5
_PutTrackHi       stx BlkRWTrkHi
                  clc
                  adc #"0"
                  sta BlkRWTrkLo

SetNoFileName     lda #$00
                  jsr SETNAM                      ; KERNAL - $FFBD = Set Filename Parameters

                  lda #$0f
                  ldx #$08
                  ldy #$0f
                  jsr SETLFS                      ; KERNAL - $FFBA = Set Logical File Parameters
                  jsr OPEN                        ; KERNAL - $FFC0 = Open a Logical File
                  bcs DiskError                   ; disk error so DiskError

                  lda #$01                        ; length data set name
                  ldx #<FilNamHash
                  ldy #>FilNamHash
                  jsr SETNAM                      ; KERNAL - $FFBD = Set Filename Parameters

                  lda #$02
                  ldx #$08
                  ldy #$02
                  jsr SETLFS                      ; KERNAL - $FFBA = Set Logical File Parameters
                  jsr OPEN                        ; KERNAL - $FFC0 = Open a Logical File
                  bcs DiskError                   ; disk error so DiskError

                  pla                             ; get mode
                  lsr a
                  bcs ExecDiskCmdRead

                  lsr a
                  bcc _ClearDataI
                  jmp ExecDiskCmdWrite

_ClearDataI       ldy #LR_TileEmpty
                  tya
_ClearData        sta LR_HiScore,y                ; clear high score storage
                  sta LR_LvlDataSavLod,y          ; clear level storage
                  iny
                  bne _ClearData

                  lda #LR_LevelDiskMax            ; 149 blocks to write
                  sta LR_LevelNoDisk              ; 000-149
                  jsr CLALL                       ; KERNAL - $FFE7 = Close all Files

_PutClearedData   lda #LR_DiskWrite               ; write 150 empty levels to disk
                  jsr ControlDiskOper

                  dec LR_LevelNoDisk              ; 000-149
                  lda LR_LevelNoDisk              ; 000-149
                  cmp #$ff
                  bne _PutClearedData

                  ldy #LR_HiScoreIdLen            ; length lr id
_SetDiskID        lda TabLrDiskId,y               ; lr disk id=DANE BIGHAM
                  sta LR_HiScoreDiskId,y          ; store as lr disk id in high score data block
                  dey
                  bpl _SetDiskID

                  iny                             ; $00 - LR_DiskNoData
                  sty LR_HiScoreDiskUM            ; offset indicator store in high score block
_PutClearedScore  lda #LR_DiskWrite
                  jsr GetPutHiScores              ; Target: $1100-$11ff

DiskRWX           rts
; ------------------------------------------------------------------------------------------------------------- ;
DiskError         jmp StartGraficOut
; ------------------------------------------------------------------------------------------------------------- ;
; ExecDiskCmdRead Function: Generate Command for Disk Block Read
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
ExecDiskCmdRead   lda #"1"                        ;
                  sta BlkRWCmd                    ; u1=read
                  jsr CLRCHN                      ; KERNAL - $FFCC = Restore Default Devices

                  ldx #$0f                        ; command channel
                  jsr CHKOUT                      ; KERNAL - $FFC9 = Define an Output Channel
                  bcs DiskError

                  ldy #$00
_CmdOut           lda BlkRWCmdString,y            ; u1:02_0_tt_ss
                  beq _ChkDiskCC
                  jsr CHROUT                      ; KERNAL - $FFD2 = Output a Character
                  iny
                  jmp _CmdOut

_ChkDiskCC        jsr CheckDiskCC
                  jsr CLRCHN                      ; KERNAL - $FFCC = Restore Default Devices
                  ldx #$02                        ; data channel
                  jsr CHKIN                       ; KERNAL - $FFC6 = Define an Input Channel
                  bcs DiskError

                  jsr CHRIN                       ; KERNAL - $FFCF = Input a Character
                  ldy #$00
_ChrIn            jsr CHRIN                       ; KERNAL - $FFCF = Input a Character
                  sta LR_LvlDataSavLod,y          ; store disk data byte
Mod__GetDiskByte  = *-1
                  iny
                  bne _ChrIn
ExecDiskCmdReadX  jmp ResetDisk
; ------------------------------------------------------------------------------------------------------------- ;
; ExecDiskCmdWrite Function: Generate Command for Disk Block Write
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
ExecDiskCmdWrite  lda #"2"
                  sta BlkRWCmd                    ; u2=write
                  jsr CLRCHN                      ; KERNAL - $FFCC = Restore Default Devices

                  ldx #$02                        ; data channel
                  jsr CHKOUT                      ; KERNAL - $FFC9 = Define an Output Channel
                  bcs DiskError

                  ldy #$00
_ChrOut           lda LR_LvlDataSavLod,y          ; get data byte
Mod__PutDiskByte  = *-1
                  jsr CHROUT                      ; KERNAL - $FFD2 = Output a Character
                  iny
                  bne _ChrOut
                  jsr CLRCHN                      ; KERNAL - $FFCC = Restore Default Devices

                  ldx #$0f                        ; command channel
                  jsr CHKOUT                      ; KERNAL - $FFC9 = Define an Output Channel

                  ldy #$00
_CmdOut           lda BlkRWCmdString,y            ; u2:02_0_tt_ss
                  beq _ChkDiskCC

                  jsr CHROUT                      ; KERNAL - $FFD2 = Output a Character

                  iny
                  jmp _CmdOut

_ChkDiskCC        jsr CheckDiskCC

CalcDiskCmdX      jmp ResetDisk
; ------------------------------------------------------------------------------------------------------------- ;
                  .byte $00
FilNamHash        .byte $23 ; #

BlkRWCmdString    .byte $55 ; u
BlkRWCmd          .byte $31 ; 1
                  .byte $3a ; :
                  .byte $30 ; 0
                  .byte $32 ; 2
                  .byte $20 ; _
                  .byte $30 ; 0
                  .byte $20 ; _
BlkRWTrkHi        .byte $30 ; 0 - Track
BlkRWTrkLo        .byte $33 ; 3 - Track
                  .byte $20 ; _
BlkRWSecHi        .byte $30 ; 0 - Sector
BlkRWSecLo        .byte $30 ; 0 - Sector
                  .byte $0d ; <enter>
                  .byte $00 ; <end>

DiskInitString    .byte $55 ; u
                  .byte $2b ; +
                  .byte $0d ; <enter>
                  .byte $00 ; <end>
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
CheckDiskCC       jsr CLRCHN                      ; KERNAL - $FFCC = Restore Default Devices

                  ldx #$0f
                  jsr CHKIN                       ; KERNAL - $FFC6 = Define an Input Channel
                  jsr CHRIN                       ; KERNAL - $FFCF = Input a Character

                  sta $1e
                  jsr CHRIN                       ; KERNAL - $FFCF = Input a Character

                  ora $1e
                  sta $1e
_ChrIn            jsr CHRIN                       ; KERNAL - $FFCF = Input a Character
                  cmp #$0d                        ; ENTER
                  bne _ChrIn

                  lda $1e
                  cmp #$30
                  beq CheckDiskCCX

                  jmp ColdStart

CheckDiskCCX      rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
ResetDisk         jsr CLRCHN                      ; KERNAL - $FFCC = Restore Default Devices

                  ldx #$0f
                  jsr CHKOUT                      ; KERNAL - $FFC9 = Define an Output Channel

                  ldy #$00
_CpyCmd           lda DiskInitString,y            ; u+
                  beq ResetDiskX

                  jsr CHROUT                      ; KERNAL - $FFD2 = Output a Character

                  iny
                  jmp _CpyCmd

ResetDiskX        jmp CLALL                       ; KERNAL - $FFE7 = Close all Files
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
CheckLevel        ldy #LR_ScrnMaxRows             ; $0f - max 15 rows => start at bottom of screen
                  sty $50                         ; screen row  (00-0f)

                  lda #$00                        ; off
                  sta SPENA                       ; VIC 2 - $D015 = Sprite Enable

_SetLevelPtr      lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c

                  ldy #LR_ScrnMaxCols             ; start at end of each line = $1b - max 27 cols
                  sty $4f                         ; screen col  (00-1b)

_GetLevelByte     lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  ldx LR_LevelCtrl                ; level display control  $00=prepared copy already at $4000-$5fff
                  beq _ToGoGfxOutPrep

_ChkXitLadder     cmp #LR_TileLadderXit           ; hidden ladders
                  bne _ChkGold

                  ldx LR_NumXitLadders            ; # hidden ladders
                  cpx #LR_NumXitLdrsMax           ; max 45
                  bcs _SetEmptyByte

_CountXitLadders  inc LR_NumXitLadders            ; # hidden ladders

_PutXitLadderAdr  inx
                  lda $50                         ; screen row  (00-0f)
                  sta LR_TabXitLdrRow,x           ; adr row hidden ladders tab
                  tya
                  sta LR_TabXitLdrCol,x           ; adr column hidden ladder tab

_SetEmptyByte     lda #LR_TileEmpty               ; blank for hidden ladder/enemy
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  sta ($0b),y                     ; play level control data ($0a00-$0bc3)
_ToGoGfxOutPrep   beq _GoGfxOutPrep               ; always

_ChkGold          cmp #LR_TileGold                ; gold
                  bne _ChkEnemy

_CountGold        inc LR_GoldToGet
                  bne _GoGfxOutPrep

_ChkEnemy         cmp #LR_TileEnemy               ; enemy
                  bne _ChkLodeRunner

                  ldx LR_EnmyNo                   ; number of enemies
                  cpx #LR_EnmyNoMax               ; max 5
                  bcs _SetEmptyByte

_CountEnemies     inc LR_NoEnemy2Move             ; # of enemy to move
                  inc LR_EnmyNo                   ; number of enemies

_PutEnemyData     inx
                  tya
                  sta LR_TabEnemyCol,x            ; adr column enemies
                  lda $50                         ; screen row  (00-0f)
                  sta LR_TabEnemyRow,x            ; adr row enemies
                  lda #$00
                  sta LR_TabEnemyGold,x           ; enemy has gold tab
                  sta LR_TabEnemySprNo,x          ; actual enemy sprite number
                  lda #$02                        ; center to
                  sta LR_TabEnemyPosLR,x          ; enemy pos on image left/right tab
                  sta LR_TabEnemyPosUD,x          ; enemy pos on image up/down tab

                  lda #LR_TileEmpty
                  sta ($0b),y                     ; play level control data ($0a00-$0bc3)
                  lda #LR_TileEmpty
                  jsr ImageOutToPrep              ; direct output to preparation screen

                  lda #LR_TileEnemy               ; enemy
                  bne _GoGfxOutPrep               ; always

_GoSetLevelPtr    bpl _SetLevelPtr
_GoGetLevelByte   bpl _GetLevelByte

_ChkLodeRunner    cmp #LR_TileLR                  ; lode runner
                  bne _ChkTrap

                  ldx $03
                  bpl _SetEmptyByte               ; one lr found already so blank out

                  sty $03                         ; adr column lode runner
                  ldx $50                         ; screen row  (00-0f)
                  stx $04                         ; actual row lode runner

                  ldx #$02                        ; middle
                  stx $05                         ; lr pos on image left/right
                  stx $06                         ; lr pos on image up/down

                  ldx #$08
                  stx $07                         ; lr sprite number

                  lda #LR_TileEmpty
                  sta ($0b),y                     ; clear lr in play level control data ($0a00-$0bc3)
                  lda #LR_TileEmpty
                  jsr ImageOutToPrep              ; direct output to preparation screen

                  lda #LR_TileLR                  ; lode runner
                  bne _GoGfxOutPrep               ; always

_ChkTrap          cmp #LR_TileWallTrap            ; trap
                  bne _GoGfxOutPrep
                  lda #LR_TileWallSoft            ; wall for trap

_GoGfxOutPrep     jsr ImageOutToPrep              ; direct output to preparation screen

                  dec $4f                         ; next screen col  (00-1b) bottom up
                  ldy $4f                         ; screen col  (00-1b)
                  bpl _GoGetLevelByte

                  dec $50                         ; next screen row  (00-0f) bottom up
                  ldy $50                         ; screen row  (00-0f)
                  bpl _GoSetLevelPtr

                  lda LR_LevelCtrl                ; level display control  $00=prepared copy already at $4000-$5fff
                  beq ScreenPrep2Disp             ; copy prepared hires screen data to display screen

                  lda $03                         ; adr column lode runner
                  bpl LvlResetEnmyLR              ; lode runner tile found

_SetError         sec                             ; no lode runner tile found
CheckLevelX       rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function: Copy prepared HiRes Screen Data to HiRes Display Screen
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
ScreenPrep2Disp   lda #>LR_ScrnHiReDisp           ; to:   display hires screen
                  sta $12
                  lda #>LR_ScrnHiRePrep           ; from: prepare hires screen for direct output
                  sta $10

                  lda #$00
                  sta $11
                  sta $0f

                  tay
_Copy             lda ($0f),y
                  sta ($11),y
                  iny
                  bne _Copy
                  inc $12
                  inc $10

                  ldx $10
                  cpx #>(LR_ScrnHiRePrep + $2000) ; end of screen data $5fff reached
                  bcc _Copy                       ; no

                  clc
ScreenPrep2DispX  rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
LvlResetEnmyLRNC  lda #>LR_ScrnHiRePrep           ; $40
                  sta $51                         ; target output  $20=$2000 $40=$4000
                  jsr StatusLines
                  jsr ScreenPrep2Disp             ; copy prepared hires screen data to display screen

                  lda #>LR_ScrnHiReDisp           ; $20
                  sta $51                         ; target output  $20=$2000 $40=$4000
                  bne LvlResetEnmyLRI             ; always
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
LvlResetEnmyLR    lda LR_StartCycle               ; ==> start cycle  on=ff
                  beq LvlResetEnmyLRNC

                  jsr CircleLevelOut

LvlResetEnmyLRI   ldy #LR_ScrnMaxRows             ; $0f - max 15 rows
                  sty $50                         ; screen row  (00-0f)
_SetOutRow        lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a

                  ldy #LR_ScrnMaxCols             ; $1b - max 27 cols
                  sty $4f                         ; screen col  (00-1b)

_GetData          lda ($09),y                     ; unpacked level data ($0800-$09c3)
_ChkLodeRunner    cmp #LR_TileLR                  ; lode runner
                  beq _SetBlank

_ChkEnemy         cmp #LR_TileEnemy               ; enemy
                  bne _NextOutCol

_SetBlank         lda #$00                        ; blank substitution
                  jsr ImageOutToPrep              ; direct output to preparation screen

_NextOutCol       dec $4f                         ; screen col  (00-1b)
                  ldy $4f                         ; screen col  (00-1b)
                  bpl _GetData

_NextOutRow       dec $50                         ; screen row  (00-0f)
                  ldy $50                         ; screen row  (00-0f)
                  bpl _SetOutRow

                  clc
LvlOutX           rts
; ------------------------------------------------------------------------------------------------------------- ;
; MoveLodeRunner  Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
MoveLodeRunner    lda #LR_GetGoldGot
                  sta LR_GetGold                  ; get gold  $00=just gets it
                  lda LR_Shoots                   ; $00=no $01=right $ff=left
                  beq _MoveLR
                  bpl _GoFireRightLR
_GoFireLeftLR     jmp FireLeftLR
_GoFireRightLR    jmp FireRightLR

_MoveLR           ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c

                  ldy $03
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)  = data under lr
                  cmp #LR_TileLadder              ; ladder
                  beq _GoChkFallDown

                  cmp #LR_TilePole                ; pole
                  bne _GetPosUD

                  lda $06                         ; lr pos on image up/down
                  cmp #$02                        ; in middle of screen image
                  beq _GoChkFallDown

_GetPosUD         lda $06                         ; lr pos on image up/down
                  cmp #$02                        ; in middle of screen image
                  bcc _SetFallDown

                  ldy $04                         ; actual row lode runner
                  cpy #LR_ScrnMaxRows             ; $0f - max 15 rows
                  beq _GoChkFallDown              ; bottom reached

                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8+1,y        ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  ldy $03                         ; adr column lode runner
                  lda ($09),y                     ; unpacked level data ($0800-$09c3) + 1
                  cmp #$00                        ; nothing
                  beq _SetFallDown

                  cmp #LR_TileEnemy               ; enemy
                  beq _GoChkFallDown

                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileWallSoft            ; wall
                  beq _GoChkFallDown

                  cmp #LR_TileWallHard            ; solid wall
                  beq _GoChkFallDown

                  cmp #LR_TileLadder              ; ladder
                  bne _SetFallDown

_GoChkFallDown    jmp _EndFallDown

_SetFallDown      lda #LR_Falls
                  sta LR_FallsDown                ; $00=fall $20=no fall $ff=init
                  dec LR_FallBeep
                  jsr GetLRGfxOff
                  jsr UpdSprtModGfx               ; shooting/closing holes/removing gold

                  lda #$07
                  ldx $08                         ; control shooter mode
                  bmi _SetSpriteNo

                  lda #$0f
_SetSpriteNo      sta $07                         ; lr sprite number
                  jsr MovLRWaitPosX

                  inc $06                         ; lr pos on image up/down
                  lda $06
                  cmp #$05                        ; max
                  bcs _InitPosUD

                  jsr MovLRGold                   ; wait for center and handle the gold
                  jmp MovLRKill

_InitPosUD        lda #$00
                  sta $06                         ; lr pos on image up/down

                  ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c

                  ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileWallSoft            ; wall
                  bne _Store

                  lda #LR_TileEmpty               ; empty substitution
                  
_Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  inc $04                         ; actual row lode runner
                  ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $03                         ; adr column lode runner
                  lda #LR_TileLR                  ; lode runner
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  jmp MovLRKill

_EndFallDown      lda LR_FallsDown                ; $00=fall $20=no fall $ff=init
                  bne _Always
                  
_Always           lda #LR_FallsNo                 ; end
                  sta LR_FallsDown                ; $00=fall $20=no fall $ff=init

                  jsr GetPlayCmd

                  lda LR_JoyUpDo
_ChkMoveUp        cmp #LR_JoyMoveUp               ; move up
                  bne _ChkMoveDown

_MoveUp           jsr MovLRUp
                  bcs _ChkMoveLeft
                  rts

_ChkMoveDown      cmp #LR_JoyMoveDo               ; move down
                  bne _ChkFireLeft
_MoveDown         jsr LRMoveDown
                  bcs _ChkMoveLeft
                  rts

_ChkFireLeft      cmp #LR_JoyFireLe               ; fire left
                  bne _ChkFireRight
_FireLeft         jsr MovLRFireLeft
                  bcs _ChkMoveLeft
                  rts

_ChkFireRight     cmp #LR_JoyFireRi               ; fire right
                  bne _ChkMoveLeft
_FireRight        jsr MovLRFireRight
                  bcs _ChkMoveLeft
                  rts

_ChkMoveLeft      lda LR_JoyLeRi
                  cmp #LR_JoyMoveLe               ; move left
                  bne _ChkMoveRight
_MoveLeft         jmp MovLRLeft

_ChkMoveRight     cmp #LR_JoyMoveRi               ; move right
                  bne MoveLodeRunnerX
_MoveRight        jmp LRMoveRight

MoveLodeRunnerX   rts
; ------------------------------------------------------------------------------------------------------------- ;
MovLRLeft         ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  ldx $05
                  cpx #$03
                  bcs MovLRLeftABit               ; not yet in center so MovLRLeftABit

                  ldy $03                         ; adr column lode runner
                  beq MovLRLeftX

                  dey
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #LR_TileWallHard            ; solid wall
                  beq MovLRLeftX

                  cmp #LR_TileWallSoft            ; wall
                  beq MovLRLeftX

                  cmp #LR_TileWallTrap            ; trap
                  bne MovLRLeftABit

MovLRLeftX        rts
; ------------------------------------------------------------------------------------------------------------- ;
MovLRLeftABit     jsr GetLRGfxOff
                  jsr UpdSprtModGfx               ; shooting/closing holes/removing gold
                  
                  lda #$ff
                  sta $08                         ; control shooter mode
                  jsr MovLRWaitPosY
                  
                  dec $05                         ; lr pos on image left/right = one step left
                  bpl _Gold                       ; move from actual to next left field not yet complete
                  
_NewField         ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileWallSoft            ; wall
                  bne _Store
                                    
                  lda #LR_TileEmpty               ; empty substitution
                  
_Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)

                  dec $03                         ; adr column lode runner
                  dey
                  lda #LR_TileLR                  ; lode runner
_SetLR            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  lda #$04                        ; max right to
                  sta $05                         ;   lr pos on image left/right
                  bne _SetNextPos                 ; always
                  
_Gold             jsr MovLRGold                   ; wait for center and handle the gold

_SetNextPos       ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TilePole                ; pole
                  beq _PoleImage
                  
_RunImage         lda #$00                        ; low image no
                  ldx #$02                        ; high image no
                  bne _OutImage
                  
_PoleImage        lda #$03                        ; low image no
                  ldx #$05                        ; high image no
_OutImage         jsr MovLRSetImg

MovLRLeftABitX    jmp MovLRKill
; ------------------------------------------------------------------------------------------------------------- ;
LRMoveRight       ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldx $05                         ; lr pos on image left/right
                  cpx #$02
                  bcc MovLRRightABit              ; not yet in center so MovLRRightABit
                  
                  ldy $03                         ; adr column lode runner
                  cpy #LR_ScrnMaxCols             ; $1b - max 27 cols
                  beq LRMoveRightX
                  
                  iny
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #LR_TileWallHard            ; solid wall
                  beq LRMoveRightX
                  
                  cmp #LR_TileWallSoft            ; wall
                  beq LRMoveRightX
                  
                  cmp #LR_TileWallTrap            ; trap
                  bne MovLRRightABit
                  
LRMoveRightX      rts
; ------------------------------------------------------------------------------------------------------------- ;
MovLRRightABit    jsr GetLRGfxOff
                  jsr UpdSprtModGfx               ; shooting/closing holes/removing gold
                  
                  lda #$01
                  sta $08                         ; control shooter mode
                  jsr MovLRWaitPosY
                  
                  inc $05                         ; lr pos on image left/right
                  lda $05                         ; lr pos on image left/right
                  cmp #$05                        ; max
                  bcc _Gold
                  
                  ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileWallSoft            ; wall
                  bne _Store
                  
                  lda #LR_TileEmpty               ; empty substitution
_Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)

                  inc $03                         ; adr column lode runner
                  iny
                  lda #LR_TileLR                  ; lode runner
_SetLR            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  lda #$00
                  sta $05                         ; lr pos on image left/right
                  beq _SetNextPos                 ; always

_Gold             jsr MovLRGold                   ; wait for center and handle the gold

_SetNextPos       ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TilePole                ; pole
                  beq _PoleImage
                  
_RunImage         lda #$08                        ; low image no
                  ldx #$0a                        ; high image no
                  bne _OutImage
                  
_PoleImage        lda #$0b                        ; low image no
                  ldx #$0d                        ; high image no
_OutImage         jsr MovLRSetImg

MovLRRightABitX   jmp MovLRKill
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
MovLRUp           ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3) = data under lr
                  cmp #LR_TileLadder              ; ladder
                  beq MovLRUpABit
                  
                  ldy $06                         ; lr pos on image up/down
                  cpy #$03                        ; in center
                  bcc MovUpXitSetCarry            ; no
                  
                  ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3) + 1 = data below lr
                  cmp #LR_TileLadder
                  beq MovUpGetGfxOff
                  
MovUpXitSetCarry  sec
MovLRUpX          rts
; ------------------------------------------------------------------------------------------------------------- ;
MovLRUpABit       ldy $06                         ; lr pos on image up/down
                  cpy #$03                        ; in center
                  bcs MovUpGetGfxOff              ; equal/higher
                  
                  ldy $04                         ; actual row lode runner
                  beq MovUpXitSetCarry
                  
                  lda TabExLvlDatRowLo-1,y        ; expanded level data row pointer lo
                  sta $09
                  lda TabExLvlDatRowH8-1,y        ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $03                         ; adr column lode runner
                  lda ($09),y                     ; unpacked level data ($0800-$09c3) - 1 = data above lr
                  cmp #LR_TileWallSoft            ; wall
                  beq MovUpXitSetCarry
                  
                  cmp #LR_TileWallHard            ; solid wall
                  beq MovUpXitSetCarry
                  
                  cmp #LR_TileWallTrap            ; trap
                  beq MovUpXitSetCarry
                  
                  
MovUpGetGfxOff    jsr GetLRGfxOff
                  jsr UpdSprtModGfx               ; shooting/closing holes/removing gold
                  
                  ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  jsr MovLRWaitPosX
                  
                  dec $06                         ; lr pos on image up/down
                  bpl MovUpDownGold
                  
                  ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileWallSoft            ; wall
                  bne _Store
                  
                  lda #LR_TileEmpty               ; empty substitution
                  
_Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)

                  dec $04                         ; actual row lode runner
                  ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a

                  ldy $03                         ; adr column lode runner
                  lda #LR_TileLR                  ; lode runner
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)

                  lda #$04
                  sta $06                         ; lr pos on image up/down
                  bne MovUpDown                   ; always
                  
MovUpDownGold     jsr MovLRGold                   ; wait for center and handle the gold

MovUpDown         lda #$10                        ; low image no
                  ldx #$11                        ; high image no
                  jsr MovLRSetImg
                  jsr MovLRKill
                  
                  clc
MovLRUpABitX      rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
LRMoveDown        ldy $06                         ; lr pos on image up/down
                  cpy #$02                        ; in center of screen image
                  bcc MovLRDownABit
                  
                  ldy $04                         ; actual row lode runner
                  cpy #LR_ScrnMaxRows             ; $0f - max 15 rows
                  bcs _XitSetCarry
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8+1,y        ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $03                         ; adr column lode runner
                  lda ($09),y                     ; unpacked level data ($0800-$09c3) + 1
                  cmp #LR_TileWallHard            ; solid wall
                  beq _XitSetCarry
                  
                  cmp #LR_TileWallSoft            ; wall
                  bne MovLRDownABit
                  
_XitSetCarry      sec
LRMoveDownX       rts
; ------------------------------------------------------------------------------------------------------------- ;
MovLRDownABit     jsr GetLRGfxOff
                  jsr UpdSprtModGfx               ; shooting/closing holes/removing gold
                  
                  ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  jsr MovLRWaitPosX
                  
                  inc $06                         ; lr pos on image up/down
                  lda $06                         ; lr pos on image up/down
                  cmp #$05                        ; center screen image
                  bcc _GoMovUpDownGold
                  
                  ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileWallSoft            ; wall
                  bne _Store
                  
                  lda #LR_TileEmpty               ; empty substitution
                  
_Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  inc $04                         ; actual row lode runner
                  ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $03                         ; adr column lode runner
                  lda #LR_TileLR                  ; lode runner
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)

                  lda #$00
                  sta $06                         ; lr pos on image up/down
                  jmp MovUpDown
                  
_GoMovUpDownGold  jmp MovUpDownGold

FireLeftNone      jmp OutLRFireLeftNo
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
MovLRFireLeft     lda #LR_ShootsLe
                  sta LR_Shoots                   ; $00=no $01=right $ff=left
                  sta LR_JoyUpDo
                  sta LR_JoyLeRi
                  lda #$00
                  sta $54                         ; lr actual sprite number

FireLeftLR        ldy $04                         ; actual row lode runner
                  cpy #LR_ScrnMaxRows             ; $0f - max 15 rows
                  bcs FireLeftNone                ; no walls left for shooting

                  iny
                  jsr GetCtrlDataPtr
                  
                  ldy $03                         ; adr column lode runner
                  beq FireLeftNone                ; leftmost position
                  
                  dey
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #LR_TileWallSoft            ; wall
                  bne FireLeftNone
                  
                  ldy $04                         ; actual row lode runner
                  jsr GetCtrlDataPtr
                  
                  ldy $03                         ; adr column lode runner
                  dey
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #LR_TileEmpty               ; empty
                  bne OutLRFireLeft

                  jsr GetLRGfxOff
                  jsr UpdSprtModGfx               ; shooting/closing holes/removing gold
                  
                  jsr MovLRWaitPosX
                  jsr MovLRWaitPosY
                  
                  ldx $54                         ; lr actual sprite number
                  lda #$00
                  cpx #$06
                  bcs _StoreSpriteNo
                  
                  lda #$06
                  
_StoreSpriteNo    sta $07
                  jsr MovLRKill
                  
                  ldx $54                         ; lr actual sprite number
                  cpx #$0c
                  beq MovLRSetHoleLe
                  
                  cpx #$00
                  beq _GetImageNo
                  
                  lda TabLRFireLeLo,x
                  pha

                  ldx $03                         ; adr column lode runner
                  dex
                  ldy $04                         ; actual row lode runner
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row

                  pla
                  jsr UpdSprtModGfx               ; shooting/closing holes/removing gold
                  
                  ldx $54                         ; lr actual sprite number
_GetImageNo       lda TabLRFireLeHi,x
                  pha                             ; save image number

                  ldx $03                         ; adr column lode runner
                  dex
                  stx $4f                         ; screen col  (00-1b)
                  
                  ldy $04                         ; actual row lode runner
                  sty $50                         ; screen row  (00-0f)
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row

                  pla                             ; restore image number
                  jsr OutSpriteGfx

                  ldx $54                         ; lr actual sprite number
                  lda TabLRFireLe,x
                  inc $50                         ; screen row  (00-0f)
                  jsr ImageOutToDisp              ; direct output to display screen

                  inc $54                         ; lr actual sprite number
                  
                  clc
MovLRFireLeftX    rts
; ------------------------------------------------------------------------------------------------------------- ;
OutLRFireLeft     ldy $04                         ; actual row lode runner
                  iny                             ; +1
                  sty $50                         ; screen row  (00-0f)
                  ldy $03                         ; adr column lode runner
                  dey
                  sty $4f                         ; screen col  (00-1b)

                  lda #LR_TileWallSoft
                  jsr ImageOutToDisp              ; direct output to display screen

                  ldx $54                         ; lr actual sprite number
                  beq OutLRFireLeftNo

                  dex
                  lda TabLRFireLeHi,x
                  pha

                  ldy $04                         ; actual row lode runner
                  ldx $03                         ; adr column lode runner
                  dex
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row

                  pla
                  jsr UpdSprtModGfx               ; shooting/closing holes/removing gold

OutLRFireLeftNo   lda #LR_ShootsNo
                  sta LR_Shoots                   ; $00=no $01=right $ff=left

                  sec
OutLRFireLeftX    rts
; ------------------------------------------------------------------------------------------------------------- ;
MovLRSetHoleLe    ldx $03                         ; adr column lode runner
                  dex
                  jmp MovLRSetHole
; ------------------------------------------------------------------------------------------------------------- ;
GoSetNoShoot      jmp SetNoShoot
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
MovLRFireRight    lda #LR_ShootsRi
                  sta LR_Shoots                   ; $00=no $01=right $ff=left
                  sta LR_JoyUpDo
                  sta LR_JoyLeRi
                  lda #$0c
                  sta $54                         ; lr actual sprite number

FireRightLR       ldy $04                         ; actual row lode runner
                  cpy #LR_ScrnMaxRows             ; $0f - max 15 rows
                  bcs GoSetNoShoot

                  iny
                  jsr GetCtrlDataPtr
                  ldy $03                         ; adr column lode runner
                  cpy #LR_ScrnMaxCols             ; $1b - max 27 cols
                  bcs GoSetNoShoot

                  iny
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #LR_TileWallSoft            ; wall
                  bne GoSetNoShoot

                  ldy $04                         ; actual row lode runner
                  jsr GetCtrlDataPtr

                  ldy $03                         ; adr column lode runner
                  iny
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #LR_TileEmpty               ; empty
                  bne MovLRFireNoHole

                  jsr GetLRGfxOff
                  jsr UpdSprtModGfx               ; shooting/closing holes/removing gold
                  jsr MovLRWaitPosX
                  jsr MovLRWaitPosY

                  ldx $54                         ; lr actual sprite number
                  lda #$08
                  cpx #$12
                  bcs _SetSprite

                  lda #$0e
_SetSprite        sta $07                         ; lr sprite number
                  jsr MovLRKill

                  ldx $54                         ; lr actual sprite number
                  cpx #$18
                  beq MovLRSetHoleRi

                  cpx #$0c
                  beq _GetFireLeHi

_GetFireLeLo      lda TabLRFireLeLo,x
                  pha

                  ldx $03                         ; adr column lode runner
                  inx
                  ldy $04                         ; actual row lode runner
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row

                  pla
                  jsr UpdSprtModGfx               ; shooting/closing holes/removing gold

                  ldx $54                         ; lr actual sprite number
_GetFireLeHi      lda TabLRFireLeHi,x
                  pha

                  ldx $03                         ; adr column lode runner
                  inx
                  stx $4f                         ; screen col  (00-1b)
                  ldy $04                         ; actual row lode runner
                  sty $50                         ; screen row  (00-0f)
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row

                  pla
                  jsr OutSpriteGfx

                  inc $50                         ; screen row  (00-0f)
                  ldx $54
                  lda TabLRFireRi,x
                  jsr ImageOutToDisp              ; direct output to display screen

                  inc $54
                  clc
MovLRFireRightX   rts
; ------------------------------------------------------------------------------------------------------------- ;
MovLRFireNoHole   ldy $04                         ; actual row lode runner
                  iny
                  sty $50                         ; screen row  (00-0f)
                  ldy $03                         ; adr column lode runner
                  iny
                  sty $4f                         ; screen col  (00-1b)
                  lda #LR_TileWallSoft            ; wall
                  jsr ImageOutToDisp              ; direct output to display screen

                  ldx $54                         ; lr actual sprite number
                  cpx #$0c
                  beq SetNoShoot

                  dex
                  lda TabLRFireLeHi,x
                  pha

                  ldx $03                         ; adr column lode runner
                  inx
                  ldy $04                         ; actual row lode runner
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row

                  pla
                  jsr UpdSprtModGfx               ; shooting/closing holes/removing gold

SetNoShoot        lda #LR_ShootsNo
                  sta LR_Shoots                   ; $00=no $01=right $ff=left

                  sec
MovLRFireNoHoleX  rts
; ------------------------------------------------------------------------------------------------------------- ;
MovLRSetHoleRi    ldx $03
                  inx
                  jmp MovLRSetHole
; ------------------------------------------------------------------------------------------------------------- ;
TabLRImages       .byte $0b
                  .byte $0c
                  .byte $0d
                  .byte $18
                  .byte $19
                  .byte $1a
                  .byte $0f
                  .byte $13
                  .byte $09
                  .byte $10
                  .byte $11
                  .byte $15
                  .byte $16
                  .byte $17
                  .byte $25
                  .byte $14
                  .byte $0e
; ------------------------------------------------------------------------------------------------------------- ;
TabLRFireLeLo     .byte $12
TabLRFireLeHi     .byte $1b
                  .byte $1b
                  .byte $1c
                  .byte $1c
                  .byte $1d
                  .byte $1d
                  .byte $1e
                  .byte $1e
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
; ------------------------------------------------------------------------------------------------------------- ;
TabLRFireRi       .byte $26
                  .byte $26
                  .byte $27
                  .byte $27
                  .byte $1d
                  .byte $1d
                  .byte $1e
                  .byte $1e
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
; ------------------------------------------------------------------------------------------------------------- ;
TabLRFireLe       .byte $1f
                  .byte $1f
                  .byte $20
                  .byte $20
                  .byte $21
                  .byte $21
                  .byte $22
                  .byte $22
                  .byte $23
                  .byte $23
                  .byte $24
                  .byte $24
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
StartDemo         lda LR_KeyNew
                  bne _KeyPressed

                  lda CIAPRA                      ; CIA 1 - $DC00 = Data Port A
                  and #$10                        ; isolate fire button
                  bne RunDemo

_KeyPressed       lsr $59
                  lsr LR_Alive                    ; $00=lr killed
                  lda #$01
                  sta LR_NumLives

StartDemoX        rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
RunDemo           lda $58                         ; duration demo move
                  bne _DoMove                     ; not ended yet

                  ldy #$00
_GetMove          lda ($55),y                     ; demo data pointer
                  sta $57                         ; type of demo move  (l/r/u/d/fire)

                  iny
                  lda ($55),y                     ; demo data pointer
                  sta $58                         ; duration demo move

_IncMovePtr       lda $55                         ; demo data pointer low
                  clc
                  adc #$02                        ; point to next demo data pair
                  sta $55                         ; demo data pointer low
                  lda $56                         ; demo data pointer high
                  adc #$00                        ; add carry
                  sta $56                         ; demo data pointer high

_DoMove           lda $57                         ; type demo move  (l/r/u/d/fire)
                  and #$0f                        ; isolate right nybble for up/down moves
                  tax
                  lda TabDemoJoyActn,x            ; demo joystick action tab
_SetUpDo          sta LR_JoyUpDo

                  lda $57                         ; type demo move  (l/r/u/d/fire)
                  lsr a                           ; isolate left nybble for left/right moves
                  lsr a
                  lsr a
                  lsr a
                  tax
                  lda TabDemoJoyActn,x
_SetLeRi          sta LR_JoyLeRi

_DecTime          dec $58                         ; duration demo move

RunDemoX          rts
; ------------------------------------------------------------------------------------------------------------- ;
TabDemoJoyActn    .byte LR_JoyMoveUp ; $00=up
                  .byte LR_JoyMoveLe ; $01=left
                  .byte LR_JoyMoveDo ; $02=down
                  .byte LR_JoyMoveRi ; $03=right
                  .byte LR_JoyFireRi ; $04=fire-right
                  .byte LR_JoyFireLe ; $05=fire-left
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
GetPlayCmd        lda LR_GameCtrl                 ; $00=start $01=demo $02=game $03=play_level $05=edit
                  cmp #LR_GameDemo
                  beq StartDemo

                  ldx LR_KeyNew
                  bne _ChkKeyI                    ; pressed

                  lda LR_ControllerTyp            ; controler type  ca=joystick  cb=keyboard
                  cmp #LR_Keyboard
                  beq GetPlayCmdX

_GoChkJoyPort     jmp ChkJoyPort

_ChkKeyI          lda #$00                        ; reset actual key
                  sta LR_KeyNew
                  stx $23                         ; save actual key
                  ldy #$ff
_ChkKey           iny
                  lda TabPlayCmdChr,y             ; in game keys tab  (U F Run/Stop R A J K + - Z D)
                  beq _ChkCtrlType                ; was no legal command key

                  cmp $23                         ; level input tile $00-$09
                  bne _ChkKey

                  tya
                  asl a                           ; *2
                  tay
_PrepareCmd       lda TabPlayCmdSub+1,y
                  pha
                  lda TabPlayCmdSub,y
                  pha
_DispatchCmd      rts                             ; dispatch command

_ChkCtrlType      lda LR_ControllerTyp            ; controler type  ca=joystick  cb=keyboard
                  cmp #LR_Joystick
                  beq _GoChkJoyPort

                  ldx $23                         ; saved actual key
                  stx LR_JoyUpDo
                  stx LR_JoyLeRi

GetPlayCmdX       rts
; ------------------------------------------------------------------------------------------------------------- ;
IGC_NextLvl       inc LR_NumLives                 ; U=play next level
                  inc LR_LevelNoGame              ; 001-150
                  inc LR_LevelNoDisk              ; 000-149
                  lsr LR_Alive                    ; $00=lr killed
                  lsr LR_Cheated                  ; $00=yes
                  
IGC_NextLvlX      rts
; ------------------------------------------------------------------------------------------------------------- ;
IGC_IncNumLife    inc LR_NumLives                 ; F=increase life counter
                  bne _Out
                  
                  dec LR_NumLives
_Out              jsr LivesToBaseLine

                  lsr LR_Cheated                  ; $00=yes  $01=no
                  
IGC_IncNumLifeX   jmp GetPlayCmd
; ------------------------------------------------------------------------------------------------------------- ;
B_7955            inc LR_CntSpeedLaps             ; ==> ?=not dispatched
                  inc LR_NumLives
                  lsr LR_Alive                    ; $00=lr killed
                  
                  rts
; ------------------------------------------------------------------------------------------------------------- ;
IGC_Pause         jsr GetAKey                     ; RUN/STOP=pause game
                  cmp #$3f                        ; RUN/STOP
                  bne IGC_Pause
                  
IGC_PauseX        jmp GetPlayCmd
; ------------------------------------------------------------------------------------------------------------- ;
IGC_GiveUp        jmp GameOver                    ; R=give up
; ------------------------------------------------------------------------------------------------------------- ;
IGC_Suicide       lsr LR_Alive                    ; A=suicide - $00=lr killed
IGC_SuicideX      rts
; ------------------------------------------------------------------------------------------------------------- ;
IGC_SetJoy        lda #LR_Joystick
                  sta LR_ControllerTyp
IGC_SetJoyX       jmp GetPlayCmd
; ------------------------------------------------------------------------------------------------------------- ;
IGC_SetKey        lda #LR_Keyboard
                  sta LR_ControllerTyp
IGC_SetKeyX       jmp GetPlayCmd
; ------------------------------------------------------------------------------------------------------------- ;
IGC_DecSpeed      lda LR_GameSpeed                ; -=decrease game speed
                  cmp #LR_SpeedMin
                  beq IGC_IncSpeedX
                  
                  dec LR_GameSpeed
IGC_DecSpeedX     jmp GetPlayCmd
; ------------------------------------------------------------------------------------------------------------- ;
IGC_IncSpeed      lda LR_GameSpeed                ; +=increase game speed
                  cmp #LR_SpeedMax
                  beq IGC_IncSpeedX
                  
                  inc LR_GameSpeed
IGC_IncSpeedX     jmp GetPlayCmd
; ------------------------------------------------------------------------------------------------------------- ;
IGC_Cycle         lda LR_StartCycle               ; ==> Z=toggle start circle
                  eor #$ff
                  sta LR_StartCycle
IGC_CycleX        jmp GetPlayCmd
; ------------------------------------------------------------------------------------------------------------- ;
IGC_ShootMode     lda LR_ShootMode                ; D=toggle shooter mode
                  eor #$ff
                  sta LR_ShootMode
IGC_ShootModeX    jmp GetPlayCmd
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
ChkJoyPort        lda CIAPRA                      ; CIA 1 - $DC00 = Data Port A
                  and #$10                        ; Bit 4: Joystick 2 - Fire   0=pressed
                  bne _ChkMoves

_CheckMode        lda $08
                  eor LR_ShootMode
                  bpl _FireLeft

_FireRight        lda #LR_JoyFireRi
                  sta LR_JoyUpDo
                  sta LR_JoyLeRi
_FireRightX       rts

_FireLeft         lda #LR_JoyFireLe
                  sta LR_JoyUpDo
                  sta LR_JoyLeRi
_FireLeftX        rts

_ChkMoves         lda CIAPRA                      ; CIA 1 - $DC00 = Data Port A
                  sta $1e                         ; SavCIA

_ChkUpDown        and #$02                        ; Bit 1: Joystick 2 - Down   0=pressed
                  beq _SetDown

                  lda $1e                         ; SavCIA
                  and #$01                        ; Bit 0: Joystick 2 - Up     0=pressed
                  beq _SetUp

_NetNoneUpDown    ldx #LR_JoyMoveNone
                  stx LR_JoyUpDo
                  beq _ChkLeftRight               ; always

_SetUp            ldx #LR_JoyMoveUp
                  stx LR_JoyUpDo
                  bne _ChkLeftRight               ; always

_SetDown          ldx #LR_JoyMoveDo
                  stx LR_JoyUpDo

_ChkLeftRight     lda $1e                         ; SavCIA
                  and #$08                        ; Bit 3: Joystick 2 - Right  0=pressed
                  beq _SetRight

                  lda $1e
                  and #$04                        ; Bit 2: Joystick 2 - Left   0=pressed
                  beq _SetLeft

_SetNoneRiLeft    ldx #LR_JoyMoveNone
                  stx LR_JoyLeRi
_SetNoneRiLeftX   rts

_SetRight         ldx #LR_JoyMoveRi
                  stx LR_JoyLeRi
_SetRightX        rts

_SetLeft          ldx #LR_JoyMoveLe
                  stx LR_JoyLeRi
ChkJoyPortX       rts
; ------------------------------------------------------------------------------------------------------------- ;
TabPlayCmdChr     .byte $9e ; U
                  .byte $95 ; F
                  .byte $3f ; RUN/STOP
                  .byte $91 ; R
                  .byte $8a ; A
                  .byte $a2 ; J
                  .byte $a5 ; K
                  .byte $2b ; +
                  .byte $28 ; -
                  .byte $8c ; Z
                  .byte $92 ; D
                  .byte $00 ; <end_of_tab>

TabPlayCmdSub     .word IGC_NextLvl    -1 ; U        - Try Next Level
                  .word IGC_IncNumLife -1 ; F        - Inc Number of Lives
                  .word IGC_Pause      -1 ; RUN/STOP - Pause game
                  .word IGC_GiveUp     -1 ; R        - Give Up
                  .word IGC_Suicide    -1 ; A        - Suizide
                  .word IGC_SetJoy     -1 ; J        - Set Joystick Control
                  .word IGC_SetKey     -1 ; K        - Set Keyboard Control
                  .word IGC_IncSpeed   -1 ; +        - Inc Game Speed
                  .word IGC_DecSpeed   -1 ; -        - Dec Game Speed
                  .word IGC_Cycle      -1 ; Z        - Toggle Cycle
                  .word IGC_ShootMode  -1 ; D        - Toggle Shoot Mode
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
GetLRGfxOff       ldx $03                         ; adr column lode runner
                  ldy $05                         ; lr pos on image left/right
                  jsr GetXOff

                  stx $23                         ; level input tile $00-$09
                  ldy $04                         ; actual row lode runner
                  ldx $06                         ; lr pos on image up/down
                  jsr GetYOff

                  ldx $07                         ; lr sprite number
                  lda TabLRImages,x               ; lr images tab
                  ldx $23                         ; level input tile $00-$09
GetLRGfxOffX      rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
MovLRGold         lda $05                         ; lr pos on image left/right
                  cmp #$02                        ; centered
                  bne MovLRGoldX                  ; no

                  lda $06                         ; lr pos on image up/down
                  cmp #$02                        ; centered
                  bne MovLRGoldX                  ; no

                  ldy $04                         ; actual row lode runner
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c

                  ldy $03                         ; adr column lode runner
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileGold                ; gold
                  bne MovLRGoldX                  ; no

                  lsr LR_GetGold                  ; get gold  $00=just gets it
                  ldx #$10
                  ldy #$20
                  lda #$04
                  jsr Randomizer
                  sta _Rnd01

                  lda #$04
                  jsr Randomizer
                  sta _Rnd02

                  lda #$04
                  jsr Randomizer
                  sta _Rnd03

                  lda #$04
                  jsr Randomizer
                  sta _Rnd04

                  jsr SetTune                     ; data must follow directly
                  .byte $04                       ; tune time
_Rnd01            .byte $00                       ; tune data pointer voice 2
                  .byte $ff                       ; tune data pointer voice 3
                  .byte $b0                       ; tune s/r/volume  (not used)

                  .byte $04                       ; tune time
_Rnd02            .byte $00                       ; tune data pointer voice 2
                  .byte $ff                       ; tune data pointer voice 3
                  .byte $a0                       ; tune s/r/volume  (not used)

                  .byte $04                       ; tune time
_Rnd03            .byte $00                       ; tune data pointer voice 2
                  .byte $ff                       ; tune data pointer voice 3
                  .byte $90                       ; tune s/r/volume  (not used)

                  .byte $04                       ; tune time
_Rnd04            .byte $00                       ; tune data pointer voice 2
                  .byte $ff                       ; tune data pointer voice 3
                  .byte $a0                       ; tune s/r/volume  (not used)

                  .byte $00                       ; <EndOfTuneData>

_DecGoldToGet     dec LR_GoldToGet
                  ldy $04                         ; actual row lode runner
                  sty $50                         ; screen row  (00-0f)
                  ldy $03                         ; adr column lode runner
                  sty $4f                         ; screen col  (00-1b)
                  lda #LR_TileEmpty
                  sta ($0b),y                     ; play level control data ($0a00-$0bc3)
                  jsr ImageOutToPrep              ; direct output to preparation screen

                  ldy $50                         ; screen row  (00-0f)
                  ldx $4f                         ; screen col  (00-1b)
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row

                  lda #LR_TileGold                ; gold
                  jsr UpdSprtModGfx               ; shooting/closing holes/removing gold

                  ldy #$02                        ; gold gives 250 points
                  lda #$50                        ; screen row  (00-0f)
                  jsr ScoreToBaseLine

MovLRGoldX        rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
MovLRSetImg       inc $07                         ; lr sprite number = next

                  cmp $07                         ; compare 07 with minimum
                  bcc _ChkMax                     ; lower - check max

_Set              sta $07
                  rts

_ChkMax           cpx $07
                  bcc _Set

MovLRSetImgX      rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
MovLRKill         jsr GetLRGfxOff
                  jsr OutSpriteGfx
                  lda $27                         ; sprite collision  $01=lr caught
                  beq MovLRKillX

                  lda LR_GetGold                  ; get gold  $00=just gets it
                  beq MovLRKillX

                  lsr LR_Alive                    ; $00=lr killed
                  
MovLRKillX        rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
MovLRWaitPosX     lda $05                         ; lr pos on image left/right
                  cmp #$02                        ; center
                  bcc _IncPos                     ; lower
                  beq MovLRWaitPosXX

                  dec $05                         ; greater so dec lr pos on image left/right
                  jmp MovLRGold                   ; wait for center and handle the gold

_IncPos           inc $05                         ; lr pos on image left/right
                  jmp MovLRGold                   ; wait for center and handle the gold

MovLRWaitPosXX    rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
MovLRWaitPosY     lda $06                         ; lr pos on image up/down
                  cmp #$02                        ; center
                  bcc _IncPos                     ; lower
                  beq MovLRWaitPosYX

                  dec $06                         ; greater so dec lr pos on image up/down
                  jmp MovLRGold                   ; wait for center and handle the gold

_IncPos           inc $06                         ; lr pos on image up/down
                  jmp MovLRGold                   ; wait for center and handle the gold

MovLRWaitPosYX    rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
MovLRSetHole      lda #$00
                  sta LR_Shoots                   ; $00=no $01=right $ff=left
                  ldy $04                         ; actual row lode runner
                  iny
                  stx $4f                         ; screen col  (00-1b)
                  sty $50                         ; screen row  (00-0f)
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda #LR_TileEmpty               ; empty
                  ldy $4f                         ; screen col  (00-1b)
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  jsr ImageOutToDisp              ; direct output to display screen

                  lda #$00                        ; emtpy
                  jsr ImageOutToPrep              ; direct output to preparation screen

                  dec $50                         ; screen row  (00-0f)
                  lda #LR_TileEmpty               ; empty
                  jsr ImageOutToDisp              ; direct output to display screen

                  inc $50                         ; screen row  (00-0f)
                  ldx #$ff
_GetFreeSlot      inx
                  cpx #LR_TabHoleMax              ; $1e - max 30 slots
                  beq MovLRSetHoleX
                  
                  lda LR_TabHoleOpenT,x           ; hole open time tab
                  bne _GetFreeSlot                ; already used - check next slot
                  
                  lda $50                         ; screen row  (00-0f)
                  sta LR_TabHoleRow,x             ; hole row tab
                  lda $4f                         ; screen col  (00-1b)
                  sta LR_TabHoleCol,x             ; hole column tab
                  
                  lda #LR_TabHoleOpenI
                  sta LR_TabHoleOpenT,x           ; hole open time tab
                  sec
                  
MovLRSetHoleX     rts
; ------------------------------------------------------------------------------------------------------------- ;
; MoveEnemies     Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
MoveEnemies       ldx LR_EnmyNo                   ; number of enemies
                  beq MoveEnemiesX
                  
                  inc $36                         ; pointer actual enemy cycles
                  ldy $36
                  cpy #$03
                  bcc _NextCycle                  ; lower $00-$02
                  
                  ldy #$00                        ; reset
                  sty $36
                  
_NextCycle        lda $0032,y                     ; ==> load move cycles
                  sta $35                         ; enemy move control
_Cycle            lsr $35                         ; enemy move control
                  bcc _ChkCycle
                  
                  jsr MoveOneEnemy
                  
                  lda LR_Alive                    ; $00=lr killed
                  beq MoveEnemiesX                ; exit if dead
                  
_ChkCycle         lda $35                         ; enemy move control
                  bne _Cycle
                  
MoveEnemiesX      rts
; ------------------------------------------------------------------------------------------------------------- ;
TabEnmyCycles1    .byte $00 ; ........            ; LR_CntSpeedLaps ($00-$09) + LR_EnmyNo
TabEnmyCycles2    .byte $00 ; ........
TabEnmyCycles3    .byte $00 ; ........

                  .byte $00 ; ........
                  .byte $01 ; .......#
                  .byte $01 ; .......#

                  .byte $01 ; .......#
                  .byte $01 ; .......#
                  .byte $01 ; .......#

                  .byte $01 ; .......#
                  .byte $03 ; ......##
                  .byte $01 ; .......#

                  .byte $01 ; .......#
                  .byte $03 ; ......##
                  .byte $03 ; ......##

                  .byte $03 ; ......##
                  .byte $03 ; ......##
                  .byte $03 ; ......##

                  .byte $03 ; ......##
                  .byte $03 ; ......##
                  .byte $07 ; .....###

                  .byte $03 ; ......##
                  .byte $07 ; .....###
                  .byte $07 ; .....###

                  .byte $07 ; .....###
                  .byte $07 ; .....###
                  .byte $07 ; .....###

                  .byte $07 ; .....###
                  .byte $07 ; .....###
                  .byte $0f ; ....####

                  .byte $07 ; .....###
                  .byte $0f ; ....####
                  .byte $0f ; ....####

                  .byte $0f ; ....####
                  .byte $0f ; ....####
                  .byte $0f ; ....####

                  .byte $0f ; ....####
                  .byte $0f ; ....####
                  .byte $1f ; ...#####

                  .byte $0f ; ....####
                  .byte $1f ; ...#####
                  .byte $1f ; ...#####

                  .byte $1f ; ...#####
                  .byte $1f ; ...#####
                  .byte $1f ; ...#####

                  .byte $1f ; ...#####
                  .byte $1f ; ...#####
                  .byte $3f ; ..######

                  .byte $1f ; ...#####
                  .byte $3f ; ..######
                  .byte $3f ; ..######

                  .byte $3f ; ..######
                  .byte $3f ; ..######
                  .byte $3f ; ..######

                  .byte $3f ; ..######
                  .byte $3f ; ..######
                  .byte $7f ; .#######

                  .byte $3f ; ..######
                  .byte $7f ; .#######
                  .byte $7f ; .#######

                  .byte $7f ; .#######
                  .byte $7f ; .#######
                  .byte $7f ; .#######
; ------------------------------------------------------------------------------------------------------------- ;
TabEnemyImageNo   .byte $08
                  .byte $2b
                  .byte $2c
                  .byte $30
                  .byte $31
                  .byte $32
                  .byte $36
                  .byte $28
                  .byte $29
                  .byte $2a
                  .byte $2d
                  .byte $2e
                  .byte $2f
                  .byte $35
                  .byte $33
                  .byte $34
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
MoveOneEnemy      inc LR_NoEnemy2Move             ; select next enemy
                  ldx LR_EnmyNo                   ; number of enemies
                  cpx LR_NoEnemy2Move             ; # of enemy to move
                  bcs _GetStatus                  ; max not reached
                  
                  ldx #LR_NoEnemy2MvMin           ; reset to first enemy
                  stx LR_NoEnemy2Move
                  
_GetStatus        jsr GetEnemyStatus

_ChkHoleTime      lda $19                         ; enemy time in hole
                  bmi EnemyHoleTimeUp             ; time is up
                  beq EnemyHoleTimeUp             ; time is up
                  
                  dec $19                         ; enemy time in hole
                  ldy $19                         ; enemy time in hole
                  cpy #LR_EnmyShivStart
                  bcs _GetEnemyNo                 ; greater/equal
                  
                  jmp ShiverEnemyOut              ; lower - do shiver

_GetEnemyNo       ldx LR_NoEnemy2Move             ; # of enemy to move
                  lda LR_TabEnemyBirtT,x          ; enemy rebirth step time
                  beq GoGfxOutXit
                  
MoveOneEnemyX     jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
GoGfxOutXit       jmp MoveEnemyGfxOutX            ; enemy sprite out and exit move
; ------------------------------------------------------------------------------------------------------------- ;
EnemyHoleTimeUp   ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  
                  cmp #LR_TileLadder
                  beq EnemyHoleTimeUpX            ; free again
                  
                  cmp #LR_TilePole
                  bne _ChkCenterLow
                  
_ChkCenter        lda $1b                         ; actual enemy pos on image up/down
                  cmp #$02                        ; centered
                  beq EnemyHoleTimeUpX            ; free again
                  
_ChkCenterLow     lda $1b                         ; actual enemy pos on image up/down
                  cmp #$02                        ; center
                  bcc MoveEnemyGfxOut             ; lower
                  
_ChkCenterHigh    ldy $16                         ; actual enemy row
                  cpy #LR_ScrnMaxRows             ; $0f - max 15 rows
                  beq EnemyHoleTimeUpX            ; free again
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  lda TabExLvlDatRowH8+1,y        ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $15                         ; actual enemy col
                  lda ($09),y                     ; unpacked level data ($0800-$09c3) + 1

                  cmp #LR_TileEmpty
                  beq MoveEnemyGfxOut
                  
                  cmp #LR_TileLR
                  beq MoveEnemyGfxOut
                  
                  cmp #LR_TileEnemy
                  beq EnemyHoleTimeUpX            ; free again
                  
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3) + 1
                  cmp #LR_TileWallSoft
                  beq EnemyHoleTimeUpX            ; free again
                  
                  cmp #LR_TileWallHard
                  beq EnemyHoleTimeUpX            ; free again
                  
                  cmp #LR_TileLadder
                  bne MoveEnemyGfxOut
                  
EnemyHoleTimeUpX  jmp MoveEnemy
; ------------------------------------------------------------------------------------------------------------- ;
MoveEnemyGfxOut   jsr MovEnmyGetXYNo
                  jsr UpdSprtModGfx               ; shooting/closing holes/removing gold
                  jsr CenterEnemyLR
                  
                  lda #$06
                  
                  ldy $18                         ; actual enemy dir right/left  $ff=left  $01=right
                  bmi _SetEnemySprtNo
                  
                  lda #$0d
                  
_SetEnemySprtNo   sta $17                         ; actual enemy sprite number

                  inc $1b                         ; actual enemy pos on image up/down
                  lda $1b                         ; actual enemy pos on image up/down
                  cmp #$05                        ; max
                  bcs B_7cb4
                  
                  lda $1b                         ; actual enemy pos on image up/down
                  cmp #$02                        ; center
                  bne MoveEnemyGfxOutX            ; enemy sprite out and exit move
                  
_GoTakeGold       jsr EnmyTakeGold
                  
                  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileWallSoft
                  bne MoveEnemyGfxOutX            ; enemy sprite out and exit move
                  
                  lda $19                         ; enemy time in hole
                  bpl _StoreHoleTime
                  
                  dec LR_GoldToGet
                  
_StoreHoleTime    lda LR_EnmyHoleTime             ; enemy time in hole
                  sta $19                         ; enemy time in hole
                  
_ScoreEnemyHole   ldy #$00
                  lda #$75                        ; score 75 points for a digged in enemy
                  jsr ScoreToBaseLine
                  
MoveEnemyGfxOutX  jsr MovEnmyGetXYNo              ; ==> enemy sprite out and exit move
                  jsr OutSpriteGfx
                  jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
B_7cb4            lda #$00
                  sta $1b                         ; actual enemy pos on image up/down
                  
                  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileWallSoft
                  bne _Store
                  
                  lda #LR_TileEmpty
                  
_Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)

                  inc $16                         ; actual enemy row
                  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $15                         ; actual enemy col
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
_ChkCatchLR       cmp #LR_TileLR
                  bne _NoCatchLR
                  
_KillLR           lsr LR_Alive                    ; $00=lr killed
                  
_NoCatchLR        lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileWallSoft
                  bne _SetEnemyTile
                  
                  lda $19                         ; enemy time in hole
                  bpl _SetEnemyTile
                  
                  ldy $16                         ; actual enemy row
                  dey
                  sty $50                         ; screen row  (00-0f)
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $15                         ; actual enemy col
                  sty $4f                         ; screen col  (00-1b)
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
_ChkEmpty         cmp #LR_TileEmpty
                  beq _LeaveGold
                  
                  dec LR_GoldToGet
                  jmp _GetEnemyTilePtr            ; a piece of gold got lost

_LeaveGold        lda #LR_TileGold                ; gold
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  sta ($0b),y                     ; play level control data ($0a00-$0bc3)

_DisplayGold      jsr ImageOutToPrep              ; direct output to preparation screen

                  ldy $50                         ; screen row  (00-0f)
                  ldx $4f                         ; screen col  (00-1b)
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row

                  lda #LR_TileGold                ; gold
                  jsr OutSpriteGfx
                  
_GetEnemyTilePtr  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  lda #LR_EnmyHoleTI              ; $00 - init
                  sta $19                         ; enemy time in hole
                  
                  ldy $15                         ; actual enemy col
_SetEnemyTile     lda #LR_TileEnemy
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  jsr MovEnmyGetXYNo              ; ==>
                  jsr OutSpriteGfx
                  jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
ShiverEnemyOut    cpy #LR_EnmyShivStop            ; move out if lower
                  bcc MoveEnemy
                  
                  jsr MovEnmyGetXYNo              ; Gold/Enemy/LR
                  jsr UpdSprtModGfx               ; shooting/closing holes/removing gold
                  
                  ldy $19                         ; enemy time in hole
                  lda TabEnemyShiver-7,y          ; ==> shiver the last hole seconds
                  sta $1a                         ; actual enemy pos on image left/right
                  
_ShiverOut        jsr MovEnmyGetXYNo              ; ==>
                  jsr OutSpriteGfx
ShiverEnemyOutX   jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
TabEnemyShiver    .byte $02                       ; let enemy shiver from left ro right before leaving a hole
                  .byte $01
                  .byte $02
                  .byte $03
                  .byte $02
                  .byte $01
; ------------------------------------------------------------------------------------------------------------- ;
MoveEnemy         ldx $15                         ; actual enemy col
                  ldy $16                         ; actual enemy row
                  jsr GetEnemyMoveDir
                  
                  asl a
                  tay
                  lda TabEnemyMoveDir+1,y
                  pha
                  lda TabEnemyMoveDir,y
                  pha
                  
MoveEnemyX        rts
; ------------------------------------------------------------------------------------------------------------- ;
TabEnemyMoveDir   .word SavEnemyStatus -1
                  .word MoveEnemyLeft  -1
                  .word MoveEnemyRight -1
                  .word MoveEnemyUp    -1
                  .word MoveEnemyDown  -1
; ------------------------------------------------------------------------------------------------------------- ;
MoveEnemyUpHole   lda $19                         ; enemy time in hole
                  beq MoveEnemyUpHoleX
                  bmi MoveEnemyUpHoleX
                  
                  inc $19                         ; enemy time in hole
MoveEnemyUpHoleX  jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
MoveEnemyUp       ldy $1b                         ; actual enemy pos on image up/down
                  cpy #$03
                  bcs StepEnemyUp
                  
                  ldy $16                         ; actual enemy row
                  beq MoveEnemyUpHole             ; already already max up
                  
                  dey
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $15                         ; actual enemy col
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #LR_TileWallSoft
                  beq MoveEnemyUpHole             ; blocked
                  
                  cmp #LR_TileWallHard
                  beq MoveEnemyUpHole             ; blocked
                  
                  cmp #LR_TileWallTrap
                  beq MoveEnemyUpHole             ; blocked
                  
                  cmp #LR_TileEnemy
MoveEnemyUpX      beq MoveEnemyUpHole             ; blocked
; ------------------------------------------------------------------------------------------------------------- ;
StepEnemyUp       jsr MovEnmyGetXYNo
                  jsr UpdSprtModGfx               ; shooting/closing holes/removing gold
                  jsr CenterEnemyLR
                  
                  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  dec $1b                         ; actual enemy pos on image up/down
                  bpl GoEnemyTakeGold
                  
_GoEnemyDropGold  jsr EnmyDropGold
                  
                  ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileWallSoft
                  bne _Store
                  
                  lda #LR_TileEmpty
                  
_Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)

                  dec $16                         ; actual enemy row
                  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $15                         ; actual enemy col
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
_ChkCatchLR       cmp #LR_TileLR
                  bne _NoCatchLR
                  
_KillLR           lsr LR_Alive                    ; $00=lr killed
                  
_NoCatchLR        lda #LR_TileEnemy
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  lda #$04
                  sta $1b                         ; actual enemy pos on image up/down
                  bne ChkEnemySprtRng
                  
GoEnemyTakeGold   jsr EnmyTakeGold

ChkEnemySprtRng   lda #$0e                        ; min
                  ldx #$0f                        ; max
                  
                  jsr IncSprtNoChkRng             ; increase sprite number and check range
                  jsr MovEnmyGetXYNo              ; ==>
                  jsr OutSpriteGfx
StepEnemyUpX      jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
MoveEnemyDown     ldy $1b                         ; actual enemy pos on image up/down
                  cpy #$02
                  bcc StepEnemyDown
                  
                  ldy $16                         ; actual enemy row
                  cpy #LR_ScrnMaxRows
                  bcs MoveEnemyDownX              ; already max down
                  
                  iny
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $15                         ; actual enemy col
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #LR_TileWallHard
                  beq MoveEnemyDownX              ; blocked
                  
                  cmp #LR_TileEnemy
                  beq MoveEnemyDownX              ; blocked
                  
                  cmp #LR_TileWallSoft            ; blocked
                  bne StepEnemyDown
                  
MoveEnemyDownX    jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
StepEnemyDown     jsr MovEnmyGetXYNo
                  jsr UpdSprtModGfx               ; shooting/closing holes/removing gold
                  jsr CenterEnemyLR
                  
                  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  inc $1b                         ; actual enemy pos on image up/down
                  lda $1b                         ; actual enemy pos on image up/down
                  cmp #$05
                  bcc StepEnemyDownX
                  
                  jsr EnmyDropGold
                  
                  ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileWallSoft
                  bne _Store
                  
                  lda #$00
_Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  inc $16                         ; actual enemy row
                  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $15                         ; actual enemy col
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
_ChkCatchLR       cmp #LR_TileLR
                  bne _NoCatchLR
                  
_KillLR           lsr LR_Alive                    ; $00=lr killed

_NoCatchLR        lda #LR_TileEnemy
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  lda #$00
                  sta $1b                         ; actual enemy pos on image up/down
                  jmp ChkEnemySprtRng
                  
StepEnemyDownX    jmp GoEnemyTakeGold
; ------------------------------------------------------------------------------------------------------------- ;
MoveEnemyLeft     ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldx $1a                         ; actual enemy pos on image left/right
                  cpx #$03
                  bcs StepEnemyLeft               ; equal or greater
                  
                  ldy $15                         ; actual enemy col
                  beq MoveEnemyLeftX              ; already max left
                  
_ChkLeft          dey
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #LR_TileEnemy
                  beq MoveEnemyLeftX              ; blocked
                  
                  cmp #LR_TileWallHard
                  beq MoveEnemyLeftX              ; blocked
                  
                  cmp #LR_TileWallSoft
                  beq MoveEnemyLeftX              ; blocked
                  
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileWallTrap            ; blocked
                  bne StepEnemyLeft
                  
MoveEnemyLeftX    jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
StepEnemyLeft     jsr MovEnmyGetXYNo
                  jsr UpdSprtModGfx               ; shooting/closing holes/removing gold
                  jsr CenterEnemyUD
                  
                  lda #$ff
                  sta $18                         ; actual enemy dir right/left  $ff=left  $01=right
                  
                  dec $1a                         ; actual enemy pos on image left/right
                  bpl _GoTakeGold
                  
_GoDropGold       jsr EnmyDropGold
                  
                  ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileWallSoft
                  bne _Store
                  
                  lda #LR_TileEmpty
                  
_Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)

                  dec $15                         ; actual enemy col
                  dey
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
_ChkCatchLR       cmp #LR_TileLR
                  bne _NoCatchLR
                  
_KillLR           lsr LR_Alive                    ; $00=lr killed
                  
_NoCatchLR        lda #LR_TileEnemy
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)

                  lda #$04
                  sta $1a                         ; actual enemy pos on image left/right
                  bne _GetTile                    ; always
                  
_GoTakeGold       jsr EnmyTakeGold

_GetTile          ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
_ChkPole          cmp #LR_TilePole
                  beq _SetSpritePoleLe
                  
_SetSpriteRunLe   lda #$00                        ; min
                  ldx #$02                        ; max
                  bne _DisplaySprite              ; always
                  
_SetSpritePoleLe  lda #$03                        ; min
                  ldx #$05                        ; max
                  
_DisplaySprite    jsr IncSprtNoChkRng             ; increase sprite number and check range
                  jsr MovEnmyGetXYNo              ; ==>
                  jsr OutSpriteGfx                  
StepEnemyLeftX    jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
MoveEnemyRight    ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldx $1a                         ; actual enemy pos on image left/right
                  cpx #$02
                  bcc StepEnemyRight
                  
                  ldy $15                         ; actual enemy col
                  cpy #LR_ScrnMaxCols
                  beq MoveEnemyRightX             ; already max right
                  
_ChkRight         iny
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #LR_TileEnemy
                  beq MoveEnemyRightX             ; blocked
                  
                  cmp #LR_TileWallHard
                  beq MoveEnemyRightX             ; blocked
                  
                  cmp #LR_TileWallSoft
                  beq MoveEnemyRightX             ; blocked
                  
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileWallTrap            ; blocked
                  bne StepEnemyRight              ; Ladder/Pole/XitLadder/Gold/LR
                  
MoveEnemyRightX   jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
StepEnemyRight    jsr MovEnmyGetXYNo
                  jsr UpdSprtModGfx               ; shooting/closing holes/removing gold
                  jsr CenterEnemyUD
                  
                  lda #$01
                  sta $18                         ; actual enemy dir right/left  $ff=left  $01=right
                  
                  inc $1a                         ; actual enemy pos on image left/right
                  lda $1a                         ; actual enemy pos on image left/right
                  cmp #$05
                  bcc _GoTakeGold
                  
_GoDropGold       jsr EnmyDropGold
                  
                  ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileWallSoft
                  bne _Store
                  
                  lda #LR_TileEmpty
                  
_Store            sta ($09),y                     ; unpacked level data ($0800-$09c3)

                  inc $15                         ; actual enemy col
                  iny
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
_ChkCatchLR       cmp #LR_TileLR
                  bne _NoCatchLR
                  
_KillLR           lsr LR_Alive                    ; $00=lr killed
                  
_NoCatchLR        lda #LR_TileEnemy
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  
                  lda #$00
                  sta $1a                         ; actual enemy pos on image left/right
                  beq _GetTile
                  
_GoTakeGold       jsr EnmyTakeGold

_GetTile          ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TilePole
                  beq _SetSpritePoleRi
                  
_SetSpriteRunRi   lda #$07                        ; min
                  ldx #$09                        ; max
                  bne _DisplaySprite
                  
_SetSpritePoleRi  lda #$0a                        ; min
                  ldx #$0c                        ; max
                  
_DisplaySprite    jsr IncSprtNoChkRng             ; increase sprite number and check range
                  jsr MovEnmyGetXYNo              ; ==>
                  jsr OutSpriteGfx                  
StepEnemyRightX   jmp SavEnemyStatus
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
GetEnemyMoveDir   stx $28                         ; actual enemy work col
                  sty $29                         ; actual enemy work row
                  
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $28                         ; actual enemy work col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)

                  cmp #LR_TileWallSoft
                  bne TstRowEnmyLR
                  
                  lda $19                         ; enemy time in hole
                  beq TstRowEnmyLR                ;   is up
                  bmi TstRowEnmyLR                ;   is up
                  
                  lda #LR_EnemyMoveUp
                  
GetEnemyMoveDirX  rts
; ------------------------------------------------------------------------------------------------------------- ;
TstRowEnmyLR      ldy $29                         ; actual enemy work row
                  cpy $04                         ; actual row lode runner
                  beq BothOnSameRow
                  
                  jmp BothOnDiffRow
; ------------------------------------------------------------------------------------------------------------- ;
BothOnSameRow     ldy $28                         ; actual enemy work col
                  sty $2a                         ; save actual enemy work col
                  
                  cpy $03                         ; actual col lode runner
                  bcs EnemyOnRiOfLR
; ------------------------------------------------------------------------------------------------------------- ;
EnemyOnLeOfLR     inc $2a                         ; save actual enemy work col

                  ldy $29                         ; actual enemy work row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $2a                         ; save actual enemy work col
_GetTileRi        lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileLadder
                  beq _ChkLRReached
                  
                  cmp #LR_TilePole
                  beq _ChkLRReached
                  
                  ldy $29                         ; actual enemy work row
                  cpy #LR_ScrnMaxRows
                  beq _ChkLRReached               ; bottom reached
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c

                  ldy $2a                         ; save actual enemy work col
_GetTileRiDo      lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileEmpty
                  beq BothOnDiffRow
                  
                  cmp #LR_TileWallTrap
                  beq BothOnDiffRow
                  
_ChkLRReached     ldy $2a                         ; save actual enemy work col
                  cpy $03                         ; actual col lode runner
                  bne EnemyOnLeOfLR
                  
                  lda #LR_EnemyMoveRi
                  
EnemyOnLeOfLRX    rts
; ------------------------------------------------------------------------------------------------------------- ;
EnemyOnRiOfLR     dec $2a                         ; save actual enemy work col

                  ldy $29                         ; actual enemy work row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $2a                         ; save actual enemy work col
_GetTileLe        lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileLadder
                  beq _ChkLRReached
                  
                  cmp #LR_TilePole
                  beq _ChkLRReached
                  
                  ldy $29                         ; actual enemy work row
                  cpy #$0f
                  beq _ChkLRReached
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $2a                         ; save actual enemy work col
_GetTileLeDo      lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileEmpty
                  beq BothOnDiffRow
                  
                  cmp #LR_TileWallTrap
                  beq BothOnDiffRow
                  
_ChkLRReached     ldy $2a                         ; save actual enemy work col
                  cpy $03                         ; actual col lode runner
                  bne EnemyOnRiOfLR
                  
                  lda #LR_EnemyMoveLe
                  
EnemyOnRiOfLRX    rts
; ------------------------------------------------------------------------------------------------------------- ;
BothOnDiffRow     lda #LR_EnemyMoveNo             ; clear
                  sta $2b                         ; actual enemy move direction
                  lda #$ff                        ; init
                  sta $2c                         ; move direction indicator
                  
                  ldx $28                         ; actual enemy work col
                  ldy $29                         ; actual enemy work row
                  jsr GetEnmyPossLR
                  jsr GetEnmyPossUD
                  jsr TestColLeft
                  jsr TestColRight
                  
                  lda $2b                         ; actual enemy move direction
                  
BothOnDiffRowX    rts
; ------------------------------------------------------------------------------------------------------------- ;
ShortCut          rts                             ; ==>
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
TestColLeft       ldy $2d                         ; actual enemy possible col left
                  cpy $28                         ; actual enemy work col
                  beq ShortCut
                  
                  ldy $29                         ; actual enemy work row
                  cpy #$0f
                  beq _ChkWorkRow
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $2d                         ; actual enemy possible col left
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileWallSoft
                  beq _ChkWorkRow
                  
                  cmp #LR_TileWallHard
                  beq _ChkWorkRow
                  
                  ldx $2d                         ; actual enemy possible col left
                  ldy $29                         ; actual enemy work row
                  jsr FindEnmyMoveUD1             ; ac=target row
                  
                  ldx $2d                         ; actual enemy possible col left
                  jsr GetDirIndicator
                  
                  cmp $2c                         ; move direction indicator
                  bcs _ChkWorkRow
                  
_SetNewInd01      sta $2c                         ; move direction indicator
                  
_SetDirLeft01     lda #LR_EnemyMoveLe
                  sta $2b                         ; actual enemy move direction
                  
_ChkWorkRow       ldy $29                         ; actual enemy work row
                  beq _IncColLeft
                  
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $2d                         ; actual enemy possible col left
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
_GetTileLe        cmp #LR_TileLadder
                  bne _IncColLeft
                  
                  ldy $29                         ; actual enemy work row
                  ldx $2d                         ; actual enemy possible col left
                  jsr FindEnmyMoveUD0
                  
                  ldx $2d                         ; actual enemy possible col left
                  jsr GetDirIndicator
                  
                  cmp $2c                         ; move direction indicator
                  bcs _IncColLeft
                  
_SetNewInd02      sta $2c                         ; move direction indicator
                  
_SetDirLeft02     lda #LR_EnemyMoveLe
                  sta $2b                         ; actual enemy move direction
                  
_IncColLeft       inc $2d                         ; actual enemy possible col left
                  jmp TestColLeft
                  
TestColLeftX      rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
TestColRight      ldy $2e                         ; actual enemy possible col right
                  cpy $28                         ; actual enemy work col
                  beq TestColLeftX                ; ==> max left
                  
                  ldy $29                         ; actual enemy work row
                  cpy #LR_ScrnMaxRows
                  beq _ChkMaxUp                   ; max down reached
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $2e                         ; actual enemy possible col right
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
_ChkTileRowDo     cmp #LR_TileWallSoft
                  beq _ChkMaxUp
                  
                  cmp #LR_TileWallHard
                  beq _ChkMaxUp
                  
                  ldx $2e                         ; actual enemy possible col right
                  ldy $29                         ; actual enemy work row
                  jsr FindEnmyMoveUD1             ; ac=target row
                  
                  ldx $2e                         ; actual enemy possible col right
                  jsr GetDirIndicator
                  
                  cmp $2c                         ; move direction indicator
                  bcs _ChkMaxUp
                  
_SetNewInd01      sta $2c                         ; move direction indicator
                  
_SetDirRight01    lda #LR_EnemyMoveRi
                  sta $2b                         ; actual enemy move direction
                  
_ChkMaxUp         ldy $29                         ; actual enemy work row
                  beq _DecColRight                ; max up reached - exit
                  
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $2e                         ; actual enemy possible col right
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileLadder
                  bne _DecColRight
                  
                  ldy $29                         ; actual enemy work row
                  ldx $2e                         ; actual enemy possible col right
                  jsr FindEnmyMoveUD0
                  
                  ldx $2e                         ; actual enemy possible col right
                  jsr GetDirIndicator
                  
                  cmp $2c                         ; move direction indicator
                  bcs _DecColRight
                  
_SetNewInd02      sta $2c                         ; move direction indicator
                  
_SetDirRight02    lda #LR_EnemyMoveRi
                  sta $2b                         ; actual enemy move direction
                  
_DecColRight      dec $2e                         ; actual enemy possible col right
                  jmp TestColRight

;TestColRight     rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
GetEnmyPossUD     ldy $29                         ; actual enemy work row
                  cpy #LR_ScrnMaxRows
                  beq _ChkTopOfScreen             ; already on bottom of screen
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $28                         ; actual enemy work col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileWallSoft
                  beq _ChkTopOfScreen
                  
                  cmp #LR_TileWallHard
                  beq _ChkTopOfScreen
                  
                  ldx $28                         ; actual enemy work col
                  ldy $29                         ; actual enemy work row
                  jsr FindEnmyMoveUD1             ; ac=target row
                  
                  ldx $28                         ; actual enemy work col
                  jsr GetDirIndicator
                  
                  cmp $2c                         ; move direction indicator
                  bcs _ChkTopOfScreen
                  
_SetNewIndDo      sta $2c                         ; move direction indicator
                  
_SetDirDown       lda #LR_EnemyMoveDo
                  sta $2b                         ; actual enemy move direction
                  
_ChkTopOfScreen   ldy $29                         ; actual enemy work row
                  beq GetEnmyPossUDX
                  
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $28                         ; actual enemy work col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileLadder
                  bne GetEnmyPossUDX
                  
                  ldx $28                         ; actual enemy work col
                  ldy $29                         ; actual enemy work row
                  jsr FindEnmyMoveUD0
                  
                  ldx $28                         ; actual enemy work col
                  jsr GetDirIndicator
                  
                  cmp $2c                         ; move direction indicator
                  bcs GetEnmyPossUDX
                  
_SetNewIndUp      sta $2c                         ; move direction indicator
                  
_SetDirUp         lda #LR_EnemyMoveUp
                  sta $2b                         ; actual enemy move direction
                  
GetEnmyPossUDX    rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   : ac=save target row  xr=actual enemy possible col left
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
GetDirIndicator   sta $1e                         ; save target row

_ChkRowLR         cmp $04                         ; actual row lode runner
                  bne _NotOnRowLR
                  
_SameLR           cpx $15                         ; actual enemy col
                  bcc _Lower                      ; lower
                  
                  txa
                  sec
                  sbc $15                         ; actual enemy col
                  rts

_Lower            stx $1e                         ; actual enemy possible col left to save target row
                  lda $15                         ; actual enemy col
                  sec
                  sbc $1e                         ; save target row                  
                  rts

_NotOnRowLR       bcc _AboveLR

_BelowLR          sec
                  sbc $04                         ; actual row lode runner
                  clc
                  adc #$64 * 2                    ; $c8
                  rts

_AboveLR          lda $04                         ; actual row lode runner
                  sec
                  sbc $1e                         ; save target row
                  clc
                  adc #$64
                  
GetDirIndicatorX  rts
; ------------------------------------------------------------------------------------------------------------- ;
RetTargetRow2     lda $31                         ; ==> target row from work row

RetTargetRow2X    rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
FindEnmyMoveUD0   sty $31                         ; target row from work row
                  stx $30                         ; target col from work col or possible col ri/le

_ChkNextTileUp0   lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c

                  ldy $30                         ; target col from work col or possible col ri/le
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileLadder
                  bne RetTargetRow2               ; exit
                  
_SetTargetRowUp   dec $31                         ; target row from work row

                  ldy $30                         ; target col from work col or possible col ri/le
                  beq _ChkMaxColRi                ; already max left
                  
                  dey
                  
_GetTileLe        lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileWallSoft
                  beq _SetSavTargRowLe
                  
                  cmp #LR_TileWallHard
                  beq _SetSavTargRowLe
                  
                  cmp #LR_TileLadder
                  beq _SetSavTargRowLe
                  
                  ldy $31                         ; target row from work row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $30                         ; target col from work col or possible col ri/le
                  
                  dey
                  
_GetTileUpLe      lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TilePole
                  bne _ChkMaxColRi
                  
_SetSavTargRowLe  ldy $31                         ; target row from work row
                  sty $2f                         ; save target row from work row 
                  cpy $04                         ; actual row lode runner
                  bcc RetSavTargetRow
                  beq RetSavTargetRow
                  
_ChkMaxColRi      ldy $30                         ; target col from work col or possible col ri/le
                  cpy #LR_ScrnMaxCols
                  beq _ChkTop
                  
                  ldy $31                         ; target row from work row
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $30                         ; target col from work col or possible col ri/le                  
                  iny
                  
_GetTileRi        lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileWallSoft
                  beq _SetSavTargRow
                  
                  cmp #LR_TileWallHard
                  beq _SetSavTargRow
                  
                  cmp #LR_TileLadder
                  beq _SetSavTargRow
                  
                  ldy $31                         ; ==> target row from work row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $30                         ; target col from work col or possible col ri/le
                  iny
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TilePole
                  bne _ChkTop
                  
_SetSavTargRow    ldy $31                         ; target row from work row
                  sty $2f                         ; save target row from work row 
                  cpy $04                         ; actual row lode runner
                  bcc RetSavTargetRow
                  beq RetSavTargetRow
                  
_ChkTop           ldy $31                         ; target row from work row
                  cpy #$01
                  bcc _RetTargetRow
                  
_GoCheckNext      jmp _ChkNextTileUp0
                  
_RetTargetRow     tya

FindEnmyMoveUD0X  rts
; ------------------------------------------------------------------------------------------------------------- ;
RetSavTargetRow   lda $2f                         ; save target row from work row 

RetSavTargetRowX  rts
; ------------------------------------------------------------------------------------------------------------- ;
RetTargetRow      lda $31                         ; ==> target row from work row

RetTargetRowX     rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
FindEnmyMoveUD1   sty $31                         ; target row from work row
                  stx $30                         ; target col from work col or possible col ri/le
                  
_ChkNextTileUp1   lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $30                         ; target col from work col or possible col ri/le
_TileUnderFoot    lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileWallSoft
                  beq RetTargetRow                ; ==>
                  
                  cmp #LR_TileWallHard
                  beq RetTargetRow                ; ==>
                  
                  ldy $31                         ; target row from work row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $30                         ; target col from work col or possible col ri/le
_TileLeRi         lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileEmpty
                  beq _ChkRows
                  
                  cpy #$00                        ; max left
                  beq _ChkCols
                  
                  dey
                  
_TileNextLe       lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TilePole
                  beq _SetTargetRowLe
                  
                  ldy $31                         ; ==> target row from work row
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $30                         ; target col from work col or possible col ri/le
                  dey
_TileUnderFootLe  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileWallSoft
                  beq _SetTargetRowLe
                  
                  cmp #LR_TileWallHard
                  beq _SetTargetRowLe
                  
                  cmp #LR_TileLadder
                  bne _ChkCols
                  
_SetTargetRowLe   ldy $31                         ; target row from work row
                  sty $2f                         ; save target row from work row 
                  cpy $04                         ; actual row lode runner
                  bcs _RetTargetRow               ; still above of LR
                  
_ChkCols          ldy $30                         ; target col from work col or possible col ri/le
                  cpy #LR_ScrnMaxCols
                  bcs _ChkRows                    ; max right reached
                  
                  iny
                  
_TileNextRi       lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TilePole
                  beq _SetTargetRowRi
                  
                  ldy $31                         ; target row from work row
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $30                         ; target col from work col or possible col ri/le
                  iny
_TileUnderFootRi  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileWallSoft
                  beq _SetTargetRowRi
                  
                  cmp #LR_TileLadder
                  beq _SetTargetRowRi
                  
                  cmp #LR_TileWallHard
                  bne _ChkRows
                  
_SetTargetRowRi   ldy $31                         ; target row from work row
                  sty $2f                         ; save target row from work row 
                  cpy $04                         ; actual row lode runner
                  bcs _RetTargetRow               ; still above of LR
                  
_ChkRows          inc $31                         ; target row from work row
                  ldy $31                         ; target row from work row
                  cpy #LR_ScrnMaxRows+1
                  bcs _RetMaxRow                  ; max reached
                  
_GoCheckNext      jmp _ChkNextTileUp1
                  
_RetMaxRow        lda #LR_ScrnMaxRows
_FindEnmyMoveUD1  rts

_RetTargetRow     lda $2f                         ; save target row from work row 
FindEnmyMoveUD1X  rts
; ------------------------------------------------------------------------------------------------------------- ;
; GetEnmyPossLR   Function: Gets a possible enemy move left/right
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
GetEnmyPossLR     stx $2d                         ; actual enemy possible col left
                  stx $2e                         ; actual enemy possible col right
                  sty $20                         ; save actual enemy work row
                  
_GetNextColLeft   lda $2d                         ; actual enemy possible col left
                  beq _GetNextColRight            ; max left reached
                  
                  ldy $20                         ; save actual enemy work row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $2d                         ; actual enemy possible col left
                  dey                             ; get tile one left from
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
_ChkLeftTile      cmp #LR_TileWallSoft
                  beq _GetNextColRight
                  
                  cmp #LR_TileWallHard
                  beq _GetNextColRight
                  
                  cmp #LR_TileLadder
                  beq _SetNextColLeft
                  
                  cmp #LR_TilePole
                  beq _SetNextColLeft
                  
                  ldy $20                         ; save actual enemy work row
                  cpy #LR_ScrnMaxRows
                  beq _SetNextColLeft
                  
_ChkLeftDownTile  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $2d                         ; actual enemy possible col left
                  dey                             ; get tile one left/down from
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileWallSoft
                  beq _SetNextColLeft
                  
                  cmp #LR_TileWallHard
                  beq _SetNextColLeft
                  
                  cmp #LR_TileLadder
                  bne _SetOneLeft
                  
_SetNextColLeft   dec $2d                         ; actual enemy possible col left
                  bpl _GetNextColLeft
                  
_SetOneLeft       dec $2d                         ; actual enemy possible col left

_GetNextColRight  lda $2e                         ; actual enemy possible col right
                  cmp #LR_ScrnMaxCols             ; $1b - max col right
                  beq GetEnmyPossLRX              ; exit
                  
                  ldy $20                         ; save actual enemy work row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldy $2e                         ; actual enemy possible col right
                  iny                             ; try one tile right from
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #LR_TileWallSoft
                  beq GetEnmyPossLRX              ; exit
                  
                  cmp #LR_TileWallHard
                  beq GetEnmyPossLRX              ; exit
                  
                  cmp #LR_TileLadder
                  beq _SetNextColRight
                  
                  cmp #LR_TilePole
                  beq _SetNextColRight
                  
                  ldy $20                         ; save actual enemy work row
                  cpy #LR_ScrnMaxRows
                  beq _SetNextColRight
                  
                  lda TabExLvlDatRowLo+1,y        ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa+1,y        ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $2e                         ; actual enemy possible col right
                  iny                             ; try one tile right from
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileWallSoft
                  beq _SetNextColRight
                  
                  cmp #LR_TileWallHard
                  beq _SetNextColRight
                  
                  cmp #LR_TileLadder
                  bne _SetOneRight
                  
_SetNextColRight  inc $2e                         ; actual enemy possible col right
                  bpl _GetNextColRight
                  
_SetOneRight      inc $2e                         ; actual enemy possible col right

GetEnmyPossLRX    rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
MovEnmyGetXYNo    ldx $15                         ; actual enemy col
                  ldy $1a                         ; actual enemy pos on image left/right
                  jsr GetXOff
                  
                  stx $23
                  
                  ldy $16                         ; actual enemy row
                  ldx $1b                         ; actual enemy pos on image up/down
                  jsr GetYOff
                  
                  ldx $17                         ; actual enemy sprite number
                  lda TabEnemyImageNo,x
                  
                  ldx $23
                  
MovEnmyGetXYNoX   rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns : 
; ------------------------------------------------------------------------------------------------------------- ;
EnmyTakeGold      lda $1a                         ; actual enemy pos on image left/right
                  cmp #$02
                  bne EnmyTakeGoldX
                  
                  lda $1b                         ; actual enemy pos on image up/down
                  cmp #$02
                  bne EnmyTakeGoldX
                  
                  ldy $16                         ; actual enemy row
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $15                         ; actual enemy col
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileGold
                  bne EnmyTakeGoldX               ; no gold on level tile
                  
                  lda $19                         ; enemy time in hole
                  bmi EnmyTakeGoldX
                  
                  lda #$ff
                  sec
                  sbc LR_EnmyBirthCol             ; pointer: enemy rebirth column
                  sta $19                         ; enemy time in hole
                  
                  lda #$00                        ; clear gold in
                  sta ($0b),y                     ; play level control data ($0a00-$0bc3)
                  
                  ldy $16                         ; actual enemy row
                  sty $50                         ; screen row  (00-0f)
                  ldy $15                         ; actual enemy col
                  sty $4f                         ; screen col  (00-1b)
                  jsr ImageOutToPrep              ; direct output to preparation screen

                  ldy $50                         ; screen row  (00-0f)
                  ldx $4f                         ; screen col  (00-1b)
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row

                  lda #LR_TileGold                ; clear gold in grafic
                  jmp UpdSprtModGfx               ; shooting/closing holes/removing gold
                  
EnmyTakeGoldX     rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
EnmyDropGold      lda $19                         ; enemy time in hole
                  bpl EnmyDropGoldX
                  
                  inc $19                         ; enemy time in hole
                  bne EnmyDropGoldX
                  
                  ldy $16                         ; actual enemy row
                  sty $50                         ; screen row  (00-0f)
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy $15                         ; actual enemy col
                  sty $4f                         ; screen col  (00-1b)
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileEmpty
                  bne _NotEmpty
                  
                  lda #LR_TileGold
                  sta ($0b),y                     ; play level control data ($0a00-$0bc3)
                  jsr ImageOutToPrep              ; direct output to preparation screen

                  ldy $50                         ; screen row  (00-0f)
                  ldx $4f                         ; screen col  (00-1b)
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row

                  lda #LR_TileGold
                  jmp OutSpriteGfx
                  
_NotEmpty         dec $19                         ; enemy time in hole
EnmyDropGoldX     rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
IncSprtNoChkRng   inc $17                         ; actual enemy sprite number
_ChkMin           cmp $17                         ; actual enemy sprite number
                  bcc _ChkMax
                  
_SetSpriteNo      sta $17                         ; actual enemy sprite number
                  rts

_ChkMax           cpx $17                         ; actual enemy sprite number
                  bcc _SetSpriteNo
                  
IncSprtNoChkRngX  rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
CenterEnemyLR     lda $1a                         ; actual enemy pos on image left/right
                  cmp #$02                        ; center
                  bcc _Inc1a                      ; lower
                  beq CenterEnemyLRX               ; in center
                  
_Dec1a            dec $1a                         ; back left a bit
                  jmp EnmyTakeGold
                  
_Inc1a            inc $1a                         ; back right a bit
                  jmp EnmyTakeGold
                  
CenterEnemyLRX    rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
CenterEnemyUD     lda $1b                         ; actual enemy pos on image up/down
                  cmp #$02                        ; center
                  bcc _Inc1b                      ; lower
                  beq CenterEnemyUDX              ; in center
                  
_Dec1b            dec $1b                         ; back up a bit
                  jmp EnmyTakeGold
                  
_Inc1b            inc $1b                         ; back down a bit
                  jmp EnmyTakeGold
                  
CenterEnemyUDX    rts
; ------------------------------------------------------------------------------------------------------------- ;
SavEnemyStatus    ldx LR_NoEnemy2Move             ; # of enemy to move

                  lda $15                         ; actual enemy col
                  sta LR_TabEnemyCol,x            ; adr column enemies
                  lda $16                         ; actual enemy row
                  sta LR_TabEnemyRow,x            ; adr row enemies
                  lda $1a                         ; actual enemy pos on image left/right
                  sta LR_TabEnemyPosLR,x          ; enemy pos on image left/right tab
                  lda $1b                         ; actual enemy pos on image up/down
                  sta LR_TabEnemyPosUD,x          ; enemy pos on image up/down tab
                  lda $19                         ; enemy time in hole
                  sta LR_TabEnemyGold,x           ; enemy has gold tab
                  lda $18                         ; actual enemy dir right/left  $ff=left  $01=right
                  sta LR_TabEnemySpr__,x          ;
                  lda $17                         ; actual enemy sprite number
                  sta LR_TabEnemySprNo,x          ; actual enemy sprite number
                  
SavEnemyStatusX   rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
GetEnemyStatus    ldx LR_NoEnemy2Move             ; # of enemy to move

                  lda LR_TabEnemyCol,x            ; adr column enemies
                  sta $15                         ; enemy col
                  lda LR_TabEnemyRow,x            ; adr row enemies
                  sta $16                         ; actual enemy row
                  lda LR_TabEnemyPosLR,x          ; enemy pos on image left/right tab
                  sta $1a                         ; actual enemy pos on image left/right
                  lda LR_TabEnemyPosUD,x          ; enemy pos on image up/down tab
                  sta $1b                         ; actual enemy pos on image up/down
                  lda LR_TabEnemySprNo,x          ; actual enemy sprite number
                  sta $17                         ; actual enemy sprite number                         ;
                  lda LR_TabEnemySpr__,x          ;
                  sta $18                         ; actual enemy dir right/left  $ff=left  $01=right                         ;
                  lda LR_TabEnemyGold,x           ; enemy has gold tab
                  sta $19                         ; enemy time in hole
                  
GetEnemyStatusX   rts
; ------------------------------------------------------------------------------------------------------------- ;
; CloseHoles      Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
CloseHoles        jsr EnemyRebirth

                  inc LR_EnmyBirthCol             ; pointer: enemy rebirth column
_ChkBirthCol      lda LR_EnmyBirthCol             ; pointer: enemy rebirth column
                  cmp #LR_EnmyBColMax             ; $1c - max 28
                  bcc _ChkHoles
                  
                  lda #$00                        ; reset
                  sta LR_EnmyBirthCol             ; pointer: enemy rebirth column
                  
_ChkHoles         ldx #LR_TabHoleMax              ; max 30 open holes
_GetNextHoleTime  lda LR_TabHoleOpenT,x           ; hole open time tab
                  stx $52                         ; open holes time pointer
                  bne _DecHoleTime
                  
                  jmp _SetNextHoleTime            ; set next hole time
                  
_DecHoleTime      dec LR_TabHoleOpenT,x           ; open holes counter
                  beq _HoleOpenTimeOut            ; open time out - so close
                  
                  lda LR_TabHoleCol,x             ; hole column tab
                  sta $4f                         ; screen col  (00-1b)
                  lda LR_TabHoleRow,x             ; hole row tab
                  sta $50                         ; screen row  (00-0f)
                  
                  lda LR_TabHoleOpenT,x           ; hole open time tab                  
_ChkClose1stStep  cmp #LR_TabHoleOpenT1           ; first step close
                  bne _ChkClose2ndStep            ;  already passed
                  
                  lda #$37                        ; image close hole first bit
_CloseStepOut     jsr ImageOutToPrep              ; direct output to preparation screen

                  ldx $4f                         ; screen col  (00-1b)
                  ldy $50                         ; screen row  (00-0f)
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row

                  lda #$00
                  jsr UpdSprtModGfx               ; shooting/closing holes/removing gold
                  
_GoSetNextHT      jmp _SetNextHoleTime            ; set next hole time

_ChkClose2ndStep  cmp #LR_TabHoleOpenT2           ; second step close
                  bne _GoSetNextHT                ;  already passed
                  
                  lda #$38                        ; image close hole second bit
                  bne _CloseStepOut               ; always
                  
_HoleOpenTimeOut  ldx $52                         ; open holes time pointer
                  ldy LR_TabHoleRow,x             ; hole row tab
                  sty $50                         ; screen row  (00-0f)
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy LR_TabHoleCol,x             ; hole column tab
                  sty $4f                         ; screen col  (00-1b)
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  cmp #$00
                  bne _ChkHoleLR                  ; closed hole was not emty
                  
                  jmp _CloseWithWall
                  
_ChkHoleLR        cmp #LR_TileLR                  ; lode runner
                  bne _ChkHoleEnemy
                  
                  lsr LR_Alive                    ; $00=lr killed
                  
_ChkHoleEnemy     cmp #LR_TileEnemy               ; enemy
                  beq _ReviveEnemy
                  
_ChkHoleGold      cmp #LR_TileGold                ; gold
                  bne _GoCloseWithWall
                  dec LR_GoldToGet
                  
_GoCloseWithWall  jmp _CloseWithWall

_ReviveEnemy      lda #LR_TileWallSoft            ; wall
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  sta ($0b),y                     ; play level control data ($0a00-$0bc3)
                  jsr ImageOutToDisp              ; direct output to display screen

                  lda #LR_TileWallSoft            ; wall
                  jsr ImageOutToPrep              ; direct output to preparation screen

                  ldx LR_EnmyNo                   ; number of enemies
_ChkEnemyCol      lda LR_TabEnemyCol,x            ; adr column enemies
                  cmp $4f                         ; screen col  (00-1b)
                  beq _ChkEnemyRow
                  
                  jmp _SetNextEnemy
                  
_ChkEnemyRow      lda LR_TabEnemyRow,x            ; adr row enemies
                  cmp $50                         ; screen row  (00-0f)
                  bne _SetNextEnemy
                  
                  lda TabEnemyDisab,x             ; disable enemy sprite tab
                  and SPENA                       ; VIC 2 - $D015 = Sprite Enable
                  sta SPENA                       ; VIC 2 - $D015 = Sprite Enable
                  lda LR_TabEnemyGold,x           ; enemy has gold tab
                  bpl _ResetValues
                  
                  dec LR_GoldToGet                ; enemy still had gold
                  
_ResetValues      lda #$7f                        ; reset
                  sta LR_TabEnemyGold,x           ; enemy has gold tab entry
                  stx LR_NoEnemy2Move             ; # of enemy to move
                  jsr GetEnemyStatus
                  jsr MovEnmyGetXYNo
                  jsr UpdSprtModGfx               ; shooting/closing holes/removing gold
                  
                  ldx LR_NoEnemy2Move             ; # of enemy to move
                  ldy #$01                        ; start with top row
                  sty $50                         ; screen row  (00-0f)
_FindRebirthPosI  ldy $50                         ; screen row  (00-0f)
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $0b
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  
                  ldy LR_EnmyBirthCol             ; pointer: enemy rebirth column
_FindRebirthPos   lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  cmp #LR_TileEmpty               ; empty
                  beq _SetRebirthPos              ; found
                  
                  inc LR_EnmyBirthCol             ; pointer: enemy rebirth column
                  ldy LR_EnmyBirthCol             ; pointer: enemy rebirth column
                  cpy #LR_ScrnMaxCols+1           ; $1b - max 27 cols
                  bcc _FindRebirthPos
                  
                  inc $50                         ; screen row  (00-0f)
                  lda #$00
                  sta LR_EnmyBirthCol             ; pointer: enemy rebirth column
                  beq _FindRebirthPosI            ; always
                  
_SetRebirthPos    tya
                  sta LR_TabEnemyCol,x            ; adr column enemies
                  lda $50                         ; screen row  (00-0f)
                  sta LR_TabEnemyRow,x            ; adr row enemies
                  lda #LR_TabEnemyBirt1+1
                  sta LR_TabEnemyBirtT,x          ; enemy rebirth step time
                  lda #$02
                  sta LR_TabEnemyPosUD,x          ; enemy pos on image up/down tab
                  sta LR_TabEnemyPosLR,x          ; enemy pos on image left/right tab
                  lda #$00
                  sta LR_TabEnemySprNo,x          ; actual enemy sprite number
                  ldy #$00
                  lda #$75                        ; score 75 points
                  jsr ScoreToBaseLine
                  jmp _SetNextHoleTime            ; set next hole time
                  
_SetNextEnemy     dex
                  beq _CloseWithWall
                  jmp _ChkEnemyCol
                  
_CloseWithWall    lda #LR_TileWallSoft            ; wall
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  jsr ImageOutToDisp              ; direct output to display screen

                  lda #LR_TileWallSoft            ; wall
                  jsr ImageOutToPrep              ; direct output to preparation screen

_SetNextHoleTime  ldx $52                         ; open holes time pointer
                  dex
                  bmi CloseHolesX                 ; all open holes processed
                  
                  jmp _GetNextHoleTime
                  
CloseHolesX       rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
EnemyRebirth      ldx LR_EnmyNo                   ; number of enemies
                  beq CloseHolesX                 ; ==>
                  
                  lda LR_NoEnemy2Move             ; # of enemy to move
                  pha                             ; save
GetNextStepTime   lda LR_TabEnemyBirtT,x          ; enemy rebirth step time
                  beq SetNextStepTime
                  
                  stx LR_NoEnemy2Move             ; # of enemy to move
                  jsr GetEnemyStatus
                  
                  lda #$7f                        ; no gold
                  sta LR_TabEnemyGold,x           ; enemy has gold tab
                  
                  lda LR_TabEnemyCol,x            ; adr column enemies
                  sta $4f                         ; screen col  (00-1b)
                  lda LR_TabEnemyRow,x            ; adr row enemies
                  sta $50                         ; screen row  (00-0f)
                  
                  dec LR_TabEnemyBirtT,x          ; enemy rebirth step time
                  beq EnemyRebirthRdy
                  
_ChkBirth1stStep  lda LR_TabEnemyBirtT,x          ; enemy rebirth step time
                  cmp #LR_TabEnemyBirt1           ; first step rebirth
                  bne _ChkBirth2ndStep            ;   already passed
                  
                  lda #$39                        ; first step rebirth
                  jsr ImageOutToPrep              ; direct output to preparation screen
                  jsr MovEnmyGetXYNo
                  
                  lda #$39                        ; first step rebirth
                  jsr OutSpriteGfx
                  jmp _GetNextEnemy
                  
_ChkBirth2ndStep  cmp #LR_TabEnemyBirt2           ; second step rebirth
                  bne SetNextStepTime             ;   already passed
                  
                  lda #$3a
                  jsr ImageOutToPrep              ; direct output to preparation screen
                  jsr MovEnmyGetXYNo
                  
                  lda #$3a                        ; second step rebirth
                  jsr OutSpriteGfx
                  
_GetNextEnemy     ldx LR_NoEnemy2Move             ; # of enemy to move
SetNextStepTime   dex
                  bne GetNextStepTime
                  
                  pla
                  sta LR_NoEnemy2Move             ; # of enemy to move
                  
EnemyRebirthX     rts
; ------------------------------------------------------------------------------------------------------------- ;
EnemyRebirthRdy   ldy $50                         ; screen row  (00-0f)
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  
                  ldx LR_NoEnemy2Move             ; # of enemy to move
                  inc LR_TabEnemyBirtT,x          ; enemy rebirth step time
                  ldy $4f                         ; screen col  (00-1b)
                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  bne SetNextStepTime
                  
                  lda #LR_TileEnemy               ; enemy
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)
                  lda #LR_TileEmpty               ; empty
                  jsr ImageOutToPrep              ; direct output to preparation screen

                  lda #LR_TileEmpty               ; empty
                  jsr ImageOutToDisp              ; direct output to display screen

                  lda #$00
                  ldx LR_NoEnemy2Move             ; # of enemy to move
                  sta LR_TabEnemyGold,x           ; enemy has gold tab
                  sta LR_TabEnemyBirtT,x          ; enemy rebirth step time
                  lda #LR_TileEnemy               ; enemy
                  jsr ImageOutToDisp              ; direct output to display screen

                  ldx LR_NoEnemy2Move             ; # of enemy to move
                  lda TabEnemyEnab,x              ; enable enemy sprite tab
                  ora SPENA                       ; VIC 2 - $D015 = Sprite Enable
                  sta SPENA                       ; VIC 2 - $D015 = Sprite Enable
EnemyRebirthRdyX  jmp SetNextStepTime
; ------------------------------------------------------------------------------------------------------------- ;
TabEnemyEnab      .byte $00 ; ........
                  .byte $04 ; .....#..
                  .byte $08 ; ....#...
                  .byte $10 ; ...#....
                  .byte $40 ; .#......
                  .byte $80 ; #.......
                  
TabEnemyDisab     .byte $00 ; ........
                  .byte $fb ; #####.##
                  .byte $f7 ; ####.###
                  .byte $ef ; ###.####
                  .byte $bf ; #.######
                  .byte $7f ; .#######
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
ClearAllScreens   jsr ClearHiresDisp
                  jsr ClearHiresPrep

StatusLines       ldx #$22                        ; length of separator line

_ChecksumSet      lda #$8e                        ; ==> CopyProt: set to S_8e11 for checksum build
                  sta Mod__AddHi

_SeparatorLine    lda $51                         ; target output  $20=$2000 $40=$4000
                  cmp #$40                        ; hires preparation screen
                  beq _HiResPrepare               ; preparation screen

_HiResDisplay     lda #$0a                        ; grafic byte for
_HiResDispLeX     sta LR_StatsLinLeD01            ; left end 0
                  sta LR_StatsLinLeD02            ; left end 1
                  sta LR_StatsLinLeD03            ; left end 2
                  sta LR_StatsLinLeD04            ; left end 3
                  lda #$a0                        ; grafic byte for
_HiResDispReX     sta LR_StatsLinRiD01            ; right end 0
                  sta LR_StatsLinRiD02            ; right end 1
                  sta LR_StatsLinRiD03            ; right end 2
                  sta LR_StatsLinRiD04            ; right end 3
_HiResDispMid     ldy #$03
                  lda #$aa                        ; grafic byte for
_HiResDispMidPut  sta LR_StatsLinMiD,y            ; middle part 0-3
__ModDispMidLo    = *-2
__ModDispMidHi    = *-1
                  dey
                  bpl _HiResDispMidPut            ; store next middle part 0-3

_HiResDispNext    lda __ModDispMidLo
                  clc
                  adc #$08
                  sta __ModDispMidLo
                  bcc _HiResDispDec
                  inc __ModDispMidHi

_HiResDispDec     dex
                  bne _HiResDispMid               ; dec linie counter

                  lda #>LR_StatsLinMiD            ; restore old values
                  sta __ModDispMidHi
                  lda #<LR_StatsLinMiD
                  sta __ModDispMidLo
                  bne _InfoLine                   ; always

_HiResPrepare     lda #$0a                        ; grafic byte for
_HiResPrepLeX     sta LR_StatsLinLeP01            ; left end 0
                  sta LR_StatsLinLeP02            ; left end 1
                  sta LR_StatsLinLeP03            ; left end 2
                  sta LR_StatsLinLeP04            ; left end 3
                  lda #$a0                        ; grafic byte for
_HiResPrepRiX     sta LR_StatsLinRiP01            ; right end 0
                  sta LR_StatsLinRiP02            ; right end 1
                  sta LR_StatsLinRiP03            ; right end 2
                  sta LR_StatsLinRiP04            ; right end 3
_HiResPrepMid     ldy #$03
                  lda #$aa                        ; grafic byte for middle part 0-3
_HiResPrepMidPut  sta LR_StatsLinMiP,y
__ModPrepMidLo    = *-2
__ModPrepMidHi    = *-1
                  dey
                  bpl _HiResPrepMidPut

                  lda __ModPrepMidLo
                  clc
                  adc #$08                        ; next position
                  sta __ModPrepMidLo
                  bcc _HiResPrepDec
                  inc __ModPrepMidHi

_HiResPrepDec     dex
                  bne _HiResPrepMid

                  lda #>LR_StatsLinMiP            ; restore old values
                  sta __ModPrepMidHi
                  lda #<LR_StatsLinMiP
                  sta __ModPrepMidLo

_InfoLine         lda #LR_ScrnMaxRows+1           ; $0f - max 15 rows -> info seperator is 16
                  sta $50                         ; screen row  (00-0f)
                  lda #$00
                  sta $4f                         ; screen col  (00-1b)
                  jsr TextOut
                  .byte $d3 ; S
                  .byte $c3 ; C
                  .byte $cf ; O
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $cd ; M
                  .byte $c5 ; E
                  .byte $ce ; N
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $cc ; L
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $00 ; EndOfText
; ------------------------------------------------------------------------------------------------------------- ;
; protect CopyProt routine with a checksum ==> obsolete
; ------------------------------------------------------------------------------------------------------------- ;
_Checksum         ldy #L_Checksum                 ; $45 - counter - build checksum for CopyProt routine S_8e11
                  lda #$db                        ; start value
_Add              clc
                  adc TabTileData0811,y           ; fiddle around a bit
Mod__AddLo        = *-2                           ; modified by GetADiskBlk
Mod__AddHi        = *-1                           ; modified by _ChecksumSet and _ChecksumEnd
                  eor #$01                        ; fiddle around a bit more
                  dey
                  bpl _Add

_ChecksumChk      cmp #$c8                        ; the good checksum
                  beq _ChecksumEnd

_ChecksumKill     inc Mod__GetImgPtrH             ; $a9 - destroy pointer to graphic pointer data in GetImageBytes

_ChecksumEnd      lda #>TabTileDataPtr            ; restore fake pointer to $a811
                  sta Mod__AddHi
; ------------------------------------------------------------------------------------------------------------- ;
_FillBaseLine     jsr LivesToBaseLine             ; good code restart
                  jsr LevelToBaseLine

                  lda #$00                        ; no score to add
                  tay                             ; no score to add
StatusLinesX      jmp ScoreToBaseLine             ; display score and return
; ------------------------------------------------------------------------------------------------------------- ;
; LivesToBaseLine Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
LivesToBaseLine   lda LR_NumLives
                  ldx #LR_BasLinColLve            ; output column

ValueToBaseLine   stx $4f                         ; screen col  (00-1b)
                  jsr ConvertHex2Dec              ; 1307=100 1308=10 1309=1

                  lda #LR_BasLinRowStat           ; row 16
                  sta $50                         ; screen row  (00-0f)

                  lda LR_Digit100                 ; digit 100 part
                  jsr PrepareDigitOut

                  lda LR_Digit10                  ; digit 10 part
                  jsr PrepareDigitOut

                  lda LR_Digit1                   ; digit 1 part
ValueToBaseLineX  jmp PrepareDigitOut
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
LevelToBaseLine   lda LR_LevelNoGame              ; 001-150
                  ldx #LR_BasLinColLvl            ; output column
                  bne ValueToBaseLine             ; always
; ------------------------------------------------------------------------------------------------------------- ;
; ScoreToBaseLine Function: Add valuse in ac/yr to score and displays the result in the base info line
;                 Parms   : ac=10s yr=100s
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
ScoreToBaseLine   clc
                  sed
                  adc LR_ScoreLo                  ; ac has 10th
                  sta LR_ScoreLo
                  tya                             ; yr has 100th
                  adc LR_ScoreMidLo
                  sta LR_ScoreMidLo
                  lda #$00                        ; add carry
                  adc LR_ScoreMidHi
                  sta LR_ScoreMidHi
                  lda #$00                        ; add carry
                  adc LR_ScoreHi
                  sta LR_ScoreHi

                  cld
                  lda #LR_BasLinColScr            ; output column
                  sta $4f                         ; screen col  (00-1b)
                  lda #LR_BasLinRowStat           ; row 16
                  sta $50                         ; screen row  (00-0f)

                  lda LR_ScoreHi
                  jsr SplitScoreDigit

                  lda LR_Digit1                   ; use only right nybble discard left nybble
                  jsr PrepareDigitOut

                  lda LR_ScoreMidHi
                  jsr SplitScoreDigit

                  lda LR_Digit10                  ; left nybble
                  jsr PrepareDigitOut
                  lda LR_Digit1                   ; right nybble
                  jsr PrepareDigitOut

                  lda LR_ScoreMidLo
                  jsr SplitScoreDigit

                  lda LR_Digit10                  ; left nybble
                  jsr PrepareDigitOut
                  lda LR_Digit1                   ; right nybble
                  jsr PrepareDigitOut

                  lda LR_ScoreLo
                  jsr SplitScoreDigit

                  lda LR_Digit10                  ; left nybble
                  jsr PrepareDigitOut
                  
                  lda LR_Digit1                   ; right nybble
ScoreToBaseLineX  jmp PrepareDigitOut
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
SplitScoreDigit   sta LR_Digit10                  ; store score byte
                  and #$0f
                  sta LR_Digit1                   ; isolate right nybble

                  lda LR_Digit10                  ; store   right nybble
                  lsr a                           ; isolate left  nybble
                  lsr a
                  lsr a
                  lsr a
                  sta LR_Digit10                  ; store   left  nybble

SplitScoreDigitX  rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
ConvertHex2Dec    ldx #$00
                  stx LR_Digit10                  ; digit 10 part
                  stx LR_Digit100                 ; digit 100 part

_Chk100           cmp #$64                        ; 100
                  bcc _Chk10                      ; lower
                  inc LR_Digit100                 ; digit 100 part
                  sbc #$64                        ; 100
                  bne _Chk100

_Chk10            cmp #$0a                        ; 10
                  bcc _Chk1                       ; lower
                  inc LR_Digit10                  ; digit 10 part
                  sbc #$0a                        ; 10
                  bne _Chk10

_Chk1             sta LR_Digit1                   ; digit 1 part

ConvertHex2DecX   rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
PrepareDigitOut   clc
                  adc #$3b                        ; calc digit equivalent
                  ldx $51                         ; target output  $20=$2000 $40=$4000
                  cpx #>LR_ScrnHiRePrep           ; $40
                  beq _OutToPrepare

_OutToDisplay     jsr ImageOutToDisp              ; direct output to display screen

_OutToDisplayX    inc $4f                         ; screen col  (00-1b)
                  rts

_OutToPrepare     jsr ImageOutToPrep              ; direct output to preparation screen

                  inc $4f                         ; screen col  (00-1b)
PrepareDigitOutX  rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
GetChrSubst       cmp #$c1                        ; "A"
                  bcc _ChkSpecial

                  cmp #$db                        ; "Z" + 1
                  bcc _SubstChr

_ChkSpecial       ldx #$7c                        ; substitution
                  cmp #$a0                        ; SHIFT BLANK
                  beq _SetSpecial

                  ldx #$db                        ; substitution
                  cmp #$be                        ;
                  beq _SetSpecial

                  inx                             ; substitution
                  cmp #$ae                        ; "."
                  beq _SetSpecial

                  inx                             ; substitution
                  cmp #$a8                        ; "("
                  beq _SetSpecial

                  inx                             ; substitution
                  cmp #$a9                        ; ")"
                  beq _SetSpecial

                  inx                             ; substitution
                  cmp #$af                        ; "-"
                  beq _SetSpecial

                  inx                             ; substitution
                  cmp #$ad                        ;
                  beq _SetSpecial

                  inx                             ; substitution
                  cmp #$bc                        ;
                  beq _SetSpecial

                  lda #$10                        ; all others
                  rts

_SetSpecial       txa
_SubstChr         sec
                  sbc #$7c
                  
GetChrSubstX      rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
DisplayChr        cmp #$8d                        ; NEWLINE
                  beq NewLine

                  jsr GetChrSubst

                  ldx $51                         ; target output  $20=$2000 $40=$4000
                  cpx #>LR_ScrnHiRePrep           ; $40
                  beq _OutToPrepare

_OutToDisplay     jsr ImageOutToDisp              ; direct output to display screen

                  inc $4f                         ; screen col  (00-1b)
                  rts

_OutToPrepare     jsr ImageOutToPrep              ; direct output to preparation screen

                  inc $4f                         ; screen col  (00-1b)
                  
DisplayChrX       rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
NewLine           inc $50                         ; screen row  (00-0f)
                  lda #$00
                  sta $4f                         ; screen col  (00-1b)

NewLineX          rts
; ------------------------------------------------------------------------------------------------------------- ;
; TextOut         Function: Output of Text Rows
;                           $00 terminated text must follow directly the JSR
;                           $00 terminator must be followed directly by a valid opcode
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
TextOut           pla                             ; pull the text start address from the stack
                  sta $13
                  pla
                  sta $14
                  bne _SetNext                    ; always

_GetNext          ldy #$00
                  lda ($13),y                     ; get text byte
                  beq _PrepXit                    ; zero as text end

                  jsr DisplayChr

_SetNext          inc $13
                  bne _GetNext

                  inc $14
                  bne _GetNext

_PrepXit          lda $14                         ; push the text end address to the stack
                  pha
                  lda $13
                  pha

TextOutX          rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
Beep              sei
                  lda #$60                        ; beep
                  sta FREHI1                      ; SID - $D401 = Oscillator 1 Frequency Control (High Byte)
                  ldy #$38                        ; init wait
                  ldx #$00
_Wait             dex
                  bne _Wait

                  dey
                  bne _Wait

                  sty FREHI1                      ; SID - $D401 = Oscillator 1 Frequency Control (High Byte)
                  cli

BeepX             rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
WaitKeyBlink      sta LR_DisplayChr               ; save byte under cursor
_WaitBlank        lda #$00                        ; init wait for action timer
                  sta LR_WaitTimeLo
                  lda #$0a
                  sta LR_WaitTimeHi
                  lda #$00
                  ldx LR_DisplayChr               ; saved byte under cursor
                  bne _Out
                  
                  lda #$0a                        ; SHIFT BLANK
_Out              jsr ImageOutToDisp              ; direct output to display screen

_WaitUser1        jsr ChkUserAction
                  bcs _GotUserKey

                  dec LR_WaitTimeLo
                  bne _WaitUser1
                  
                  dec LR_WaitTimeHi
                  bne _WaitUser1

                  lda LR_DisplayChr               ; get byte under cursor
                  jsr ImageOutToDisp              ; direct output to display screen

                  lda #$00                        ; init wait for action timer
                  sta LR_WaitTimeLo
                  lda #$0a
                  sta LR_WaitTimeHi
_WaitUser2        jsr ChkUserAction
                  bcs _GotUserKey
                  
                  dec LR_WaitTimeLo
                  bne _WaitUser2
                  
                  dec LR_WaitTimeHi
                  bne _WaitUser2

                  jmp _WaitBlank

_GotUserKey       pha                             ; save key
                  lda LR_DisplayChr               ; redisplay chr under cursor in case of got in blank blink phase
                  jsr ImageOutToDisp              ; direct output to display screen

                  pla                             ; restore key
WaitKeyBlinkX     rts
; ------------------------------------------------------------------------------------------------------------- ;
; ChkUserAction   Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
ChkUserAction     lda CIAPRA                      ; CIA 1 - $DC00 = Data Port A
                  and #$0f                        ; isolate - port a:  bit4=fire  bit3=right  bit2=left  bit1=down  bit0=up
                  eor #$0f                        ; reverse
                  bne _SetUserAction

                  lda CIAPRA                      ; CIA 1 - $DC00 = Data Port A
                  and #$10                        ; isolate fire
                  beq _SetUserAction

                  lda LR_KeyNew                   ; actual key
                  bne _SetUserAction

_SetNoUserAction  clc                             ; indicate no user action
                  rts

_SetUserAction    sec                             ; indicate user action
ChkUserActionX    rts
; ------------------------------------------------------------------------------------------------------------- ;
; ImageOutToDisp  Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
ImageOutToDisp    sta $23                         ; image number - level input tile $00-$09/sprite number
                  lda #>LR_ScrnHiReDisp           ; $20
                  bne GraficOut                   ; always
                  
ImageOutToPrep    sta $23                         ; level input tile $00-$09
                  lda #>LR_ScrnHiRePrep           ; $40                  
GraficOut         sta $24                         ; target output  $20=$2000 $40=$4000
                  
                  ldy $50                         ; screen row  (00-0f)
                  ldx $4f                         ; screen col  (00-1b)
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row
                  sty $20                         ; row offset
                  
                  jsr SetSpriteXPos               ; xr=VIC Sprite XPOS offset
                  jsr GetOutGfxPosAdd
                  stx $41                         ; image position number  (bits 0-1 of $4f substitution)
                  
                  lda TabInsImageLe,x             ; insert image left tab  (4 different image positions)
                  sta $25                         ; isolate right grafic part
                  lda TabInsImageRi,x             ; insert image right tab (4 different image positions)
                  sta $26                         ; isolate left grafic part
                  jsr GetImageBytes               ; stored from $5b-$7b
                  
_SetHeight        lda #$0b                        ; 11 - hight of each image
                  sta $22                         ; image hight
                  
                  ldx #$00
                  
                  lda $41                         ; image position number  (bits 0-1 of $4f substitution)
                  cmp #$05                        ; row positions need an additional offset of $08
                  bcs GraficOut2
                  
_ImageOut         ldy $20                         ; grafic row substitution
                  jsr GetOutGfxPtr
                  
                  ldy #$00
                  lda ($0f),y                     ; get grafic screen image byte
                  and $25                         ; clear the right grafic part
                  ora $5b,x                       ; insert new image byte
                  sta ($0f),y                     ; write grafic screen image byte
                  
                  inx                             ; point to next image byte
                  ldy #$08                        ; insert right part of image into right part of screen image
                  lda ($0f),y                     ; get grafic screen image byte
                  and $26                         ; clear the left grafic part
                  ora $5b,x                       ; insert new image byte
                  sta ($0f),y                     ; write grafic screen image byte
                  
                  inx
                  inx
                  
                  inc $20                         ; grafic row substitution
                  dec $22                         ; image hight
                  bne _ImageOut
                  
GraficOut1X       rts
; ------------------------------------------------------------------------------------------------------------- ;
GraficOut2        ldy $20                         ; grafic row substitution
                  jsr GetOutGfxPtr
                  
                  ldy #$00
                  lda ($0f),y                     ; insert left part of image into right part of screen image
                  and $25                         ; clear the right grafic part
                  ora $5b,x                       ; insert new image byte
                  sta ($0f),y                     ; write grafic screen image byte
                  
                  inx                             ; point to next image byte
                  ldy #$08                        ; insert right part of image into right part of screen image
                  lda $5b,x                       ; get image byte
                  sta ($0f),y                     ; write grafic screen image byte
                  
                  inx                             ; point to next image byte
                  ldy #$10
                  lda ($0f),y                     ; get grafic screen image byte
                  and $26                         ; clear the left image part
                  ora $5b,x                       ; insert new image byte
                  sta ($0f),y                     ; write grafic screen image byte
                  
                  inx
                  inc $20                         ; grafic row substitution
                  dec $22                         ; image hight
                  bne GraficOut2
                  
GraficOut2X       rts
; ------------------------------------------------------------------------------------------------------------- ;
TabInsImageLe     .byte $00 ; ........
                  .byte $c0 ; ##......
                  .byte $f0 ; ####....
                  .byte $fc ; ######..
                  
TabInsImageRi     .byte $3f ; ..######
                  .byte $0f ; ....####
                  .byte $03 ; ......##
                  .byte $00 ; ........
; ------------------------------------------------------------------------------------------------------------- ;
; UpdSprtModGfx   Function: Update Sprite Modified Graphics (Shooting/Close Hole Steps/Remove Gold)
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
UpdSprtModGfx     sty $20                         ; grafic row substitution
                  sta $23                         ; level input tile $00-$09
                  jsr GetOutGfxPosAdd

                  sta $21                         ; low byte grafic tab addition
                  stx $41                         ; image position number  (bits 0-1 of $4f substitution)
                  jsr GetImageBytes               ; stored from $5b-$7b

                  ldx #$0b
                  stx $22                         ; image hight
                  
                  ldx #$00

                  lda $41                         ; image position number  (bits 0-1 of $4f substitution)
                  cmp #$05                        ; max for bit 0-1 is $03
                  bcs _UpdateOutTyp2              ; never reached

_UpdateOutTyp1    ldy $20                         ; grafic row substitution
                  jsr GetMoveGfxPtr

                  ldy #$00                        ; image left part
                  
                  lda $5b,x                       ; image byte
                  eor #$ff
                  and ($0f),y                     ; screen grafic pointer byte
                  ora ($11),y                     ; hidden grafic pointer byte
                  sta ($0f),y                     ; screen grafic pointer byte
                  
                  inx                             ; point to next image byte
                  
                  ldy #$08                        ; image right part
                  
                  lda $5b,x                       ; image byte
                  eor #$ff
                  and ($0f),y                     ; screen grafic pointer byte
                  ora ($11),y                     ; hidden grafic pointer byte
                  sta ($0f),y                     ; screen grafic pointer byte
                  
                  inx                             ; 3rd image byte always blank
                  inx                             ;   so discard it

                  inc $20                         ; grafic row substitution

                  dec $22                         ; image hight
                  bne _UpdateOutTyp1

_UpdateOutTyp1X   rts
; ------------------------------------------------------------------------------------------------------------- ;
_UpdateOutTyp2    ldy $20                         ; grafic row substitution  ==> obsolete ???
                  jsr GetMoveGfxPtr

                  ldy #$00                        ; image left part
                  
                  lda $5b,x                       ; image byte
                  eor #$ff
                  and ($0f),y                     ; screen grafic pointer byte
                  ora ($11),y                     ; hidden grafic pointer byte
                  sta ($0f),y                     ; screen grafic pointer byte

                  inx                             ; point to next image byte

                  ldy #$08                        ; image right part

                  lda $5b,x                       ; image byte
                  eor #$ff
                  and ($0f),y                     ; screen grafic pointer byte
                  ora ($11),y                     ; hidden grafic pointer byte
                  sta ($0f),y                     ; screen grafic pointer byte

                  inx                             ; point to next image byte

                  ldy #$10                        ; image right part
                  lda $5b,x                       ; image byte
                  eor #$ff
                  and ($0f),y                     ; screen grafic pointer byte
                  ora ($11),y                     ; hidden grafic pointer byte
                  sta ($0f),y                     ; screen grafic pointer byte

                  inx                             ; point to next image byte

                  inc $20                         ; grafic row substitution

                  dec $22                         ; image hight
                  bne _UpdateOutTyp2

UpdSprtModGfxX    rts
; ------------------------------------------------------------------------------------------------------------- ;
; OutSpriteGfx    Function: Update and Display Sprites (Enemy Rebirth/Enemy Dropped Gold/LR Shoots)
;                 Parms   : 
;                 Returns : 
; ------------------------------------------------------------------------------------------------------------- ;
OutSpriteGfx      sty $20                         ; grafic row substitution
                  sta $23                         ; level input tile $00-$09
                  jsr SetSpriteXPos               ; xr=VIC Sprite XPOS offset
                  jsr GetOutGfxPosAdd

                  sta $21                         ; low byte grafic tab addition
                  stx $41                         ; image position number  (bits 0-1 of 4f substitution)
                  jsr GetImageBytes               ; stored from $5b-$7b

                  lda #$0b
                  sta $22                         ; image hight
                  
                  ldx #$00
                  stx $27                         ; clear sprite collision  $01=lr caught

                  lda $41                         ; image position number  (bits 0-1 of $4f substitution)
                  
                  cmp #$05                        ; max for bit 0-1 is $03
                  bcs _SpriteOutTyp2              ; never reached

_SpriteOutTyp1    ldy $20                         ; grafic row substitution
                  jsr GetMoveGfxPtr

                  ldy #$00                        ; first image half
                  
                  lda $5b,x                       ; image byte
                  ora ($0f),y                     ; screen grafic pointer byte
                  sta ($0f),y                     ; screen grafic pointer byte

                  inx                             ; image byte pointer

                  ldy #$08                        ; second image half

                  lda $5b,x                       ; image byte
                  ora ($0f),y                     ; screen grafic pointer byte
                  sta ($0f),y                     ; screen grafic pointer byte

                  inx                             ; 3rd imge byte always 00 so discard
                  inx

                  inc $20                         ; grafic row substitution

                  dec $22                         ; image hight
                  bne _SpriteOutTyp1

_SpriteOutTyp1X   rts
; ------------------------------------------------------------------------------------------------------------- ;
_SpriteOutTyp2    ldy $20                         ; grafic row substitution  ==> obsolete ???
                  jsr GetMoveGfxPtr

                  ldy #$00                        ; left image part
                  
                  lda $5b,x                       ; image byte
                  ora ($0f),y                     ; screen grafic pointer byte
                  sta ($0f),y                     ; screen grafic pointer byte

                  inx                             ; point to next image byte

                  ldy #$08                        ; middle image part
                  lda $5b,x                       ; image byte
                  ora ($0f),y                     ; screen grafic pointer byte
                  sta ($0f),y                     ; screen grafic pointer byte

                  inx                             ; point to next image byte

                  ldy #$10                        ; right image part
                  lda $5b,x                       ; image byte
                  ora ($0f),y                     ; screen grafic pointer byte
                  sta ($0f),y                     ; screen grafic pointer byte

                  inx                             ; point to next image byte

                  inc $20                         ; grafic row substitution

                  dec $22                         ; image hight
                  bne _SpriteOutTyp2

OutSpriteGfxX     rts
; ------------------------------------------------------------------------------------------------------------- ;
; GetImageBytes   Function: Contruct an 11*3 Byte Image at Zero Page $5b-$7b
;                 Parms   : xr - bit0/bit1 isolated from TabSubstCol of GetColRowGfxOff
;                 Returns : 
; ------------------------------------------------------------------------------------------------------------- ;
GetImageBytes     lda #$0b                        ; 11 rows with 3 bytes
                  sta $22                         ; image hight

                  lda #<TabTileDataPtr            ; get image data pointer
                  sta $0d
                  lda #>TabTileDataPtr
Mod__GetImgPtrH   = *-1                           ; ==> 
                  sta $0e                         ; image pointer  (a800)

_SetImgByteBase   ldy TabImageData,x              ; four different image pos tab
                  sty __ModGetImgDatH1            ; $00=$a0 $01=$a2 $02=$a4 $03=$a6
                  sty __ModGetImgDatH3
                  iny
                  sty __ModGetImgDatH2            ; $00=$a1 $01=$a3 $02=$a5 $03=$a7
                  sty __ModGetImgDatH4

_SetZeroPgPtr     ldx #$00                        ; zero page storage pointer

_ConstructImage   ldy $23                         ; image number

_Get1stImgDatOff  lda ($0d),y                     ; get the offset to the image data bytes
                  tay
                  
_Get1stImgByte    lda TabTileDataA0,y             ; get 1st image byte     from $a000/$a200/$a400/$a600
__ModGetImgDatH1  = *-1

_Sto1stImgByte    sta $5b,x                       ; store it to 1st position
                  
_Get2ndImgByteLo  lda TabTileDataA0,y             ; get 2nd image 1st part from $a100/$a300/$a500/$a700
__ModGetImgDatH2  = *-1

_Sto2ndImgByte    sta $5c,x                       ; store it to 2nd position

_IncOffsetPtr01   lda $0d                         ; point to next grafix data bytes
                  clc
                  adc #$68
                  sta $0d
                  lda $0e
                  adc #$00
                  sta $0e

                  ldy $23                         ; image number
                  
_Get2ndImgDatOff  lda ($0d),y                     ; get the offset to the image data bytes
                  tay
                  
_Get2ndImgByteHi  lda TabTileDataA0,y             ; get 2nd image 2nd part from $a000/$a200/$a400/$a600
__ModGetImgDatH3  = *-1

_Ovl2ndImgByteLo  ora $5c,x                       ; overlay it with 2nd position
_Sto2ndImgByteOK  sta $5c,x                       ; store it to 2nd position

_Get3rdImgByte    lda TabTileDataA0,y             ; get 3rd image byte     from $a100/$a300/$a500/$a700
__ModGetImgDatH4  = *-1

_Sto3rdImgByteLo  sta $5d,x                       ; store it to 3rd position

_IncOffsetPtr02   lda $0d                         ; point to next grafix data bytes
                  clc
                  adc #$68
                  sta $0d
                  lda $0e
                  adc #$00
                  sta $0e

_IncZeroPgPtr     inx                             ; point to next zero page triple
                  inx
                  inx

_DecImgRowCount   dec $22                         ; image hight
                  bne _ConstructImage             ; get next data row

GetImageBytesX    rts
; ------------------------------------------------------------------------------------------------------------- ;
TabImageData      .byte >TabTileDataA0
                  .byte >TabTileDataA2
                  .byte >TabTileDataA4
                  .byte >TabTileDataA6
; ------------------------------------------------------------------------------------------------------------- ;
; SetSpriteXPos   Function: Move Sprite Left/Right
;                 Parms   : ac=Spirte ID
;                 Returns : xr=VIC Sprite XPOS offset
; ------------------------------------------------------------------------------------------------------------- ;
SetSpriteXPos     lda LR_SprtPosCtrl              ; control sprite pos init  $00=init
                  bne SetSpriteXPosX
                  
                  lda $23                         ; image number - level input tile $00-$09
                  cmp #$39                        ; $00-$39 only
                  bcs SetSpriteXPosX
                  
                  tay
                  lda TabImageID,y                ; image id tab
                  bmi SetSpriteXPosX              ; not used
                  beq _SavOffset
                  
                  sta $23                         ; sprite images
                  
_SavOffset        stx $21                         ; grafic xr offset from GetColRowGfxOff
                  jsr CopySpriteData              ; xr=sprite number * 2

                  lda $21                         ; grafic xr offset from GetColRowGfxOff
                  clc
                  adc #$0c                        ; 12
                  asl a                           ; *2
                  and #$f8                        ; clear bits 0-2
                  sta SP0X,x                      ; VIC 2 - $D000 = Sprite 0 PosX
                  bcc _ClrXposMSB                 ; no x pos msb so ClearSpritesXMSB
                  
_GetXposMSB       lda TabSetSprtMSB,x            ; sprite set x pos msb tab
                  ora MSIGX                       ; VIC 2 - $D010 = MSBs Sprites 0-7 PosX
                  sta MSIGX                       ; VIC 2 - $D010 = MSBs Sprites 0-7 PosX
                  jmp _SetSpriteXPos
                  
_ClrXposMSB       lda TabClrSprtMSB,x             ; sprite clear x pos msb tab
                  and MSIGX                       ; VIC 2 - $D010 = MSBs Sprites 0-7 PosX
                  sta MSIGX                       ; VIC 2 - $D010 = MSBs Sprites 0-7 PosX
                  
_SetSpriteXPos    lda $20                         ; grafic row substitution
                  clc
                  adc #$32                        ; 50
                  sta SP0Y,x                      ; VIC 2 - $D001 = Sprite 0 PosY
                  lda SPSPCL                      ; VIC 2 - $D01E = Sprite/Sprite Collision
                  
                  and #$01                        ; isolate bit 0
                  sta $27                         ; sprite collision  1=lr caught
                  
                  pla                             ; discard return address
                  pla
                  
SetSpriteXPosX    rts
; ------------------------------------------------------------------------------------------------------------- ;
TabSetSprtMSB     .byte $01                       ; .......#  set   - sprite x pos msb tab
TabClrSprtMSB     .byte $fe                       ; #######.  clear - sprite x pos msb tab
                  
                  .byte $02                       ; ......#.  set   - sprite x pos msb tab
                  .byte $fd                       ; ######.#  clear - sprite x pos msb tab
                  
                  .byte $04                       ; .....#..  set   - sprite x pos msb tab
                  .byte $fb                       ; #####.##  clear - sprite x pos msb tab
                  
                  .byte $08                       ; ....#...  set   - sprite x pos msb tab
                  .byte $f7                       ; ####.###  clear - sprite x pos msb tab
                  
                  .byte $10                       ; ...#....  set   - sprite x pos msb tab
                  .byte $ef                       ; ###.####  clear - sprite x pos msb tab
                  
                  .byte $20                       ; ..#.....  set   - sprite x pos msb tab
                  .byte $df                       ; ##.#####  clear - sprite x pos msb tab
                  
                  .byte $40                       ; .#......  set   - sprite x pos msb tab
                  .byte $bf                       ; #.######  clear - sprite x pos msb tab
                  
                  .byte $80                       ; #.......  set   - sprite x pos msb tab
                  .byte $7f                       ; .#######  clear - sprite x pos msb tab
; ------------------------------------------------------------------------------------------------------------- ;
TabImageID        .byte $ff                       ; not used - image selection tab - $00-$38 = $39
                  .byte $ff                       ; not used
                  .byte $ff                       ; not used
                  .byte $ff                       ; not used
                  .byte $ff                       ; not used
                  .byte $ff                       ; not used
                  .byte $ff                       ; not used
                  .byte $ff                       ; not used
                  .byte $0b                       ; sprite: enemy
                  .byte $00                       ; sprite: lode runner
                  .byte $ff                       ; not used
                  .byte $00                       ; 
                  .byte $00                       ; 
                  .byte $00                       ; 
                  .byte $00                       ; 
                  .byte $00                       ; 
                  .byte $00                       ; 
                  .byte $00                       ; 
                  .byte $00                       ; 
                  .byte $00                       ; 
                  .byte $00                       ; 
                  .byte $00                       ; 
                  .byte $00                       ; 
                  .byte $00                       ; 
                  .byte $00                       ; 
                  .byte $00                       ; 
                  .byte $00                       ; 
                  .byte $ff                       ; not used
                  .byte $ff                       ; not used
                  .byte $ff                       ; not used
                  .byte $ff                       ; not used
                  .byte $ff                       ; not used
                  .byte $ff                       ; not used
                  .byte $ff                       ; not used
                  .byte $ff                       ; not used
                  .byte $ff                       ; not used
                  .byte $ff                       ; not used
                  .byte $00                       ; 
                  .byte $ff                       ; not used
                  .byte $ff                       ; not used
                  .byte $09                       ; sprite:
                  .byte $10                       ; sprite:
                  .byte $11                       ; sprite:
                  .byte $0c                       ; sprite:
                  .byte $0d                       ; sprite:
                  .byte $15                       ; sprite:
                  .byte $16                       ; sprite:
                  .byte $17                       ; sprite:
                  .byte $18                       ; sprite:
                  .byte $19                       ; sprite:
                  .byte $1a                       ; sprite:
                  .byte $0e                       ; sprite:
                  .byte $12                       ; sprite:
                  .byte $14                       ; sprite:
                  .byte $13                       ; sprite:
                  .byte $ff                       ; not used
                  .byte $ff                       ; not used
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
CopySpriteData    pha                             ; save image id
                  
                  lda $21                         ; grafic xr offset from GetColRowGfxOff
                  and #$03                        ; isolate bit 0-1
                  tax
                  jsr GetImageBytes               ; stored from $5b-$7b
                  
                  pla                             ; restore image id
                  beq _CopyDataI                  ; lode runner
                  
                  lda LR_NoEnemy2Move             ; # of enemy to move
                  
_CopyDataI        tax
                  lda TabSprtDatPtrLo,x           ; sprite data pos low tab
                  sta __ModMovSprtDatH            ; modify store address low
                  lda TabSprtDatPtrHi,x           ; sprite data pos high tab
                  sta __ModMovSprtDatL            ; modify store address high
                  
                  lda TabSprtNum,x                ; sprite number tab
                  tax
                  
                  ldy #$20                        ; 32
_CopyData         lda $005b,y                     ; ==> image has 33 bytes
_MoveSprtDat      sta _MoveSprtDat,y              ; store it to correct sprite data storage  ($0c00-$0dff)
__ModMovSprtDatH  = *-2
__ModMovSprtDatL  = *-1
                  dey
                  bpl _CopyData
                  
                  txa
                  asl a                           ; *2 - gives VIC sprite XPOS offset
                  tax
                  
CopySpriteDataX   rts
; ------------------------------------------------------------------------------------------------------------- ;
TabSprtDatPtrLo   .byte <LR_SpriteData00          ; sprite data pos low tab
                  .byte <LR_SpriteData01
                  .byte <LR_SpriteData02
                  .byte <LR_SpriteData03
                  .byte <LR_SpriteData04
                  .byte <LR_SpriteData05
; ------------------------------------------------------------------------------------------------------------- ;
TabSprtDatPtrHi   .byte >LR_SpriteData00          ; sprite data pos high tab
                  .byte >LR_SpriteData01
                  .byte >LR_SpriteData02
                  .byte >LR_SpriteData03
                  .byte >LR_SpriteData04
                  .byte >LR_SpriteData05
; ------------------------------------------------------------------------------------------------------------- ;
TabSprtNum        .byte $00                       ; sprite number tab
                  .byte $02
                  .byte $03
                  .byte $04
                  .byte $06
                  .byte $07
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns : offsets in xr=col yr=row
; ------------------------------------------------------------------------------------------------------------- ;
GetColRowGfxOff   lda TabSubstRow,y               ; substitute row tab
                  pha
                  lda TabSubstCol,x               ; substitute column tab
                  tax                             ; col
                  pla
                  tay                             ; row

GetColRowGfxOffX  rts
; ------------------------------------------------------------------------------------------------------------- ;
TabSubstRow       .byte $00 ; 00: ........
                  .byte $0b ; 01: ....#.##
                  .byte $16 ; 02: ...#.##.
                  .byte $21 ; 03: ..#....#
                  .byte $2c ; 04: ..#.##..
                  .byte $37 ; 05: ..##.###
                  .byte $42 ; 06: .#....#.
                  .byte $4d ; 07: .#..##.#
                  .byte $58 ; 08: .#.##...
                  .byte $63 ; 09: .##...##
                  .byte $6e ; 0a: .##.###.
                  .byte $79 ; 0b: .####..#
                  .byte $84 ; 0c: #....#..
                  .byte $8f ; 0d: #...####
                  .byte $9a ; 0e: #..##.#.
                  .byte $a5 ; 0f: #.#..#.#
                  .byte $b5 ; 10: #.##.#.#
; ------------------------------------------------------------------------------------------------------------- ;
TabSubstCol       .byte $0a ; 01: ....#.   #.   - rightmost two bits isolated for GetImageBytes
                  .byte $0f ; 02: ....##   ##
                  .byte $14 ; 03: ...#.#   ..
                  .byte $19 ; 04: ...##.   .#
                  .byte $1e ; 05: ...###   #.
                  .byte $23 ; 06: ..#...   ##
                  .byte $28 ; 07: ..#.#.   ..
                  .byte $2d ; 08: ..#.##   .#
                  .byte $32 ; 09: ..##..   #.
                  .byte $37 ; 0a: ..##.#   ##
                  .byte $3c ; 0b: ..####   ..
                  .byte $41 ; 0c: .#....   .#
                  .byte $46 ; 0d: .#...#   #.
                  .byte $4b ; 0e: .#..#.   ##
                  .byte $50 ; 0f: .#.#..   ..
                  .byte $55 ; 10: .#.#.#   .#
                  .byte $5a ; 11: .#.##.   #.
                  .byte $5f ; 12: .#.###   ##
                  .byte $64 ; 13: .##..#   ..
                  .byte $69 ; 14: .##.#.   .#
                  .byte $6e ; 15: .##.##   #.
                  .byte $73 ; 16: .###..   ##
                  .byte $78 ; 17: .####.   ..
                  .byte $7d ; 18: .#####   .#
                  .byte $82 ; 19: #.....   #.
                  .byte $87 ; 1a: #....#   ##
                  .byte $8c ; 1b: #...##   ..
                  .byte $91 ; 1c: #..#..   .#
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
GetXOff           tya
                  pha                             ; save yr
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row

                  pla
                  tay                             ; restore yr
                  txa
                  clc
                  adc TabOffsetsX,y               ; offset tab
                  tax

GetXOffX          rts
; ------------------------------------------------------------------------------------------------------------- ;
TabOffsetsX       .byte $fe ; -2
                  .byte $ff ; -1
                  .byte $00 ;  0
                  .byte $01 ; +1
                  .byte $02 ; +2
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
GetYOff           txa
                  pha                             ; save xr
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row

                  pla
                  tax                             ; restore
                  tya
                  clc
                  adc TabOffsetsY,x
                  tay

GetYOffX          rts
; ------------------------------------------------------------------------------------------------------------- ;
TabOffsetsY       .byte $fb ; -4
                  .byte $fd ; -2
                  .byte $00 ;  0
                  .byte $02 ; +2
                  .byte $04 ; +4
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
GarbageSub_8c92   lda GarbageTab_8c9c,x          ; garbage sub - not dispatched
                  pha
                  lda GarbageTab_8cba,x
                  tax
                  pla

                  rts
; ------------------------------------------------------------------------------------------------------------- ;
GarbageTab_8c9c   .byte $02                       ; ==> garbage ac tab
                  .byte $03
                  .byte $05
                  .byte $06
                  .byte $07
                  .byte $08
                  .byte $0a
                  .byte $0b
                  .byte $0c
                  .byte $0d
                  .byte $0f
                  .byte $10
                  .byte $11
                  .byte $12
                  .byte $14
                  .byte $15
                  .byte $16
                  .byte $17
                  .byte $19
                  .byte $1a
                  .byte $1b
                  .byte $1c
                  .byte $1e
                  .byte $1f
                  .byte $20

GarbageTab_8cb5   .byte $21                       ; garbage tab
                  .byte $23
                  .byte $24
                  .byte $25
                  .byte $26

GarbageTab_8cba   .byte $02                       ; garbage x tab
                  .byte $03
                  .byte $00
                  .byte $01
                  .byte $02
                  .byte $03
                  .byte $00
                  .byte $01
                  .byte $02
                  .byte $03
                  .byte $00
                  .byte $01
                  .byte $02
                  .byte $03
                  .byte $00
                  .byte $01
                  .byte $02
                  .byte $03
                  .byte $00
                  .byte $01
                  .byte $02
                  .byte $03
                  .byte $00
                  .byte $01
                  .byte $02
                  .byte $03
                  .byte $00
                  .byte $01
                  .byte $02
                  .byte $03
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
GetOutGfxPosAdd   lda #$00
                  sta LR_GfxAddHi                 ; init high grafic add
                  
                  txa
                  pha                             ; save xr
                  and #$03                        ; isolate bit 0-1
                  tax
                  pla                             ; restore xr

                  asl a                           ; *2
                  rol LR_GfxAddHi                 ; save carry in high grafic add
                  and #$f8                        ; kill bits 0-2
                  sta LR_GfxAddLo                 ;   of low grafic add

GetOutGfxPosAddX  rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
GetCtrlDataPtr    lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c

GetCtrlDataPtrX   rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
GetOutGfxPtrClr   lda #$00
                  sta LR_GfxAddLo
                  sta LR_GfxAddHi
GetOutGfxPtr      lda LR_TabOffHiresLo,y          ; offset grafic output low
                  clc
                  adc LR_GfxAddLo                 ; low grafic add
                  sta $0f                         ; screen grafic low pointer
                  lda LR_TabOffHiresHi,y          ; offset grafic output high
                  adc LR_GfxAddHi                 ; high grafic add
                  ora $24                         ; graphic output  (20=2000-2fff  40=4000-4fff)
                  sta $10                         ; screen grafic high pointer

GetOutGfxPtrX     rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
CircleGetGfxPtr   lda #$00
                  sta LR_GfxAddHi                 ; init high grafic add
                  txa
                  asl a
                  asl a
                  asl a
                  rol LR_GfxAddHi                 ; save carry in high grafic add
                  sta LR_GfxAddLo                 ; low grafic add

GetMoveGfxPtr     lda LR_TabOffHiresLo,y          ; offset grafic output low
                  clc
                  adc LR_GfxAddLo                 ; low grafic add
                  sta $0f                         ; screen grafic low pointer
                  sta $11                         ; hidden grafic low pointer

                  lda LR_TabOffHiresHi,y          ; offset grafic output high
                  adc LR_GfxAddHi                 ; high grafic add
                  ora #>LR_ScrnHiReDisp            ; $20 - point to $2000-$3fff  (display screen)
                  sta $10                         ; screen grafic high pointer
                  eor #>LR_ScrnHiReDisp + >LR_ScrnHiRePrep ; $60 - point to $4000-$5fff  (hidden screen)
                  sta $12                         ; hidden grafic high pointer

GetMoveGfxPtrX    rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
ClearHiresDisp    lda #>LR_ScrnHiReDisp           ; $2000-$3fff - hires display screen
                  ldx #$00
                  stx SPENA                       ; VIC 2 - $D015 = Sprite Enable
                  ldx #>LR_ScrnHiRePrep           ; $40 - upper border
                  bne ClearScrn                   ; always

ClearHiresPrep    lda #>LR_ScrnHiRePrep           ; $40=$4000-$5fff  copy of screen  (hidden setup/copy to $2000)
                  ldx #>(LR_ScrnHiRePrep + $2000) ; $60 - upper border
ClearScrn         sta $10                         ; screen grafic high pointer
                  ldy #$00
                  sty $0f                         ; screen grafic low pointer
                  tya
_Clear            sta ($0f),y                     ; screen grafic pointer byte
                  iny                             ; next byte
                  bne _Clear

                  inc $10                         ; next block
                  cpx $10                         ; upper border
                  bne _Clear                      ; not reached

ClearScrnX        rts
; ------------------------------------------------------------------------------------------------------------- ;
TabExLvlDatRowLo  .byte $00                       ; expanded level data row pointer lo
                  .byte $1c
                  .byte $38
                  .byte $54
                  .byte $70
                  .byte $8c
                  .byte $a8
                  .byte $c4
                  .byte $e0

                  .byte $00
                  .byte $1c
                  .byte $38
                  .byte $54
                  .byte $70
                  .byte $8c
                  .byte $a8
; ------------------------------------------------------------------------------------------------------------- ;
TabExLvlDatRowH8  .byte $08                       ; expanded level data row pointer $0800-$09c3
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08

                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
; ------------------------------------------------------------------------------------------------------------- ;
TabExLvlDatRowHa  .byte $0a                       ; expanded level data row pointer $0a00-$0bc3
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a

                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
; ------------------------------------------------------------------------------------------------------------- ;
; ShowExitLadders Function: Show secret ladders if all gold is collected
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
ShowExitLadders   lda #$00
                  sta LR_TabXitLdrCol             ; init not empty mark

                  ldx LR_NumXitLadders            ; # hidden ladders
                  stx WrkXitLadders               ; # hidden ladders to display
_Ladders          ldx WrkXitLadders               ; # hidden ladders to display
                  beq _ExitCheckGold              ; finished

                  lda LR_TabXitLdrCol,x           ; adr column hidden ladder tab
                  bmi _DecLadderCount             ; already cleared

                  sta $4f                         ; screen col  (00-1b)
                  lda LR_TabXitLdrRow,x           ; adr row hidden ladders tab
                  sta $50                         ; screen row  (00-0f)
                  tay
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c

                  ldy $4f                         ; screen col  (00-1b)
                  lda ($0b),y                     ; play level control data ($0a00-$0bc3)
                  bne _SetNotEmpty                ; position not empty

_LadderOutCtrl    lda #LR_TileLadder              ; ladder
                  sta ($0b),y                     ; play level control data ($0a00-$0bc3)

                  lda ($09),y                     ; unpacked level data ($0800-$09c3)
                  bne _LadderOutDisp              ; not empty

_LadderOutData    lda #LR_TileLadder              ; ladder
                  sta ($09),y                     ; unpacked level data ($0800-$09c3)

_LadderOutDisp    lda #LR_TileLadder              ; ladder
                  jsr ImageOutToPrep              ; direct output to preparation screen

                  ldx $4f                         ; screen col  (00-1b)
                  ldy $50                         ; screen row  (00-0f)
                  jsr GetColRowGfxOff             ; offsets in xr=col yr=row

                  lda #LR_TileLadder              ; ladder
                  jsr OutSpriteGfx

_ClrTabXitLadder  ldx WrkXitLadders               ; # hidden ladders to display
                  lda #$ff
                  sta LR_TabXitLdrCol,x           ; clear adr column hidden ladder tab
                  bmi _DecLadderCount             ; always

_SetNotEmpty      lda #$01
                  sta LR_TabXitLdrCol             ; set not empty mark

_DecLadderCount   dec WrkXitLadders               ; # hidden ladders to display
                  jmp _Ladders

_ExitCheckGold    lda LR_TabXitLdrCol             ; not empty mark
                  bne ShowExitLaddersX            ; not set

                  dec LR_GoldToGet

ShowExitLaddersX  rts
; ------------------------------------------------------------------------------------------------------------- ;
WrkXitLadders     .byte $00
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
GetAKey           lda LR_KeyNew
                  beq GetAKey

                  ldx #$00
                  stx LR_KeyNew

GetAKeyX          rts
; ------------------------------------------------------------------------------------------------------------- ;
; S_8e11          Function:  Copy Protection ==> Obsolete code start
;                            Checksummed by _Checksum of StatusLines until L_Checksum is reached
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
GetSomeDiskBlks   ldx #$30                        ; track high
                  ldy #$32                        ; track low
                  lda #$00                        ; offset digits1/2 tab
                  jsr GetADiskBlk
                  beq GetSomeDiskBlksX

                  ldx #$30                        ; track high
                  ldy #$31                        ; track low
                  lda #$01                        ; offset digits1/2 tab
                  jsr GetADiskBlk
                  bne GetSomeDiskBlksX

                  ldx #$33                        ; track high
                  ldy #$34                        ; track low
                  lda #$02                        ; offset digits1/2 tab
                  jsr GetADiskBlk
                  beq GetSomeDiskBlksX

                  ldx #$33                        ; track high
                  ldy #$35                        ; track low
                  lda #$03                        ; offset digits1/2 tab
                  jsr GetADiskBlk

GetSomeDiskBlksX  rts
; ------------------------------------------------------------------------------------------------------------- ;
TabDiskDigits1    .byte "2"
                  .byte "0"
                  .byte "2"
                  .byte "0"
TabDiskDigits2    .byte "3"
                  .byte "0"
                  .byte "7"
                  .byte "0"
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
GetADiskBlk       sta $1e
                  stx TabDiskTrkHi01              ; track in disk command
                  sty TabDiskTrkHi02              ; track in disk command

                  lda #$00                        ; no data set name
                  jsr SETNAM                      ; KERNAL - $FFBD = Set Filename Parameters

                  lda #$0f
                  ldx #$08
                  tay                             ; command channel

L_Checksum = * - GetSomeDiskBlks                  ; CopyProt: _Checksum creation length
                                                  ;   any changes in the section above will destroy the game gfx
; ------------------------------------------------------------------------------------------------------------- ;
                  jsr SETLFS                      ; KERNAL - $FFBA = Set Logical File Parameters
                  jsr OPEN                        ; KERNAL - $FFC0 = Open a Logical File
                  
                  lda #$01                        ; name length
                  ldx #<TabDiskHash
                  ldy #>TabDiskHash
                  jsr SETNAM                      ; KERNAL - $FFBD = Set Filename Parameters

                  lda #$05
                  ldx #$08
                  tay                             ; data channel
                  jsr SETLFS                      ; KERNAL - $FFBA = Set Logical File Parameters
                  jsr OPEN                        ; KERNAL - $FFC0 = Open a Logical File
                  jsr CLRCHN                      ; KERNAL - $FFCC = Restore Default Devices
                  ldx #$0f                        ; command channel
                  jsr CHKOUT                      ; KERNAL - $FFC9 = Define an Output Channel
                  ldy #$00
_CpyCommand       lda TabDiskCmd,y
                  beq _EndCommand

                  jsr CHROUT                      ; KERNAL - $FFD2 = Output a Character
                  iny
                  bne _CpyCommand

_EndCommand       jsr CLRCHN                      ; KERNAL - $FFCC = Restore Default Devices

                  ldx #$0f                        ; command channnel
                  jsr CHKIN                       ; KERNAL - $FFC6 = Define an Input Channel
                  jsr CHRIN                       ; KERNAL - $FFCF = Input a Character

                  ldy $1e
                  sta TabDiskDigits1,y
                  jsr CHRIN                       ; KERNAL - $FFCF = Input a Character
                  sta TabDiskDigits2,y
_GetData          jsr CHRIN                       ; KERNAL - $FFCF = Input a Character
                  cmp #$0d                        ; ENTER
                  bne _GetData

                  jsr CLALL                       ; KERNAL - $FFE7 = Close all Files

                  lda #$11
                  sta Mod__AddLo                  ; CopyProt: ==> obsolete
                  
                  ldy $1e
                  lda TabDiskDigits1,y
                  ora TabDiskDigits2,y
                  cmp #$30                        ; carry

GetADiskBlkX      rts
; ------------------------------------------------------------------------------------------------------------- ;
TabDiskHash       .byte $23 ; #
TabDiskCmd        .byte $55 ; u - command
TabDiskRW         .byte $31 ; 1 - 1=read 2=write
                  .byte $3a ; :
TabDiskTrkHi      .byte $20 ; _
TabDiskTrkLo      .byte $35 ; 5 - track
                  .byte $20 ; _
TabDiskSecHi      .byte $30 ; 0 - sector
TabDiskSecLo      .byte $20 ; _
; ------------------------------------------------------------------------------------------------------------- ;
TabDiskTrkHi01    .byte $30 ; 0 - track
TabDiskTrkHi02    .byte $31 ; 1
                  .byte $20 ; _
                  .byte $32 ; 2 - sector
                  .byte $0d ; <enter>
                  .byte $00                       ; obsolete code end
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
FlipGmeOverSign   lda #$01
                  sta WrkSignSpinSpeed            ; init flip sign spin speed
                  lda #>LR_ScrnHiReDisp           ; $20
                  sta $24                         ; graphic output  ($20=$2000-$2fff  $40=$4000-$4fff)

_FlipSign         jsr FlipSignPhase05
                  jsr FlipSignPhase04
                  jsr FlipSignPhase03
                  jsr FlipSignPhase02
                  jsr FlipSignPhase01
                  jsr FlipSignPhase00
                  jsr FlipSignPhase01
                  jsr FlipSignPhase02
                  jsr FlipSignPhase03
                  jsr FlipSignPhase04
                  jsr FlipSignPhase05
                  jsr FlipSignPhase0a
                  jsr FlipSignPhase09
                  jsr FlipSignPhase08
                  jsr FlipSignPhase07
                  jsr FlipSignPhase06
                  jsr FlipSignPhase07
                  jsr FlipSignPhase08
                  jsr FlipSignPhase09
                  jsr FlipSignPhase0a

_ChkSpeed         lda WrkSignSpinSpeed            ; flip sign spin speed
                  cmp #LR_FlipSpeedMin            ; max 100  (slowest)
                  bcc _FlipSign

_StopSign         jsr FlipSignPhase05
                  jsr FlipSignPhase04
                  jsr FlipSignPhase03
                  jsr FlipSignPhase02
                  jsr FlipSignPhase01
                  jsr FlipSignPhase00

                  clc
FlipGmeOverSignX  rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
FlipSignPhase00   jsr FlipSignOut
                  .byte NoSignLine00
                  .byte NoSignLine01
                  .byte NoSignLine02
                  .byte NoSignLine03
                  .byte NoSignLine04
                  .byte NoSignLine05
                  .byte NoSignLine06
                  .byte NoSignLine07
                  .byte NoSignLine08
                  .byte NoSignLine09
                  .byte NoSignLine0a
                  .byte NoSignLine02
                  .byte NoSignLine01
                  .byte NoSignLine00
FlipSignPhase01   jsr FlipSignOut
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine01
                  .byte NoSignLine02
                  .byte NoSignLine03
                  .byte NoSignLine04
                  .byte NoSignLine05
                  .byte NoSignLine07
                  .byte NoSignLine09
                  .byte NoSignLine0a
                  .byte NoSignLine02
                  .byte NoSignLine01
                  .byte NoSignLine00
                  .byte NoSignLine00
FlipSignPhase02   jsr FlipSignOut
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine01
                  .byte NoSignLine02
                  .byte NoSignLine03
                  .byte NoSignLine04
                  .byte NoSignLine09
                  .byte NoSignLine0a
                  .byte NoSignLine02
                  .byte NoSignLine01
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
FlipSignPhase03   jsr FlipSignOut
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine01
                  .byte NoSignLine02
                  .byte NoSignLine03
                  .byte NoSignLine0a
                  .byte NoSignLine02
                  .byte NoSignLine01
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
FlipSignPhase04   jsr FlipSignOut
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine01
                  .byte NoSignLine03
                  .byte NoSignLine0a
                  .byte NoSignLine01
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
FlipSignPhase05   jsr FlipSignOut
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine01
                  .byte NoSignLine01
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
FlipSignPhase06   jsr FlipSignOut
                  .byte NoSignLine00
                  .byte NoSignLine01
                  .byte NoSignLine02
                  .byte NoSignLine0a
                  .byte NoSignLine09
                  .byte NoSignLine08
                  .byte NoSignLine07
                  .byte NoSignLine06
                  .byte NoSignLine05
                  .byte NoSignLine04
                  .byte NoSignLine03
                  .byte NoSignLine02
                  .byte NoSignLine01
                  .byte NoSignLine00
FlipSignPhase07   jsr FlipSignOut
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine01
                  .byte NoSignLine02
                  .byte NoSignLine0a
                  .byte NoSignLine09
                  .byte NoSignLine07
                  .byte NoSignLine05
                  .byte NoSignLine04
                  .byte NoSignLine03
                  .byte NoSignLine02
                  .byte NoSignLine01
                  .byte NoSignLine00
                  .byte NoSignLine00
FlipSignPhase08   jsr FlipSignOut
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine01
                  .byte NoSignLine02
                  .byte NoSignLine0a
                  .byte NoSignLine09
                  .byte NoSignLine04
                  .byte NoSignLine03
                  .byte NoSignLine02
                  .byte NoSignLine01
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
FlipSignPhase09   jsr FlipSignOut
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine01
                  .byte NoSignLine02
                  .byte NoSignLine0a
                  .byte NoSignLine03
                  .byte NoSignLine02
                  .byte NoSignLine01
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
FlipSignPhase0a   jsr FlipSignOut
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine01
                  .byte NoSignLine0a
                  .byte NoSignLine03
                  .byte NoSignLine01
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
                  .byte NoSignLine00
; ------------------------------------------------------------------------------------------------------------- ;
;   Line00: ................................................................................................
;   Line01: ....#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.......
;   Line02: ..#.......................................................................................#.....
;   Line03: ..#...#.#.#.#...#.#.#...#.#.#.#.#...#.#.#.#.......#.#.#.#...#.#...#...#.#.#.#...#.#.#.#...#.....
;   Line04: ..#...#.....#...#...#...#.#.#...#...#.#...........#...#.#...#.#...#...#.#.#.#...#.....#...#.....
;   Line05: ..#...#.........#...#...#...#...#...#.#...........#...#.#...#.#...#...#.#.......#.....#...#.....
;   Line06: ..#...#.........#...#...#...#...#...#.#.#.#.......#...#.#...#.#...#...#.#.#.....#.#.#.#...#.....
;   Line07: ..#...#...#.#...#.#.#...#...#...#...#.#.#.#.......#.....#...#.#...#...#.........#.#.#.....#.....
;   Line08: ..#...#.....#...#...#...#...#...#...#.............#.....#...#.#.#.#...#.........#.#.#.....#.....
;   Line09: ..#...#.....#...#...#...#...#...#...#.............#.....#.....#.#.....#.........#.#...#...#.....
;   Line0a: ..#...#.#.#.#...#...#...#...#...#...#.#.#.#.......#.#.#.#.....#.......#.#.#.#...#.....#...#.....
; ------------------------------------------------------------------------------------------------------------- ;
DataSignLine00    .byte $00 ; ................................................................................................
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;

DataSignLine01    .byte $0a ; ....#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.......
                  .byte $aa ;
                  .byte $aa ;
                  .byte $aa ;
                  .byte $aa ;
                  .byte $aa ;
                  .byte $aa ;
                  .byte $aa ;
                  .byte $aa ;
                  .byte $aa ;
                  .byte $aa ;
                  .byte $80 ;

DataSignLine02    .byte $20 ; ..#.......................................................................................#.....
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $00 ;
                  .byte $20 ;

DataSignLine03    .byte $22 ; ..#...#.#.#.#...#.#.#...#.#.#.#.#...#.#.#.#.......#.#.#.#...#.#...#...#.#.#.#...#.#.#.#...#.....
                  .byte $a8 ;
                  .byte $a8 ;
                  .byte $aa ;
                  .byte $8a ;
                  .byte $a0 ;
                  .byte $2a ;
                  .byte $8a ;
                  .byte $22 ;
                  .byte $a8 ;
                  .byte $aa ;
                  .byte $20 ;

DataSignLine04    .byte $22 ; ..#...#.....#...#...#...#.#.#...#...#.#...........#...#.#...#.#...#...#.#.#.#...#.....#...#.....
                  .byte $08 ;
                  .byte $88 ;
                  .byte $a8 ;
                  .byte $8a ;
                  .byte $00 ;
                  .byte $22 ;
                  .byte $8a ;
                  .byte $22 ;
                  .byte $a8 ;
                  .byte $82 ;
                  .byte $20 ;

DataSignLine05    .byte $22 ; ..#...#.........#...#...#...#...#...#.#...........#...#.#...#.#...#...#.#.......#.....#...#.....
                  .byte $00 ;
                  .byte $88 ;
                  .byte $88 ;
                  .byte $8a ;
                  .byte $00 ;
                  .byte $22 ;
                  .byte $8a ;
                  .byte $22 ;
                  .byte $80 ;
                  .byte $82 ;
                  .byte $20 ;

DataSignLine06    .byte $22 ; ..#...#.........#...#...#...#...#...#.#.#.#.......#...#.#...#.#...#...#.#.#.....#.#.#.#...#.....
                  .byte $00 ;
                  .byte $88 ;
                  .byte $88 ;
                  .byte $8a ;
                  .byte $a0 ;
                  .byte $22 ;
                  .byte $8a ;
                  .byte $22 ;
                  .byte $a0 ;
                  .byte $aa ;
                  .byte $20 ;


DataSignLine07    .byte $22 ; ..#...#...#.#...#.#.#...#...#...#...#.#.#.#.......#.....#...#.#...#...#.........#.#.#.....#.....
                  .byte $28 ;
                  .byte $a8 ;
                  .byte $88 ;
                  .byte $8a ;
                  .byte $a0 ;
                  .byte $20 ;
                  .byte $8a ;
                  .byte $22 ;
                  .byte $00 ;
                  .byte $a8 ;
                  .byte $20 ;

DataSignLine08    .byte $22 ; ..#...#.....#...#...#...#...#...#...#.............#.....#...#.#.#.#...#.........#.#.#.....#.....
                  .byte $08 ;
                  .byte $88 ;
                  .byte $88 ;
                  .byte $88 ;
                  .byte $00 ;
                  .byte $20 ;
                  .byte $8a ;
                  .byte $a2 ;
                  .byte $00 ;
                  .byte $a8 ;
                  .byte $20 ;

DataSignLine09    .byte $22 ; ..#...#.....#...#...#...#...#...#...#.............#.....#.....#.#.....#.........#.#...#...#.....
                  .byte $08 ;
                  .byte $88 ;
                  .byte $88 ;
                  .byte $88 ;
                  .byte $00 ;
                  .byte $20 ;
                  .byte $82 ;
                  .byte $82 ;
                  .byte $00 ;
                  .byte $a2 ;
                  .byte $20 ;

DataSignLine0a    .byte $22 ; ..#...#.#.#.#...#...#...#...#...#...#.#.#.#.......#.#.#.#.....#.......#.#.#.#...#.....#...#.....
                  .byte $a8 ;
                  .byte $88 ;
                  .byte $88 ;
                  .byte $8a ;
                  .byte $a0 ;
                  .byte $2a ;
                  .byte $82 ;
                  .byte $02 ;
                  .byte $a8 ;
                  .byte $a2 ;
                  .byte $20 ;
; ------------------------------------------------------------------------------------------------------------- ;
TabSignDataAdr    =*                              ; flip data address tab
TabSignDataLen    = DataSignLine01-DataSignLine00 ; line data length

ObjLine00         .word DataSignLine00 - TabSignDataLen - $02
ObjLine01         .word DataSignLine01 - TabSignDataLen - $02
ObjLine02         .word DataSignLine02 - TabSignDataLen - $02
ObjLine03         .word DataSignLine03 - TabSignDataLen - $02
ObjLine04         .word DataSignLine04 - TabSignDataLen - $02
ObjLine05         .word DataSignLine05 - TabSignDataLen - $02
ObjLine06         .word DataSignLine06 - TabSignDataLen - $02
ObjLine07         .word DataSignLine07 - TabSignDataLen - $02
ObjLine08         .word DataSignLine08 - TabSignDataLen - $02
ObjLine09         .word DataSignLine09 - TabSignDataLen - $02
ObjLine0a         .word DataSignLine0a - TabSignDataLen - $02

NoSignLine00      := (DataSignLine00-DataSignLine00)/TabSignDataLen
NoSignLine01      := (DataSignLine01-DataSignLine00)/TabSignDataLen
NoSignLine02      := (DataSignLine02-DataSignLine00)/TabSignDataLen
NoSignLine03      := (DataSignLine03-DataSignLine00)/TabSignDataLen
NoSignLine04      := (DataSignLine04-DataSignLine00)/TabSignDataLen
NoSignLine05      := (DataSignLine05-DataSignLine00)/TabSignDataLen
NoSignLine06      := (DataSignLine06-DataSignLine00)/TabSignDataLen
NoSignLine07      := (DataSignLine07-DataSignLine00)/TabSignDataLen
NoSignLine08      := (DataSignLine08-DataSignLine00)/TabSignDataLen
NoSignLine09      := (DataSignLine09-DataSignLine00)/TabSignDataLen
NoSignLine0a      := (DataSignLine0a-DataSignLine00)/TabSignDataLen
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
FlipSignOut       pla                             ; start adr of data array is the return adr
                  sta $0d
                  pla
                  sta $0e

                  ldy #$50
                  sty $50                         ; screen row  (00-0f)
                  bne _SetSignPtr                 ; always

_SetGfxPtr        jsr GetOutGfxPtrClr             ; ($0f/$10) pointer

                  ldy #$00
                  lda ($0d),y                     ; get sign control byte
                  asl a                           ; *2
                  tax
                  lda TabSignDataAdr,x            ; flip data address tab
                  sta __ModGetDataLo              ; modify load cmd low
                  lda TabSignDataAdr+1,x          ; flip data address tab + 1
                  sta __ModGetDataHi              ; modify load cmd high

                  ldy #$70
                  sty $20                         ; grafic row substitution

                  ldy #TabSignDataLen+2           ; $0e - sign data lenght
                  sty $1e

_FlipSign         ldy $1e
                  inc $1e
_GetSignData      lda _GetSignData,y              ; get sign data byte
__ModGetDataLo    = *-2
__ModGetDataHi    = *-1
                  lsr a                           ; *2
                  ldy $20                         ; grafic row substitution
                  sta ($0f),y                     ; screen grafic pointer byte
                  tya
                  clc
                  adc #$08                        ; point to next position
                  sta $20                         ; grafic row substitution

                  ldy $1e
                  cpy #$1a                        ; max
                  bcc _FlipSign

_SetSignPtr       jsr FlipSignIncPtr

                  inc $50                         ; screen row  (00-0f)
                  ldy $50                         ; screen row  (00-0f)
                  cpy #$5f                        ; max
                  bcc _SetGfxPtr

                  ldx WrkSignSpinSpeed            ; flip sign spin speed
                  ldy #$ff
_Wait             dey
                  bne _Wait
                  dex
                  bne _Wait

                  inc WrkSignSpinSpeed            ; flip sign spin speed so wait longer the next time
                  lda CIAPRA                      ; CIA 1 - $DC00 = Data Port A
                  and #$10                        ; isolate fire
                  beq FlipSignFinish              ; pressed

                  lda LR_KeyNew                   ; actual key
                  bne FlipSignFinish              ; pressed some

FlipSignOutX      rts
; ------------------------------------------------------------------------------------------------------------- ;
FlipSignFinish    pla                             ; pull return address from stack
                  pla

                  sec
FlipSignFinishX   rts
; ------------------------------------------------------------------------------------------------------------- ;
WrkSignSpinSpeed  .byte $00
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
FlipSignIncPtr    inc $0d
                  bne FlipSignIncPtrX
                  inc $0e

FlipSignIncPtrX   rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
CircleLevelOut    lda LR_CtrlCircle               ; ==> circle obsolete
                  beq _OpenI

                  ldx #$a4
                  stx $3d
                  ldx #$00
                  stx $42
_Close            jsr CircleOutStart

                  dec $3d
                  bne _Close

_OpenI            lda #$01
                  sta $3d
                  sta $42
                  jsr LivesToBaseLine
                  jsr LevelToBaseLine

_Open             jsr CircleOutStart
                  inc $3d
                  lda $3d
                  cmp #$a4
                  bne _Open

CircleLevelOutX   rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
CircleOutStart    lda $3d
                  sta $39
                  lda #$00
                  sta $3a
                  sta $37
                  sta $38
                  lda $39
                  asl a
                  sta $3b
                  lda $3a
                  rol a
                  sta $3c
                  lda #$03
                  sec
                  sbc $3b
                  sta $3b
                  lda #$00
                  sbc $3c
                  sta $3c
                  lda #$58
                  sec
                  sbc $3d
                  sta $43
                  lda #$58
                  sta $44
                  sta $45
                  lda #$58
                  clc
                  adc $3d
                  sta $46
                  lda #$a0
                  sec
                  sbc $3d
                  tax
                  lda #$00
                  sbc #$00
                  jsr CircleOut_925c

                  sty $47
                  sta $4b
                  ldx #$a0
                  lda #$00
                  jsr CircleOut_925c

                  sty $48
                  sty $49
                  sta $4c
                  sta $4d
                  lda #$a0
                  clc
                  adc $3d
                  tax
                  lda #$00
                  adc #$00
                  jsr CircleOut_925c

                  sty $4a
                  sta $4e
CircleOut_9180    lda $38
                  cmp $3a
                  bcc CircleOut_919e
                  beq CircleOut_9198

CircleOut_9188    lda $37
                  cmp $39
                  bne CircleOutStartX

                  lda $38
                  cmp $3a
                  bne CircleOutStartX

                  jmp CircleOut_9270

CircleOutStartX   rts
; ------------------------------------------------------------------------------------------------------------- ;
CircleOut_9198    lda $37
                  cmp $39
                  bcs CircleOut_9188

CircleOut_919e    jsr CircleOut_9270

                  lda $3c
                  bpl CircleOut_91d6

                  lda $37
                  asl a
                  sta $3f
                  lda $38
                  rol a
                  sta $40
                  lda $3f
                  asl a
                  sta $3f
                  lda $40
                  rol a
                  sta $40
                  lda $3b
                  clc
                  adc $3f
                  sta $3f
                  lda $3c
                  adc $40
                  sta $40
                  lda #$06
                  clc
                  adc $3f
                  sta $3b
                  lda #$00
                  adc $40
                  sta $3c
                  jmp CircleOut_9237

CircleOut_91d6    lda $37
                  sec
                  sbc $39
                  sta $3f
                  lda $38
                  sbc $3a
                  sta $40
                  lda $3f
                  asl a
                  sta $3f
                  lda $40
                  rol a
                  sta $40
                  lda $3f
                  asl a
                  sta $3f
                  lda $40
                  rol a
                  sta $40
                  lda $3f
                  clc
                  adc #$10
                  sta $3f
                  lda $40
                  adc #$00
                  sta $40
                  lda $3f
                  clc
                  adc $3b
                  sta $3b
                  lda $40
                  adc $3c
                  sta $3c
                  lda $39
                  php
                  dec $39
                  plp
                  bne CircleOut_921b

                  dec $3a
CircleOut_921b    inc $43
                  dec $4e
                  bpl CircleOut_9227

                  lda #$07
                  sta $4e
                  dec $4a
CircleOut_9227    inc $4b
                  lda $4b
                  cmp #$08
                  bne CircleOut_9235

                  lda #$00
                  sta $4b
                  inc $47
CircleOut_9235    dec $46
CircleOut_9237    inc $37
                  bne CircleOut_923d

                  inc $38
CircleOut_923d    inc $4d
                  lda $4d
                  cmp #$08
                  bne CircleOut_924b

                  lda #$00
                  sta $4d
                  inc $49
CircleOut_924b    dec $44
                  inc $45
                  dec $4c
                  bpl CircleOut_9259

                  lda #$07
                  sta $4c
                  dec $48
CircleOut_9259    jmp CircleOut_9180
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
CircleOut_925c    sta $3f
                  txa
                  and #$07
                  pha
                  tay
                  txa
                  ror $3f
                  ror a
                  ror $3f
                  ror a
                  ror $3f
                  ror a
                  tay
                  pla

CircleOut_925cX   rts
; ------------------------------------------------------------------------------------------------------------- ;
;                 Function:
;                 Parms   :
;                 Returns :
; ------------------------------------------------------------------------------------------------------------- ;
CircleOut_9270    ldy $46
                  cpy #$b0
                  bcs CircleOut_92c0

                  ldx $49
                  cpx #$28
                  bcs CircleOut_929a

                  jsr CircleGetGfxPtr

                  ldx $4d
                  ldy #$00
                  lda $42
                  bne CircleOut_9291

                  lda ($0f),y
                  and CircleTab_93af,x
                  sta ($0f),y
                  jmp CircleOut_929a

CircleOut_9291    lda ($11),y
                  and CircleTab_93b3,x
                  ora ($0f),y
                  sta ($0f),y
CircleOut_929a    ldx $48
                  cpx #$28
                  bcs CircleOut_92c0

                  ldy $46
                  jsr CircleGetGfxPtr

                  ldx $4c
                  ldy #$00
                  lda $42
                  bne CircleOut_92b7

                  lda ($0f),y
                  and CircleTab_93af,x
                  sta ($0f),y
                  jmp CircleOut_92c0

CircleOut_92b7    lda ($11),y
                  and CircleTab_93b3,x
                  ora ($0f),y
                  sta ($0f),y
CircleOut_92c0    ldy $43
                  cpy #$b0
                  bcs CircleOut_9310

                  ldx $49
                  cpx #$28
                  bcs CircleOut_92ea

                  jsr CircleGetGfxPtr

                  ldx $4d
                  ldy #$00
                  lda $42
                  bne CircleOut_92e1

                  lda ($0f),y
                  and CircleTab_93af,x
                  sta ($0f),y
                  jmp CircleOut_92ea

CircleOut_92e1    lda ($11),y
                  and CircleTab_93b3,x
                  ora ($0f),y
                  sta ($0f),y
CircleOut_92ea    ldx $48
                  cpx #$28
                  bcs CircleOut_9310

                  ldy $43
                  jsr CircleGetGfxPtr

                  ldx $4c
                  ldy #$00
                  lda $42
                  bne CircleOut_9307

                  lda ($0f),y
                  and CircleTab_93af,x
                  sta ($0f),y
                  jmp CircleOut_9310

CircleOut_9307    lda ($11),y
                  and CircleTab_93b3,x
                  ora ($0f),y
                  sta ($0f),y
CircleOut_9310    ldy $45
                  cpy #$b0
                  bcs CircleOut_9360

                  ldx $4a
                  cpx #$28
                  bcs CircleOut_933a

                  jsr CircleGetGfxPtr

                  ldx $4e
                  ldy #$00
                  lda $42
                  bne CircleOut_9331

                  lda ($0f),y
                  and CircleTab_93af,x
                  sta ($0f),y
                  jmp CircleOut_933a

CircleOut_9331    lda ($11),y
                  and CircleTab_93b3,x
                  ora ($0f),y
                  sta ($0f),y
CircleOut_933a    ldx $47
                  cpx #$28
                  bcs CircleOut_9360

                  ldy $45
                  jsr CircleGetGfxPtr

                  ldx $4b
                  ldy #$00
                  lda $42
                  bne CircleOut_9357

                  lda ($0f),y
                  and CircleTab_93af,x
                  sta ($0f),y
                  jmp CircleOut_9360

CircleOut_9357    lda ($11),y
                  and CircleTab_93b3,x
                  ora ($0f),y
                  sta ($0f),y
CircleOut_9360    ldy $44
                  cpy #$b0
                  bcs CircleOut_93ae

                  ldx $4a
                  cpx #$28
                  bcs CircleOut_938a

                  jsr CircleGetGfxPtr

                  ldx $4e
                  ldy #$00
                  lda $42
                  bne CircleOut_9381

                  lda ($0f),y
                  and CircleTab_93af,x
                  sta ($0f),y
                  jmp CircleOut_938a

CircleOut_9381    lda ($11),y
                  and CircleTab_93b3,x
                  ora ($0f),y
                  sta ($0f),y
CircleOut_938a    ldx $47
                  cpx #$28
                  bcs CircleOut_93ae

                  ldy $44
                  jsr CircleGetGfxPtr

                  ldx $4b
                  ldy #$00
                  lda $42
                  bne CircleOut_93a5

                  lda ($0f),y
                  and CircleTab_93af,x
                  sta ($0f),y

                  rts

CircleOut_93a5    lda ($11),y
                  and CircleTab_93b3,x
                  ora ($0f),y
                  sta ($0f),y

CircleOut_93ae    rts
; ------------------------------------------------------------------------------------------------------------- ;
CircleTab_93af    .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
; ------------------------------------------------------------------------------------------------------------- ;
CircleTab_93b3    .byte $f0
                  .byte $f0
                  .byte $f0
                  .byte $f0

                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
; ------------------------------------------------------------------------------------------------------------- ;
TabGarbage        .byte $61                       ; ==> $93bb - old memory garbage start
                  .byte $6d
                  .byte $65
                  .byte $6f
                  .byte $76
                  .byte $65
                  .byte $72
                  .byte $c4
                  .byte $8e
                  .byte $88
                  .byte $67
                  .byte $61
                  .byte $6d
                  .byte $65
                  .byte $6f
                  .byte $76
                  .byte $72
                  .byte $32
                  .byte $cd
                  .byte $8e
                  .byte $84
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $31
                  .byte $24
                  .byte $8f
                  .byte $84
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $32
                  .byte $35
                  .byte $8f
                  .byte $84
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $33
                  .byte $46
                  .byte $8f
                  .byte $84
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $34
                  .byte $57
                  .byte $8f
                  .byte $84
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $35
                  .byte $68
                  .byte $8f
                  .byte $84
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $36
                  .byte $79
                  .byte $8f
                  .byte $84
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $37
                  .byte $8a
                  .byte $8f
                  .byte $84
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $38
                  .byte $9b
                  .byte $8f
                  .byte $84
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $39
                  .byte $ac
                  .byte $8f
                  .byte $85
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $31
                  .byte $30
                  .byte $bd
                  .byte $8f
                  .byte $85
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $31
                  .byte $31
                  .byte $ce
                  .byte $8f
                  .byte $87
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $64
                  .byte $61
                  .byte $74
                  .byte $30
                  .byte $df
                  .byte $8f
                  .byte $87
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $64
                  .byte $61
                  .byte $74
                  .byte $31
                  .byte $eb
                  .byte $8f
                  .byte $87
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $64
                  .byte $61
                  .byte $74
                  .byte $32
                  .byte $f7
                  .byte $8f
                  .byte $87
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $64
                  .byte $61
                  .byte $74
                  .byte $33
                  .byte $03
                  .byte $90
                  .byte $87
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $64
                  .byte $61
                  .byte $74
                  .byte $34
                  .byte $0f
                  .byte $90
                  .byte $87
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $64
                  .byte $61
                  .byte $74
                  .byte $35
                  .byte $1b
                  .byte $90
                  .byte $87
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $64
                  .byte $61
                  .byte $74
                  .byte $36
                  .byte $27
                  .byte $90
                  .byte $87
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $64
                  .byte $61
                  .byte $74
                  .byte $37
                  .byte $33
                  .byte $90
                  .byte $87
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $64
                  .byte $61
                  .byte $74
                  .byte $38
                  .byte $3f
                  .byte $90
                  .byte $87
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $64
                  .byte $61
                  .byte $74
                  .byte $39
                  .byte $4b
                  .byte $90
                  .byte $88
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $64
                  .byte $61
                  .byte $74
                  .byte $31
                  .byte $30
                  .byte $57
                  .byte $90
                  .byte $87
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $76
                  .byte $65
                  .byte $63
                  .byte $74
                  .byte $63
                  .byte $90
                  .byte $87
                  .byte $64
                  .byte $72
                  .byte $61
                  .byte $77
                  .byte $65
                  .byte $6e
                  .byte $64
                  .byte $79
                  .byte $90
                  .byte $88
                  .byte $64
                  .byte $72
                  .byte $61
                  .byte $77
                  .byte $65
                  .byte $6e
                  .byte $64
                  .byte $31
                  .byte $85
                  .byte $90
                  .byte $86
                  .byte $64
                  .byte $72
                  .byte $61
                  .byte $77
                  .byte $69
                  .byte $74
                  .byte $a2
                  .byte $90
                  .byte $88
                  .byte $64
                  .byte $72
                  .byte $61
                  .byte $77
                  .byte $73
                  .byte $61
                  .byte $76
                  .byte $65
                  .byte $a6
                  .byte $90
                  .byte $88
                  .byte $64
                  .byte $72
                  .byte $61
                  .byte $77
                  .byte $65
                  .byte $6e
                  .byte $64
                  .byte $33
                  .byte $ba
                  .byte $90
                  .byte $87
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $77
                  .byte $61
                  .byte $69
                  .byte $74
                  .byte $ca
                  .byte $90
                  .byte $88
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $77
                  .byte $72
                  .byte $74
                  .byte $73
                  .byte $32
                  .byte $e0
                  .byte $90
                  .byte $87
                  .byte $62
                  .byte $61
                  .byte $6e
                  .byte $74
                  .byte $69
                  .byte $6d
                  .byte $65
                  .byte $e4
                  .byte $90
                  .byte $88
                  .byte $64
                  .byte $72
                  .byte $61
                  .byte $77
                  .byte $69
                  .byte $6e
                  .byte $63
                  .byte $72
                  .byte $e5
                  .byte $90
                  .byte $88
                  .byte $64
                  .byte $72
                  .byte $61
                  .byte $77
                  .byte $69
                  .byte $6e
                  .byte $63
                  .byte $32
                  .byte $eb
TabGarbageX       .byte $90                       ; $94ff - old memory garbage end
; ------------------------------------------------------------------------------------------------------------- ;
MelodyMaxNo       .byte $09
MelodyMinHight    .byte $02
MelodyMaxHight    .byte $0c
TabMelodyPtr      .word TabMelody00
                  .word TabMelody01
                  .word TabMelody02
                  .word TabMelody03
                  .word TabMelody04
                  .word TabMelody05
                  .word TabMelody06
                  .word TabMelody07
                  .word TabMelody08
                  .word TabMelody09
                  .word TabMelody0a               ; $00 - not used
                  .word TabMelody0a
                  .word TabMelody0a
                  .word TabMelody0a
                  .word TabMelody0a
; ------------------------------------------------------------------------------------------------------------- ;
TabVocsFreqDatLo  .byte $00
                  .byte $e1
                  .byte $68
                  .byte $f7
                  .byte $8f
                  .byte $30
                  .byte $da
                  .byte $8f
                  .byte $4e
                  .byte $18
                  .byte $ef
                  .byte $d2
                  .byte $c3
                  .byte $c3
                  .byte $d1
                  .byte $ef
                  .byte $1f
                  .byte $60
                  .byte $b5
                  .byte $1e
                  .byte $9c
                  .byte $31
                  .byte $df
                  .byte $a5
                  .byte $87
                  .byte $86
                  .byte $a2
                  .byte $df
                  .byte $3e
                  .byte $c1
                  .byte $6b
                  .byte $3c
                  .byte $39
                  .byte $63
                  .byte $be
                  .byte $4b
                  .byte $0f

TabVocsFreqDatHi  .byte $00
                  .byte $08
                  .byte $09
                  .byte $09
                  .byte $0a
                  .byte $0b
                  .byte $0b
                  .byte $0c
                  .byte $0d
                  .byte $0e
                  .byte $0e
                  .byte $0f
                  .byte $10
                  .byte $11
                  .byte $12
                  .byte $13
                  .byte $15
                  .byte $16
                  .byte $17
                  .byte $19
                  .byte $1a
                  .byte $1c
                  .byte $1d
                  .byte $1f
                  .byte $21
                  .byte $23
                  .byte $25
                  .byte $27
                  .byte $2a
                  .byte $2c
                  .byte $2f
                  .byte $32
                  .byte $35
                  .byte $38
                  .byte $3b
                  .byte $3f
                  .byte $43

TabMelody09       .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $08
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $08
                  .byte $0c
                  .byte $ff
                  .byte $a0
                  .byte $08
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $d0
                  .byte $0c
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $08
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $06
                  .byte $13
                  .byte $ff
                  .byte $d0
                  .byte $06
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $06
                  .byte $13
                  .byte $ff
                  .byte $70
                  .byte $10
                  .byte $13
                  .byte $ff
                  .byte $40
                  .byte $10
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00

TabMelody05       .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $c0
                  .byte $04
                  .byte $12
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $11
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $0f
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $14
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $12
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $d0
                  .byte $04
                  .byte $12
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $11
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $0f
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $11
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $12
                  .byte $ff
                  .byte $a0
                  .byte $03
                  .byte $13
                  .byte $ff
                  .byte $d0
                  .byte $03
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $03
                  .byte $13
                  .byte $ff
                  .byte $70
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $40
                  .byte $10
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00

TabMelody02       .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $05
                  .byte $02
                  .byte $1c
                  .byte $a0
                  .byte $05
                  .byte $04
                  .byte $17
                  .byte $a0
                  .byte $05
                  .byte $05
                  .byte $15
                  .byte $a0
                  .byte $05
                  .byte $07
                  .byte $13
                  .byte $a0
                  .byte $05
                  .byte $09
                  .byte $11
                  .byte $a0
                  .byte $05
                  .byte $0b
                  .byte $10
                  .byte $a0
                  .byte $05
                  .byte $0c
                  .byte $0c
                  .byte $a0
                  .byte $05
                  .byte $10
                  .byte $0b
                  .byte $a0
                  .byte $05
                  .byte $11
                  .byte $09
                  .byte $a0
                  .byte $05
                  .byte $13
                  .byte $07
                  .byte $a0
                  .byte $05
                  .byte $15
                  .byte $05
                  .byte $a0
                  .byte $05
                  .byte $17
                  .byte $04
                  .byte $a0
                  .byte $05
                  .byte $1c
                  .byte $02
                  .byte $a0
                  .byte $10
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00

TabMelody06       .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $0c
                  .byte $ff
                  .byte $c0
                  .byte $08
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $06
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $08
                  .byte $ff
                  .byte $a0
                  .byte $08
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $08
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $0c
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $17
                  .byte $11
                  .byte $a0
                  .byte $08
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $18
                  .byte $10
                  .byte $a0
                  .byte $10
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00

TabMelody08       .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $05
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $05
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $0c
                  .byte $ff
                  .byte $b0
                  .byte $05
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $0e
                  .byte $ff
                  .byte $b0
                  .byte $05
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $10
                  .byte $ff
                  .byte $b0
                  .byte $05
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $05
                  .byte $00
                  .byte $00
                  .byte $a0
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $05
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $0c
                  .byte $ff
                  .byte $a0
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $0e
                  .byte $ff
                  .byte $b0
                  .byte $05
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $0b
                  .byte $ff
                  .byte $b0
                  .byte $05
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $07
                  .byte $ff
                  .byte $b0
                  .byte $10
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00

TabMelody03       .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $0c
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $d0
                  .byte $08
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $02
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $02
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $a0

                  .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $10
                  .byte $ff
                  .byte $d0
                  .byte $08
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $02
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $02
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $0c
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $0c
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $06
                  .byte $07
                  .byte $ff
                  .byte $d0
                  .byte $06
                  .byte $07
                  .byte $ff
                  .byte $a0
                  .byte $06
                  .byte $07
                  .byte $ff
                  .byte $70
                  .byte $06
                  .byte $07
                  .byte $ff
                  .byte $50
                  .byte $10
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00

TabMelody00       .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $02
                  .byte $13
                  .byte $10
                  .byte $d0
                  .byte $06
                  .byte $13
                  .byte $10
                  .byte $a0
                  .byte $08
                  .byte $11
                  .byte $0e
                  .byte $a0
                  .byte $06
                  .byte $10
                  .byte $0c
                  .byte $a0
                  .byte $02
                  .byte $10
                  .byte $0c
                  .byte $40
                  .byte $08
                  .byte $10
                  .byte $0c
                  .byte $a0
                  .byte $08
                  .byte $11
                  .byte $0e
                  .byte $a0
                  .byte $06
                  .byte $10
                  .byte $0c
                  .byte $a0
                  .byte $02
                  .byte $10
                  .byte $0c
                  .byte $40
                  .byte $08
                  .byte $0e
                  .byte $07
                  .byte $a0
                  .byte $08
                  .byte $10
                  .byte $0c
                  .byte $a0
                  .byte $06
                  .byte $0e
                  .byte $07
                  .byte $a0
                  .byte $02
                  .byte $0e
                  .byte $07
                  .byte $40
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $d0
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $b0
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $a0
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $90
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $80
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $70
                  .byte $08
                  .byte $0e
                  .byte $07
                  .byte $a0
                  .byte $08
                  .byte $10
                  .byte $0c
                  .byte $a0
                  .byte $06
                  .byte $0e
                  .byte $07
                  .byte $a0
                  .byte $02
                  .byte $0e
                  .byte $07
                  .byte $40
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $d0
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $b0
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $a0
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $90
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $80
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $70
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $60
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $50
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $40
                  .byte $04
                  .byte $0e
                  .byte $07
                  .byte $30
                  .byte $08
                  .byte $0e
                  .byte $07
                  .byte $20
                  .byte $10
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00

TabMelody04       .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $18
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $15
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $11
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $0e
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $11
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $0e
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $0c
                  .byte $ff
                  .byte $a0
                  .byte $0c
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $02
                  .byte $18
                  .byte $ff
                  .byte $a0
                  .byte $02
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $02
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $0c
                  .byte $ff
                  .byte $a0
                  .byte $10
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00

TabMelody07       .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $18
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $17
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $16
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $15
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $14
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $12
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $11
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $0f
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $0e
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $0d
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $0c
                  .byte $ff
                  .byte $a0
                  .byte $0c
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $02
                  .byte $0c
                  .byte $ff
                  .byte $a0
                  .byte $02
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $02
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $18
                  .byte $ff
                  .byte $a0
                  .byte $10
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00

TabMelody01       .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $18
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $10
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $18
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $15
                  .byte $ff
                  .byte $d0
                  .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $02
                  .byte $11
                  .byte $ff
                  .byte $a0
                  .byte $02
                  .byte $11
                  .byte $ff
                  .byte $80
                  .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $02
                  .byte $11
                  .byte $ff
                  .byte $a0
                  .byte $02
                  .byte $11
                  .byte $ff
                  .byte $80
                  .byte $0c
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $04
                  .byte $12
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $15
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $1f
                  .byte $0f
                  .byte $a0
                  .byte $04
                  .byte $15
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $12
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $15
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $1f
                  .byte $0f
                  .byte $a0
                  .byte $04
                  .byte $15
                  .byte $ff
                  .byte $a0
                  .byte $04
                  .byte $17
                  .byte $ff
                  .byte $d0
                  .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $02
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $02
                  .byte $13
B_992a            .byte $ff
                  .byte $80
                  .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $02
                  .byte $13
                  .byte $ff
                  .byte $a0
                  .byte $02
                  .byte $13
                  .byte $ff
                  .byte $80
                  .byte $10
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00

TabMelody0a       .byte $00
; ------------------------------------------------------------------------------------------------------------- ;
; sudden DuplicateCodeStart - whole area same as 693e-6fff and not referenced
; ------------------------------------------------------------------------------------------------------------- ;
                  sta $0a                         ; ==> obsolete
                  ldy $4f                         ; screen col  (00-1b)
                  lda $23                         ; level input tile $00-$09
                  eor ($09),y
                  beq B_994a
                  lsr $5a                         ; edit status  $00=modified
B_994a            lda $23                         ; level input tile $00-$09
                  sta ($09),y
                  jsr ImageOutToDisp              ; direct output to display screen
                  jmp LevelEdGetKey
                  sta $23                         ; level input tile $00-$09
                  ldy #$ff
B_9958            iny
                  lda TabEditorCmds,y
                  beq B_996e
                  cmp $23                         ; level input tile $00-$09
                  bne B_9958
                  tya
                  asl a
                  tay
                  lda TabEditorSubs+1,y
                  pha
                  lda TabEditorSubs,y
                  pha
                  rts
; ------------------------------------------------------------------------------------------------------------- ;
B_996e            jsr Beep
                  jmp LevelEdGetKey
                  lda $50                         ; screen row  (00-0f)
                  beq B_996e
                  dec $50                         ; screen row  (00-0f)
                  bpl B_992a
                  lda $4f                         ; screen col  (00-1b)
                  beq B_996e
                  dec $4f                         ; screen col  (00-1b)
                  bpl B_992a
                  lda $4f                         ; screen col  (00-1b)
                  cmp #$1b
                  bcs B_996e
                  inc $4f                         ; screen col  (00-1b)
                  bne B_992a
                  lda $50                         ; screen row  (00-0f)
                  cmp #$0f
                  bcs B_996e
                  inc $50                         ; screen row  (00-0f)
                  bne B_992a
                  lda $50                         ; screen row  (00-0f)
                  pha
                  lda $4f                         ; screen col  (00-1b)
                  pha
                  lda #LR_DiskRead
                  jsr GetPutHiScores              ; Target: $1100-$11ff
                  cmp #$00
                  bne B_99ad
                  jsr MsgNoLRDisk
                  jmp LvlEdResCur
B_99ad            cmp #$01
                  bne B_99b7
                  jsr MsgMasterDisk
                  jmp LvlEdResCur
B_99b7            jsr PackSaveLevel
                  pla
                  sta $4f                         ; screen col  (00-1b)
                  pla
                  sta $50                         ; screen row  (00-0f)
                  lda #$01                        ; level data not modified
                  sta $5a                         ; edit status
                  rts
; ------------------------------------------------------------------------------------------------------------- ;
                  lda #$00
                  sta $4f                         ; screen col  (00-1b)
                  sta $50                         ; screen row  (00-0f)
                  jmp LevelEdGetKey
                  jsr LvlEdChkSave
                  jmp LevelEdGetKey
                  lda LR_LevelNoDisk              ; 000-149
                  cmp #$95
B_99d9            beq B_996e
                  jsr LvlEdChkChFlag
                  inc LR_LevelNoDisk              ; 000-149
                  inc LR_LevelNoGame              ; 001-150
                  jmp LevelEditor
                  lda LR_LevelNoDisk              ; 000-149
                  beq B_99d9
                  jsr LvlEdChkChFlag
                  dec LR_LevelNoGame              ; 001-150
                  dec LR_LevelNoDisk              ; 000-149
                  jmp LevelEditor
                  jsr LvlEdChkChFlag
                  jmp GoClearScrnDisp             ; clear hires display screen
                  lda $5a                         ; edit status  $00=modified
                  beq B_9a03
                  rts
; ------------------------------------------------------------------------------------------------------------- ;
B_9a03            jsr ClearHiresDisp
                  lda M_MultiColors
                  pha
                  lda #$73
                  jsr SetMultiColors
                  lda #>LR_ScrnHiReDisp           ; $20
                  sta $51                         ; target output  $20=$2000 $40=$4000
                  lda #$00
                  sta $4f                         ; screen col  (00-1b)
                  sta $50                         ; screen row  (00-0f)
                  jsr TextOut
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $cc ; L
                  .byte $a0 ; <blank>
                  .byte $c8 ; H
                  .byte $c1 ; A
                  .byte $d3 ; S
                  .byte $a0 ; <blank>
                  .byte $c2 ; B
                  .byte $c5 ; E
                  .byte $c5 ; E
                  .byte $ce ; N
                  .byte $a0 ; <blank>
                  .byte $c3 ; C
                  .byte $c8 ; H
                  .byte $c1 ; A
                  .byte $ce ; N
                  .byte $c7 ; G
                  .byte $c5 ; E
                  .byte $c4 ; D
                  .byte $a0 ; <blank>
                  .byte $c2 ; B
                  .byte $d5 ; U
                  .byte $d4 ; T
                  .byte $8d ; <nl>
                  .byte $ce ; N
                  .byte $cf ; O
                  .byte $d4 ; T
                  .byte $a0 ; <blank>
                  .byte $d3 ; S
                  .byte $c1 ; A
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $c4 ; D
                  .byte $ae ; .
                  .byte $a0 ; <blank>
                  .byte $c4 ; D
                  .byte $cf ; O
                  .byte $a0 ; <blank>
                  .byte $d9 ; Y
                  .byte $cf ; O
                  .byte $d5 ; U
                  .byte $a0 ; <blank>
                  .byte $d7 ; W
                  .byte $c9 ; I
                  .byte $d3 ; S
                  .byte $c8 ; H
                  .byte $a0 ; <blank>
                  .byte $d4 ; T
                  .byte $cf ; O
                  .byte $8d ; <nl>
                  .byte $d3 ; S
                  .byte $c1 ; A
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $cd ; M
                  .byte $cf ; O
                  .byte $c4 ; D
                  .byte $c9 ; I
                  .byte $c6 ; F
                  .byte $c9 ; I
                  .byte $c5 ; E
                  .byte $c4 ; D
                  .byte $a0 ; <blank>
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $cc ; L
                  .byte $a0 ; <blank>
                  .byte $a8 ; (
                  .byte $d9 ; Y
                  .byte $af ; /
                  .byte $ce ; N
                  .byte $a9 ; )
                  .byte $a0 ; <blank>
                  .byte $00 ; EndOfText
                  jsr Beep
B_9a6f            lda #$00
                  jsr WaitKeyBlink                ; wait for input key and blink cursor
                  ldx #$00
                  stx LR_KeyNew
                  cmp #$27
                  beq B_9a84
                  cmp #$19
                  bne B_9a6f
                  jsr LvlEdChkSave
B_9a84            pla
                  jmp SetMultiColors
                  lda #LR_DiskRead
                  jsr GetPutHiScores              ; Target: $1100-$11ff
                  cmp #$00
                  bne B_9a97
                  jsr MsgNoLRDisk
                  jmp GoClearScrnDisp             ; clear hires display screen
B_9a97            cmp #$01
                  bne B_9aa1
                  jsr MsgMasterDisk
                  jmp GoClearScrnDisp             ; clear hires display screen
B_9aa1            rts
; ------------------------------------------------------------------------------------------------------------- ;
                  jsr ClearHiresDisp
                  lda M_MultiColors
                  pha
                  lda #>LR_ScrnHiReDisp           ; $20
                  sta $51                         ; target output  $20=$2000 $40=$4000
                  lda #$73
                  jsr SetMultiColors
                  lda #$00
                  sta $4f                         ; screen col  (00-1b)
                  sta $50                         ; screen row  (00-0f)
                  jsr TextOut
                  .byte $d5 ; U
                  .byte $d3 ; S
                  .byte $c5 ; E
                  .byte $d2 ; R
                  .byte $a0 ; <blank>
                  .byte $ce ; N
                  .byte $cf ; O
                  .byte $d4 ; T
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $cc ; L
                  .byte $cc ; L
                  .byte $cf ; O
                  .byte $d7 ; W
                  .byte $c5 ; E
                  .byte $c4 ; D
                  .byte $a0 ; <blank>
                  .byte $d4 ; T
                  .byte $cf ; O
                  .byte $8d ; <nl>
                  .byte $cd ; M
                  .byte $c1 ; A
                  .byte $ce ; N
                  .byte $c9 ; I
                  .byte $d0 ; P
                  .byte $d5 ; U
                  .byte $cc ; L
                  .byte $c1 ; A
                  .byte $d4 ; T
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $cd ; M
                  .byte $c1 ; A
                  .byte $d3 ; S
                  .byte $d4 ; T
                  .byte $c5 ; E
                  .byte $d2 ; R
                  .byte $a0 ; <blank>
                  .byte $c4 ; D
                  .byte $c9 ; I
                  .byte $d3 ; S
                  .byte $cb ; K
                  .byte $c5 ; E
                  .byte $d4 ; T
                  .byte $d4 ; T
                  .byte $c5 ; E
                  .byte $ae ; .
                  .byte $00 ; EndOfText
; ------------------------------------------------------------------------------------------------------------- ;
                  jsr TextOut
                  .byte $8d ; <nl>
                  .byte $8d ; <nl>
                  .byte $c8 ; H
                  .byte $c9 ; I
                  .byte $d4 ; T
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $a0 ; <blank>
                  .byte $cb ; K
                  .byte $c5 ; E
                  .byte $d9 ; Y
                  .byte $a0 ; <blank>
                  .byte $d4 ; T
                  .byte $cf ; O
                  .byte $a0 ; <blank>
                  .byte $c3 ; C
                  .byte $cf ; O
                  .byte $ce ; N
                  .byte $d4 ; T
                  .byte $c9 ; I
                  .byte $ce ; N
                  .byte $d5 ; U
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $00 ; EndOfText
; ------------------------------------------------------------------------------------------------------------- ;
                  jsr Beep
                  lda #$00
                  jsr WaitKeyBlink                ; wait for input key and blink cursor
                  lda #$00
                  sta LR_KeyNew
                  lda #>LR_ScrnHiRePrep           ; $40
                  sta $51                         ; target output  $20=$2000 $40=$4000
                  jsr StatusLines
                  lda #LR_LevelPrep
                  sta LR_LevelCtrl                ; level display control  $00=prepared copy already at $4000-$5fff
                  jsr CheckLevel
                  pla
                  jmp SetMultiColors
                  jsr ClearHiresDisp
                  lda M_MultiColors
                  pha
                  lda #$73
                  jsr SetMultiColors
                  lda #>LR_ScrnHiReDisp           ; $20
                  sta $51                         ; target output  $20=$2000 $40=$4000
                  lda #$00
                  sta $4f                         ; screen col  (00-1b)
                  sta $50                         ; screen row  (00-0f)
                  jsr TextOut
                  .byte $c4 ; D
                  .byte $c9 ; I
                  .byte $d3 ; S
                  .byte $cb ; K
                  .byte $c5 ; E
                  .byte $d4 ; T
                  .byte $d4 ; T
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $c9 ; I
                  .byte $ce ; N
                  .byte $a0 ; <blank>
                  .byte $c4 ; D
                  .byte $d2 ; R
                  .byte $c9 ; I
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $c9 ; I
                  .byte $d3 ; S
                  .byte $a0 ; <blank>
                  .byte $ce ; N
                  .byte $cf ; O
                  .byte $d4 ; T
                  .byte $a0 ; <blank>
                  .byte $c1 ; A
                  .byte $8d ; <nl>
                  .byte $cc ; L
                  .byte $cf ; O
                  .byte $c4 ; D
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $d2 ; R
                  .byte $d5 ; U
                  .byte $ce ; N
                  .byte $ce ; N
                  .byte $c5 ; E
                  .byte $d2 ; R
                  .byte $a0 ; <blank>
                  .byte $c4 ; D
                  .byte $c1 ; A
                  .byte $d4 ; T
                  .byte $c1 ; A
                  .byte $a0 ; <blank>
                  .byte $c4 ; D
                  .byte $c9 ; I
                  .byte $d3 ; S
                  .byte $cb ; K
                  .byte $ae ; .
                  .byte $00 ; EndOfText
; ------------------------------------------------------------------------------------------------------------- ;
                  jmp MsgKey2Cont
B_9b75            ldy $50                         ; screen row  (00-0f)
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  ldy $4f                         ; screen col  (00-1b)
                  lda ($09),y
                  jsr WaitKeyBlink                ; wait for input key and blink cursor
                  rts
; ------------------------------------------------------------------------------------------------------------- ;
                  .byte $22
                  .byte $21
                  .byte $25
                  .byte $24
                  .byte $8d
                  .byte $95
                  .byte $9c
                  .byte $be
                  .byte $00
                  .byte $7b
                  .byte $69
                  .byte $73
                  .byte $69
                  .byte $83
                  .byte $69
                  .byte $8d
                  .byte $69
                  .byte $cd
                  .byte $69
                  .byte $d3
                  .byte $69
                  .byte $e6
                  .byte $69
                  .byte $f7
                  .byte $69
B_9ba2            ldy LR_LevelNoDisk              ; 000-149
                  iny
                  tya
                  jsr ConvertHex2Dec              ; 1307=100 1308=10 1309=1
                  lda $4f                         ; screen col  (00-1b)
                  sta SavScreenCol
                  ldy #$00
B_9bb1            lda LR_Digit100,y
                  sty SavCurrentPos
                  jsr PrepareDigitOut

                  ldy SavCurrentPos
                  iny
                  cpy #$03
                  bcc B_9bb1
                  lda SavScreenCol
                  sta $4f                         ; screen col  (00-1b)
                  ldy #$00
                  sty SavCurrentPos
B_9bcc            ldx SavCurrentPos
                  lda LR_Digit100,x
                  clc
                  adc #$3b
                  jsr WaitKeyBlink                ; wait for input key and blink cursor
                  jsr CheckDigitInput
                  bcc B_9c15
                  cmp #$01
                  beq B_9c36
                  cmp #$07
                  beq B_9be9
                  cmp #$82
                  bne B_9bf6
B_9be9            ldx SavCurrentPos
                  beq B_9c30
                  dec SavCurrentPos
                  dec $4f                         ; screen col  (00-1b)
                  jmp $6bcc
B_9bf6            cmp #$02
                  bne B_9c09
                  ldx SavCurrentPos
                  cpx #$02
                  beq B_9c30
                  inc $4f                         ; screen col  (00-1b)
                  inc SavCurrentPos
                  jmp $6bcc
B_9c09            cmp #$3f
                  bne B_9c10
                  jmp BoEdWaitCmd
B_9c10            jsr CheckDigitInput
                  bcs B_9c30
B_9c15            ldy SavCurrentPos
                  sta LR_Digit100,y
                  jsr PrepareDigitOut

                  inc SavCurrentPos
                  lda SavCurrentPos
                  cmp #$03
                  bcc B_9bcc
                  dec SavCurrentPos
                  dec $4f                         ; screen col  (00-1b)
                  jmp $6bcc
B_9c30            jsr Beep
                  jmp $6bcc
B_9c36            lda SavScreenCol
                  clc
                  adc #$03
                  sta $4f                         ; screen col  (00-1b)
                  lda #$00
                  ldx LR_Digit100
                  beq B_9c4d
                  clc
B_9c46            adc #$64
                  bcs B_9c6a
                  dex
                  bne B_9c46
B_9c4d            ldx LR_Digit10
                  beq B_9c5a
                  clc
B_9c53            adc #$0a
                  bcs B_9c6a
                  dex
                  bne B_9c53
B_9c5a            clc
                  adc LR_Digit1
                  bcs B_9c6a
                  sta LR_LevelNoGame              ; 001-150
                  tay
                  dey
                  sty LR_LevelNoDisk              ; 000-149
                  cpy #$96
B_9c6a            rts
; ------------------------------------------------------------------------------------------------------------- ;
                  lda #$00
                  jsr WaitKeyBlink                ; wait for input key and blink cursor
                  ldx #$00
                  stx LR_KeyNew
                  cmp #$3f
                  bne B_9c7c
                  jmp BoEdWaitCmd
B_9c7c            rts
; ------------------------------------------------------------------------------------------------------------- ;
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  lda LR_KeyNew
                  ldy #$00
                  sty LR_KeyNew
                  ldy #$09
B_9c8b            cmp TabDigitKeys,y
                  beq B_9c95
                  dey
                  bpl B_9c8b
                  sec
                  rts
; ------------------------------------------------------------------------------------------------------------- ;
B_9c95            .byte $98
                  .byte $18
                  .byte $60
                  .byte $23
                  .byte $38
                  .byte $3b
                  .byte $08
                  .byte $0b
                  .byte $10
                  .byte $13
                  .byte $18
                  .byte $1b
                  .byte $20
                  .byte $c4 ; D
                  .byte $c1 ; A
                  .byte $ce ; N
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $c2 ; B
                  .byte $c9 ; I
                  .byte $c7 ; G
                  .byte $c8 ; H
                  .byte $c1 ; A
                  .byte $cd ; M
                  .byte $ad ;
                  .byte $18
                  .byte $13
                  .byte $f0
                  .byte $5c
; ------------------------------------------------------------------------------------------------------------- ;
B_9cb2            lda LR_ScoreHi
                  ora LR_ScoreMidLo
                  ora LR_ScoreMidHi
                  ora LR_ScoreLo
                  beq B_9d0e
                  lda #LR_DiskRead
                  jsr GetPutHiScores              ; Target: $1100-$11ff
                  beq B_9d0e
                  ldy #$00
B_9cc9            lda LR_HiScore,y
                  sta LR_HiScoreOld,y
                  iny
                  bne B_9cc9
                  ldy #$01
B_9cd4            ldx TabHiScOffRows,y 
                  lda LR_LevelNoGame              ; 001-150
                  cmp $1103,x
                  bcc B_9d09
                  bne B_9d0f
                  lda LR_ScoreLo
                  cmp $1104,x
                  bcc B_9d09
                  bne B_9d0f
                  lda LR_ScoreMidHi
                  cmp $1105,x
                  bcc B_9d09
                  bne B_9d0f
                  lda LR_ScoreMidLo
                  cmp $1106,x
                  bcc B_9d09
                  bne B_9d0f
                  lda LR_ScoreHi
                  cmp $1107,x
                  bcc B_9d09
                  bne B_9d0f
B_9d09            iny
                  cpy #$0b
                  bcc B_9cd4
B_9d0e            rts
; ------------------------------------------------------------------------------------------------------------- ;
B_9d0f            cpy #$0a
                  beq B_9d30
                  sty $29
                  ldy #$09
B_9d17            ldx TabHiScOffRows,y
                  lda #$08
                  sta $22
B_9d1e            lda LR_HiScore,x
                  sta LR_HiScoreMovUp,x
                  inx
                  dec $22
                  bne B_9d1e
                  cpy $29
                  beq B_9d30
                  dey
                  bne B_9d17
B_9d30            ldx TabHiScOffRows,y            ; high score rows offsets
                  lda #$a0
                  sta $1100,x
                  sta $1101,x
                  sta $1102,x
                  lda LR_LevelNoGame              ; 001-150
                  sta $1103,x
                  lda LR_ScoreLo
                  sta $1104,x
                  lda LR_ScoreMidHi
                  sta $1105,x
                  lda LR_ScoreMidLo
                  sta $1106,x
                  lda LR_ScoreHi
                  sta $1107,x
                  sty $39
                  lda TabHiScOffRows,y            ; high score rows offsets
                  sta $6d7e
                  sta $6dca
                  jsr ShowHighScores
                  lda $39
                  clc
                  adc #$04
                  sta $50                         ; screen row  (00-0f)
                  lda #$07
                  sta $4f                         ; screen col  (00-1b)
                  ldx #$00
                  stx SavCurrentPos
B_9d7a            ldx SavCurrentPos
                  lda $1100,x
                  jsr GetChrSubst
                  jsr WaitKeyBlink                ; wait for input key and blink cursor
                  ldx #$00
                  stx LR_KeyNew
                  jsr GetChrSubst2
                  cmp #$8d
                  beq B_9de7
                  cmp #$88
                  bne B_9da3
                  ldx SavCurrentPos
                  beq B_9de1
                  dec SavCurrentPos
                  dec $4f                         ; screen col  (00-1b)
                  jmp $6d7a
B_9da3            cmp #$95
                  bne B_9db6
                  ldx SavCurrentPos
                  cpx #$02
                  beq B_9de1
                  inc $4f                         ; screen col  (00-1b)
                  inc SavCurrentPos
                  jmp $6d7a
B_9db6            cmp #$ae
                  beq B_9dc6
                  cmp #$a0
                  beq B_9dc6
                  cmp #$c1
                  bcc B_9de1
                  cmp #$db
                  bcs B_9de1
B_9dc6            ldy SavCurrentPos
                  sta $1100,y
                  jsr DisplayChr
                  inc SavCurrentPos
                  lda SavCurrentPos
                  cmp #$03
                  bcc B_9d7a
                  dec SavCurrentPos
                  dec $4f                         ; screen col  (00-1b)
                  jmp $6d7a
B_9de1            jsr Beep
                  jmp $6d7a
B_9de7            ldy #$00
B_9de9            lda $1100,y
                  sta LR_HiScoreNew,y
                  iny
                  bne B_9de9
                  lda #LR_DiskRead
                  jsr GetPutHiScores              ; Target: $1100-$11ff
                  ldy #$00
B_9df9            lda LR_HiScore,y
                  cmp LR_HiScoreOld,y
                  bne B_9e0f
                  lda LR_HiScoreNew,y
                  sta LR_HiScore,y
                  iny
                  bne B_9df9
                  lda #LR_DiskWrite
                  jsr GetPutHiScores              ; Target: $1100-$11ff
B_9e0f            jmp WaitForDemoI
                  jsr ClearHiresDisp
                  lda #$73
                  jsr SetMultiColors
                  lda #$00
                  sta $4f                         ; screen col  (00-1b)
                  sta $50                         ; screen row  (00-0f)
                  jsr TextOut
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $cc ; L
                  .byte $cf ; O
                  .byte $c4 ; D
                  .byte $c5 ; E
                  .byte $a0 ; <blank>
                  .byte $d2 ; R
                  .byte $d5 ; U
                  .byte $ce ; N
                  .byte $ce ; N
                  .byte $c5 ; E
                  .byte $d2 ; R
                  .byte $a0 ; <blank>
                  .byte $c8 ; H
                  .byte $c9 ; I
                  .byte $c7 ; G
                  .byte $c8 ; H
                  .byte $a0 ; <blank>
                  .byte $d3 ; S
                  .byte $c3 ; C
                  .byte $cf ; O
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $d3 ; S
                  .byte $8d ; <nl>
                  .byte $8d ; <nl>
                  .byte $8d ; <nl>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $c9 ; I
                  .byte $ce ; N
                  .byte $c9 ; I
                  .byte $d4 ; T
                  .byte $c9 ; I
                  .byte $c1 ; A
                  .byte $cc ; L
                  .byte $d3 ; S
                  .byte $a0 ; <blank>
                  .byte $cc ; L
                  .byte $c5 ; E
                  .byte $d6 ; V
                  .byte $c5 ; E
                  .byte $cc ; L
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $d3 ; S
                  .byte $c3 ; C
                  .byte $cf ; O
                  .byte $d2 ; R
                  .byte $c5 ; E
                  .byte $8d ; <nl>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $a0 ; <blank>
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $a0 ; <blank>
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $ad ; -
                  .byte $8d ; <nl>
                  .byte $00 ; EndOfText
; ------------------------------------------------------------------------------------------------------------- ;
                  lda #$01
                  sta $28
                  cmp #$0a
                  bne B_9e8d
                  lda #$01
                  jsr PrepareDigitOut
                  lda #$00
                  jsr PrepareDigitOut
                  jmp $6e97
B_9e8d            lda #$a0
                  jsr DisplayChr
                  lda $28
                  jsr PrepareDigitOut
                  jsr TextOut
                  .byte $ae ; .
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $00 ; EndOfText
; ------------------------------------------------------------------------------------------------------------- ;
                  ldx $28
                  ldy TabHiScOffRows,x            ; high score rows offsets
                  sty $29
                  lda $1103,y
                  bne B_9eaf
                  jmp $6f3f
B_9eaf            ldy $29
                  lda LR_HiScore,y
                  jsr DisplayChr
                  ldy $29
                  lda $1101,y
                  jsr DisplayChr
                  ldy $29
                  lda $1102,y
                  jsr DisplayChr
                  jsr TextOut
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $00 ; EndOfText
; ------------------------------------------------------------------------------------------------------------- ;
                  ldy $29
                  lda $1103,y
                  jsr ConvertHex2Dec              ; 1307=100 1308=10 1309=1
                  lda LR_Digit100
                  jsr PrepareDigitOut
                  lda LR_Digit10
                  jsr PrepareDigitOut
                  lda LR_Digit1
                  jsr PrepareDigitOut
                  jsr TextOut
                  .byte $a0 ; <blank>
                  .byte $a0 ; <blank>
                  .byte $00 ; EndOfText
; ------------------------------------------------------------------------------------------------------------- ;
                  ldy $29
                  lda $1104,y
                  jsr SplitScoreDigit
                  lda LR_Digit10
                  jsr PrepareDigitOut

                  lda LR_Digit1
                  jsr PrepareDigitOut

                  ldy $29
                  lda $1105,y
                  jsr SplitScoreDigit
                  lda LR_Digit10
                  jsr PrepareDigitOut

                  lda LR_Digit1
                  jsr PrepareDigitOut

                  ldy $29
                  lda $1106,y
                  jsr SplitScoreDigit
                  lda LR_Digit10
                  jsr PrepareDigitOut

                  lda LR_Digit1
                  jsr PrepareDigitOut

                  ldy $29
                  lda $1107,y
                  jsr SplitScoreDigit
                  lda LR_Digit10
                  jsr PrepareDigitOut

                  lda LR_Digit1
                  jsr PrepareDigitOut

                  jsr NewLine
                  inc $28
                  lda $28
                  cmp #$0b
                  bcs B_9f4d
                  jmp $6e7c
B_9f4d            rts
; ------------------------------------------------------------------------------------------------------------- ;
                  .byte $00
                  .byte $00
                  .byte $08
                  .byte $10
                  .byte $18
                  .byte $20
                  .byte $28
                  .byte $30
                  .byte $38
                  .byte $40
                  .byte $48
                  .byte $c9
                  .byte $82
                  .byte $d0
                  .byte $02
                  .byte $a9
                  .byte $07
                  .byte $a8
                  .byte $b9
                  .byte $66
                  .byte $6f
                  .byte $09
                  .byte $80
                  .byte $60
                  .byte $00
                  .byte $0d
                  .byte $15
                  .byte $ff
                  .byte $ff
                  .byte $ff
                  .byte $ff
                  .byte $08
                  .byte $33
                  .byte $57
                  .byte $41
                  .byte $34
                  .byte $5a
                  .byte $53
                  .byte $45
                  .byte $ff
                  .byte $35
                  .byte $52
                  .byte $44
                  .byte $36
                  .byte $43
                  .byte $46
                  .byte $54
                  .byte $58
                  .byte $37
                  .byte $59
                  .byte $47
                  .byte $38
                  .byte $42
                  .byte $48
                  .byte $55
                  .byte $56
                  .byte $39
                  .byte $49
                  .byte $4a
                  .byte $30
                  .byte $4d
                  .byte $4b
                  .byte $4f
                  .byte $4e
                  .byte $2b
                  .byte $50
                  .byte $4c
                  .byte $2d
                  .byte $2e
                  .byte $3a
                  .byte $ff
                  .byte $2c
                  .byte $5c
                  .byte $2a
                  .byte $3b
                  .byte $ff
                  .byte $ff
                  .byte $3d
                  .byte $ff
                  .byte $2f
                  .byte $31
                  .byte $ff
                  .byte $ff
                  .byte $32
                  .byte $20
                  .byte $ff
                  .byte $51
                  .byte $ff
; ------------------------------------------------------------------------------------------------------------- ;
                  stx LR_LevelCtrl                ; level display control  $00=prepared copy already at $4000-$5fff
                  ldx #$ff
                  stx $03
                  inx
                  stx LR_NumXitLadders            ; # hidden ladders
                  stx LR_GoldToGet
                  stx LR_EnmyNo                   ; number of enemies
                  stx LR_NoEnemy2Move
                  stx $54
                  stx $53
                  stx $1e
                  stx $50                         ; screen row  (00-0f)
                  txa
                  ldx #$1e
B_9fc5            sta LR_TabHoleOpenT,x
                  dex
                  bpl B_9fc5
                  ldx #$05
B_9fcd            sta LR_TabEnemyBirtT,x
                  dex
                  bpl B_9fcd
                  lda #$01
                  sta LR_Alive                    ; $00=lr killed
B_9fd8            lda LR_LevelNoDisk              ; 000-149
                  cmp LR_LvlReload
                  beq B_9fe5
                  lda #LR_DiskRead
                  jsr ControlDiskOper
B_9fe5            lda LR_LevelNoDisk              ; 000-149
                  sta LR_LvlReload
                  ldy $50                         ; screen row  (00-0f)
                  lda TabExLvlDatRowLo,y          ; expanded level data row pointer low
                  sta $09
                  sta $0b
                  lda TabExLvlDatRowH8,y          ; expanded level data row pointer $0800-$09c3
                  sta $0a
                  lda TabExLvlDatRowHa,y          ; expanded level data row pointer $0a00-$0bc3
                  sta $0c
                  lda #$00
; ------------------------------------------------------------------------------------------------------------- ;
TabTileDataA0     .byte $00                       ; values $00-$ff in steps of $01
                  .byte $01
                  .byte $02
                  .byte $03
                  .byte $04
                  .byte $05
                  .byte $06
                  .byte $07
                  .byte $08
                  .byte $09
                  .byte $0a
                  .byte $0b
                  .byte $0c
                  .byte $0d
                  .byte $0e
                  .byte $0f
                  .byte $10
                  .byte $11
                  .byte $12
                  .byte $13
                  .byte $14
                  .byte $15
                  .byte $16
                  .byte $17
                  .byte $18
                  .byte $19
                  .byte $1a
                  .byte $1b
                  .byte $1c
                  .byte $1d
                  .byte $1e
                  .byte $1f
                  .byte $20
                  .byte $21
                  .byte $22
                  .byte $23
                  .byte $24
                  .byte $25
                  .byte $26
                  .byte $27
                  .byte $28
                  .byte $29
                  .byte $2a
                  .byte $2b
                  .byte $2c
                  .byte $2d
                  .byte $2e
                  .byte $2f
                  .byte $30
                  .byte $31
                  .byte $32
                  .byte $33
                  .byte $34
                  .byte $35
                  .byte $36
                  .byte $37
                  .byte $38
                  .byte $39
                  .byte $3a
                  .byte $3b
                  .byte $3c
                  .byte $3d
                  .byte $3e
                  .byte $3f
                  .byte $40
                  .byte $41
                  .byte $42
                  .byte $43
                  .byte $44
                  .byte $45
                  .byte $46
                  .byte $47
                  .byte $48
                  .byte $49
                  .byte $4a
                  .byte $4b
                  .byte $4c
                  .byte $4d
                  .byte $4e
                  .byte $4f
                  .byte $50
                  .byte $51
                  .byte $52
                  .byte $53
                  .byte $54
                  .byte $55
                  .byte $56
                  .byte $57
                  .byte $58
                  .byte $59
                  .byte $5a
                  .byte $5b
                  .byte $5c
                  .byte $5d
                  .byte $5e
                  .byte $5f
                  .byte $60
                  .byte $61
                  .byte $62
                  .byte $63
                  .byte $64
                  .byte $65
                  .byte $66
                  .byte $67
                  .byte $68
                  .byte $69
                  .byte $6a
                  .byte $6b
                  .byte $6c
                  .byte $6d
                  .byte $6e
                  .byte $6f
                  .byte $70
                  .byte $71
                  .byte $72
                  .byte $73
                  .byte $74
                  .byte $75
                  .byte $76
                  .byte $77
                  .byte $78
                  .byte $79
                  .byte $7a
                  .byte $7b
                  .byte $7c
                  .byte $7d
                  .byte $7e
                  .byte $7f
                  .byte $80
                  .byte $81
                  .byte $82
                  .byte $83
                  .byte $84
                  .byte $85
                  .byte $86
                  .byte $87
                  .byte $88
                  .byte $89
                  .byte $8a
                  .byte $8b
                  .byte $8c
                  .byte $8d
                  .byte $8e
                  .byte $8f
                  .byte $90
                  .byte $91
                  .byte $92
                  .byte $93
                  .byte $94
                  .byte $95
                  .byte $96
                  .byte $97
                  .byte $98
                  .byte $99
                  .byte $9a
                  .byte $9b
                  .byte $9c
                  .byte $9d
                  .byte $9e
                  .byte $9f
                  .byte $a0
                  .byte $a1
                  .byte $a2
                  .byte $a3
                  .byte $a4
                  .byte $a5
                  .byte $a6
                  .byte $a7
                  .byte $a8
                  .byte $a9
                  .byte $aa
                  .byte $ab
                  .byte $ac
                  .byte $ad
                  .byte $ae
                  .byte $af
                  .byte $b0
                  .byte $b1
                  .byte $b2
                  .byte $b3
                  .byte $b4
                  .byte $b5
                  .byte $b6
                  .byte $b7
                  .byte $b8
                  .byte $b9
                  .byte $ba
                  .byte $bb
                  .byte $bc
                  .byte $bd
                  .byte $be
                  .byte $bf
                  .byte $c0
                  .byte $c1
                  .byte $c2
                  .byte $c3
                  .byte $c4
                  .byte $c5
                  .byte $c6
                  .byte $c7
                  .byte $c8
                  .byte $c9
                  .byte $ca
                  .byte $cb
                  .byte $cc
                  .byte $cd
                  .byte $ce
                  .byte $cf
                  .byte $d0
                  .byte $d1
                  .byte $d2
                  .byte $d3
                  .byte $d4
                  .byte $d5
                  .byte $d6
                  .byte $d7
                  .byte $d8
                  .byte $d9
                  .byte $da
                  .byte $db
                  .byte $dc
                  .byte $dd
                  .byte $de
                  .byte $df
                  .byte $e0
                  .byte $e1
                  .byte $e2
                  .byte $e3
                  .byte $e4
                  .byte $e5
                  .byte $e6
                  .byte $e7
                  .byte $e8
                  .byte $e9
                  .byte $ea
                  .byte $eb
                  .byte $ec
                  .byte $ed
                  .byte $ee
                  .byte $ef
                  .byte $f0
                  .byte $f1
                  .byte $f2
                  .byte $f3
                  .byte $f4
                  .byte $f5
                  .byte $f6
                  .byte $f7
                  .byte $f8
                  .byte $f9
                  .byte $fa
                  .byte $fb
                  .byte $fc
                  .byte $fd
                  .byte $fe
                  .byte $ff

TabTileDataA1     .byte $00                       ; $ff values of $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00

TabTileDataA2     .byte $00                       ; values $00-$3f in steps of $01 and packs of $04
                  .byte $00
                  .byte $00
                  .byte $00

                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01

                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02

                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03

                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04

                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05

                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06

                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07

                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08

                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09

                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a

                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b

                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c

                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d

                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e

                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f

                  .byte $10
                  .byte $10
                  .byte $10
                  .byte $10

                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11

                  .byte $12
                  .byte $12
                  .byte $12
                  .byte $12

                  .byte $13
                  .byte $13
                  .byte $13
                  .byte $13

                  .byte $14
                  .byte $14
                  .byte $14
                  .byte $14

                  .byte $15
                  .byte $15
                  .byte $15
                  .byte $15

                  .byte $16
                  .byte $16
                  .byte $16
                  .byte $16

                  .byte $17
                  .byte $17
                  .byte $17
                  .byte $17

                  .byte $18
                  .byte $18
                  .byte $18
                  .byte $18

                  .byte $19
                  .byte $19
                  .byte $19
                  .byte $19

                  .byte $1a
                  .byte $1a
                  .byte $1a
                  .byte $1a

                  .byte $1b
                  .byte $1b
                  .byte $1b
                  .byte $1b

                  .byte $1c
                  .byte $1c
                  .byte $1c
                  .byte $1c

                  .byte $1d
                  .byte $1d
                  .byte $1d
                  .byte $1d

                  .byte $1e
                  .byte $1e
                  .byte $1e
                  .byte $1e

                  .byte $1f
                  .byte $1f
                  .byte $1f
                  .byte $1f

                  .byte $20
                  .byte $20
                  .byte $20
                  .byte $20

                  .byte $21
                  .byte $21
                  .byte $21
                  .byte $21

                  .byte $22
                  .byte $22
                  .byte $22
                  .byte $22

                  .byte $23
                  .byte $23
                  .byte $23
                  .byte $23

                  .byte $24
                  .byte $24
                  .byte $24
                  .byte $24

                  .byte $25
                  .byte $25
                  .byte $25
                  .byte $25

                  .byte $26
                  .byte $26
                  .byte $26
                  .byte $26

                  .byte $27
                  .byte $27
                  .byte $27
                  .byte $27

                  .byte $28
                  .byte $28
                  .byte $28
                  .byte $28

                  .byte $29
                  .byte $29
                  .byte $29
                  .byte $29

                  .byte $2a
                  .byte $2a
                  .byte $2a
                  .byte $2a

                  .byte $2b
                  .byte $2b
                  .byte $2b
                  .byte $2b

                  .byte $2c
                  .byte $2c
                  .byte $2c
                  .byte $2c

                  .byte $2d
                  .byte $2d
                  .byte $2d
                  .byte $2d

                  .byte $2e
                  .byte $2e
                  .byte $2e
                  .byte $2e

                  .byte $2f
                  .byte $2f
                  .byte $2f
                  .byte $2f

                  .byte $30
                  .byte $30
                  .byte $30
                  .byte $30

                  .byte $31
                  .byte $31
                  .byte $31
                  .byte $31

                  .byte $32
                  .byte $32
                  .byte $32
                  .byte $32

                  .byte $33
                  .byte $33
                  .byte $33
                  .byte $33

                  .byte $34
                  .byte $34
                  .byte $34
                  .byte $34

                  .byte $35
                  .byte $35
                  .byte $35
                  .byte $35

                  .byte $36
                  .byte $36
                  .byte $36
                  .byte $36

                  .byte $37
                  .byte $37
                  .byte $37
                  .byte $37

                  .byte $38
                  .byte $38
                  .byte $38
                  .byte $38

                  .byte $39
                  .byte $39
                  .byte $39
                  .byte $39

                  .byte $3a
                  .byte $3a
                  .byte $3a
                  .byte $3a

                  .byte $3b
                  .byte $3b
                  .byte $3b
                  .byte $3b

                  .byte $3c
                  .byte $3c
                  .byte $3c
                  .byte $3c

                  .byte $3d
                  .byte $3d
                  .byte $3d
                  .byte $3d

                  .byte $3e
                  .byte $3e
                  .byte $3e
                  .byte $3e

                  .byte $3f
                  .byte $3f
                  .byte $3f
                  .byte $3f

TabTileDataA3     .byte $00                       ; values $00-$c0 in steps of $40
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

                  .byte $00
                  .byte $40
                  .byte $80
                  .byte $c0

TabTileDataA4     .byte $00                       ; values $00-$0f in steps of $01 and packs of $10
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00

                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01

                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02

                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03

                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04
                  .byte $04

                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05
                  .byte $05

                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06
                  .byte $06

                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07
                  .byte $07

                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08
                  .byte $08

                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09
                  .byte $09

                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a
                  .byte $0a

                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b
                  .byte $0b

                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c
                  .byte $0c

                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d
                  .byte $0d

                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e
                  .byte $0e

                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f
                  .byte $0f

TabTileDataA5     .byte $00                       ; values $00-$f0 in steps of $10 and packs of $10
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0

                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0

                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0

                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0

                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0

                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0

                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0

                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0

                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0

                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0

                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0

                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0

                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0

                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0

                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0

                  .byte $00
                  .byte $10
                  .byte $20
                  .byte $30
                  .byte $40
                  .byte $50
                  .byte $60
                  .byte $70
                  .byte $80
                  .byte $90
                  .byte $a0
                  .byte $b0
                  .byte $c0
                  .byte $d0
                  .byte $e0
                  .byte $f0

TabTileDataA6     .byte $00                       ; values $00-$03 in steps of $01 and packs of $40
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00

                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01
                  .byte $01

                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02
                  .byte $02

                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03
                  .byte $03

TabTileDataA7     .byte $00                       ; values $00-$ff in steps of $04 and packs of $40
                  .byte $04
                  .byte $08
                  .byte $0c
                  .byte $10
                  .byte $14
                  .byte $18
                  .byte $1c
                  .byte $20
                  .byte $24
                  .byte $28
                  .byte $2c
                  .byte $30
                  .byte $34
                  .byte $38
                  .byte $3c
                  .byte $40
                  .byte $44
                  .byte $48
                  .byte $4c
                  .byte $50
                  .byte $54
                  .byte $58
                  .byte $5c
                  .byte $60
                  .byte $64
                  .byte $68
                  .byte $6c
                  .byte $70
                  .byte $74
                  .byte $78
                  .byte $7c
                  .byte $80
                  .byte $84
                  .byte $88
                  .byte $8c
                  .byte $90
                  .byte $94
                  .byte $98
                  .byte $9c
                  .byte $a0
                  .byte $a4
                  .byte $a8
                  .byte $ac
                  .byte $b0
                  .byte $b4
                  .byte $b8
                  .byte $bc
                  .byte $c0
                  .byte $c4
                  .byte $c8
                  .byte $cc
                  .byte $d0
                  .byte $d4
                  .byte $d8
                  .byte $dc
                  .byte $e0
                  .byte $e4
                  .byte $e8
                  .byte $ec
                  .byte $f0
                  .byte $f4
                  .byte $f8
                  .byte $fc

                  .byte $00
                  .byte $04
                  .byte $08
                  .byte $0c
                  .byte $10
                  .byte $14
                  .byte $18
                  .byte $1c
                  .byte $20
                  .byte $24
                  .byte $28
                  .byte $2c
                  .byte $30
                  .byte $34
                  .byte $38
                  .byte $3c
                  .byte $40
                  .byte $44
                  .byte $48
                  .byte $4c
                  .byte $50
                  .byte $54
                  .byte $58
                  .byte $5c
                  .byte $60
                  .byte $64
                  .byte $68
                  .byte $6c
                  .byte $70
                  .byte $74
                  .byte $78
                  .byte $7c
                  .byte $80
                  .byte $84
                  .byte $88
                  .byte $8c
                  .byte $90
                  .byte $94
                  .byte $98
                  .byte $9c
                  .byte $a0
                  .byte $a4
                  .byte $a8
                  .byte $ac
                  .byte $b0
                  .byte $b4
                  .byte $b8
                  .byte $bc
                  .byte $c0
                  .byte $c4
                  .byte $c8
                  .byte $cc
                  .byte $d0
                  .byte $d4
                  .byte $d8
                  .byte $dc
                  .byte $e0
                  .byte $e4
                  .byte $e8
                  .byte $ec
                  .byte $f0
                  .byte $f4
                  .byte $f8
                  .byte $fc

                  .byte $00
                  .byte $04
                  .byte $08
                  .byte $0c
                  .byte $10
                  .byte $14
                  .byte $18
                  .byte $1c
                  .byte $20
                  .byte $24
                  .byte $28
                  .byte $2c
                  .byte $30
                  .byte $34
                  .byte $38
                  .byte $3c
                  .byte $40
                  .byte $44
                  .byte $48
                  .byte $4c
                  .byte $50
                  .byte $54
                  .byte $58
                  .byte $5c
                  .byte $60
                  .byte $64
                  .byte $68
                  .byte $6c
                  .byte $70
                  .byte $74
                  .byte $78
                  .byte $7c
                  .byte $80
                  .byte $84
                  .byte $88
                  .byte $8c
                  .byte $90
                  .byte $94
                  .byte $98
                  .byte $9c
                  .byte $a0
                  .byte $a4
                  .byte $a8
                  .byte $ac
                  .byte $b0
                  .byte $b4
                  .byte $b8
                  .byte $bc
                  .byte $c0
                  .byte $c4
                  .byte $c8
                  .byte $cc
                  .byte $d0
                  .byte $d4
                  .byte $d8
                  .byte $dc
                  .byte $e0
                  .byte $e4
                  .byte $e8
                  .byte $ec
                  .byte $f0
                  .byte $f4
                  .byte $f8
                  .byte $fc

                  .byte $00
                  .byte $04
                  .byte $08
                  .byte $0c
                  .byte $10
                  .byte $14
                  .byte $18
                  .byte $1c
                  .byte $20
                  .byte $24
                  .byte $28
                  .byte $2c
                  .byte $30
                  .byte $34
                  .byte $38
                  .byte $3c
                  .byte $40
                  .byte $44
                  .byte $48
                  .byte $4c
                  .byte $50
                  .byte $54
                  .byte $58
                  .byte $5c
                  .byte $60
                  .byte $64
                  .byte $68
                  .byte $6c
                  .byte $70
                  .byte $74
                  .byte $78
                  .byte $7c
                  .byte $80
                  .byte $84
                  .byte $88
                  .byte $8c
                  .byte $90
                  .byte $94
                  .byte $98
                  .byte $9c
                  .byte $a0
                  .byte $a4
                  .byte $a8
                  .byte $ac
                  .byte $b0
                  .byte $b4
                  .byte $b8
                  .byte $bc
                  .byte $c0
                  .byte $c4
                  .byte $c8
                  .byte $cc
                  .byte $d0
                  .byte $d4
                  .byte $d8
                  .byte $dc
                  .byte $e0
                  .byte $e4
                  .byte $e8
                  .byte $ec
                  .byte $f0
                  .byte $f4
                  .byte $f8
                  .byte $fc

TabTileDataPtr    .byte $00 ; $00 - row00
                  .byte $a8 ; $01
                  .byte $aa ; $02
                  .byte $c3 ; $03
                  .byte $00 ; $04
                  .byte $aa ; $05
                  .byte $c0 ; $06
                  .byte $00 ; $07
                  .byte $08 ; $08
                  .byte $02 ; $09
                  .byte $ff ; $0a
                  .byte $10 ; $0b
                  .byte $10 ; $0c
                  .byte $10 ; $0d
                  .byte $0c ; $0e
                  .byte $02 ; $0f
                  .byte $02 ; $10
TabTileData0811   .byte $02 ; $11   ==> obsolete
                  .byte $0c ; $12
                  .byte $64 ; $13
                  .byte $c9 ; $14
                  .byte $61 ; $15
                  .byte $06 ; $16
                  .byte $18 ; $17
                  .byte $61 ; $18
                  .byte $18 ; $19
                  .byte $06 ; $1a
                  .byte $00 ; $1b
                  .byte $00 ; $1c
                  .byte $08 ; $1d
                  .byte $00 ; $1e
                  .byte $a4 ; $1f
                  .byte $04 ; $20
                  .byte $00 ; $21
                  .byte $00 ; $22
                  .byte $00 ; $23
                  .byte $00 ; $24
                  .byte $08 ; $25
                  .byte $00 ; $26
                  .byte $00 ; $27
                  .byte $02 ; $28
                  .byte $02 ; $29
                  .byte $02 ; $2a
                  .byte $08 ; $2b
                  .byte $08 ; $2c
                  .byte $41 ; $2d
                  .byte $04 ; $2e
                  .byte $10 ; $2f
                  .byte $41 ; $30
                  .byte $10 ; $31
                  .byte $04 ; $32
                  .byte $04 ; $33
                  .byte $04 ; $34
                  .byte $44 ; $35
                  .byte $44 ; $36
                  .byte $00 ; $37
                  .byte $00 ; $38
                  .byte $00 ; $39
                  .byte $00 ; $3a
                  .byte $00 ; $3b
                  .byte $00 ; $3c
                  .byte $00 ; $3d
                  .byte $00 ; $3e
                  .byte $00 ; $3f
                  .byte $00 ; $40
                  .byte $00 ; $41
                  .byte $00 ; $42
                  .byte $00 ; $43
                  .byte $00 ; $44
                  .byte $00 ; $45
                  .byte $00 ; $46
                  .byte $00 ; $47
                  .byte $00 ; $48
                  .byte $00 ; $49
                  .byte $00 ; $4a
                  .byte $00 ; $4b
                  .byte $00 ; $4c
                  .byte $00 ; $4d
                  .byte $00 ; $4e
                  .byte $00 ; $4f
                  .byte $00 ; $50
                  .byte $00 ; $51
                  .byte $00 ; $52
                  .byte $00 ; $53
                  .byte $00 ; $54
                  .byte $00 ; $55
                  .byte $00 ; $56
                  .byte $00 ; $57
                  .byte $00 ; $58
                  .byte $00 ; $59
                  .byte $00 ; $5a
                  .byte $00 ; $5b
                  .byte $00 ; $5c
                  .byte $00 ; $5d
                  .byte $00 ; $5e
                  .byte $00 ; $5f
                  .byte $00 ; $60
                  .byte $00 ; $61
                  .byte $00 ; $62
                  .byte $00 ; $63
                  .byte $00 ; $64
                  .byte $00 ; $65
                  .byte $00 ; $66
                  .byte $00 ; $67
                  .byte $00 ; $68

                  .byte $80 ; $00 - row01
                  .byte $80 ; $01
                  .byte $00 ; $02
                  .byte $00 ; $03
                  .byte $80 ; $04
                  .byte $00 ; $05
                  .byte $00 ; $06
                  .byte $00 ; $07
                  .byte $00 ; $08
                  .byte $c0 ; $09
                  .byte $00 ; $0a
                  .byte $00 ; $0b
                  .byte $00 ; $0c
                  .byte $00 ; $0d
                  .byte $00 ; $0e
                  .byte $00 ; $0f
                  .byte $00 ; $10
                  .byte $00 ; $11
                  .byte $c0 ; $12
                  .byte $80 ; $13
                  .byte $80 ; $14
                  .byte $00 ; $15
                  .byte $00 ; $16
                  .byte $80 ; $17
                  .byte $00 ; $18
                  .byte $00 ; $19
                  .byte $00 ; $1a
                  .byte $00 ; $1b
                  .byte $00 ; $1c
                  .byte $00 ; $1d
                  .byte $80 ; $1e
                  .byte $00 ; $1f
                  .byte $00 ; $20
                  .byte $00 ; $21
                  .byte $00 ; $22
                  .byte $00 ; $23
                  .byte $00 ; $24
                  .byte $00 ; $25
                  .byte $00 ; $26
                  .byte $00 ; $27
                  .byte $00 ; $28
                  .byte $00 ; $29
                  .byte $00 ; $2a
                  .byte $00 ; $2b
                  .byte $00 ; $2c
                  .byte $00 ; $2d
                  .byte $00 ; $2e
                  .byte $00 ; $2f
                  .byte $00 ; $30
                  .byte $00 ; $31
                  .byte $00 ; $32
                  .byte $00 ; $33
                  .byte $40 ; $34
                  .byte $40 ; $35
                  .byte $00 ; $36
                  .byte $00 ; $37
                  .byte $00 ; $38
                  .byte $00 ; $39
                  .byte $00 ; $3a
                  .byte $00 ; $3b
                  .byte $00 ; $3c
                  .byte $00 ; $3d
                  .byte $00 ; $3e
                  .byte $00 ; $3f
                  .byte $00 ; $40
                  .byte $00 ; $41
                  .byte $00 ; $42
                  .byte $00 ; $43
                  .byte $00 ; $44
                  .byte $00 ; $45
                  .byte $00 ; $46
                  .byte $00 ; $47
                  .byte $00 ; $48
                  .byte $00 ; $49
                  .byte $00 ; $4a
                  .byte $00 ; $4b
                  .byte $00 ; $4c
                  .byte $00 ; $4d
                  .byte $00 ; $4e
                  .byte $00 ; $4f
                  .byte $00 ; $50
                  .byte $00 ; $51
                  .byte $00 ; $52
                  .byte $00 ; $53
                  .byte $00 ; $54
                  .byte $00 ; $55
                  .byte $00 ; $56
                  .byte $00 ; $57
                  .byte $00 ; $58
                  .byte $00 ; $59
                  .byte $00 ; $5a
                  .byte $00 ; $5b
                  .byte $00 ; $5c
                  .byte $00 ; $5d
                  .byte $00 ; $5e
                  .byte $00 ; $5f
                  .byte $00 ; $60
                  .byte $00 ; $61
                  .byte $00 ; $62
                  .byte $00 ; $63
                  .byte $00 ; $64
                  .byte $00 ; $65
                  .byte $00 ; $66
                  .byte $00 ; $67
                  .byte $a8 ; $68
                  
                  .byte $aa ; $00 - row02
                  .byte $c3 ; $01
                  .byte $ff ; $02
                  .byte $aa ; $03
                  .byte $c0 ; $04
                  .byte $00 ; $05
                  .byte $14 ; $06
                  .byte $07 ; $07
                  .byte $ff ; $08
                  .byte $38 ; $09
                  .byte $38 ; $0a
                  .byte $38 ; $0b
                  .byte $0c ; $0c
                  .byte $07 ; $0d
                  .byte $07 ; $0e
                  .byte $07 ; $0f
                  .byte $8c ; $10
                  .byte $6e ; $11
                  .byte $dd ; $12
                  .byte $61 ; $13
                  .byte $06 ; $14
                  .byte $18 ; $15
                  .byte $61 ; $16
                  .byte $18 ; $17
                  .byte $06 ; $18
                  .byte $00 ; $19
                  .byte $00 ; $1a
                  .byte $00 ; $1b
                  .byte $00 ; $1c
                  .byte $a8 ; $1d
                  .byte $14 ; $1e
                  .byte $04 ; $1f
                  .byte $00 ; $20
                  .byte $00 ; $21
                  .byte $00 ; $22
                  .byte $1c ; $23
                  .byte $00 ; $24
                  .byte $00 ; $25
                  .byte $05 ; $26
                  .byte $05 ; $27
                  .byte $05 ; $28
                  .byte $14 ; $29
                  .byte $14 ; $2a
                  .byte $41 ; $2b
                  .byte $04 ; $2c
                  .byte $10 ; $2d
TabTileDataA9     .byte $41 ; $2e
                  .byte $10 ; $2f
                  .byte $04 ; $30
                  .byte $04 ; $31
                  .byte $84 ; $32
                  .byte $44 ; $33
                  .byte $44 ; $34
                  .byte $00 ; $35
                  .byte $00 ; $36
                  .byte $00 ; $37
                  .byte $00 ; $38
                  .byte $00 ; $39
                  .byte $00 ; $3a
                  .byte $00 ; $3b
                  .byte $00 ; $3c
                  .byte $00 ; $3d
                  .byte $00 ; $3e
                  .byte $00 ; $3f
                  .byte $00 ; $40
                  .byte $00 ; $41
                  .byte $00 ; $42
                  .byte $00 ; $43
                  .byte $00 ; $44
                  .byte $00 ; $45
                  .byte $00 ; $46
                  .byte $00 ; $47
                  .byte $00 ; $48
                  .byte $00 ; $49
                  .byte $00 ; $4a
                  .byte $00 ; $4b
                  .byte $00 ; $4c
                  .byte $00 ; $4d
                  .byte $00 ; $4e
                  .byte $00 ; $4f
                  .byte $00 ; $50
                  .byte $00 ; $51
                  .byte $00 ; $52
                  .byte $00 ; $53
                  .byte $00 ; $54
                  .byte $00 ; $55
                  .byte $00 ; $56
                  .byte $00 ; $57
                  .byte $00 ; $58
                  .byte $00 ; $59
                  .byte $00 ; $5a
                  .byte $00 ; $5b
                  .byte $00 ; $5c
                  .byte $00 ; $5d
                  .byte $00 ; $5e
                  .byte $00 ; $5f
                  .byte $00 ; $60
                  .byte $00 ; $61
                  .byte $00 ; $62
                  .byte $00 ; $63
                  .byte $00 ; $64
                  .byte $00 ; $65
                  .byte $00 ; $66
                  .byte $80 ; $67
                  .byte $80 ; $68
                  
                  .byte $00 ; $00 - row03
                  .byte $c0 ; $01
                  .byte $80 ; $02
                  .byte $00 ; $03
                  .byte $00 ; $04
                  .byte $00 ; $05
                  .byte $00 ; $06
                  .byte $c0 ; $07
                  .byte $00 ; $08
                  .byte $00 ; $09
                  .byte $00 ; $0a
                  .byte $40 ; $0b
                  .byte $00 ; $0c
                  .byte $00 ; $0d
                  .byte $00 ; $0e
                  .byte $00 ; $0f
                  .byte $c0 ; $10
                  .byte $80 ; $11
                  .byte $80 ; $12
                  .byte $00 ; $13
                  .byte $00 ; $14
                  .byte $80 ; $15
                  .byte $00 ; $16
                  .byte $00 ; $17
                  .byte $00 ; $18
                  .byte $00 ; $19
                  .byte $00 ; $1a
                  .byte $00 ; $1b
                  .byte $80 ; $1c
                  .byte $00 ; $1d
                  .byte $00 ; $1e
                  .byte $00 ; $1f
                  .byte $00 ; $20
                  .byte $00 ; $21
                  .byte $00 ; $22
                  .byte $00 ; $23
                  .byte $00 ; $24
                  .byte $00 ; $25
                  .byte $00 ; $26
                  .byte $00 ; $27
                  .byte $00 ; $28
                  .byte $00 ; $29
                  .byte $00 ; $2a
                  .byte $00 ; $2b
                  .byte $00 ; $2c
                  .byte $00 ; $2d
                  .byte $00 ; $2e
                  .byte $00 ; $2f
                  .byte $40 ; $30
                  .byte $00 ; $31
                  .byte $40 ; $32
                  .byte $40 ; $33
                  .byte $00 ; $34
                  .byte $00 ; $35
                  .byte $00 ; $36
                  .byte $00 ; $37
                  .byte $00 ; $38
                  .byte $00 ; $39
                  .byte $00 ; $3a
                  .byte $00 ; $3b
                  .byte $00 ; $3c
                  .byte $00 ; $3d
                  .byte $00 ; $3e
                  .byte $00 ; $3f
                  .byte $00 ; $40
                  .byte $00 ; $41
                  .byte $00 ; $42
                  .byte $00 ; $43
                  .byte $00 ; $44
                  .byte $00 ; $45
                  .byte $00 ; $46
                  .byte $00 ; $47
                  .byte $00 ; $48
                  .byte $00 ; $49
                  .byte $00 ; $4a
                  .byte $00 ; $4b
                  .byte $00 ; $4c
                  .byte $00 ; $4d
                  .byte $00 ; $4e
                  .byte $00 ; $4f
                  .byte $00 ; $50
                  .byte $00 ; $51
                  .byte $00 ; $52
                  .byte $00 ; $53
                  .byte $00 ; $54
                  .byte $00 ; $55
                  .byte $00 ; $56
                  .byte $00 ; $57
                  .byte $00 ; $58
                  .byte $00 ; $59
                  .byte $00 ; $5a
                  .byte $00 ; $5b
                  .byte $00 ; $5c
                  .byte $00 ; $5d
                  .byte $00 ; $5e
                  .byte $00 ; $5f
                  .byte $00 ; $60
                  .byte $00 ; $61
                  .byte $00 ; $62
                  .byte $00 ; $63
                  .byte $00 ; $64
                  .byte $00 ; $65
                  .byte $a8 ; $66
                  .byte $aa ; $67
                  .byte $ff ; $68
                  
                  .byte $00 ; $00 - row04
                  .byte $00 ; $01
                  .byte $ff ; $02
                  .byte $00 ; $03
                  .byte $14 ; $04
                  .byte $07 ; $05
                  .byte $ff ; $06
                  .byte $38 ; $07
                  .byte $38 ; $08
                  .byte $38 ; $09
                  .byte $0f ; $0a
                  .byte $07 ; $0b
                  .byte $07 ; $0c
                  .byte $07 ; $0d
                  .byte $fc ; $0e
                  .byte $6e ; $0f
                  .byte $dd ; $10
                  .byte $6d ; $11
                  .byte $1e ; $12
                  .byte $1e ; $13
                  .byte $6d ; $14
                  .byte $1e ; $15
                  .byte $1e ; $16
                  .byte $00 ; $17
                  .byte $00 ; $18
                  .byte $00 ; $19
                  .byte $00 ; $1a
                  .byte $a8 ; $1b
                  .byte $80 ; $1c
                  .byte $14 ; $1d
                  .byte $00 ; $1e
                  .byte $00 ; $1f
                  .byte $00 ; $20
                  .byte $1c ; $21
                  .byte $00 ; $22
                  .byte $00 ; $23
                  .byte $05 ; $24
                  .byte $05 ; $25
                  .byte $05 ; $26
                  .byte $14 ; $27
                  .byte $14 ; $28
                  .byte $45 ; $29
                  .byte $14 ; $2a
                  .byte $14 ; $2b
                  .byte $51 ; $2c
                  .byte $14 ; $2d
                  .byte $14 ; $2e
                  .byte $05 ; $2f
                  .byte $d4 ; $30
                  .byte $44 ; $31
                  .byte $44 ; $32
                  .byte $00 ; $33
                  .byte $00 ; $34
                  .byte $00 ; $35
                  .byte $00 ; $36
                  .byte $00 ; $37
                  .byte $00 ; $38
                  .byte $00 ; $39
                  .byte $00 ; $3a
                  .byte $00 ; $3b
                  .byte $00 ; $3c
                  .byte $00 ; $3d
                  .byte $00 ; $3e
                  .byte $00 ; $3f
                  .byte $00 ; $40
                  .byte $00 ; $41
                  .byte $00 ; $42
                  .byte $00 ; $43
                  .byte $00 ; $44
                  .byte $00 ; $45
                  .byte $00 ; $46
                  .byte $00 ; $47
                  .byte $00 ; $48
                  .byte $00 ; $49
                  .byte $00 ; $4a
                  .byte $00 ; $4b
                  .byte $00 ; $4c
                  .byte $00 ; $4d
                  .byte $00 ; $4e
                  .byte $00 ; $4f
                  .byte $00 ; $50
                  .byte $00 ; $51
                  .byte $00 ; $52
                  .byte $00 ; $53
                  .byte $00 ; $54
                  .byte $00 ; $55
                  .byte $00 ; $56
                  .byte $00 ; $57
                  .byte $00 ; $58
                  .byte $00 ; $59
                  .byte $00 ; $5a
                  .byte $00 ; $5b
TabTileDataAa     .byte $00 ; $5c
                  .byte $00 ; $5d
                  .byte $00 ; $5e
                  .byte $00 ; $5f
                  .byte $00 ; $60
                  .byte $00 ; $61
                  .byte $00 ; $62
                  .byte $00 ; $63
                  .byte $00 ; $64
                  .byte $80 ; $65
                  .byte $80 ; $66
                  .byte $00 ; $67
                  .byte $00 ; $68
                  
                  .byte $00 ; $00 - row05
                  .byte $00 ; $01
                  .byte $00 ; $02
                  .byte $00 ; $03
                  .byte $00 ; $04
                  .byte $c0 ; $05
                  .byte $00 ; $06
                  .byte $00 ; $07
                  .byte $00 ; $08
                  .byte $c0 ; $09
                  .byte $00 ; $0a
                  .byte $00 ; $0b
                  .byte $00 ; $0c
                  .byte $00 ; $0d
                  .byte $c0 ; $0e
                  .byte $80 ; $0f
                  .byte $80 ; $10
                  .byte $00 ; $11
                  .byte $00 ; $12
                  .byte $80 ; $13
                  .byte $00 ; $14
                  .byte $00 ; $15
                  .byte $00 ; $16
                  .byte $00 ; $17
                  .byte $00 ; $18
                  .byte $00 ; $19
                  .byte $80 ; $1a
                  .byte $80 ; $1b
                  .byte $00 ; $1c
                  .byte $00 ; $1d
                  .byte $00 ; $1e
                  .byte $00 ; $1f
                  .byte $00 ; $20
                  .byte $00 ; $21
                  .byte $00 ; $22
                  .byte $00 ; $23
                  .byte $00 ; $24
                  .byte $00 ; $25
                  .byte $00 ; $26
                  .byte $00 ; $27
                  .byte $00 ; $28
                  .byte $00 ; $29
                  .byte $00 ; $2a
                  .byte $00 ; $2b
                  .byte $00 ; $2c
                  .byte $00 ; $2d
                  .byte $40 ; $2e
                  .byte $00 ; $2f
                  .byte $40 ; $30
                  .byte $40 ; $31
                  .byte $00 ; $32
                  .byte $00 ; $33
                  .byte $00 ; $34
                  .byte $00 ; $35
                  .byte $00 ; $36
                  .byte $00 ; $37
                  .byte $00 ; $38
                  .byte $00 ; $39
                  .byte $00 ; $3a
                  .byte $00 ; $3b
                  .byte $00 ; $3c
                  .byte $00 ; $3d
                  .byte $00 ; $3e
                  .byte $00 ; $3f
                  .byte $00 ; $40
                  .byte $00 ; $41
                  .byte $00 ; $42
                  .byte $00 ; $43
                  .byte $00 ; $44
                  .byte $00 ; $45
                  .byte $00 ; $46
                  .byte $00 ; $47
                  .byte $00 ; $48
                  .byte $00 ; $49
                  .byte $00 ; $4a
                  .byte $00 ; $4b
                  .byte $00 ; $4c
                  .byte $00 ; $4d
                  .byte $00 ; $4e
                  .byte $00 ; $4f
                  .byte $00 ; $50
                  .byte $00 ; $51
                  .byte $00 ; $52
                  .byte $00 ; $53
                  .byte $00 ; $54
                  .byte $00 ; $55
                  .byte $00 ; $56
                  .byte $00 ; $57
                  .byte $00 ; $58
                  .byte $00 ; $59
                  .byte $00 ; $5a
                  .byte $00 ; $5b
                  .byte $00 ; $5c
                  .byte $00 ; $5d
                  .byte $00 ; $5e
                  .byte $00 ; $5f
                  .byte $00 ; $60
                  .byte $00 ; $61
                  .byte $00 ; $62
                  .byte $00 ; $63
                  .byte $a8 ; $64
                  .byte $aa ; $65
                  .byte $c3 ; $66
                  .byte $00 ; $67
                  .byte $3f ; $68
                  
                  .byte $c3 ; $00 - row06
                  .byte $00 ; $01
                  .byte $04 ; $02
                  .byte $0e ; $03
                  .byte $ff ; $04
                  .byte $1c ; $05
                  .byte $18 ; $06
                  .byte $18 ; $07
                  .byte $4e ; $08
                  .byte $03 ; $09
                  .byte $06 ; $0a
                  .byte $06 ; $0b
                  .byte $1c ; $0c
                  .byte $3f ; $0d
                  .byte $7f ; $0e
                  .byte $6f ; $0f
                  .byte $1c ; $10
                  .byte $0e ; $11
                  .byte $3d ; $12
                  .byte $0e ; $13
                  .byte $dc ; $14
                  .byte $00 ; $15
                  .byte $08 ; $16
                  .byte $00 ; $17
                  .byte $08 ; $18
                  .byte $a8 ; $19
                  .byte $a8 ; $1a
                  .byte $94 ; $1b
                  .byte $04 ; $1c
                  .byte $00 ; $1d
                  .byte $00 ; $1e
                  .byte $18 ; $1f
                  .byte $00 ; $20
                  .byte $08 ; $21
                  .byte $04 ; $22
                  .byte $04 ; $23
                  .byte $04 ; $24
                  .byte $04 ; $25
                  .byte $04 ; $26
                  .byte $45 ; $27
                  .byte $14 ; $28
                  .byte $04 ; $29
                  .byte $51 ; $2a
                  .byte $14 ; $2b
                  .byte $10 ; $2c
                  .byte $44 ; $2d
                  .byte $14 ; $2e
                  .byte $15 ; $2f
                  .byte $15 ; $30
                  .byte $00 ; $31
                  .byte $00 ; $32
                  .byte $00 ; $33
                  .byte $00 ; $34
                  .byte $55 ; $35
                  .byte $14 ; $36
                  .byte $55 ; $37
                  .byte $55 ; $38
                  .byte $51 ; $39
                  .byte $55 ; $3a
                  .byte $55 ; $3b
                  .byte $55 ; $3c
                  .byte $15 ; $3d
                  .byte $55 ; $3e
                  .byte $2a ; $3f
                  .byte $a8 ; $40
                  .byte $aa ; $41
                  .byte $a8 ; $42
                  .byte $aa ; $43
                  .byte $aa ; $44
                  .byte $aa ; $45
                  .byte $82 ; $46
                  .byte $20 ; $47
                  .byte $08 ; $48
                  .byte $82 ; $49
                  .byte $80 ; $4a
                  .byte $82 ; $4b
                  .byte $82 ; $4c
                  .byte $aa ; $4d
                  .byte $aa ; $4e
                  .byte $aa ; $4f
                  .byte $aa ; $50
                  .byte $aa ; $51
                  .byte $aa ; $52
                  .byte $82 ; $53
                  .byte $a2 ; $54
                  .byte $82 ; $55
                  .byte $82 ; $56
                  .byte $8a ; $57
                  .byte $aa ; $58
                  .byte $80 ; $59
                  .byte $00 ; $5a
                  .byte $28 ; $5b
                  .byte $28 ; $5c
                  .byte $02 ; $5d
                  .byte $00 ; $5e
                  .byte $02 ; $5f
                  .byte $00 ; $60
                  .byte $00 ; $61
                  .byte $00 ; $62
                  .byte $80 ; $63
                  .byte $80 ; $64
                  .byte $00 ; $65
                  .byte $00 ; $66
                  .byte $00 ; $67
                  .byte $00 ; $68
                  
                  .byte $00 ; $00 - row07
                  .byte $00 ; $01
                  .byte $00 ; $02
                  .byte $c0 ; $03
                  .byte $00 ; $04
                  .byte $00 ; $05
                  .byte $00 ; $06
                  .byte $00 ; $07
                  .byte $00 ; $08
                  .byte $00 ; $09
                  .byte $00 ; $0a
                  .byte $80 ; $0b
                  .byte $80 ; $0c
                  .byte $00 ; $0d
                  .byte $00 ; $0e
                  .byte $00 ; $0f
                  .byte $c0 ; $10
                  .byte $80 ; $11
                  .byte $00 ; $12
                  .byte $00 ; $13
                  .byte $00 ; $14
                  .byte $00 ; $15
                  .byte $00 ; $16
                  .byte $00 ; $17
                  .byte $80 ; $18
                  .byte $80 ; $19
                  .byte $80 ; $1a
                  .byte $00 ; $1b
                  .byte $00 ; $1c
                  .byte $00 ; $1d
                  .byte $00 ; $1e
                  .byte $00 ; $1f
                  .byte $00 ; $20
TabTileDataAb     .byte $00 ; $21
                  .byte $00 ; $22
                  .byte $00 ; $23
                  .byte $00 ; $24
                  .byte $00 ; $25
                  .byte $00 ; $26
                  .byte $00 ; $27
                  .byte $40 ; $28
                  .byte $00 ; $29
                  .byte $00 ; $2a
                  .byte $00 ; $2b
                  .byte $00 ; $2c
                  .byte $80 ; $2d
                  .byte $00 ; $2e
                  .byte $00 ; $2f
                  .byte $00 ; $30
                  .byte $00 ; $31
                  .byte $00 ; $32
                  .byte $00 ; $33
                  .byte $00 ; $34
                  .byte $00 ; $35
                  .byte $00 ; $36
                  .byte $00 ; $37
                  .byte $00 ; $38
                  .byte $00 ; $39
                  .byte $00 ; $3a
                  .byte $00 ; $3b
                  .byte $00 ; $3c
                  .byte $00 ; $3d
                  .byte $00 ; $3e
                  .byte $00 ; $3f
                  .byte $00 ; $40
                  .byte $00 ; $41
                  .byte $00 ; $42
                  .byte $00 ; $43
                  .byte $00 ; $44
                  .byte $00 ; $45
                  .byte $00 ; $46
                  .byte $00 ; $47
                  .byte $00 ; $48
                  .byte $00 ; $49
                  .byte $00 ; $4a
                  .byte $00 ; $4b
                  .byte $00 ; $4c
                  .byte $00 ; $4d
                  .byte $00 ; $4e
                  .byte $00 ; $4f
                  .byte $00 ; $50
                  .byte $00 ; $51
                  .byte $00 ; $52
                  .byte $00 ; $53
                  .byte $00 ; $54
                  .byte $00 ; $55
                  .byte $00 ; $56
                  .byte $00 ; $57
                  .byte $00 ; $58
                  .byte $00 ; $59
                  .byte $00 ; $5a
                  .byte $00 ; $5b
                  .byte $00 ; $5c
                  .byte $00 ; $5d
                  .byte $00 ; $5e
                  .byte $00 ; $5f
                  .byte $00 ; $60
                  .byte $00 ; $61
                  .byte $00 ; $62
                  .byte $aa ; $63
                  .byte $c3 ; $64
                  .byte $00 ; $65
                  .byte $0c ; $66
                  .byte $03 ; $67
                  .byte $00 ; $68
                  
                  .byte $15 ; $00 - row08
                  .byte $37 ; $01
                  .byte $ff ; $02
                  .byte $3b ; $03
                  .byte $1c ; $04
                  .byte $5e ; $05
                  .byte $7e ; $06
                  .byte $0f ; $07
                  .byte $0e ; $08
                  .byte $1e ; $09
                  .byte $1f ; $0a
                  .byte $06 ; $0b
                  .byte $18 ; $0c
                  .byte $3c ; $0d
                  .byte $78 ; $0e
                  .byte $07 ; $0f
                  .byte $0f ; $10
                  .byte $07 ; $11
                  .byte $78 ; $12
                  .byte $00 ; $13
                  .byte $00 ; $14
                  .byte $00 ; $15
                  .byte $00 ; $16
                  .byte $00 ; $17
                  .byte $00 ; $18
                  .byte $00 ; $19
                  .byte $14 ; $1a
                  .byte $00 ; $1b
                  .byte $00 ; $1c
                  .byte $7e ; $1d
                  .byte $00 ; $1e
                  .byte $00 ; $1f
                  .byte $15 ; $20
                  .byte $14 ; $21
                  .byte $15 ; $22
                  .byte $05 ; $23
                  .byte $15 ; $24
                  .byte $14 ; $25
                  .byte $50 ; $26
                  .byte $05 ; $27
                  .byte $14 ; $28
                  .byte $05 ; $29
                  .byte $50 ; $2a
                  .byte $54 ; $2b
                  .byte $15 ; $2c
                  .byte $04 ; $2d
                  .byte $04 ; $2e
                  .byte $00 ; $2f
                  .byte $00 ; $30
                  .byte $00 ; $31
                  .byte $00 ; $32
                  .byte $41 ; $33
                  .byte $14 ; $34
                  .byte $41 ; $35
                  .byte $41 ; $36
                  .byte $51 ; $37
                  .byte $40 ; $38
                  .byte $41 ; $39
                  .byte $05 ; $3a
                  .byte $11 ; $3b
                  .byte $41 ; $3c
                  .byte $22 ; $3d
                  .byte $88 ; $3e
                  .byte $82 ; $3f
                  .byte $82 ; $40
                  .byte $a0 ; $41
                  .byte $a0 ; $42
                  .byte $82 ; $43
                  .byte $82 ; $44
                  .byte $20 ; $45
                  .byte $08 ; $46
                  .byte $8a ; $47
                  .byte $80 ; $48
                  .byte $a2 ; $49
                  .byte $82 ; $4a
                  .byte $8a ; $4b
                  .byte $82 ; $4c
                  .byte $8a ; $4d
                  .byte $82 ; $4e
                  .byte $82 ; $4f
                  .byte $20 ; $50
                  .byte $82 ; $51
                  .byte $a2 ; $52
                  .byte $82 ; $53
                  .byte $82 ; $54
                  .byte $8a ; $55
                  .byte $82 ; $56
                  .byte $a0 ; $57
                  .byte $00 ; $58
                  .byte $28 ; $59
                  .byte $28 ; $5a
                  .byte $02 ; $5b
                  .byte $00 ; $5c
                  .byte $0a ; $5d
                  .byte $00 ; $5e
                  .byte $00 ; $5f
                  .byte $00 ; $60
                  .byte $00 ; $61
                  .byte $80 ; $62
                  .byte $00 ; $63
                  .byte $00 ; $64
                  .byte $00 ; $65
                  .byte $00 ; $66
                  .byte $00 ; $67
                  .byte $00 ; $68
                  
                  .byte $00 ; $00 - row09
                  .byte $c0 ; $01
                  .byte $00 ; $02
                  .byte $00 ; $03
                  .byte $00 ; $04
                  .byte $00 ; $05
                  .byte $c0 ; $06
                  .byte $00 ; $07
                  .byte $80 ; $08
                  .byte $80 ; $09
                  .byte $00 ; $0a
                  .byte $00 ; $0b
                  .byte $00 ; $0c
                  .byte $00 ; $0d
                  .byte $80 ; $0e
                  .byte $00 ; $0f
                  .byte $80 ; $10
                  .byte $00 ; $11
                  .byte $00 ; $12
                  .byte $00 ; $13
                  .byte $00 ; $14
                  .byte $00 ; $15
                  .byte $00 ; $16
                  .byte $00 ; $17
                  .byte $00 ; $18
                  .byte $00 ; $19
                  .byte $00 ; $1a
                  .byte $00 ; $1b
                  .byte $00 ; $1c
                  .byte $00 ; $1d
                  .byte $00 ; $1e
                  .byte $00 ; $1f
                  .byte $00 ; $20
                  .byte $00 ; $21
                  .byte $00 ; $22
                  .byte $00 ; $23
                  .byte $00 ; $24
                  .byte $00 ; $25
                  .byte $00 ; $26
                  .byte $00 ; $27
                  .byte $00 ; $28
                  .byte $00 ; $29
                  .byte $00 ; $2a
                  .byte $80 ; $2b
                  .byte $00 ; $2c
                  .byte $00 ; $2d
                  .byte $00 ; $2e
                  .byte $00 ; $2f
                  .byte $00 ; $30
                  .byte $00 ; $31
                  .byte $00 ; $32
                  .byte $00 ; $33
                  .byte $00 ; $34
                  .byte $00 ; $35
                  .byte $00 ; $36
                  .byte $00 ; $37
                  .byte $00 ; $38
                  .byte $00 ; $39
                  .byte $00 ; $3a
                  .byte $00 ; $3b
                  .byte $00 ; $3c
                  .byte $00 ; $3d
                  .byte $00 ; $3e
                  .byte $00 ; $3f
                  .byte $00 ; $40
                  .byte $00 ; $41
                  .byte $00 ; $42
                  .byte $00 ; $43
                  .byte $00 ; $44
                  .byte $00 ; $45
                  .byte $00 ; $46
                  .byte $00 ; $47
                  .byte $00 ; $48
                  .byte $00 ; $49
                  .byte $00 ; $4a
                  .byte $00 ; $4b
                  .byte $00 ; $4c
                  .byte $00 ; $4d
                  .byte $00 ; $4e
TabTileDataAc     .byte $00 ; $4f
                  .byte $00 ; $50
                  .byte $00 ; $51
                  .byte $00 ; $52
                  .byte $00 ; $53
                  .byte $00 ; $54
                  .byte $00 ; $55
                  .byte $00 ; $56
                  .byte $00 ; $57
                  .byte $00 ; $58
                  .byte $00 ; $59
                  .byte $00 ; $5a
                  .byte $00 ; $5b
                  .byte $00 ; $5c
                  .byte $00 ; $5d
                  .byte $00 ; $5e
                  .byte $00 ; $5f
                  .byte $8a ; $60
                  .byte $aa ; $61
                  .byte $c3 ; $62
                  .byte $00 ; $63
                  .byte $0c ; $64
                  .byte $03 ; $65
                  .byte $ff ; $66
                  .byte $44 ; $67
                  .byte $6c ; $68
                  
                  .byte $ff ; $00 - row0a
                  .byte $cd ; $01
                  .byte $3e ; $02
                  .byte $7b ; $03
                  .byte $0e ; $04
                  .byte $5b ; $05
                  .byte $1f ; $06
                  .byte $37 ; $07
                  .byte $1c ; $08
                  .byte $06 ; $09
                  .byte $18 ; $0a
                  .byte $18 ; $0b
                  .byte $d8 ; $0c
                  .byte $06 ; $0d
                  .byte $06 ; $0e
                  .byte $06 ; $0f
                  .byte $18 ; $10
                  .byte $00 ; $11
                  .byte $00 ; $12
                  .byte $00 ; $13
                  .byte $80 ; $14
                  .byte $8a ; $15
                  .byte $8a ; $16
                  .byte $8a ; $17
                  .byte $15 ; $18
                  .byte $04 ; $19
                  .byte $00 ; $1a
                  .byte $5b ; $1b
                  .byte $00 ; $1c
                  .byte $00 ; $1d
                  .byte $44 ; $1e
                  .byte $15 ; $1f
                  .byte $45 ; $20
                  .byte $15 ; $21
                  .byte $14 ; $22
                  .byte $10 ; $23
                  .byte $50 ; $24
                  .byte $04 ; $25
                  .byte $04 ; $26
                  .byte $05 ; $27
                  .byte $10 ; $28
                  .byte $04 ; $29
                  .byte $14 ; $2a
                  .byte $04 ; $2b
                  .byte $04 ; $2c
                  .byte $00 ; $2d
                  .byte $00 ; $2e
                  .byte $00 ; $2f
                  .byte $00 ; $30
                  .byte $41 ; $31
                  .byte $04 ; $32
                  .byte $01 ; $33
                  .byte $01 ; $34
                  .byte $51 ; $35
                  .byte $40 ; $36
                  .byte $40 ; $37
                  .byte $05 ; $38
                  .byte $11 ; $39
                  .byte $41 ; $3a
                  .byte $22 ; $3b
                  .byte $88 ; $3c
                  .byte $80 ; $3d
                  .byte $82 ; $3e
                  .byte $a0 ; $3f
                  .byte $a0 ; $40
                  .byte $80 ; $41
                  .byte $82 ; $42
                  .byte $20 ; $43
                  .byte $08 ; $44
                  .byte $88 ; $45
                  .byte $80 ; $46
                  .byte $aa ; $47
                  .byte $a2 ; $48
                  .byte $8a ; $49
                  .byte $82 ; $4a
                  .byte $8a ; $4b
                  .byte $82 ; $4c
                  .byte $80 ; $4d
                  .byte $20 ; $4e
                  .byte $82 ; $4f
                  .byte $a2 ; $50
                  .byte $82 ; $51
                  .byte $82 ; $52
                  .byte $8a ; $53
                  .byte $82 ; $54
                  .byte $28 ; $55
                  .byte $00 ; $56
                  .byte $a0 ; $57
                  .byte $0a ; $58
                  .byte $08 ; $59
                  .byte $aa ; $5a
                  .byte $28 ; $5b
                  .byte $00 ; $5c
                  .byte $00 ; $5d
                  .byte $00 ; $5e
                  .byte $80 ; $5f
                  .byte $80 ; $60
                  .byte $00 ; $61
                  .byte $00 ; $62
                  .byte $00 ; $63
                  .byte $00 ; $64
                  .byte $00 ; $65
                  .byte $40 ; $66
                  .byte $c0 ; $67
                  .byte $c0 ; $68
                  
                  .byte $80 ; $00 - row0b
                  .byte $00 ; $01
                  .byte $00 ; $02
                  .byte $00 ; $03
                  .byte $40 ; $04
                  .byte $00 ; $05
                  .byte $80 ; $06
                  .byte $00 ; $07
                  .byte $00 ; $08
                  .byte $00 ; $09
                  .byte $00 ; $0a
                  .byte $00 ; $0b
                  .byte $00 ; $0c
                  .byte $00 ; $0d
                  .byte $c0 ; $0e
                  .byte $00 ; $0f
                  .byte $00 ; $10
                  .byte $80 ; $11
                  .byte $00 ; $12
                  .byte $00 ; $13
                  .byte $80 ; $14
                  .byte $80 ; $15
                  .byte $80 ; $16
                  .byte $00 ; $17
                  .byte $00 ; $18
                  .byte $00 ; $19
                  .byte $40 ; $1a
                  .byte $00 ; $1b
                  .byte $80 ; $1c
                  .byte $40 ; $1d
                  .byte $00 ; $1e
                  .byte $00 ; $1f
                  .byte $00 ; $20
                  .byte $40 ; $21
                  .byte $00 ; $22
                  .byte $00 ; $23
                  .byte $00 ; $24
                  .byte $00 ; $25
                  .byte $00 ; $26
                  .byte $00 ; $27
                  .byte $00 ; $28
                  .byte $00 ; $29
                  .byte $00 ; $2a
                  .byte $00 ; $2b
                  .byte $00 ; $2c
                  .byte $00 ; $2d
                  .byte $00 ; $2e
                  .byte $00 ; $2f
                  .byte $00 ; $30
                  .byte $00 ; $31
                  .byte $00 ; $32
                  .byte $00 ; $33
                  .byte $00 ; $34
                  .byte $00 ; $35
                  .byte $00 ; $36
                  .byte $00 ; $37
                  .byte $00 ; $38
                  .byte $00 ; $39
                  .byte $00 ; $3a
                  .byte $00 ; $3b
                  .byte $00 ; $3c
                  .byte $00 ; $3d
                  .byte $00 ; $3e
                  .byte $00 ; $3f
                  .byte $00 ; $40
                  .byte $00 ; $41
                  .byte $00 ; $42
                  .byte $00 ; $43
                  .byte $00 ; $44
                  .byte $00 ; $45
                  .byte $00 ; $46
                  .byte $00 ; $47
                  .byte $00 ; $48
                  .byte $00 ; $49
                  .byte $00 ; $4a
                  .byte $00 ; $4b
                  .byte $00 ; $4c
                  .byte $00 ; $4d
                  .byte $00 ; $4e
                  .byte $00 ; $4f
                  .byte $00 ; $50
                  .byte $00 ; $51
                  .byte $00 ; $52
                  .byte $00 ; $53
                  .byte $00 ; $54
                  .byte $00 ; $55
                  .byte $00 ; $56
                  .byte $00 ; $57
                  .byte $00 ; $58
                  .byte $80 ; $59
                  .byte $00 ; $5a
                  .byte $00 ; $5b
                  .byte $00 ; $5c
                  .byte $00 ; $5d
                  .byte $8a ; $5e
                  .byte $aa ; $5f
                  .byte $c3 ; $60
                  .byte $00 ; $61
                  .byte $0c ; $62
                  .byte $03 ; $63
                  .byte $eb ; $64
                  .byte $06 ; $65
                  .byte $0c ; $66
                  .byte $ff ; $67
                  .byte $0c ; $68
                  
                  .byte $de ; $00 - row0c
                  .byte $18 ; $01
                  .byte $0e ; $02
                  .byte $43 ; $03
                  .byte $1e ; $04
                  .byte $06 ; $05
                  .byte $1c ; $06
                  .byte $1e ; $07
                  .byte $1e ; $08
                  .byte $18 ; $09
                  .byte $18 ; $0a
                  .byte $06 ; $0b
                  .byte $06 ; $0c
                  .byte $06 ; $0d
                  .byte $18 ; $0e
                  .byte $08 ; $0f
                  .byte $80 ; $10
                  .byte $88 ; $11
                  .byte $00 ; $12
                  .byte $8a ; $13
TabTileDataAd     .byte $8a ; $14
                  .byte $8a ; $15
                  .byte $00 ; $16
                  .byte $05 ; $17
                  .byte $00 ; $18
                  .byte $18 ; $19
                  .byte $08 ; $1a
                  .byte $a0 ; $1b
                  .byte $0c ; $1c
                  .byte $06 ; $1d
                  .byte $06 ; $1e
                  .byte $4c ; $1f
                  .byte $0c ; $20
                  .byte $10 ; $21
                  .byte $10 ; $22
                  .byte $04 ; $23
                  .byte $04 ; $24
                  .byte $04 ; $25
                  .byte $10 ; $26
                  .byte $0e ; $27
                  .byte $1c ; $28
                  .byte $0f ; $29
                  .byte $1e ; $2a
                  .byte $00 ; $2b
                  .byte $80 ; $2c
                  .byte $00 ; $2d
                  .byte $00 ; $2e
                  .byte $41 ; $2f
                  .byte $04 ; $30
                  .byte $55 ; $31
                  .byte $15 ; $32
                  .byte $55 ; $33
                  .byte $55 ; $34
                  .byte $40 ; $35
                  .byte $05 ; $36
                  .byte $55 ; $37
                  .byte $55 ; $38
                  .byte $aa ; $39
                  .byte $aa ; $3a
                  .byte $80 ; $3b
                  .byte $82 ; $3c
                  .byte $a8 ; $3d
                  .byte $a8 ; $3e
                  .byte $80 ; $3f
                  .byte $aa ; $40
                  .byte $28 ; $41
                  .byte $0a ; $42
                  .byte $a8 ; $43
                  .byte $80 ; $44
                  .byte $aa ; $45
                  .byte $aa ; $46
                  .byte $82 ; $47
                  .byte $aa ; $48
                  .byte $82 ; $49
                  .byte $aa ; $4a
                  .byte $aa ; $4b
                  .byte $20 ; $4c
                  .byte $82 ; $4d
                  .byte $a2 ; $4e
                  .byte $82 ; $4f
                  .byte $28 ; $50
                  .byte $aa ; $51
                  .byte $08 ; $52
                  .byte $0a ; $53
                  .byte $00 ; $54
                  .byte $a0 ; $55
                  .byte $0a ; $56
                  .byte $08 ; $57
                  .byte $aa ; $58
                  .byte $a0 ; $59
                  .byte $00 ; $5a
                  .byte $00 ; $5b
                  .byte $00 ; $5c
                  .byte $80 ; $5d
                  .byte $80 ; $5e
                  .byte $00 ; $5f
                  .byte $00 ; $60
                  .byte $00 ; $61
                  .byte $00 ; $62
                  .byte $00 ; $63
                  .byte $00 ; $64
                  .byte $00 ; $65
                  .byte $c0 ; $66
                  .byte $00 ; $67
                  .byte $00 ; $68
                  
                  .byte $00 ; $00 - row0d
                  .byte $00 ; $01
                  .byte $00 ; $02
                  .byte $c0 ; $03
                  .byte $00 ; $04
                  .byte $00 ; $05
                  .byte $00 ; $06
                  .byte $00 ; $07
                  .byte $00 ; $08
                  .byte $00 ; $09
                  .byte $00 ; $0a
                  .byte $00 ; $0b
                  .byte $00 ; $0c
                  .byte $00 ; $0d
                  .byte $00 ; $0e
                  .byte $00 ; $0f
                  .byte $00 ; $10
                  .byte $00 ; $11
                  .byte $80 ; $12
                  .byte $80 ; $13
                  .byte $80 ; $14
                  .byte $00 ; $15
                  .byte $00 ; $16
                  .byte $00 ; $17
                  .byte $40 ; $18
                  .byte $00 ; $19
                  .byte $00 ; $1a
                  .byte $00 ; $1b
                  .byte $40 ; $1c
                  .byte $00 ; $1d
                  .byte $00 ; $1e
                  .byte $00 ; $1f
                  .byte $00 ; $20
                  .byte $00 ; $21
                  .byte $00 ; $22
                  .byte $00 ; $23
                  .byte $00 ; $24
                  .byte $00 ; $25
                  .byte $00 ; $26
                  .byte $00 ; $27
                  .byte $00 ; $28
                  .byte $00 ; $29
                  .byte $00 ; $2a
                  .byte $80 ; $2b
                  .byte $00 ; $2c
                  .byte $00 ; $2d
                  .byte $00 ; $2e
                  .byte $00 ; $2f
                  .byte $00 ; $30
                  .byte $00 ; $31
                  .byte $00 ; $32
                  .byte $00 ; $33
                  .byte $00 ; $34
                  .byte $00 ; $35
                  .byte $00 ; $36
                  .byte $00 ; $37
                  .byte $00 ; $38
                  .byte $00 ; $39
                  .byte $00 ; $3a
                  .byte $00 ; $3b
                  .byte $00 ; $3c
                  .byte $00 ; $3d
                  .byte $00 ; $3e
                  .byte $00 ; $3f
                  .byte $00 ; $40
                  .byte $00 ; $41
                  .byte $00 ; $42
                  .byte $00 ; $43
                  .byte $00 ; $44
                  .byte $00 ; $45
                  .byte $00 ; $46
                  .byte $00 ; $47
                  .byte $00 ; $48
                  .byte $00 ; $49
                  .byte $00 ; $4a
                  .byte $00 ; $4b
                  .byte $00 ; $4c
                  .byte $00 ; $4d
                  .byte $00 ; $4e
                  .byte $00 ; $4f
                  .byte $00 ; $50
                  .byte $00 ; $51
                  .byte $00 ; $52
                  .byte $00 ; $53
                  .byte $00 ; $54
                  .byte $00 ; $55
                  .byte $00 ; $56
                  .byte $80 ; $57
                  .byte $00 ; $58
                  .byte $00 ; $59
                  .byte $00 ; $5a
                  .byte $00 ; $5b
                  .byte $8a ; $5c
                  .byte $aa ; $5d
                  .byte $ff ; $5e
                  .byte $00 ; $5f
                  .byte $0c ; $60
                  .byte $c3 ; $61
                  .byte $eb ; $62
                  .byte $15 ; $63
                  .byte $0e ; $64
                  .byte $ff ; $65
                  .byte $1c ; $66
                  .byte $38 ; $67
                  .byte $3c ; $68
                  
                  .byte $1b ; $00 - row0e
                  .byte $07 ; $01
                  .byte $07 ; $02
                  .byte $0f ; $03
                  .byte $36 ; $04
                  .byte $36 ; $05
                  .byte $1b ; $06
                  .byte $78 ; $07
                  .byte $38 ; $08
                  .byte $0e ; $09
                  .byte $07 ; $0a
                  .byte $07 ; $0b
                  .byte $1c ; $0c
                  .byte $02 ; $0d
                  .byte $20 ; $0e
                  .byte $00 ; $0f
                  .byte $00 ; $10
                  .byte $8a ; $11
                  .byte $8a ; $12
                  .byte $8a ; $13
                  .byte $8a ; $14
                  .byte $95 ; $15
                  .byte $04 ; $16
                  .byte $1c ; $17
                  .byte $22 ; $18
                  .byte $40 ; $19
                  .byte $0e ; $1a
                  .byte $07 ; $1b
                  .byte $0f ; $1c
                  .byte $1c ; $1d
                  .byte $1e ; $1e
                  .byte $78 ; $1f
                  .byte $38 ; $20
                  .byte $0e ; $21
                  .byte $0f ; $22
                  .byte $0e ; $23
                  .byte $38 ; $24
                  .byte $1b ; $25
                  .byte $36 ; $26
                  .byte $0d ; $27
                  .byte $36 ; $28
                  .byte $00 ; $29
                  .byte $80 ; $2a
                  .byte $00 ; $2b
                  .byte $14 ; $2c
                  .byte $45 ; $2d
                  .byte $04 ; $2e
                  .byte $40 ; $2f
                  .byte $01 ; $30
                  .byte $01 ; $31
                  .byte $05 ; $32
                  .byte $55 ; $33
                  .byte $14 ; $34
                  .byte $41 ; $35
                  .byte $05 ; $36
                  .byte $82 ; $37
                  .byte $82 ; $38
                  .byte $a0 ; $39
                  .byte $a2 ; $3a
                  .byte $80 ; $3b
                  .byte $80 ; $3c
                  .byte $8a ; $3d
                  .byte $a2 ; $3e
                  .byte $28 ; $3f
                  .byte $0a ; $40
                  .byte $aa ; $41
TabTileDataAe     .byte $a0 ; $42
                  .byte $82 ; $43
                  .byte $aa ; $44
                  .byte $82 ; $45
                  .byte $a0 ; $46
                  .byte $82 ; $47
                  .byte $a8 ; $48
                  .byte $0a ; $49
                  .byte $28 ; $4a
                  .byte $a2 ; $4b
                  .byte $a2 ; $4c
                  .byte $aa ; $4d
                  .byte $28 ; $4e
                  .byte $28 ; $4f
                  .byte $28 ; $50
                  .byte $0a ; $51
                  .byte $00 ; $52
                  .byte $a0 ; $53
                  .byte $0a ; $54
                  .byte $20 ; $55
                  .byte $aa ; $56
                  .byte $a0 ; $57
                  .byte $00 ; $58
                  .byte $00 ; $59
                  .byte $00 ; $5a
                  .byte $80 ; $5b
                  .byte $80 ; $5c
                  .byte $00 ; $5d
                  .byte $00 ; $5e
                  .byte $00 ; $5f
                  .byte $00 ; $60
                  .byte $00 ; $61
                  .byte $00 ; $62
                  .byte $00 ; $63
                  .byte $c0 ; $64
                  .byte $00 ; $65
                  .byte $00 ; $66
                  .byte $00 ; $67
                  .byte $00 ; $68
                  
                  .byte $00 ; $00 - row0f
                  .byte $00 ; $01
                  .byte $00 ; $02
                  .byte $00 ; $03
                  .byte $00 ; $04
                  .byte $00 ; $05
                  .byte $00 ; $06
                  .byte $00 ; $07
                  .byte $00 ; $08
                  .byte $80 ; $09
                  .byte $00 ; $0a
                  .byte $00 ; $0b
                  .byte $40 ; $0c
                  .byte $00 ; $0d
                  .byte $80 ; $0e
                  .byte $80 ; $0f
                  .byte $80 ; $10
                  .byte $80 ; $11
                  .byte $80 ; $12
                  .byte $80 ; $13
                  .byte $00 ; $14
                  .byte $00 ; $15
                  .byte $00 ; $16
                  .byte $00 ; $17
                  .byte $00 ; $18
                  .byte $00 ; $19
                  .byte $00 ; $1a
                  .byte $00 ; $1b
                  .byte $00 ; $1c
                  .byte $00 ; $1d
                  .byte $00 ; $1e
                  .byte $00 ; $1f
                  .byte $00 ; $20
                  .byte $00 ; $21
                  .byte $00 ; $22
                  .byte $00 ; $23
                  .byte $00 ; $24
                  .byte $00 ; $25
                  .byte $80 ; $26
                  .byte $00 ; $27
                  .byte $00 ; $28
                  .byte $80 ; $29
                  .byte $00 ; $2a
                  .byte $00 ; $2b
                  .byte $00 ; $2c
                  .byte $00 ; $2d
                  .byte $00 ; $2e
                  .byte $00 ; $2f
                  .byte $00 ; $30
                  .byte $00 ; $31
                  .byte $00 ; $32
                  .byte $00 ; $33
                  .byte $00 ; $34
                  .byte $00 ; $35
                  .byte $00 ; $36
                  .byte $00 ; $37
                  .byte $00 ; $38
                  .byte $00 ; $39
                  .byte $00 ; $3a
                  .byte $00 ; $3b
                  .byte $00 ; $3c
                  .byte $00 ; $3d
                  .byte $00 ; $3e
                  .byte $00 ; $3f
                  .byte $00 ; $40
                  .byte $00 ; $41
                  .byte $00 ; $42
                  .byte $00 ; $43
                  .byte $00 ; $44
                  .byte $00 ; $45
                  .byte $00 ; $46
                  .byte $00 ; $47
                  .byte $00 ; $48
                  .byte $00 ; $49
                  .byte $00 ; $4a
                  .byte $00 ; $4b
                  .byte $00 ; $4c
                  .byte $00 ; $4d
                  .byte $00 ; $4e
                  .byte $00 ; $4f
                  .byte $00 ; $50
                  .byte $00 ; $51
                  .byte $00 ; $52
                  .byte $00 ; $53
                  .byte $00 ; $54
                  .byte $80 ; $55
                  .byte $00 ; $56
                  .byte $00 ; $57
                  .byte $00 ; $58
                  .byte $00 ; $59
                  .byte $8a ; $5a
                  .byte $aa ; $5b
                  .byte $c3 ; $5c
                  .byte $00 ; $5d
                  .byte $aa ; $5e
                  .byte $ff ; $5f
                  .byte $eb ; $60
                  .byte $15 ; $61
                  .byte $7b ; $62
                  .byte $ff ; $63
                  .byte $37 ; $64
                  .byte $3c ; $65
                  .byte $66 ; $66
                  .byte $1b ; $67
                  .byte $0d ; $68
                  
                  .byte $0f ; $00 - row10
                  .byte $19 ; $01
                  .byte $76 ; $02
                  .byte $36 ; $03
                  .byte $1b ; $04
                  .byte $d8 ; $05
                  .byte $6c ; $06
                  .byte $1b ; $07
                  .byte $06 ; $08
                  .byte $0d ; $09
                  .byte $36 ; $0a
                  .byte $20 ; $0b
                  .byte $0a ; $0c
                  .byte $80 ; $0d
                  .byte $00 ; $0e
                  .byte $8a ; $0f
                  .byte $8a ; $10
                  .byte $8a ; $11
                  .byte $8a ; $12
                  .byte $80 ; $13
                  .byte $14 ; $14
                  .byte $36 ; $15
                  .byte $48 ; $16
                  .byte $4a ; $17
                  .byte $7b ; $18
                  .byte $0f ; $19
                  .byte $19 ; $1a
                  .byte $1e ; $1b
                  .byte $33 ; $1c
                  .byte $d8 ; $1d
                  .byte $6c ; $1e
                  .byte $1b ; $1f
                  .byte $0d ; $20
                  .byte $1b ; $21
                  .byte $6c ; $22
                  .byte $1b ; $23
                  .byte $76 ; $24
                  .byte $0d ; $25
                  .byte $36 ; $26
                  .byte $80 ; $27
                  .byte $80 ; $28
                  .byte $14 ; $29
                  .byte $55 ; $2a
                  .byte $45 ; $2b
                  .byte $04 ; $2c
                  .byte $40 ; $2d
                  .byte $01 ; $2e
                  .byte $01 ; $2f
                  .byte $05 ; $30
                  .byte $45 ; $31
                  .byte $10 ; $32
                  .byte $41 ; $33
                  .byte $05 ; $34
                  .byte $82 ; $35
                  .byte $82 ; $36
                  .byte $a0 ; $37
                  .byte $a2 ; $38
                  .byte $80 ; $39
                  .byte $80 ; $3a
                  .byte $8a ; $3b
                  .byte $a2 ; $3c
                  .byte $28 ; $3d
                  .byte $0a ; $3e
                  .byte $a2 ; $3f
                  .byte $a0 ; $40
                  .byte $82 ; $41
                  .byte $8a ; $42
                  .byte $82 ; $43
                  .byte $a0 ; $44
                  .byte $82 ; $45
                  .byte $a8 ; $46
                  .byte $0a ; $47
                  .byte $28 ; $48
                  .byte $a2 ; $49
                  .byte $aa ; $4a
                  .byte $aa ; $4b
                  .byte $82 ; $4c
                  .byte $28 ; $4d
                  .byte $80 ; $4e
                  .byte $28 ; $4f
                  .byte $28 ; $50
                  .byte $a0 ; $51
                  .byte $0a ; $52
                  .byte $20 ; $53
                  .byte $aa ; $54
                  .byte $28 ; $55
                  .byte $00 ; $56
                  .byte $00 ; $57
                  .byte $00 ; $58
                  .byte $80 ; $59
                  .byte $80 ; $5a
                  .byte $00 ; $5b
                  .byte $00 ; $5c
                  .byte $80 ; $5d
                  .byte $00 ; $5e
                  .byte $00 ; $5f
                  .byte $40 ; $60
                  .byte $00 ; $61
                  .byte $c0 ; $62
                  .byte $80 ; $63
                  .byte $00 ; $64
                  .byte $00 ; $65
                  .byte $80 ; $66
                  .byte $80 ; $67
                  .byte $00 ; $68
                  
                  .byte $80 ; $00 - row11
                  .byte $00 ; $01
                  .byte $00 ; $02
                  .byte $00 ; $03
                  .byte $00 ; $04
                  .byte $00 ; $05
                  .byte $00 ; $06
TabTileDataAf     .byte $c0 ; $07
                  .byte $80 ; $08
                  .byte $00 ; $09
                  .byte $40 ; $0a
                  .byte $40 ; $0b
                  .byte $00 ; $0c
                  .byte $00 ; $0d
                  .byte $80 ; $0e
                  .byte $80 ; $0f
                  .byte $80 ; $10
                  .byte $80 ; $11
                  .byte $00 ; $12
                  .byte $00 ; $13
                  .byte $00 ; $14
                  .byte $00 ; $15
                  .byte $00 ; $16
                  .byte $00 ; $17
                  .byte $00 ; $18
                  .byte $80 ; $19
                  .byte $00 ; $1a
                  .byte $00 ; $1b
                  .byte $00 ; $1c
                  .byte $00 ; $1d
                  .byte $00 ; $1e
                  .byte $80 ; $1f
                  .byte $00 ; $20
                  .byte $00 ; $21
                  .byte $80 ; $22
                  .byte $00 ; $23
                  .byte $80 ; $24
                  .byte $00 ; $25
                  .byte $80 ; $26
                  .byte $80 ; $27
                  .byte $00 ; $28
                  .byte $00 ; $29
                  .byte $00 ; $2a
                  .byte $00 ; $2b
                  .byte $00 ; $2c
                  .byte $00 ; $2d
                  .byte $00 ; $2e
                  .byte $00 ; $2f
                  .byte $00 ; $30
                  .byte $00 ; $31
                  .byte $00 ; $32
                  .byte $00 ; $33
                  .byte $00 ; $34
                  .byte $00 ; $35
                  .byte $00 ; $36
                  .byte $00 ; $37
                  .byte $00 ; $38
                  .byte $00 ; $39
                  .byte $00 ; $3a
                  .byte $00 ; $3b
                  .byte $00 ; $3c
                  .byte $00 ; $3d
                  .byte $00 ; $3e
                  .byte $00 ; $3f
                  .byte $00 ; $40
                  .byte $00 ; $41
                  .byte $00 ; $42
                  .byte $00 ; $43
                  .byte $00 ; $44
                  .byte $00 ; $45
                  .byte $00 ; $46
                  .byte $00 ; $47
                  .byte $00 ; $48
                  .byte $00 ; $49
                  .byte $00 ; $4a
                  .byte $00 ; $4b
                  .byte $00 ; $4c
                  .byte $00 ; $4d
                  .byte $00 ; $4e
                  .byte $00 ; $4f
                  .byte $00 ; $50
                  .byte $00 ; $51
                  .byte $00 ; $52
                  .byte $80 ; $53
                  .byte $00 ; $54
                  .byte $00 ; $55
                  .byte $00 ; $56
                  .byte $00 ; $57
                  .byte $8a ; $58
                  .byte $aa ; $59
                  .byte $c3 ; $5a
                  .byte $00 ; $5b
                  .byte $aa ; $5c
                  .byte $c0 ; $5d
                  .byte $ff ; $5e
                  .byte $10 ; $5f
                  .byte $03 ; $60
                  .byte $ff ; $61
                  .byte $30 ; $62
                  .byte $0e ; $63
                  .byte $63 ; $64
                  .byte $18 ; $65
                  .byte $0d ; $66
                  .byte $1c ; $67
                  .byte $31 ; $68
                  
                  .byte $06 ; $00 - row12
                  .byte $36 ; $01
                  .byte $1b ; $02
                  .byte $d8 ; $03
                  .byte $6c ; $04
                  .byte $1b ; $05
                  .byte $06 ; $06
                  .byte $0d ; $07
                  .byte $36 ; $08
                  .byte $09 ; $09
                  .byte $21 ; $0a
                  .byte $20 ; $0b
                  .byte $00 ; $0c
                  .byte $8a ; $0d
                  .byte $8a ; $0e
                  .byte $8a ; $0f
                  .byte $8a ; $10
                  .byte $8a ; $11
                  .byte $15 ; $12
                  .byte $36 ; $13
                  .byte $50 ; $14
                  .byte $11 ; $15
                  .byte $03 ; $16
                  .byte $1c ; $17
                  .byte $31 ; $18
                  .byte $07 ; $19
                  .byte $31 ; $1a
                  .byte $d8 ; $1b
                  .byte $6c ; $1c
                  .byte $1b ; $1d
                  .byte $0d ; $1e
                  .byte $1b ; $1f
                  .byte $6c ; $20
                  .byte $18 ; $21
                  .byte $06 ; $22
                  .byte $0d ; $23
                  .byte $36 ; $24
                  .byte $80 ; $25
                  .byte $80 ; $26
                  .byte $55 ; $27
                  .byte $55 ; $28
                  .byte $45 ; $29
                  .byte $15 ; $2a
                  .byte $45 ; $2b
                  .byte $41 ; $2c
                  .byte $01 ; $2d
                  .byte $05 ; $2e
                  .byte $45 ; $2f
                  .byte $10 ; $30
                  .byte $41 ; $31
                  .byte $05 ; $32
                  .byte $8a ; $33
                  .byte $82 ; $34
                  .byte $a2 ; $35
                  .byte $a2 ; $36
                  .byte $80 ; $37
                  .byte $80 ; $38
                  .byte $82 ; $39
                  .byte $a2 ; $3a
                  .byte $28 ; $3b
                  .byte $8a ; $3c
                  .byte $a2 ; $3d
                  .byte $a0 ; $3e
                  .byte $82 ; $3f
                  .byte $82 ; $40
                  .byte $82 ; $41
                  .byte $a0 ; $42
                  .byte $88 ; $43
                  .byte $a2 ; $44
                  .byte $8a ; $45
                  .byte $28 ; $46
                  .byte $a2 ; $47
                  .byte $28 ; $48
                  .byte $a2 ; $49
                  .byte $82 ; $4a
                  .byte $28 ; $4b
                  .byte $8a ; $4c
                  .byte $a0 ; $4d
                  .byte $28 ; $4e
                  .byte $28 ; $4f
                  .byte $28 ; $50
                  .byte $80 ; $51
                  .byte $00 ; $52
                  .byte $0a ; $53
                  .byte $00 ; $54
                  .byte $00 ; $55
                  .byte $00 ; $56
                  .byte $80 ; $57
                  .byte $80 ; $58
                  .byte $00 ; $59
                  .byte $00 ; $5a
                  .byte $80 ; $5b
                  .byte $00 ; $5c
                  .byte $00 ; $5d
                  .byte $00 ; $5e
                  .byte $00 ; $5f
                  .byte $c0 ; $60
                  .byte $00 ; $61
                  .byte $00 ; $62
                  .byte $00 ; $63
                  .byte $00 ; $64
                  .byte $80 ; $65
                  .byte $00 ; $66
                  .byte $80 ; $67
                  .byte $00 ; $68
                  
                  .byte $00 ; $00 - row13
                  .byte $00 ; $01
                  .byte $00 ; $02
                  .byte $00 ; $03
                  .byte $00 ; $04
                  .byte $c0 ; $05
                  .byte $80 ; $06
                  .byte $00 ; $07
                  .byte $00 ; $08
                  .byte $40 ; $09
                  .byte $00 ; $0a
                  .byte $00 ; $0b
                  .byte $80 ; $0c
                  .byte $80 ; $0d
                  .byte $80 ; $0e
                  .byte $80 ; $0f
                  .byte $80 ; $10
                  .byte $00 ; $11
                  .byte $00 ; $12
                  .byte $80 ; $13
                  .byte $00 ; $14
                  .byte $00 ; $15
                  .byte $00 ; $16
                  .byte $80 ; $17
                  .byte $00 ; $18
                  .byte $80 ; $19
                  .byte $00 ; $1a
                  .byte $00 ; $1b
                  .byte $00 ; $1c
                  .byte $80 ; $1d
                  .byte $00 ; $1e
                  .byte $00 ; $1f
                  .byte $00 ; $20
                  .byte $00 ; $21
                  .byte $80 ; $22
                  .byte $00 ; $23
                  .byte $80 ; $24
                  .byte $80 ; $25
                  .byte $00 ; $26
                  .byte $00 ; $27
                  .byte $00 ; $28
                  .byte $00 ; $29
                  .byte $00 ; $2a
                  .byte $00 ; $2b
                  .byte $00 ; $2c
                  .byte $00 ; $2d
                  .byte $00 ; $2e
                  .byte $00 ; $2f
                  .byte $00 ; $30
                  .byte $00 ; $31
                  .byte $00 ; $32
                  .byte $00 ; $33
                  .byte $00 ; $34
TabTileDataB0     .byte $00 ; $35
                  .byte $00 ; $36
                  .byte $00 ; $37
                  .byte $00 ; $38
                  .byte $00 ; $39
                  .byte $00 ; $3a
                  .byte $00 ; $3b
                  .byte $00 ; $3c
                  .byte $00 ; $3d
                  .byte $00 ; $3e
                  .byte $00 ; $3f
                  .byte $00 ; $40
                  .byte $00 ; $41
                  .byte $00 ; $42
                  .byte $00 ; $43
                  .byte $00 ; $44
                  .byte $00 ; $45
                  .byte $00 ; $46
                  .byte $00 ; $47
                  .byte $00 ; $48
                  .byte $00 ; $49
                  .byte $00 ; $4a
                  .byte $00 ; $4b
                  .byte $00 ; $4c
                  .byte $00 ; $4d
                  .byte $00 ; $4e
                  .byte $00 ; $4f
                  .byte $00 ; $50
                  .byte $00 ; $51
                  .byte $00 ; $52
                  .byte $00 ; $53
                  .byte $00 ; $54
                  .byte $00 ; $55
                  .byte $00 ; $56
                  .byte $00 ; $57
                  .byte $c3 ; $58
                  .byte $00 ; $59
                  .byte $00 ; $5a
                  .byte $c0 ; $5b
                  .byte $00 ; $5c
                  .byte $10 ; $5d
                  .byte $03 ; $5e
                  .byte $ff ; $5f
                  .byte $30 ; $60
                  .byte $0c ; $61
                  .byte $03 ; $62
                  .byte $38 ; $63
                  .byte $0d ; $64
                  .byte $0c ; $65
                  .byte $30 ; $66
                  .byte $07 ; $67
                  .byte $06 ; $68
                  
                  .byte $18 ; $00 - row14
                  .byte $b0 ; $01
                  .byte $6c ; $02
                  .byte $1b ; $03
                  .byte $03 ; $04
                  .byte $0d ; $05
                  .byte $36 ; $06
                  .byte $01 ; $07
                  .byte $09 ; $08
                  .byte $02 ; $09
                  .byte $00 ; $0a
                  .byte $00 ; $0b
                  .byte $00 ; $0c
                  .byte $00 ; $0d
                  .byte $00 ; $0e
                  .byte $00 ; $0f
                  .byte $00 ; $10
                  .byte $36 ; $11
                  .byte $10 ; $12
                  .byte $11 ; $13
                  .byte $03 ; $14
                  .byte $0c ; $15
                  .byte $30 ; $16
                  .byte $06 ; $17
                  .byte $01 ; $18
                  .byte $b0 ; $19
                  .byte $0c ; $1a
                  .byte $1b ; $1b
                  .byte $06 ; $1c
                  .byte $1b ; $1d
                  .byte $6c ; $1e
                  .byte $38 ; $1f
                  .byte $07 ; $20
                  .byte $0c ; $21
                  .byte $06 ; $22
                  .byte $00 ; $23
                  .byte $00 ; $24
                  .byte $00 ; $25
                  .byte $00 ; $26
                  .byte $55 ; $27
                  .byte $15 ; $28
                  .byte $55 ; $29
                  .byte $55 ; $2a
                  .byte $01 ; $2b
                  .byte $55 ; $2c
                  .byte $55 ; $2d
                  .byte $10 ; $2e
                  .byte $55 ; $2f
                  .byte $05 ; $30
                  .byte $8a ; $31
                  .byte $aa ; $32
                  .byte $aa ; $33
                  .byte $a8 ; $34
                  .byte $aa ; $35
                  .byte $80 ; $36
                  .byte $aa ; $37
                  .byte $a2 ; $38
                  .byte $28 ; $39
                  .byte $aa ; $3a
                  .byte $a2 ; $3b
                  .byte $aa ; $3c
                  .byte $82 ; $3d
                  .byte $82 ; $3e
                  .byte $aa ; $3f
                  .byte $a0 ; $40
                  .byte $a2 ; $41
                  .byte $a2 ; $42
                  .byte $aa ; $43
                  .byte $28 ; $44
                  .byte $aa ; $45
                  .byte $20 ; $46
                  .byte $82 ; $47
                  .byte $82 ; $48
                  .byte $28 ; $49
                  .byte $aa ; $4a
                  .byte $80 ; $4b
                  .byte $28 ; $4c
                  .byte $28 ; $4d
                  .byte $28 ; $4e
                  .byte $80 ; $4f
                  .byte $00 ; $50
                  .byte $02 ; $51
                  .byte $00 ; $52
                  .byte $00 ; $53
                  .byte $00 ; $54
                  .byte $00 ; $55
                  .byte $00 ; $56
                  .byte $00 ; $57
                  .byte $00 ; $58
                  .byte $00 ; $59
                  .byte $00 ; $5a
                  .byte $00 ; $5b
                  .byte $00 ; $5c
                  .byte $00 ; $5d
                  .byte $c0 ; $5e
                  .byte $00 ; $5f
                  .byte $00 ; $60
                  .byte $00 ; $61
                  .byte $00 ; $62
                  .byte $80 ; $63
                  .byte $00 ; $64
                  .byte $00 ; $65
                  .byte $00 ; $66
                  .byte $00 ; $67
                  .byte $00 ; $68
                  
                  .byte $00 ; $00 - row15
                  .byte $00 ; $01
                  .byte $00 ; $02
                  .byte $40 ; $03
                  .byte $80 ; $04
                  .byte $00 ; $05
                  .byte $00 ; $06
                  .byte $00 ; $07
                  .byte $00 ; $08
                  .byte $00 ; $09
                  .byte $00 ; $0a
                  .byte $00 ; $0b
                  .byte $00 ; $0c
                  .byte $00 ; $0d
                  .byte $00 ; $0e
                  .byte $00 ; $0f
                  .byte $00 ; $10
                  .byte $00 ; $11
                  .byte $00 ; $12
                  .byte $00 ; $13
                  .byte $00 ; $14
                  .byte $00 ; $15
                  .byte $00 ; $16
                  .byte $80 ; $17
                  .byte $00 ; $18
                  .byte $00 ; $19
                  .byte $00 ; $1a
                  .byte $80 ; $1b
                  .byte $00 ; $1c
                  .byte $00 ; $1d
                  .byte $00 ; $1e
                  .byte $00 ; $1f
                  .byte $00 ; $20
                  .byte $00 ; $21
                  .byte $00 ; $22
                  .byte $00 ; $23
                  .byte $00 ; $24
                  .byte $00 ; $25
                  .byte $00 ; $26
                  .byte $00 ; $27
                  .byte $00 ; $28
                  .byte $00 ; $29
                  .byte $00 ; $2a
                  .byte $00 ; $2b
                  .byte $00 ; $2c
                  .byte $00 ; $2d
                  .byte $00 ; $2e
                  .byte $00 ; $2f
                  .byte $00 ; $30
                  .byte $00 ; $31
                  .byte $00 ; $32
                  .byte $00 ; $33
                  .byte $00 ; $34
                  .byte $00 ; $35
                  .byte $00 ; $36
                  .byte $00 ; $37
                  .byte $00 ; $38
                  .byte $00 ; $39
                  .byte $00 ; $3a
                  .byte $00 ; $3b
                  .byte $00 ; $3c
                  .byte $00 ; $3d
                  .byte $00 ; $3e
                  .byte $00 ; $3f
                  .byte $00 ; $40
                  .byte $00 ; $41
                  .byte $00 ; $42
                  .byte $00 ; $43
                  .byte $00 ; $44
                  .byte $00 ; $45
                  .byte $00 ; $46
                  .byte $00 ; $47
                  .byte $00 ; $48
                  .byte $00 ; $49
                  .byte $00 ; $4a
                  .byte $00 ; $4b
                  .byte $00 ; $4c
                  .byte $00 ; $4d
                  .byte $00 ; $4e
                  .byte $00 ; $4f
                  .byte $00 ; $50
                  .byte $00 ; $51
                  .byte $00 ; $52
                  .byte $00 ; $53
                  .byte $00 ; $54
                  .byte $00 ; $55
                  .byte $00 ; $56
                  .byte $00 ; $57
                  .byte $00 ; $58
                  .byte $00 ; $59
                  .byte $00 ; $5a
                  .byte $00 ; $5b
                  .byte $00 ; $5c
                  .byte $00 ; $5d
                  .byte $00 ; $5e
                  .byte $00 ; $5f
                  .byte $00 ; $60
                  .byte $00 ; $61
                  .byte $00 ; $62
                            ; $63
                            ; $64
                            ; $65
                            ; $66
                            ; $67
                            ; $68
                   
TabMoveDemoLvl01  .byte $16                       ; $b100
                  .byte $4c
                  .byte $66
                  .byte $02
                  .byte $55
                  .byte $01
                  .byte $66
                  .byte $02
                  .byte $36
                  .byte $18
                  .byte $55
                  .byte $01
                  .byte $44
                  .byte $01
                  .byte $66
                  .byte $14
                  .byte $36
                  .byte $0d
                  .byte $30
                  .byte $17
                  .byte $60
                  .byte $08
                  .byte $66
                  .byte $03
                  .byte $16
                  .byte $16
                  .byte $66
                  .byte $04
                  .byte $36
                  .byte $23
                  .byte $32
                  .byte $01
                  .byte $62
                  .byte $01
                  .byte $55
                  .byte $01
                  .byte $66
                  .byte $20
                  .byte $16
                  .byte $07
                  .byte $66
                  .byte $02
                  .byte $36
                  .byte $25
                  .byte $30
                  .byte $14
                  .byte $60
                  .byte $0e
                  .byte $10
                  .byte $11
                  .byte $16
                  .byte $25
                  .byte $10
                  .byte $08
                  .byte $16
                  .byte $23
                  .byte $10
                  .byte $06
                  .byte $60
                  .byte $02
                  .byte $30
                  .byte $0f
                  .byte $36
                  .byte $17
                  .byte $66
                  .byte $02
                  .byte $16
                  .byte $07
                  .byte $55
                  .byte $01
                  .byte $66
                  .byte $1e
                  .byte $16
                  .byte $38
                  .byte $44
                  .byte $01
                  .byte $16
                  .byte $05
                  .byte $44
                  .byte $01
                  .byte $16
                  .byte $07
                  .byte $44
                  .byte $01
                  .byte $36
                  .byte $07
                  .byte $55
                  .byte $01
                  .byte $36
                  .byte $04
                  .byte $55
                  .byte $01
                  .byte $16
                  .byte $03
                  .byte $55
                  .byte $01
                  .byte $16
                  .byte $03
                  .byte $36
                  .byte $0b
                  .byte $55
                  .byte $01
                  .byte $16
                  .byte $03
                  .byte $36
                  .byte $0e
                  .byte $44
                  .byte $01
                  .byte $66
                  .byte $01
                  .byte $60
                  .byte $0c
                  .byte $30
                  .byte $29
                  .byte $60
                  .byte $02
                  .byte $44
                  .byte $01
                  .byte $16
                  .byte $2b
                  .byte $10
                  .byte $04
                  .byte $60
                  .byte $05
                  .byte $30
                  .byte $01
                  .byte $36
                  .byte $67
                  .byte $32
                  .byte $01
                  .byte $44
                  .byte $01
                  .byte $66
                  .byte $2b
                  .byte $36
                  .byte $0c
                  .byte $30
                  .byte $15
                  .byte $36
                  .byte $12
                  .byte $55
                  .byte $01
                  .byte $16
                  .byte $03
                  .byte $55
                  .byte $01
                  .byte $36
                  .byte $05
                  .byte $55
                  .byte $01
                  .byte $16
                  .byte $03
                  .byte $36
                  .byte $08
                  .byte $66
                  .byte $02
                  .byte $16
                  .byte $4a
                  .byte $10
                  .byte $04
                  .byte $60
                  .byte $07
                  .byte $30
                  .byte $09
                  .byte $36
                  .byte $15
                  .byte $66
                  .byte $0a
                  .byte $16
                  .byte $0d
                  .byte $44
                  .byte $01
                  .byte $66
                  .byte $02
                  .byte $16
                  .byte $04
                  .byte $44
                  .byte $01
                  .byte $16
                  .byte $02
                  .byte $44
                  .byte $06
                  .byte $16
                  .byte $04
                  .byte $44
                  .byte $01
                  .byte $16
                  .byte $02
                  .byte $62
                  .byte $15
                  .byte $36
                  .byte $31
                  .byte $66
                  .byte $01
                  .byte $62
                  .byte $04
                  .byte $12
                  .byte $06
                  .byte $44
                  .byte $01
                  .byte $66
                  .byte $37
                  .byte $36
                  .byte $01
                  .byte $30
                  .byte $1d
                  .byte $60
                  .byte $33

TabMoveDemoLvl02  .byte $36                       ; $b1d0
                  .byte $32
                  .byte $66
                  .byte $03
                  .byte $16
                  .byte $01
                  .byte $10
                  .byte $1b
                  .byte $60
                  .byte $05
                  .byte $36
                  .byte $28
                  .byte $44
                  .byte $01
                  .byte $66
                  .byte $1f
                  .byte $36
                  .byte $14
                  .byte $44
                  .byte $01
                  .byte $55
                  .byte $01
                  .byte $66
                  .byte $2d
                  .byte $36
                  .byte $01
                  .byte $30
                  .byte $12
                  .byte $60
                  .byte $25
                  .byte $66
                  .byte $01
                  .byte $55
                  .byte $01
                  .byte $16
                  .byte $0d
                  .byte $66
                  .byte $02
                  .byte $36
                  .byte $09
                  .byte $30
                  .byte $0a
                  .byte $36
                  .byte $04
                  .byte $44
                  .byte $01
                  .byte $36
                  .byte $03
                  .byte $44
                  .byte $01
                  .byte $36
                  .byte $03
                  .byte $16
                  .byte $22
                  .byte $44
                  .byte $01
                  .byte $16
                  .byte $07
                  .byte $44
                  .byte $04
                  .byte $16
                  .byte $03
                  .byte $44
                  .byte $01
                  .byte $16
                  .byte $27
                  .byte $12
                  .byte $0e
                  .byte $16
                  .byte $1e
                  .byte $55
                  .byte $01
                  .byte $66
                  .byte $19
                  .byte $36
                  .byte $01
                  .byte $30
                  .byte $03
                  .byte $60
                  .byte $07
                  .byte $10
                  .byte $1f
                  .byte $60
                  .byte $07
                  .byte $30
                  .byte $09
                  .byte $36
                  .byte $33
                  .byte $66
                  .byte $04
                  .byte $10
                  .byte $09
                  .byte $16
                  .byte $08
                  .byte $12
                  .byte $01
                  .byte $62
                  .byte $0c
                  .byte $32
                  .byte $01
                  .byte $36
                  .byte $32
                  .byte $44
                  .byte $01
                  .byte $16
                  .byte $0b
                  .byte $44
                  .byte $01
                  .byte $16
                  .byte $09
                  .byte $44
                  .byte $01
                  .byte $10
                  .byte $2c
                  .byte $60
                  .byte $04
                  .byte $30
                  .byte $03
                  .byte $36
                  .byte $0a
                  .byte $44
                  .byte $01
                  .byte $16
                  .byte $05
                  .byte $44
                  .byte $01
                  .byte $36
                  .byte $03
                  .byte $44
                  .byte $01
                  .byte $36
                  .byte $03
                  .byte $44
                  .byte $01
                  .byte $66
                  .byte $03
                  .byte $36
                  .byte $03
                  .byte $55
                  .byte $01
                  .byte $36
                  .byte $08
                  .byte $55
                  .byte $01
                  .byte $66
                  .byte $4c
                  .byte $16
                  .byte $09
                  .byte $10
                  .byte $15
                  .byte $44
                  .byte $01
                  .byte $10
                  .byte $2f
                  .byte $16
                  .byte $09
                  .byte $12
                  .byte $03
                  .byte $16
                  .byte $12
                  .byte $66
                  .byte $02
                  .byte $36
                  .byte $06
                  .byte $66
                  .byte $2d
                  .byte $55
                  .byte $01
                  .byte $16
                  .byte $03
                  .byte $10
                  .byte $1c
                  .byte $55
                  .byte $01
                  .byte $16
                  .byte $03
                  .byte $44
                  .byte $01
                  .byte $36
                  .byte $03
                  .byte $32
                  .byte $15
                  .byte $36
                  .byte $0b
                  .byte $30
                  .byte $0b
                  .byte $60
                  .byte $0c
                  .byte $44
                  .byte $01
                  .byte $62
                  .byte $0d
                  .byte $12
                  .byte $02
                  .byte $16
                  .byte $0d
                  .byte $44
                  .byte $01
                  .byte $66
                  .byte $20
                  .byte $36
                  .byte $04
                  .byte $30
                  .byte $17
                  .byte $36
                  .byte $1e
                  .byte $44
                  .byte $01
                  .byte $36
                  .byte $2f
                  .byte $30
                  .byte $08
                  .byte $60
                  .byte $03
                  .byte $10
                  .byte $22
                  .byte $16
                  .byte $1b
                  .byte $66
                  .byte $26
                  .byte $55
                  .byte $07
                  .byte $16
                  .byte $03
                  .byte $55
                  .byte $01
                  .byte $66
                  .byte $1d
                  .byte $16
                  .byte $02
                  .byte $10
                  .byte $85
                  .byte $60
                  .byte $02
                  .byte $30
                  .byte $03
                  .byte $36
                  .byte $03
                  .byte $32
                  .byte $0f
                  .byte $36
                  .byte $03
                  .byte $30
                  .byte $0c

TabMoveDemoLvl03  .byte $36                       ; $b2c4
                  .byte $20
                  .byte $66
                  .byte $01
                  .byte $16
                  .byte $0a
                  .byte $60
                  .byte $06
                  .byte $66
                  .byte $02
                  .byte $36
                  .byte $08
                  .byte $30
                  .byte $05
                  .byte $60
                  .byte $02
                  .byte $66
                  .byte $02
                  .byte $16
                  .byte $08
                  .byte $10
                  .byte $01
                  .byte $60
                  .byte $06
                  .byte $66
                  .byte $01
                  .byte $36
                  .byte $08
                  .byte $30
                  .byte $04
                  .byte $60
                  .byte $03
                  .byte $66
                  .byte $01
                  .byte $16
                  .byte $08
                  .byte $10
                  .byte $02
                  .byte $60
                  .byte $03
                  .byte $30
                  .byte $01
                  .byte $36
                  .byte $08
                  .byte $30
                  .byte $03
                  .byte $60
                  .byte $03
                  .byte $16
                  .byte $09
                  .byte $10
                  .byte $02
                  .byte $60
                  .byte $03
                  .byte $30
                  .byte $03
                  .byte $36
                  .byte $07
                  .byte $30
                  .byte $03
                  .byte $60
                  .byte $02
                  .byte $10
                  .byte $02
                  .byte $16
                  .byte $08
                  .byte $10
                  .byte $01
                  .byte $60
                  .byte $02
                  .byte $30
                  .byte $02
                  .byte $36
                  .byte $0a
                  .byte $30
                  .byte $02
                  .byte $60
                  .byte $02
                  .byte $10
                  .byte $03
                  .byte $16
                  .byte $04
                  .byte $10
                  .byte $03
                  .byte $60
                  .byte $05
                  .byte $30
                  .byte $02
                  .byte $36
                  .byte $07
                  .byte $66
                  .byte $16
                  .byte $36
                  .byte $02
                  .byte $66
                  .byte $33
                  .byte $55
                  .byte $01
                  .byte $36
                  .byte $05
                  .byte $55
                  .byte $01
                  .byte $36
                  .byte $04
                  .byte $55
                  .byte $01
                  .byte $36
                  .byte $03
                  .byte $55
                  .byte $01
                  .byte $36
                  .byte $03
                  .byte $55
                  .byte $01
                  .byte $66
                  .byte $a9
                  .byte $62
                  .byte $0c
                  .byte $66
                  .byte $07
                  .byte $60
                  .byte $0f
                  .byte $55
                  .byte $01
                  .byte $66
                  .byte $18
                  .byte $16
                  .byte $2a
                  .byte $55
                  .byte $01
                  .byte $16
                  .byte $03
                  .byte $66
                  .byte $01
                  .byte $60
                  .byte $07
                  .byte $66
                  .byte $03
                  .byte $36
                  .byte $03
                  .byte $30
                  .byte $1b
                  .byte $36
                  .byte $08
                  .byte $44
                  .byte $01
                  .byte $66
                  .byte $18
                  .byte $36
                  .byte $0f
                  .byte $66
                  .byte $08
                  .byte $44
                  .byte $01
                  .byte $66
                  .byte $38
                  .byte $30
                  .byte $0e
                  .byte $66
                  .byte $11
                  .byte $60
                  .byte $04
                  .byte $66
                  .byte $49
                  .byte $37

                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $33
                  .byte $07
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $37
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $33
                  .byte $07
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $37
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $33
                  .byte $07
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $37
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $09
                  .byte $00
                  .byte $33
                  .byte $07
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $30
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $03
                  .byte $00
                  .byte $30
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00

Tab_B400          .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $b1
                  .byte $c3
                  .byte $b3
                  .byte $b5
                  .byte $8d
                  .byte $f9
                  .byte $f4
                  .byte $e1
                  .byte $e2
                  .byte $ec
                  .byte $e5
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $b1
                  .byte $c3
                  .byte $b5
                  .byte $b1
                  .byte $8d
                  .byte $e2
                  .byte $f9
                  .byte $f4
                  .byte $e1
                  .byte $e2
                  .byte $ec
                  .byte $e5
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $b1
                  .byte $c3
                  .byte $b6
                  .byte $b2
                  .byte $8d
                  .byte $e2
                  .byte $e9
                  .byte $f4
                  .byte $e1
                  .byte $e2
                  .byte $ec
                  .byte $e5
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $b1
                  .byte $c3
                  .byte $b7
                  .byte $c5
                  .byte $8d
                  .byte $f8
                  .byte $e2
                  .byte $f9
                  .byte $f4
                  .byte $e1
                  .byte $e2
                  .byte $ec
                  .byte $e5
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $b1
                  .byte $c3
                  .byte $b9
                  .byte $c1
                  .byte $8d
                  .byte $f8
                  .byte $e2
                  .byte $e9
                  .byte $f4
                  .byte $e1
                  .byte $e2
                  .byte $ec
                  .byte $e5
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $b1
                  .byte $c4
                  .byte $b2
                  .byte $b6
                  .byte $8d
                  .byte $e2
                  .byte $ef
                  .byte $ef
                  .byte $f4
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $b1
                  .byte $c4
                  .byte $c2
                  .byte $b2
                  .byte $8d
                  .byte $f3
                  .byte $e3
                  .byte $ef
                  .byte $f2
                  .byte $e5
                  .byte $e2
                  .byte $f5
                  .byte $e6
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $b1
                  .byte $c6
                  .byte $b0
                  .byte $b0
                  .byte $8d
                  .byte $e3
                  .byte $e8
                  .byte $e1
                  .byte $f2
                  .byte $e4
                  .byte $e1
                  .byte $f4
                  .byte $e1
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $c1
                  .byte $c4
                  .byte $b0
                  .byte $b0
                  .byte $8d
                  .byte $8d
                  .byte $f2
                  .byte $f7
                  .byte $f4
                  .byte $f3
                  .byte $f0
                  .byte $e1
                  .byte $f2
                  .byte $ed
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $c2
                  .byte $b7
                  .byte $c5
                  .byte $b8
                  .byte $8d
                  .byte $f2
                  .byte $f7
                  .byte $f4
                  .byte $f3
                  .byte $f6
                  .byte $ef
                  .byte $ec
                  .byte $ed
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $c2
                  .byte $b7
                  .byte $c5
                  .byte $c2
                  .byte $8d
                  .byte $f2
                  .byte $f7
                  .byte $f4
                  .byte $f3
                  .byte $f4
                  .byte $f2
                  .byte $e3
                  .byte $eb
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $c2
                  .byte $b7
                  .byte $c5
                  .byte $c3
                  .byte $8d
                  .byte $f2
                  .byte $f7
                  .byte $f4
                  .byte $f3
                  .byte $f3
                  .byte $e5
                  .byte $e3
                  .byte $f4
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $c2
                  .byte $b7
                  .byte $c5
                  .byte $c4
                  .byte $8d
                  .byte $f2
                  .byte $f7
                  .byte $f4
                  .byte $f3
                  .byte $e2
                  .byte $f5
                  .byte $e6
                  .byte $e6
                  .byte $a0
                  .byte $c5
                  .byte $d1
                  .byte $d5
                  .byte $a0
                  .byte $a4
                  .byte $c2
                  .byte $b7
                  .byte $c6
                  .byte $b0
                  .byte $8d
                  .byte $f2
                  .byte $f7
                  .byte $f4
                  .byte $f3
                  .byte $e3
                  .byte $ed
                  .byte $ee

TabDemoLvlData    = *                             ; demo level data
TabDemoLvlData01  .byte $06                       ; data demo  level 01
                  .byte $00
                  .byte $00
                  .byte $07
                  .byte $00
                  .byte $00
                  .byte $07
                  .byte $00
                  .byte $00
                  .byte $06
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $06
                  .byte $13
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $06
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $07
                  .byte $00
                  .byte $43
                  .byte $44
                  .byte $44
                  .byte $03
                  .byte $76
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $31
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $13
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $33
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $00
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $31
                  .byte $43
                  .byte $44
                  .byte $44
                  .byte $44
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $00
                  .byte $71
                  .byte $70
                  .byte $11
                  .byte $33
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $08
                  .byte $03
                  .byte $70
                  .byte $00
                  .byte $08
                  .byte $03
                  .byte $70
                  .byte $11
                  .byte $11
                  .byte $31
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $13
                  .byte $11
                  .byte $21
                  .byte $22
                  .byte $11
                  .byte $11
                  .byte $13
                  .byte $11
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $38
                  .byte $00
                  .byte $70
                  .byte $00
                  .byte $43
                  .byte $44
                  .byte $44
                  .byte $44
                  .byte $44
                  .byte $44
                  .byte $03
                  .byte $70
                  .byte $13
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $03
                  .byte $70
                  .byte $00
                  .byte $00
                  .byte $70
                  .byte $00
                  .byte $13
                  .byte $11
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $01
                  .byte $03
                  .byte $00
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $00
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $70
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $00
                  .byte $90
                  .byte $70
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $00
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00

TabDemoLvlData02  .byte $11                       ; data demo level 02
                  .byte $11
                  .byte $61
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $01
                  .byte $11
                  .byte $11
                  .byte $06
                  .byte $00
                  .byte $61
                  .byte $01
                  .byte $44
                  .byte $44
                  .byte $44
                  .byte $04
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $10
                  .byte $16
                  .byte $61
                  .byte $60
                  .byte $01
                  .byte $71
                  .byte $00
                  .byte $10
                  .byte $13
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $10
                  .byte $06
                  .byte $11
                  .byte $11
                  .byte $01
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $13
                  .byte $11
                  .byte $11
                  .byte $07
                  .byte $31
                  .byte $11
                  .byte $11
                  .byte $61
                  .byte $00
                  .byte $00
                  .byte $47
                  .byte $44
                  .byte $11
                  .byte $11
                  .byte $13
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $31
                  .byte $01
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $01
                  .byte $00
                  .byte $01
                  .byte $10
                  .byte $13
                  .byte $11
                  .byte $10
                  .byte $11
                  .byte $31
                  .byte $01
                  .byte $11
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $10
                  .byte $13
                  .byte $11
                  .byte $10
                  .byte $01
                  .byte $31
                  .byte $71
                  .byte $10
                  .byte $13
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $13
                  .byte $73
                  .byte $10
                  .byte $13
                  .byte $11
                  .byte $10
                  .byte $01
                  .byte $31
                  .byte $11
                  .byte $11
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $13
                  .byte $11
                  .byte $11
                  .byte $13
                  .byte $11
                  .byte $07
                  .byte $01
                  .byte $31
                  .byte $11
                  .byte $10
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $11
                  .byte $11
                  .byte $13
                  .byte $11
                  .byte $11
                  .byte $01
                  .byte $31
                  .byte $11
                  .byte $17
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $01
                  .byte $00
                  .byte $00
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $00
                  .byte $10
                  .byte $13
                  .byte $11
                  .byte $13
                  .byte $11
                  .byte $31
                  .byte $21
                  .byte $21
                  .byte $21
                  .byte $21
                  .byte $21
                  .byte $21
                  .byte $31
                  .byte $21
                  .byte $21
                  .byte $13
                  .byte $11
                  .byte $13
                  .byte $11
                  .byte $31
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $00
                  .byte $11
                  .byte $11
                  .byte $31
                  .byte $21
                  .byte $21
                  .byte $03
                  .byte $00
                  .byte $03
                  .byte $00
                  .byte $30
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $01
                  .byte $10
                  .byte $11
                  .byte $31
                  .byte $00
                  .byte $00
                  .byte $13
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $31
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $07
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $31
                  .byte $93
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $70
                  .byte $10
                  .byte $11
                  .byte $11
                  .byte $01
                  .byte $80
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00

TabDemoLvlData03  .byte $00                       ; data demo level 03
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $80
                  .byte $07
                  .byte $00
                  .byte $30
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $70
                  .byte $08
                  .byte $13
                  .byte $81
                  .byte $07
                  .byte $30
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $70
                  .byte $18
                  .byte $31
                  .byte $03
                  .byte $10
                  .byte $01
                  .byte $30
                  .byte $11
                  .byte $11
                  .byte $36
                  .byte $11
                  .byte $11
                  .byte $31
                  .byte $00
                  .byte $10
                  .byte $01
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $33
                  .byte $07
                  .byte $00
                  .byte $30
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $37
                  .byte $03
                  .byte $00
                  .byte $30
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $33
                  .byte $07
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $37
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $33
                  .byte $07
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $37
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $33
                  .byte $07
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $37
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $33
                  .byte $07
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $37
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $09
                  .byte $00
                  .byte $33
                  .byte $07
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $30
                  .byte $03
                  .byte $00
                  .byte $30
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $11
                  .byte $03
                  .byte $00
                  .byte $30
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00
                  .byte $00

                  .byte $aa
                  .byte $aa
